%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   This is an entirely synthetic 200 bus case, geographically situated
%   in the central part of the US state of Illinois. The case is
%   designed with a 230 and 115 kV transmission network to serve
%   a load that roughly mimics the actual population of its geographic
%   footprint. The synthetic transmission system was designed by
%   algorithms described in [1] to be statistically similar to actual
%   transmission system models but without modeling any actual lines.
%
%   When publishing results based on this data, please cite:
%
%   [1] A.B. Birchfield, T. Xu, K.M. Gegner, K.S. Shetye, T.J. Overbye,
%       "Grid Structural Characteristics as Validation Criteria for
%       Synthetic Networks," IEEE Transactions on Power Systems, 2017.
%
%   This is a synthetic power system model that does not represent the
%   actual grid. It was developed as part of the US ARPA-E GRID DATA
%   research project and contains no CEII.
%
%   One-line diagrams and other data formats available at:
%       https://electricgrids.engr.tamu.edu
%
%   May 16, 2017
%
%   Created from ACTIV_SG_200.pwb, saved by
%   PowerWorld Simulator, version 20 Beta, build date May 19, 2017,
%   then by MATPOWER 6.
%
%   Copyright (c) 2017 by A.B. Birchfield, T. Xu, K.M. Gegner, K.S. Shetye,
%   and T.J. Overbye
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case200_activ
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	1	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	2	 1	 7.39	 2.1	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	3	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	4	 1	 1.7	 0.48	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	5	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	6	 1	 7.95	 2.26	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	8	 1	 23.74	 6.77	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	9	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	10	 1	 42.68	 12.16	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	11	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	12	 1	 0.3	 0.09	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	13	 1	 2.52	 0.72	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	14	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	15	 1	 0.0	 0.0	 0.0	 30.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	16	 1	 44.76	 12.76	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	17	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	18	 1	 0.71	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	19	 1	 0.77	 0.22	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	20	 1	 1.13	 0.32	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	21	 1	 4.61	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	22	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	23	 1	 1.41	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	24	 1	 2.4	 0.68	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	25	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	26	 1	 1.35	 0.39	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	27	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	28	 1	 2.33	 0.67	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	29	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	30	 1	 59.09	 16.84	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	31	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	32	 1	 0.51	 0.15	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	33	 1	 6.44	 1.84	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	34	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	35	 1	 20.76	 5.92	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	36	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	37	 1	 3.57	 1.02	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	38	 1	 29.81	 8.5	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	39	 1	 7.41	 2.11	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	40	 1	 2.04	 0.58	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	41	 1	 38.34	 10.93	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	42	 1	 10.62	 3.03	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	43	 1	 2.09	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	44	 1	 4.15	 1.18	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	45	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	46	 1	 6.34	 1.81	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	47	 1	 1.54	 0.44	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	48	 1	 1.82	 0.52	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	49	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	50	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	51	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	52	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	53	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	54	 1	 2.66	 0.76	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	55	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	56	 1	 1.31	 0.37	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	57	 1	 2.82	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	58	 1	 4.23	 1.21	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	59	 1	 4.73	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	60	 1	 3.8	 1.08	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	61	 1	 20.55	 5.86	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	62	 1	 21.41	 6.1	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	63	 1	 7.98	 2.27	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	64	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	65	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	66	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	67	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	68	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	69	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	70	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	71	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	72	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	73	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	74	 1	 18.76	 5.35	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	75	 1	 3.6	 1.03	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	76	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	77	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	78	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	79	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	80	 1	 1.48	 0.42	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	81	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 6	    1.10000	    0.90000;
	82	 1	 7.6	 2.17	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	83	 1	 3.14	 0.89	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	84	 1	 3.75	 1.07	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	85	 1	 4.83	 1.38	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	86	 1	 8.25	 2.35	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	87	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 3	    1.10000	    0.90000;
	88	 1	 49.34	 14.06	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	89	 1	 62.85	 17.91	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	90	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	91	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	92	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	93	 1	 3.06	 0.87	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	94	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	95	 1	 3.0	 0.85	 0.0	 30.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	96	 1	 2.96	 0.84	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	97	 1	 7.33	 2.09	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	98	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 2	    1.10000	    0.90000;
	99	 1	 12.17	 3.47	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	100	 1	 37.39	 10.66	 0.0	 80.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	101	 1	 0.52	 0.15	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	104	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	105	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	106	 1	 2.06	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	107	 1	 52.56	 14.98	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	108	 1	 9.42	 2.68	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	109	 1	 5.16	 1.47	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	110	 1	 10.86	 3.09	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	111	 1	 8.82	 2.51	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	114	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	115	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	116	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 2	    1.10000	    0.90000;
	117	 1	 34.08	 9.71	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	118	 1	 3.94	 1.12	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	119	 1	 17.55	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	120	 1	 1.8	 0.51	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	122	 1	 15.44	 4.4	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 2	    1.10000	    0.90000;
	124	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	125	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	126	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	127	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	129	 1	 77.24	 22.01	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	130	 1	 4.4	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	131	 1	 30.25	 8.62	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	132	 1	 26.96	 7.68	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 2	    1.10000	    0.90000;
	134	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	135	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	136	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	137	 1	 1.16	 0.33	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	138	 1	 2.09	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	139	 1	 6.84	 1.95	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	140	 1	 8.21	 2.34	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	141	 1	 1.42	 0.41	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	142	 1	 37.26	 10.62	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	143	 1	 26.78	 7.63	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	144	 1	 9.05	 2.58	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	145	 1	 17.54	 5.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	147	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	148	 1	 32.02	 9.13	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 3	    1.10000	    0.90000;
	150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	151	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	152	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	153	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	154	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	155	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 2	    1.10000	    0.90000;
	157	 1	 14.76	 4.21	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	158	 1	 8.97	 2.56	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	159	 1	 1.39	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	160	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	161	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	162	 1	 1.45	 0.41	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	163	 1	 45.8	 13.05	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	164	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 5	    1.10000	    0.90000;
	165	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 5	    1.10000	    0.90000;
	166	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 5	    1.10000	    0.90000;
	167	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 5	    1.10000	    0.90000;
	168	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 5	    1.10000	    0.90000;
	169	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 5	    1.10000	    0.90000;
	170	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 5	    1.10000	    0.90000;
	171	 1	 7.94	 2.26	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	172	 1	 5.38	 1.53	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	173	 1	 8.71	 2.48	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	174	 1	 2.77	 0.79	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	175	 1	 7.31	 2.08	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	176	 1	 19.01	 5.42	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	177	 1	 11.29	 3.22	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	178	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 5	    1.10000	    0.90000;
	179	 1	 23.61	 6.73	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	180	 1	 7.74	 2.21	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	181	 1	 47.98	 13.67	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	182	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	183	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	184	 1	 10.69	 3.05	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	185	 1	 10.79	 3.07	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	186	 1	 2.1	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	187	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	188	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	189	 3	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	190	 1	 16.79	 4.78	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	191	 1	 7.23	 2.06	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	192	 1	 52.74	 15.03	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	193	 1	 21.99	 6.27	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	194	 1	 37.57	 10.71	 0.0	 50.0	 1	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	195	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	196	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	197	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	198	 1	 5.37	 1.53	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	199	 1	 4.26	 1.21	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	200	 1	 9.34	 2.66	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin
mpc.gen = [
	49	 2.945	 0.78	 2.11	 -0.55	 1.0	 5.44	 1	 4.53	 1.36;
	50	 2.945	 0.78	 2.11	 -0.55	 1.0	 5.44	 1	 4.53	 1.36;
	51	 2.945	 0.78	 2.11	 -0.55	 1.0	 5.44	 1	 4.53	 1.36;
	52	 2.945	 0.78	 2.11	 -0.55	 1.0	 5.44	 1	 4.53	 1.36;
	53	 5.895	 1.56	 4.23	 -1.11	 1.0	 10.88	 1	 9.07	 2.72;
	65	 86.5	 5.19	 32.04	 -21.66	 1.0	 180.48	 1	 86.5	 86.5;
	67	 3.055	 0.81	 2.19	 -0.57	 1.0	 5.64	 1	 4.7	 1.41;
	68	 18.15	 4.8	 13.01	 -3.41	 1.0	 33.5	 1	 27.92	 8.38;
	69	 18.15	 4.8	 13.01	 -3.41	 1.0	 33.5	 1	 27.92	 8.38;
	70	 18.15	 4.8	 13.01	 -3.41	 1.0	 33.5	 1	 27.92	 8.38;
	71	 18.15	 4.8	 13.01	 -3.41	 1.0	 33.5	 1	 27.92	 8.38;
	72	 18.15	 4.8	 13.01	 -3.41	 1.0	 33.5	 1	 27.92	 8.38;
	73	 18.15	 4.8	 13.01	 -3.41	 1.0	 33.5	 1	 27.92	 8.38;
	76	 2.6	 0.8	 2.04	 -0.44	 1.0	 4.8	 1	 4.0	 1.2;
	77	 1.56	 0.475	 1.22	 -0.27	 1.0	 2.88	 1	 2.4	 0.72;
	78	 0.0	 0.0	 9.16	 -2.0	 1.0	 21.6	 0	 18.0	 5.4;
	79	 0.0	 0.0	 9.16	 -2.0	 1.0	 21.6	 0	 18.0	 5.4;
	90	 2.08	 0.635	 1.63	 -0.36	 1.0	 3.84	 1	 3.2	 0.96;
	91	 3.25	 1.0	 2.55	 -0.55	 1.0	 6.0	 1	 5.0	 1.5;
	92	 0.0	 0.0	 3.21	 -0.7	 1.0	 7.56	 0	 6.3	 1.89;
	94	 11.7	 3.095	 8.39	 -2.2	 1.0	 21.6	 1	 18.0	 5.4;
	104	 67.6	 3.415	 21.09	 -14.26	 1.0	 118.8	 1	 67.6	 67.6;
	105	 154.8	 6.83	 42.17	 -28.51	 1.0	 237.6	 1	 154.8	 154.8;
	114	 1.4	 0.06	 0.36	 -0.24	 1.0	 2.04	 1	 1.4	 1.4;
	115	 133.5	 5.175	 31.95	 -21.6	 1.0	 180.0	 1	 133.5	 133.5;
	125	 84.535	 22.365	 60.6	 -15.87	 1.0	 156.06	 1	 130.05	 39.02;
	126	 84.535	 22.365	 60.6	 -15.87	 1.0	 156.06	 1	 130.05	 39.02;
	127	 84.535	 22.365	 60.6	 -15.87	 1.0	 156.06	 1	 130.05	 39.02;
	135	 290.16	 76.78	 208.02	 -54.46	 1.0	 535.68	 1	 446.4	 133.92;
	136	 290.16	 76.78	 208.02	 -54.46	 1.0	 535.68	 1	 446.4	 133.92;
	147	 92.4	 3.47	 21.41	 -14.47	 1.0	 120.6	 1	 92.4	 92.4;
	151	 3.51	 0.93	 2.52	 -0.66	 1.0	 6.48	 1	 5.4	 1.62;
	152	 50.195	 13.285	 35.99	 -9.42	 1.0	 92.67	 1	 77.22	 23.17;
	153	 50.195	 13.285	 35.99	 -9.42	 1.0	 92.67	 1	 77.22	 23.17;
	154	 50.195	 13.285	 35.99	 -9.42	 1.0	 92.67	 1	 77.22	 23.17;
	155	 50.195	 13.285	 35.99	 -9.42	 1.0	 92.67	 1	 77.22	 23.17;
	161	 0.0	 0.0	 70.55	 -15.38	 1.0	 166.32	 0	 138.6	 41.58;
	164	 0.0	 0.0	 6.11	 -1.33	 1.0	 14.4	 0	 12.0	 3.6;
	165	 0.0	 0.0	 13.23	 -2.89	 1.0	 31.2	 0	 26.0	 7.8;
	166	 0.0	 0.0	 4.78	 -1.04	 1.0	 11.28	 0	 9.4	 2.82;
	167	 6.11	 1.87	 4.78	 -1.04	 1.0	 11.28	 1	 9.4	 2.82;
	168	 0.0	 0.0	 4.78	 -1.04	 1.0	 11.28	 0	 9.4	 2.82;
	169	 0.0	 0.0	 4.78	 -1.04	 1.0	 11.28	 0	 9.4	 2.82;
	170	 6.11	 1.87	 4.78	 -1.04	 1.0	 11.28	 1	 9.4	 2.82;
	182	 11.375	 3.01	 8.16	 -2.14	 1.0	 21.0	 1	 17.5	 5.25;
	183	 17.29	 4.575	 12.4	 -3.25	 1.0	 31.92	 1	 26.6	 7.98;
	189	 369.95	 81.39	 209.45	 -46.67	 1.0	 682.98	 1	 569.15	 170.75;
	196	 0.0	 0.0	 34.36	 -7.49	 1.0	 81.0	 0	 67.5	 20.25;
	197	 0.0	 0.0	 34.36	 -7.49	 1.0	 81.0	 0	 67.5	 20.25;
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.120000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.120000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.120000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.120000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.240000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.130000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.740000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.740000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.740000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.740000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.740000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.740000;
	2	 0.0	 0.0	 3	   0.002000	  23.157000	 606.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.146000	 603.600000;
	2	 0.0	 0.0	 3	   0.002000	  23.252000	 627.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.252000	 627.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.152000	 604.800000;
	2	 0.0	 0.0	 3	   0.002000	  23.164000	 607.500000;
	2	 0.0	 0.0	 3	   0.002000	  23.173000	 609.450000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.480000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 610.140000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 610.140000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 610.140000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 1261.330000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 1261.330000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.140000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 253.010000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 253.010000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 253.010000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 253.010000;
	2	 0.0	 0.0	 3	   0.002000	  24.070000	 807.900000;
	2	 0.0	 0.0	 3	   0.002000	  23.211000	 618.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.306000	 639.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.194000	 614.100000;
	2	 0.0	 0.0	 3	   0.002000	  23.194000	 614.100000;
	2	 0.0	 0.0	 3	   0.002000	  23.194000	 614.100000;
	2	 0.0	 0.0	 3	   0.002000	  23.194000	 614.100000;
	2	 0.0	 0.0	 3	   0.002000	  23.194000	 614.100000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.470000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.710000;
	2	 0.0	 0.0	 3	   0.000000	   6.710000	 1272.130000;
	2	 0.0	 0.0	 3	   0.002000	  23.588000	 701.250000;
	2	 0.0	 0.0	 3	   0.002000	  23.588000	 701.250000;
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	2	 1	 0.000673	 0.003339	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1	 119	 0.018542	 0.119758	 0.02285	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 1	 0.005615	 0.036268	 0.00692	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	193	 1	 0.004258	 0.027501	 0.00525	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	4	 3	 0.000573	 0.003303	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	57	 3	 0.008505	 0.058098	 0.00988	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 137	 0.005889	 0.038035	 0.00726	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	6	 5	 0.000694	 0.003337	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	48	 5	 0.006246	 0.043513	 0.00711	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 64	 0.007877	 0.054875	 0.00897	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 7	 0.000634	 0.003189	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 86	 0.003756	 0.024259	 0.00463	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 101	 0.003597	 0.023232	 0.00443	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 148	 0.008667	 0.05598	 0.01068	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10	 9	 0.000585	 0.003967	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 124	 0.008069	 0.055123	 0.00938	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 9	 0.004139	 0.026732	 0.0051	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 141	 0.004446	 0.03097	 0.00506	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 193	 0.003695	 0.025244	 0.00429	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	12	 11	 0.000534	 0.003533	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13	 11	 0.000619	 0.003606	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 15	 0.010408	 0.06722	 0.01282	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 93	 0.018394	 0.128141	 0.02095	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	158	 11	 0.008519	 0.058199	 0.0099	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 14	 0.000637	 0.027526	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14	 121	 0.007013	 0.050098	 0.09134	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	14	 149	 0.009133	 0.065244	 0.11895	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	16	 15	 0.000553	 0.0032	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	18	 17	 0.000503	 0.003926	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19	 17	 0.000514	 0.003079	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20	 17	 0.000623	 0.003339	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 17	 0.00062	 0.00394	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	109	 17	 0.009789	 0.068198	 0.01115	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	17	 120	 0.010316	 0.070473	 0.01199	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 22	 0.000616	 0.003222	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24	 22	 0.000687	 0.003067	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22	 27	 0.011379	 0.073494	 0.01402	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	158	 22	 0.012701	 0.086769	 0.01476	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 25	 0.00061	 0.003071	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25	 64	 0.007643	 0.053244	 0.0087	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	199	 25	 0.009909	 0.064003	 0.01221	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28	 27	 0.000587	 0.003964	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27	 93	 0.025172	 0.175362	 0.02867	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27	 158	 0.020429	 0.131945	 0.02517	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30	 29	 0.000694	 0.003131	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 29	 0.005561	 0.038742	 0.00633	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	29	 140	 0.007895	 0.055004	 0.00899	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 31	 0.000667	 0.003884	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33	 31	 0.000528	 0.003639	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 31	 0.008406	 0.05856	 0.00957	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	192	 31	 0.008088	 0.05525	 0.0094	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 34	 0.000575	 0.003674	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34	 54	 0.006268	 0.042819	 0.00729	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	34	 137	 0.006911	 0.044639	 0.00852	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	37	 36	 0.000552	 0.003328	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 36	 0.00067	 0.003511	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58	 36	 0.010889	 0.07439	 0.01266	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 36	 0.009615	 0.066986	 0.01095	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40	 39	 0.000505	 0.003103	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39	 85	 0.008702	 0.060625	 0.00991	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	159	 39	 0.007332	 0.05108	 0.00835	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41	 100	 0.004595	 0.029676	 0.00566	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41	 163	 0.003165	 0.021623	 0.00368	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	41	 180	 0.009408	 0.060766	 0.01159	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 42	 0.012256	 0.085383	 0.01396	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	181	 42	 0.008008	 0.05579	 0.00912	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 84	 0.007509	 0.051295	 0.00873	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 132	 0.011052	 0.075503	 0.01285	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 200	 0.014813	 0.101195	 0.01722	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	46	 45	 0.000936	 0.049195	 0.0	 160.0	 160.0	 160.0	 1.0	 0.0	 1	 -30.0	 30.0;
	55	 45	 0.002593	 0.018527	 0.03378	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	102	 45	 0.0029	 0.020715	 0.03777	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	45	 187	 0.003474	 0.024821	 0.04525	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	61	 46	 0.006971	 0.048561	 0.00794	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	122	 46	 0.010129	 0.065419	 0.01248	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47	 54	 0.006678	 0.045623	 0.00776	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	47	 66	 0.007339	 0.047401	 0.00904	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	49	 48	 0.027149	 0.532021	 0.0	 28.9	 28.9	 28.9	 1.0	 0.0	 1	 -30.0	 30.0;
	50	 48	 0.021719	 0.404167	 0.0	 28.7	 28.7	 28.7	 1.0	 0.0	 1	 -30.0	 30.0;
	51	 48	 0.027149	 0.612711	 0.0	 24.3	 24.3	 24.3	 1.0	 0.0	 1	 -30.0	 30.0;
	52	 48	 0.021719	 0.379817	 0.0	 24.3	 24.3	 24.3	 1.0	 0.0	 1	 -30.0	 30.0;
	53	 48	 0.02121	 0.576549	 0.0	 35.3	 35.3	 35.3	 1.0	 0.0	 1	 -30.0	 30.0;
	48	 74	 0.007959	 0.054369	 0.00925	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 66	 0.007051	 0.045544	 0.00869	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	56	 55	 0.005152	 0.124653	 0.0	 160.0	 160.0	 160.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 55	 0.005467	 0.039054	 0.0712	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	55	 102	 0.001246	 0.008902	 0.01623	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	55	 112	 0.004166	 0.029763	 0.05426	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	55	 128	 0.003415	 0.024395	 0.04448	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	56	 103	 0.004282	 0.02983	 0.00488	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	57	 159	 0.00752	 0.051369	 0.00874	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	95	 58	 0.009836	 0.063526	 0.01212	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 58	 0.014049	 0.095972	 0.01633	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 119	 0.011209	 0.072397	 0.01381	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 139	 0.009665	 0.062426	 0.01191	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60	 97	 0.012274	 0.079279	 0.01512	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	134	 60	 0.009007	 0.062749	 0.01026	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	61	 103	 0.006539	 0.045556	 0.00745	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	159	 62	 0.008634	 0.058979	 0.01003	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	160	 62	 0.007628	 0.053144	 0.00869	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 66	 0.011949	 0.083244	 0.01361	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 184	 0.017963	 0.116023	 0.02214	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 64	 0.00128	 0.10157	 0.0	 195.5	 195.5	 195.5	 1.0	 0.0	 1	 -30.0	 30.0;
	67	 66	 0.020951	 0.144786	 0.0	 30.0	 30.0	 30.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68	 66	 0.00689	 0.264997	 0.0	 73.0	 73.0	 73.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69	 66	 0.00441	 0.09499	 0.0	 70.5	 70.5	 70.5	 1.0	 0.0	 1	 -30.0	 30.0;
	70	 66	 0.00689	 0.199449	 0.0	 70.5	 70.5	 70.5	 1.0	 0.0	 1	 -30.0	 30.0;
	71	 66	 0.003528	 0.081544	 0.0	 68.0	 68.0	 68.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72	 66	 0.003528	 0.074599	 0.0	 68.0	 68.0	 68.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73	 66	 0.00689	 0.146423	 0.0	 65.0	 65.0	 65.0	 1.0	 0.0	 1	 -30.0	 30.0;
	66	 158	 0.004993	 0.032251	 0.00615	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74	 190	 0.008894	 0.06076	 0.01034	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	76	 75	 0.038464	 0.784328	 0.0	 24.3	 24.3	 24.3	 1.0	 0.0	 1	 -30.0	 30.0;
	77	 75	 0.08013	 2.192105	 0.0	 7.4	 7.4	 7.4	 1.0	 0.0	 1	 -30.0	 30.0;
	78	 75	 0.008544	 0.181406	 0.0	 65.0	 65.0	 65.0	 1.0	 0.0	 1	 -30.0	 30.0;
	79	 75	 0.01068	 0.277774	 0.0	 62.1	 62.1	 62.1	 1.0	 0.0	 1	 -30.0	 30.0;
	108	 75	 0.010988	 0.070969	 0.01354	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	75	 157	 0.013487	 0.087112	 0.01662	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80	 100	 0.021463	 0.149525	 0.02444	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80	 143	 0.020594	 0.14347	 0.02345	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82	 81	 0.00097	 0.042371	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81	 178	 0.006598	 0.047137	 0.08594	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	82	 195	 0.003845	 0.026265	 0.00447	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 146	 0.005382	 0.036767	 0.00626	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 186	 0.00792	 0.055174	 0.00902	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84	 113	 0.006652	 0.04544	 0.00773	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	85	 120	 0.007786	 0.050291	 0.00959	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86	 101	 0.00512	 0.033072	 0.00631	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	142	 86	 0.003387	 0.023141	 0.00394	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	86	 193	 0.006606	 0.042664	 0.00814	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88	 87	 0.000832	 0.034189	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	149	 87	 0.001621	 0.011579	 0.02111	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	88	 150	 0.00557	 0.035973	 0.00686	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	176	 88	 0.003859	 0.024922	 0.00475	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	88	 194	 0.004258	 0.029088	 0.00495	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	90	 89	 0.0601	 2.279922	 0.0	 8.6	 8.6	 8.6	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 89	 0.024614	 0.503424	 0.0	 32.0	 32.0	 32.0	 1.0	 0.0	 1	 -30.0	 30.0;
	92	 89	 0.019539	 0.36204	 0.0	 35.3	 35.3	 35.3	 1.0	 0.0	 1	 -30.0	 30.0;
	89	 95	 0.008734	 0.056409	 0.01076	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	188	 89	 0.00805	 0.051996	 0.00992	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	94	 93	 0.01068	 0.280602	 0.0	 62.1	 62.1	 62.1	 1.0	 0.0	 1	 -30.0	 30.0;
	93	 191	 0.022088	 0.142662	 0.02722	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	122	 96	 0.01062	 0.073986	 0.01209	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	96	 143	 0.015858	 0.102423	 0.01954	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	96	 188	 0.010903	 0.070421	 0.01343	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	97	 200	 0.01318	 0.085125	 0.01624	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	99	 98	 0.000643	 0.030516	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	98	 123	 0.0047	 0.033574	 0.06121	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	99	 142	 0.007605	 0.052982	 0.00866	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	100	 174	 0.010698	 0.074531	 0.01218	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	100	 179	 0.007093	 0.049413	 0.00808	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	100	 184	 0.012745	 0.08879	 0.01451	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	110	 101	 0.00196	 0.012657	 0.00241	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	101	 117	 0.005245	 0.035833	 0.0061	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	101	 141	 0.003144	 0.020305	 0.00387	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	103	 102	 0.001709	 0.054578	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	104	 102	 0.0021	 0.087749	 0.0	 130.0	 130.0	 130.0	 1.0	 0.0	 1	 -30.0	 30.0;
	105	 102	 0.00097	 0.059419	 0.0	 260.0	 260.0	 260.0	 1.0	 0.0	 1	 -30.0	 30.0;
	102	 128	 0.0027	 0.019292	 0.03517	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	103	 106	 0.007749	 0.053987	 0.00883	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 106	 0.006991	 0.047761	 0.00813	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	107	 113	 0.006748	 0.046101	 0.00784	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	107	 129	 0.005168	 0.035307	 0.00601	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	192	 107	 0.003939	 0.025441	 0.00485	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	108	 198	 0.024792	 0.160126	 0.03055	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	186	 109	 0.008774	 0.059942	 0.0102	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	110	 193	 0.003444	 0.022243	 0.00424	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	163	 111	 0.005281	 0.034111	 0.00651	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	111	 175	 0.00795	 0.055386	 0.00905	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	113	 112	 0.002077	 0.058615	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	114	 112	 0.06	 0.434013	 0.0	 20.0	 20.0	 20.0	 1.0	 0.0	 1	 -30.0	 30.0;
	115	 112	 0.00128	 0.062771	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	128	 112	 0.001295	 0.009255	 0.01687	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	113	 192	 0.005418	 0.034995	 0.00668	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	117	 116	 0.000517	 0.034943	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	133	 116	 0.00389	 0.027793	 0.05067	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	117	 132	 0.011912	 0.082984	 0.01357	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	117	 162	 0.01617	 0.104442	 0.01993	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 118	 0.00718	 0.046377	 0.00885	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 134	 0.011598	 0.0808	 0.01321	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 198	 0.009487	 0.064809	 0.01103	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	122	 121	 0.000786	 0.063023	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	121	 178	 0.008903	 0.063604	 0.11596	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 121	 0.001063	 0.007593	 0.01384	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 123	 0.000329	 0.017481	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	125	 123	 0.00448	 0.104562	 0.0	 170.0	 170.0	 170.0	 1.0	 0.0	 1	 -30.0	 30.0;
	126	 123	 0.00148	 0.066043	 0.0	 170.0	 170.0	 170.0	 1.0	 0.0	 1	 -30.0	 30.0;
	127	 123	 0.001	 0.031691	 0.0	 170.0	 170.0	 170.0	 1.0	 0.0	 1	 -30.0	 30.0;
	123	 133	 0.001459	 0.010423	 0.019	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	156	 123	 0.001117	 0.007981	 0.01455	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 193	 0.006577	 0.04582	 0.00749	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	129	 128	 0.000753	 0.044453	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	128	 133	 0.009554	 0.068257	 0.12444	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 144	 0.022678	 0.157988	 0.02583	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	134	 133	 0.0002	 0.013328	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	135	 133	 0.00043	 0.033512	 0.0	 580.0	 580.0	 580.0	 1.0	 0.0	 1	 -30.0	 30.0;
	136	 133	 0.00043	 0.027478	 0.0	 580.0	 580.0	 580.0	 1.0	 0.0	 1	 -30.0	 30.0;
	156	 133	 0.001958	 0.013985	 0.0255	 402.36	 402.36	 402.36	 0.0	 0.0	 1	 -30.0	 30.0;
	134	 140	 0.010445	 0.071357	 0.01214	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	134	 186	 0.014463	 0.093412	 0.01782	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	138	 139	 0.026477	 0.184455	 0.03015	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	138	 195	 0.008728	 0.05637	 0.01075	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	141	 148	 0.01019	 0.065817	 0.01256	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	141	 193	 0.002896	 0.018702	 0.00357	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	162	 144	 0.006962	 0.048504	 0.00793	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	145	 176	 0.008799	 0.060111	 0.01023	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	185	 145	 0.010839	 0.075509	 0.01234	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	147	 146	 0.0025	 0.10181	 0.0	 130.6	 130.6	 130.6	 1.0	 0.0	 1	 -30.0	 30.0;
	146	 177	 0.011064	 0.07708	 0.0126	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 149	 0.000412	 0.020251	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	151	 149	 0.02267	 0.625521	 0.0	 20.0	 20.0	 20.0	 1.0	 0.0	 1	 -30.0	 30.0;
	152	 149	 0.00249	 0.141687	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	153	 149	 0.00549	 0.184603	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	154	 149	 0.00249	 0.10294	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	155	 149	 0.00249	 0.099835	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	185	 150	 0.013458	 0.091934	 0.01564	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	194	 150	 0.003138	 0.021435	 0.00365	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	157	 156	 0.000592	 0.045654	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	161	 160	 0.00139	 0.080288	 0.0	 180.2	 180.2	 180.2	 1.0	 0.0	 1	 -30.0	 30.0;
	160	 181	 0.004296	 0.029345	 0.00499	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 163	 0.008207	 0.11301	 0.0	 58.1	 58.1	 58.1	 1.0	 0.0	 1	 -30.0	 30.0;
	165	 163	 0.0074	 0.301657	 0.0	 65.0	 65.0	 65.0	 1.0	 0.0	 1	 -30.0	 30.0;
	166	 163	 0.016368	 0.382075	 0.0	 42.0	 42.0	 42.0	 1.0	 0.0	 1	 -30.0	 30.0;
	167	 163	 0.010476	 0.196499	 0.0	 42.0	 42.0	 42.0	 1.0	 0.0	 1	 -30.0	 30.0;
	168	 163	 0.018	 0.490983	 0.0	 40.0	 40.0	 40.0	 1.0	 0.0	 1	 -30.0	 30.0;
	169	 163	 0.016368	 0.396417	 0.0	 40.0	 40.0	 40.0	 1.0	 0.0	 1	 -30.0	 30.0;
	170	 163	 0.016368	 0.374902	 0.0	 35.6	 35.6	 35.6	 1.0	 0.0	 1	 -30.0	 30.0;
	163	 179	 0.00579	 0.039557	 0.00673	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	171	 190	 0.009866	 0.0674	 0.01147	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	195	 171	 0.011644	 0.081116	 0.01326	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	180	 172	 0.015296	 0.106558	 0.01742	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	199	 172	 0.024005	 0.155042	 0.02958	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	173	 174	 0.015373	 0.099293	 0.01894	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	173	 175	 0.008572	 0.055363	 0.01056	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	174	 188	 0.017952	 0.12264	 0.02087	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	179	 178	 0.000495	 0.036157	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	180	 191	 0.026393	 0.183866	 0.03006	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	180	 199	 0.012185	 0.078698	 0.01501	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 181	 0.01099	 0.297746	 0.0	 60.3	 60.3	 60.3	 1.0	 0.0	 1	 -30.0	 30.0;
	183	 181	 0.004627	 0.114254	 0.0	 65.0	 65.0	 65.0	 1.0	 0.0	 1	 -30.0	 30.0;
	181	 194	 0.004395	 0.028384	 0.00542	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	188	 187	 0.001394	 0.044762	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	189	 187	 0.0003	 0.007815	 0.0	 740.0	 740.0	 740.0	 1.0	 0.0	 1	 -30.0	 30.0;
	196	 195	 0.00285	 0.060038	 0.0	 87.7	 87.7	 87.7	 1.0	 0.0	 1	 -30.0	 30.0;
	197	 195	 0.00285	 0.191484	 0.0	 87.7	 87.7	 87.7	 1.0	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Setting Flat Start
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : Updated Thermal Rating: on line 2-1 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 1-119 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 124-1 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 193-1 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 4-3 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 57-3 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 3-137 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 6-5 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 48-5 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 5-64 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 8-7 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 7-86 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 7-101 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 7-148 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 10-9 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 9-124 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 131-9 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 9-141 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 9-193 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 12-11 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 13-11 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 11-15 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 11-93 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 158-11 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 15-14 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 14-121 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 14-149 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 16-15 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 18-17 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 19-17 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 20-17 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 21-17 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 109-17 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 17-120 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 23-22 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 24-22 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 22-27 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 158-22 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 26-25 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 25-64 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 199-25 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 28-27 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 27-93 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 27-158 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 30-29 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 124-29 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 29-140 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 32-31 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 33-31 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 177-31 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 192-31 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 35-34 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 34-54 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 34-137 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 37-36 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 38-36 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 58-36 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 83-36 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 40-39 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 39-85 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 159-39 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 41-100 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 41-163 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 41-180 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 44-42 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 181-42 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 43-84 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 43-132 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 44-200 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 46-45 : Rate B, Rate C - 0.0, 0.0 -> 160.0, 160.0
% INFO    : Updated Thermal Rating: on line 55-45 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 102-45 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 45-187 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 61-46 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 122-46 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 47-54 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 47-66 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 49-48 : Rate B, Rate C - 0.0, 0.0 -> 28.9, 28.9
% INFO    : Updated Thermal Rating: on transformer 50-48 : Rate B, Rate C - 0.0, 0.0 -> 28.7, 28.7
% INFO    : Updated Thermal Rating: on transformer 51-48 : Rate B, Rate C - 0.0, 0.0 -> 24.3, 24.3
% INFO    : Updated Thermal Rating: on transformer 52-48 : Rate B, Rate C - 0.0, 0.0 -> 24.3, 24.3
% INFO    : Updated Thermal Rating: on transformer 53-48 : Rate B, Rate C - 0.0, 0.0 -> 35.3, 35.3
% INFO    : Updated Thermal Rating: on line 48-74 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 54-66 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 56-55 : Rate B, Rate C - 0.0, 0.0 -> 160.0, 160.0
% INFO    : Updated Thermal Rating: on line 81-55 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 55-102 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 55-112 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 55-128 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 56-103 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 57-159 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 95-58 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 177-58 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 59-119 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 59-139 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 60-97 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 134-60 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 61-103 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 159-62 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 160-62 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 63-66 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 63-184 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 65-64 : Rate B, Rate C - 0.0, 0.0 -> 195.5, 195.5
% INFO    : Updated Thermal Rating: on transformer 67-66 : Rate B, Rate C - 0.0, 0.0 -> 30.0, 30.0
% INFO    : Updated Thermal Rating: on transformer 68-66 : Rate B, Rate C - 0.0, 0.0 -> 73.0, 73.0
% INFO    : Updated Thermal Rating: on transformer 69-66 : Rate B, Rate C - 0.0, 0.0 -> 70.5, 70.5
% INFO    : Updated Thermal Rating: on transformer 70-66 : Rate B, Rate C - 0.0, 0.0 -> 70.5, 70.5
% INFO    : Updated Thermal Rating: on transformer 71-66 : Rate B, Rate C - 0.0, 0.0 -> 68.0, 68.0
% INFO    : Updated Thermal Rating: on transformer 72-66 : Rate B, Rate C - 0.0, 0.0 -> 68.0, 68.0
% INFO    : Updated Thermal Rating: on transformer 73-66 : Rate B, Rate C - 0.0, 0.0 -> 65.0, 65.0
% INFO    : Updated Thermal Rating: on line 66-158 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 74-190 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 76-75 : Rate B, Rate C - 0.0, 0.0 -> 24.3, 24.3
% INFO    : Updated Thermal Rating: on transformer 77-75 : Rate B, Rate C - 0.0, 0.0 -> 7.4, 7.4
% INFO    : Updated Thermal Rating: on transformer 78-75 : Rate B, Rate C - 0.0, 0.0 -> 65.0, 65.0
% INFO    : Updated Thermal Rating: on transformer 79-75 : Rate B, Rate C - 0.0, 0.0 -> 62.1, 62.1
% INFO    : Updated Thermal Rating: on line 108-75 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 75-157 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 80-100 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 80-143 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 82-81 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 81-178 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 82-195 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 83-146 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 83-186 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 84-113 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 85-120 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 86-101 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 142-86 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 86-193 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 88-87 : Rate B, Rate C - 0.0, 0.0 -> 350.0, 350.0
% INFO    : Updated Thermal Rating: on line 149-87 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 88-150 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 176-88 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 88-194 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 90-89 : Rate B, Rate C - 0.0, 0.0 -> 8.6, 8.6
% INFO    : Updated Thermal Rating: on transformer 91-89 : Rate B, Rate C - 0.0, 0.0 -> 32.0, 32.0
% INFO    : Updated Thermal Rating: on transformer 92-89 : Rate B, Rate C - 0.0, 0.0 -> 35.3, 35.3
% INFO    : Updated Thermal Rating: on line 89-95 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 188-89 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 94-93 : Rate B, Rate C - 0.0, 0.0 -> 62.1, 62.1
% INFO    : Updated Thermal Rating: on line 93-191 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 122-96 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 96-143 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 96-188 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 97-200 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 99-98 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 98-123 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 99-142 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 100-174 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 100-179 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 100-184 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 110-101 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 101-117 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 101-141 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 103-102 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 104-102 : Rate B, Rate C - 0.0, 0.0 -> 130.0, 130.0
% INFO    : Updated Thermal Rating: on transformer 105-102 : Rate B, Rate C - 0.0, 0.0 -> 260.0, 260.0
% INFO    : Updated Thermal Rating: on line 102-128 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 103-106 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 130-106 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 107-113 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 107-129 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 192-107 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 108-198 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 186-109 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 110-193 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 163-111 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 111-175 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 113-112 : Rate B, Rate C - 0.0, 0.0 -> 350.0, 350.0
% INFO    : Updated Thermal Rating: on transformer 114-112 : Rate B, Rate C - 0.0, 0.0 -> 20.0, 20.0
% INFO    : Updated Thermal Rating: on transformer 115-112 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 128-112 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 113-192 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 117-116 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 133-116 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 117-132 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 117-162 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 131-118 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 118-134 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 118-198 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 122-121 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 121-178 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 187-121 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on transformer 124-123 : Rate B, Rate C - 0.0, 0.0 -> 400.0, 400.0
% INFO    : Updated Thermal Rating: on transformer 125-123 : Rate B, Rate C - 0.0, 0.0 -> 170.0, 170.0
% INFO    : Updated Thermal Rating: on transformer 126-123 : Rate B, Rate C - 0.0, 0.0 -> 170.0, 170.0
% INFO    : Updated Thermal Rating: on transformer 127-123 : Rate B, Rate C - 0.0, 0.0 -> 170.0, 170.0
% INFO    : Updated Thermal Rating: on line 123-133 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 156-123 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 124-193 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 129-128 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 128-133 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 130-144 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 134-133 : Rate B, Rate C - 0.0, 0.0 -> 400.0, 400.0
% INFO    : Updated Thermal Rating: on transformer 135-133 : Rate B, Rate C - 0.0, 0.0 -> 580.0, 580.0
% INFO    : Updated Thermal Rating: on transformer 136-133 : Rate B, Rate C - 0.0, 0.0 -> 580.0, 580.0
% INFO    : Updated Thermal Rating: on line 156-133 : Rate B, Rate C - 0.0, 0.0 -> 402.36, 402.36
% INFO    : Updated Thermal Rating: on line 134-140 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 134-186 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 138-139 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 138-195 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 141-148 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 141-193 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 162-144 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 145-176 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 185-145 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 147-146 : Rate B, Rate C - 0.0, 0.0 -> 130.6, 130.6
% INFO    : Updated Thermal Rating: on line 146-177 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 150-149 : Rate B, Rate C - 0.0, 0.0 -> 400.0, 400.0
% INFO    : Updated Thermal Rating: on transformer 151-149 : Rate B, Rate C - 0.0, 0.0 -> 20.0, 20.0
% INFO    : Updated Thermal Rating: on transformer 152-149 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 153-149 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 154-149 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 155-149 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 185-150 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 194-150 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 157-156 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on transformer 161-160 : Rate B, Rate C - 0.0, 0.0 -> 180.2, 180.2
% INFO    : Updated Thermal Rating: on line 160-181 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 164-163 : Rate B, Rate C - 0.0, 0.0 -> 58.1, 58.1
% INFO    : Updated Thermal Rating: on transformer 165-163 : Rate B, Rate C - 0.0, 0.0 -> 65.0, 65.0
% INFO    : Updated Thermal Rating: on transformer 166-163 : Rate B, Rate C - 0.0, 0.0 -> 42.0, 42.0
% INFO    : Updated Thermal Rating: on transformer 167-163 : Rate B, Rate C - 0.0, 0.0 -> 42.0, 42.0
% INFO    : Updated Thermal Rating: on transformer 168-163 : Rate B, Rate C - 0.0, 0.0 -> 40.0, 40.0
% INFO    : Updated Thermal Rating: on transformer 169-163 : Rate B, Rate C - 0.0, 0.0 -> 40.0, 40.0
% INFO    : Updated Thermal Rating: on transformer 170-163 : Rate B, Rate C - 0.0, 0.0 -> 35.6, 35.6
% INFO    : Updated Thermal Rating: on line 163-179 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 171-190 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 195-171 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 180-172 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 199-172 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 173-174 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 173-175 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 174-188 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 179-178 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 180-191 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 180-199 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 182-181 : Rate B, Rate C - 0.0, 0.0 -> 60.3, 60.3
% INFO    : Updated Thermal Rating: on transformer 183-181 : Rate B, Rate C - 0.0, 0.0 -> 65.0, 65.0
% INFO    : Updated Thermal Rating: on line 181-194 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on transformer 188-187 : Rate B, Rate C - 0.0, 0.0 -> 400.0, 400.0
% INFO    : Updated Thermal Rating: on transformer 189-187 : Rate B, Rate C - 0.0, 0.0 -> 740.0, 740.0
% INFO    : Updated Thermal Rating: on transformer 196-195 : Rate B, Rate C - 0.0, 0.0 -> 87.7, 87.7
% INFO    : Updated Thermal Rating: on transformer 197-195 : Rate B, Rate C - 0.0, 0.0 -> 87.7, 87.7
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 1	: V=1.0191524, theta=-7.085196 -> V=1.0, theta=0.0
% INFO    : Bus 2	: V=1.0190346, theta=-7.098018 -> V=1.0, theta=0.0
% INFO    : Bus 3	: V=1.0300537, theta=-10.029102 -> V=1.0, theta=0.0
% INFO    : Bus 4	: V=1.0300287, theta=-10.031977 -> V=1.0, theta=0.0
% INFO    : Bus 5	: V=1.0372733, theta=-3.546274 -> V=1.0, theta=0.0
% INFO    : Bus 6	: V=1.0371472, theta=-3.559563 -> V=1.0, theta=0.0
% INFO    : Bus 7	: V=1.0130981, theta=-7.793195 -> V=1.0, theta=0.0
% INFO    : Bus 8	: V=1.0127362, theta=-7.833073 -> V=1.0, theta=0.0
% INFO    : Bus 9	: V=1.0157742, theta=-7.471766 -> V=1.0, theta=0.0
% INFO    : Bus 10	: V=1.0150515, theta=-7.561889 -> V=1.0, theta=0.0
% INFO    : Bus 11	: V=1.0464424, theta=-7.604683 -> V=1.0, theta=0.0
% INFO    : Bus 12	: V=1.046438, theta=-7.60522 -> V=1.0, theta=0.0
% INFO    : Bus 13	: V=1.0464027, theta=-7.609214 -> V=1.0, theta=0.0
% INFO    : Bus 14	: V=1.044617, theta=-6.245575 -> V=1.0, theta=0.0
% INFO    : Bus 15	: V=1.0491072, theta=-7.105388 -> V=1.0, theta=0.0
% INFO    : Bus 16	: V=1.048481, theta=-7.176325 -> V=1.0, theta=0.0
% INFO    : Bus 17	: V=1.0247944, theta=-8.305174 -> V=1.0, theta=0.0
% INFO    : Bus 18	: V=1.0247831, theta=-8.306647 -> V=1.0, theta=0.0
% INFO    : Bus 19	: V=1.0247839, theta=-8.306404 -> V=1.0, theta=0.0
% INFO    : Bus 20	: V=1.024777, theta=-8.307127 -> V=1.0, theta=0.0
% INFO    : Bus 21	: V=1.024716, theta=-8.31463 -> V=1.0, theta=0.0
% INFO    : Bus 22	: V=1.0446532, theta=-8.021549 -> V=1.0, theta=0.0
% INFO    : Bus 23	: V=1.0446325, theta=-8.023805 -> V=1.0, theta=0.0
% INFO    : Bus 24	: V=1.0446174, theta=-8.025162 -> V=1.0, theta=0.0
% INFO    : Bus 25	: V=1.0425139, theta=-4.003351 -> V=1.0, theta=0.0
% INFO    : Bus 26	: V=1.0424947, theta=-4.005417 -> V=1.0, theta=0.0
% INFO    : Bus 27	: V=1.0457273, theta=-7.975065 -> V=1.0, theta=0.0
% INFO    : Bus 28	: V=1.045689, theta=-7.979706 -> V=1.0, theta=0.0
% INFO    : Bus 29	: V=1.0181686, theta=-7.054086 -> V=1.0, theta=0.0
% INFO    : Bus 30	: V=1.0172458, theta=-7.149969 -> V=1.0, theta=0.0
% INFO    : Bus 31	: V=1.0215416, theta=-5.832082 -> V=1.0, theta=0.0
% INFO    : Bus 32	: V=1.0215327, theta=-5.833121 -> V=1.0, theta=0.0
% INFO    : Bus 33	: V=1.0214429, theta=-5.844415 -> V=1.0, theta=0.0
% INFO    : Bus 34	: V=1.0327185, theta=-9.326455 -> V=1.0, theta=0.0
% INFO    : Bus 35	: V=1.032392, theta=-9.365615 -> V=1.0, theta=0.0
% INFO    : Bus 36	: V=1.0280697, theta=-6.178381 -> V=1.0, theta=0.0
% INFO    : Bus 37	: V=1.0280176, theta=-6.18452 -> V=1.0, theta=0.0
% INFO    : Bus 38	: V=1.0275847, theta=-6.23205 -> V=1.0, theta=0.0
% INFO    : Bus 39	: V=1.024585, theta=-10.493094 -> V=1.0, theta=0.0
% INFO    : Bus 40	: V=1.0245573, theta=-10.496396 -> V=1.0, theta=0.0
% INFO    : Bus 41	: V=1.0462799, theta=-7.96017 -> V=1.0, theta=0.0
% INFO    : Bus 42	: V=1.0301465, theta=-11.069993 -> V=1.0, theta=0.0
% INFO    : Bus 43	: V=1.017201, theta=-6.400585 -> V=1.0, theta=0.0
% INFO    : Bus 44	: V=1.0280137, theta=-10.39886 -> V=1.0, theta=0.0
% INFO    : Bus 45	: V=1.0384367, theta=-2.068677 -> V=1.0, theta=0.0
% INFO    : Bus 46	: V=1.0378124, theta=-2.889424 -> V=1.0, theta=0.0
% INFO    : Bus 47	: V=1.0392618, theta=-8.19532 -> V=1.0, theta=0.0
% INFO    : Bus 48	: V=1.0351468, theta=-4.17501 -> V=1.0, theta=0.0
% INFO    : Bus 49	: V=1.04, theta=-3.80269 -> V=1.0, theta=0.0
% INFO    : Bus 50	: V=1.04, theta=-3.896095 -> V=1.0, theta=0.0
% INFO    : Bus 51	: V=1.04, theta=-3.742621 -> V=1.0, theta=0.0
% INFO    : Bus 52	: V=1.04, theta=-3.914588 -> V=1.0, theta=0.0
% INFO    : Bus 53	: V=1.04, theta=-3.349326 -> V=1.0, theta=0.0
% INFO    : Bus 54	: V=1.0375005, theta=-8.493516 -> V=1.0, theta=0.0
% INFO    : Bus 55	: V=1.0370718, theta=-2.298751 -> V=1.0, theta=0.0
% INFO    : Bus 56	: V=1.0364415, theta=-2.736582 -> V=1.0, theta=0.0
% INFO    : Bus 57	: V=1.0281336, theta=-10.449132 -> V=1.0, theta=0.0
% INFO    : Bus 58	: V=1.0349414, theta=-6.030088 -> V=1.0, theta=0.0
% INFO    : Bus 59	: V=1.0187885, theta=-7.693149 -> V=1.0, theta=0.0
% INFO    : Bus 60	: V=1.0291097, theta=-6.554687 -> V=1.0, theta=0.0
% INFO    : Bus 61	: V=1.0351527, theta=-3.102719 -> V=1.0, theta=0.0
% INFO    : Bus 62	: V=1.0267194, theta=-11.318015 -> V=1.0, theta=0.0
% INFO    : Bus 63	: V=1.0437777, theta=-8.233032 -> V=1.0, theta=0.0
% INFO    : Bus 64	: V=1.0415417, theta=-2.532761 -> V=1.0, theta=0.0
% INFO    : Bus 65	: V=1.04, theta=2.119 -> V=1.0, theta=0.0
% INFO    : Bus 66	: V=1.0410702, theta=-7.846441 -> V=1.0, theta=0.0
% INFO    : Bus 67	: V=1.0405589, theta=-7.73215 -> V=1.0, theta=0.0
% INFO    : Bus 68	: V=1.04, theta=-6.669196 -> V=1.0, theta=0.0
% INFO    : Bus 69	: V=1.04, theta=-7.421629 -> V=1.0, theta=0.0
% INFO    : Bus 70	: V=1.04, theta=-6.959081 -> V=1.0, theta=0.0
% INFO    : Bus 71	: V=1.04, theta=-7.48165 -> V=1.0, theta=0.0
% INFO    : Bus 72	: V=1.04, theta=-7.512144 -> V=1.0, theta=0.0
% INFO    : Bus 73	: V=1.04, theta=-7.193069 -> V=1.0, theta=0.0
% INFO    : Bus 74	: V=1.0294816, theta=-5.12964 -> V=1.0, theta=0.0
% INFO    : Bus 75	: V=1.028977, theta=-6.116296 -> V=1.0, theta=0.0
% INFO    : Bus 76	: V=1.04, theta=-5.641354 -> V=1.0, theta=0.0
% INFO    : Bus 77	: V=1.04, theta=-5.292751 -> V=1.0, theta=0.0
% INFO    : Bus 78	: V=1.028977, theta=-6.116296 -> V=1.0, theta=0.0
% INFO    : Bus 79	: V=1.028977, theta=-6.116296 -> V=1.0, theta=0.0
% INFO    : Bus 80	: V=1.0475622, theta=-7.25821 -> V=1.0, theta=0.0
% INFO    : Bus 81	: V=1.038152, theta=-3.896426 -> V=1.0, theta=0.0
% INFO    : Bus 82	: V=1.0353106, theta=-4.72467 -> V=1.0, theta=0.0
% INFO    : Bus 83	: V=1.0305903, theta=-5.147124 -> V=1.0, theta=0.0
% INFO    : Bus 84	: V=1.0192369, theta=-5.836735 -> V=1.0, theta=0.0
% INFO    : Bus 85	: V=1.0241032, theta=-9.891841 -> V=1.0, theta=0.0
% INFO    : Bus 86	: V=1.0142895, theta=-7.633369 -> V=1.0, theta=0.0
% INFO    : Bus 87	: V=1.0382378, theta=-9.281203 -> V=1.0, theta=0.0
% INFO    : Bus 88	: V=1.0367741, theta=-10.475486 -> V=1.0, theta=0.0
% INFO    : Bus 89	: V=1.0367956, theta=-6.001781 -> V=1.0, theta=0.0
% INFO    : Bus 90	: V=1.04, theta=-4.84285 -> V=1.0, theta=0.0
% INFO    : Bus 91	: V=1.04, theta=-5.608287 -> V=1.0, theta=0.0
% INFO    : Bus 92	: V=1.0367956, theta=-6.001781 -> V=1.0, theta=0.0
% INFO    : Bus 93	: V=1.0467635, theta=-7.705981 -> V=1.0, theta=0.0
% INFO    : Bus 94	: V=1.0412845, theta=-6.897097 -> V=1.0, theta=0.0
% INFO    : Bus 95	: V=1.0452705, theta=-6.143695 -> V=1.0, theta=0.0
% INFO    : Bus 96	: V=1.0399843, theta=-4.622369 -> V=1.0, theta=0.0
% INFO    : Bus 97	: V=1.0266279, theta=-8.070874 -> V=1.0, theta=0.0
% INFO    : Bus 98	: V=1.0259732, theta=-5.693301 -> V=1.0, theta=0.0
% INFO    : Bus 99	: V=1.021759, theta=-6.532648 -> V=1.0, theta=0.0
% INFO    : Bus 100	: V=1.05559, theta=-7.845164 -> V=1.0, theta=0.0
% INFO    : Bus 101	: V=1.0153419, theta=-7.486883 -> V=1.0, theta=0.0
% INFO    : Bus 102	: V=1.0375884, theta=-1.855349 -> V=1.0, theta=0.0
% INFO    : Bus 103	: V=1.0361908, theta=-2.820525 -> V=1.0, theta=0.0
% INFO    : Bus 104	: V=1.04, theta=1.292356 -> V=1.0, theta=0.0
% INFO    : Bus 105	: V=1.04, theta=3.030149 -> V=1.0, theta=0.0
% INFO    : Bus 106	: V=1.0333053, theta=-3.587524 -> V=1.0, theta=0.0
% INFO    : Bus 107	: V=1.0164253, theta=-5.897801 -> V=1.0, theta=0.0
% INFO    : Bus 108	: V=1.02631, theta=-6.590908 -> V=1.0, theta=0.0
% INFO    : Bus 109	: V=1.0266885, theta=-7.119037 -> V=1.0, theta=0.0
% INFO    : Bus 110	: V=1.0153998, theta=-7.494693 -> V=1.0, theta=0.0
% INFO    : Bus 111	: V=1.0422996, theta=-8.069078 -> V=1.0, theta=0.0
% INFO    : Bus 112	: V=1.0338868, theta=-2.38601 -> V=1.0, theta=0.0
% INFO    : Bus 113	: V=1.0214787, theta=-5.246294 -> V=1.0, theta=0.0
% INFO    : Bus 114	: V=1.0362036, theta=-2.072597 -> V=1.0, theta=0.0
% INFO    : Bus 115	: V=1.04, theta=2.075284 -> V=1.0, theta=0.0
% INFO    : Bus 116	: V=1.0260581, theta=-5.40757 -> V=1.0, theta=0.0
% INFO    : Bus 117	: V=1.0194057, theta=-6.761358 -> V=1.0, theta=0.0
% INFO    : Bus 118	: V=1.0220863, theta=-6.761277 -> V=1.0, theta=0.0
% INFO    : Bus 119	: V=1.0162966, theta=-7.890283 -> V=1.0, theta=0.0
% INFO    : Bus 120	: V=1.0244523, theta=-9.26074 -> V=1.0, theta=0.0
% INFO    : Bus 121	: V=1.0413751, theta=-2.550667 -> V=1.0, theta=0.0
% INFO    : Bus 122	: V=1.0392113, theta=-3.476706 -> V=1.0, theta=0.0
% INFO    : Bus 123	: V=1.0317706, theta=-4.799729 -> V=1.0, theta=0.0
% INFO    : Bus 124	: V=1.0241995, theta=-6.311793 -> V=1.0, theta=0.0
% INFO    : Bus 125	: V=1.04, theta=-2.638002 -> V=1.0, theta=0.0
% INFO    : Bus 126	: V=1.04, theta=-3.433514 -> V=1.0, theta=0.0
% INFO    : Bus 127	: V=1.04, theta=-4.153305 -> V=1.0, theta=0.0
% INFO    : Bus 128	: V=1.0336624, theta=-2.641873 -> V=1.0, theta=0.0
% INFO    : Bus 129	: V=1.0199071, theta=-5.280933 -> V=1.0, theta=0.0
% INFO    : Bus 130	: V=1.0308537, theta=-4.215383 -> V=1.0, theta=0.0
% INFO    : Bus 131	: V=1.0159516, theta=-7.483658 -> V=1.0, theta=0.0
% INFO    : Bus 132	: V=1.0142019, theta=-7.143976 -> V=1.0, theta=0.0
% INFO    : Bus 133	: V=1.033428, theta=-4.376173 -> V=1.0, theta=0.0
% INFO    : Bus 134	: V=1.0315652, theta=-5.231244 -> V=1.0, theta=0.0
% INFO    : Bus 135	: V=1.04, theta=-1.987898 -> V=1.0, theta=0.0
% INFO    : Bus 136	: V=1.04, theta=-2.419807 -> V=1.0, theta=0.0
% INFO    : Bus 137	: V=1.0313258, theta=-9.719095 -> V=1.0, theta=0.0
% INFO    : Bus 138	: V=1.0307923, theta=-5.699318 -> V=1.0, theta=0.0
% INFO    : Bus 139	: V=1.0214166, theta=-7.361468 -> V=1.0, theta=0.0
% INFO    : Bus 140	: V=1.0231103, theta=-6.390899 -> V=1.0, theta=0.0
% INFO    : Bus 141	: V=1.0153587, theta=-7.521902 -> V=1.0, theta=0.0
% INFO    : Bus 142	: V=1.0140717, theta=-7.617783 -> V=1.0, theta=0.0
% INFO    : Bus 143	: V=1.0372589, theta=-6.549447 -> V=1.0, theta=0.0
% INFO    : Bus 144	: V=1.0236389, theta=-5.928282 -> V=1.0, theta=0.0
% INFO    : Bus 145	: V=1.0320168, theta=-11.164121 -> V=1.0, theta=0.0
% INFO    : Bus 146	: V=1.0331184, theta=-4.010275 -> V=1.0, theta=0.0
% INFO    : Bus 147	: V=1.04, theta=1.000906 -> V=1.0, theta=0.0
% INFO    : Bus 148	: V=1.0102299, theta=-8.189318 -> V=1.0, theta=0.0
% INFO    : Bus 149	: V=1.0395559, theta=-8.879345 -> V=1.0, theta=0.0
% INFO    : Bus 150	: V=1.039664, theta=-9.999925 -> V=1.0, theta=0.0
% INFO    : Bus 151	: V=1.04, theta=-8.34258 -> V=1.0, theta=0.0
% INFO    : Bus 152	: V=1.04, theta=-7.139644 -> V=1.0, theta=0.0
% INFO    : Bus 153	: V=1.04, theta=-6.612046 -> V=1.0, theta=0.0
% INFO    : Bus 154	: V=1.04, theta=-7.61542 -> V=1.0, theta=0.0
% INFO    : Bus 155	: V=1.04, theta=-7.653539 -> V=1.0, theta=0.0
% INFO    : Bus 156	: V=1.0321033, theta=-4.724707 -> V=1.0, theta=0.0
% INFO    : Bus 157	: V=1.0305206, theta=-5.439245 -> V=1.0, theta=0.0
% INFO    : Bus 158	: V=1.0434577, theta=-7.900145 -> V=1.0, theta=0.0
% INFO    : Bus 159	: V=1.0265896, theta=-10.742416 -> V=1.0, theta=0.0
% INFO    : Bus 160	: V=1.0311472, theta=-11.239582 -> V=1.0, theta=0.0
% INFO    : Bus 161	: V=1.0311472, theta=-11.239582 -> V=1.0, theta=0.0
% INFO    : Bus 162	: V=1.0225791, theta=-6.221058 -> V=1.0, theta=0.0
% INFO    : Bus 163	: V=1.0431643, theta=-7.926244 -> V=1.0, theta=0.0
% INFO    : Bus 164	: V=1.0431643, theta=-7.926244 -> V=1.0, theta=0.0
% INFO    : Bus 165	: V=1.0431643, theta=-7.926244 -> V=1.0, theta=0.0
% INFO    : Bus 166	: V=1.0431643, theta=-7.926244 -> V=1.0, theta=0.0
% INFO    : Bus 167	: V=1.0414716, theta=-7.628263 -> V=1.0, theta=0.0
% INFO    : Bus 168	: V=1.0431643, theta=-7.926244 -> V=1.0, theta=0.0
% INFO    : Bus 169	: V=1.0431643, theta=-7.926244 -> V=1.0, theta=0.0
% INFO    : Bus 170	: V=1.04, theta=-7.359358 -> V=1.0, theta=0.0
% INFO    : Bus 171	: V=1.0293606, theta=-5.544471 -> V=1.0, theta=0.0
% INFO    : Bus 172	: V=1.0446624, theta=-6.737828 -> V=1.0, theta=0.0
% INFO    : Bus 173	: V=1.0438694, theta=-7.824896 -> V=1.0, theta=0.0
% INFO    : Bus 174	: V=1.048556, theta=-6.975714 -> V=1.0, theta=0.0
% INFO    : Bus 175	: V=1.042508, theta=-8.051141 -> V=1.0, theta=0.0
% INFO    : Bus 176	: V=1.034057, theta=-10.848998 -> V=1.0, theta=0.0
% INFO    : Bus 177	: V=1.0279083, theta=-5.445402 -> V=1.0, theta=0.0
% INFO    : Bus 178	: V=1.0414926, theta=-4.889523 -> V=1.0, theta=0.0
% INFO    : Bus 179	: V=1.0462277, theta=-6.907941 -> V=1.0, theta=0.0
% INFO    : Bus 180	: V=1.045211, theta=-7.124937 -> V=1.0, theta=0.0
% INFO    : Bus 181	: V=1.0333892, theta=-11.195233 -> V=1.0, theta=0.0
% INFO    : Bus 182	: V=1.04, theta=-10.37446 -> V=1.0, theta=0.0
% INFO    : Bus 183	: V=1.04, theta=-10.723282 -> V=1.0, theta=0.0
% INFO    : Bus 184	: V=1.0492205, theta=-8.289414 -> V=1.0, theta=0.0
% INFO    : Bus 185	: V=1.0341291, theta=-10.871111 -> V=1.0, theta=0.0
% INFO    : Bus 186	: V=1.0294683, theta=-5.915141 -> V=1.0, theta=0.0
% INFO    : Bus 187	: V=1.0411088, theta=-1.59351 -> V=1.0, theta=0.0
% INFO    : Bus 188	: V=1.0422271, theta=-4.274235 -> V=1.0, theta=0.0
% INFO    : Bus 189	: V=1.04, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 190	: V=1.0275107, theta=-5.607695 -> V=1.0, theta=0.0
% INFO    : Bus 191	: V=1.0460774, theta=-7.762654 -> V=1.0, theta=0.0
% INFO    : Bus 192	: V=1.0166276, theta=-5.99268 -> V=1.0, theta=0.0
% INFO    : Bus 193	: V=1.0164747, theta=-7.379588 -> V=1.0, theta=0.0
% INFO    : Bus 194	: V=1.0400826, theta=-10.703489 -> V=1.0, theta=0.0
% INFO    : Bus 195	: V=1.0332601, theta=-5.127426 -> V=1.0, theta=0.0
% INFO    : Bus 196	: V=1.0332601, theta=-5.127426 -> V=1.0, theta=0.0
% INFO    : Bus 197	: V=1.0332601, theta=-5.127426 -> V=1.0, theta=0.0
% INFO    : Bus 198	: V=1.0232234, theta=-6.849765 -> V=1.0, theta=0.0
% INFO    : Bus 199	: V=1.0438791, theta=-5.721465 -> V=1.0, theta=0.0
% INFO    : Bus 200	: V=1.0259148, theta=-9.367606 -> V=1.0, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 49	: Pg=1.36, Qg=0.88 -> Pg=2.945, Qg=0.78
% INFO    : Gen at bus 49	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 50	: Pg=1.36, Qg=1.18 -> Pg=2.945, Qg=0.78
% INFO    : Gen at bus 50	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 51	: Pg=1.36, Qg=0.77 -> Pg=2.945, Qg=0.78
% INFO    : Gen at bus 51	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 52	: Pg=1.36, Qg=1.25 -> Pg=2.945, Qg=0.78
% INFO    : Gen at bus 52	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 53	: Pg=2.72, Qg=0.79 -> Pg=5.895, Qg=1.56
% INFO    : Gen at bus 53	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 65	: Pg=86.5, Qg=0.84 -> Pg=86.5, Qg=5.19
% INFO    : Gen at bus 65	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 67	: Pg=1.41, Qg=-0.57 -> Pg=3.055, Qg=0.81
% INFO    : Gen at bus 67	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 68	: Pg=8.38, Qg=-0.55 -> Pg=18.15, Qg=4.8
% INFO    : Gen at bus 68	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 69	: Pg=8.38, Qg=-1.53 -> Pg=18.15, Qg=4.8
% INFO    : Gen at bus 69	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 70	: Pg=8.38, Qg=-0.78 -> Pg=18.15, Qg=4.8
% INFO    : Gen at bus 70	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 71	: Pg=8.38, Qg=-1.7 -> Pg=18.15, Qg=4.8
% INFO    : Gen at bus 71	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 72	: Pg=8.38, Qg=-1.86 -> Pg=18.15, Qg=4.8
% INFO    : Gen at bus 72	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 73	: Pg=8.38, Qg=-1.11 -> Pg=18.15, Qg=4.8
% INFO    : Gen at bus 73	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 76	: Pg=1.2, Qg=1.41 -> Pg=2.6, Qg=0.8
% INFO    : Gen at bus 76	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 77	: Pg=0.72, Qg=0.5 -> Pg=1.56, Qg=0.475
% INFO    : Gen at bus 77	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 78	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 79	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 90	: Pg=0.96, Qg=0.13 -> Pg=2.08, Qg=0.635
% INFO    : Gen at bus 90	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 91	: Pg=1.5, Qg=0.59 -> Pg=3.25, Qg=1.0
% INFO    : Gen at bus 91	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 92	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=5.4, Qg=-2.2 -> Pg=11.7, Qg=3.095
% INFO    : Gen at bus 94	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 104	: Pg=67.6, Qg=3.1 -> Pg=67.6, Qg=3.415
% INFO    : Gen at bus 104	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 105	: Pg=154.8, Qg=8.29 -> Pg=154.8, Qg=6.83
% INFO    : Gen at bus 105	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 114	: Pg=1.4, Qg=0.36 -> Pg=1.4, Qg=0.06
% INFO    : Gen at bus 114	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 115	: Pg=133.5, Qg=12.6 -> Pg=133.5, Qg=5.175
% INFO    : Gen at bus 115	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 125	: Pg=39.02, Qg=7.24 -> Pg=84.535, Qg=22.365
% INFO    : Gen at bus 125	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 126	: Pg=39.02, Qg=12.55 -> Pg=84.535, Qg=22.365
% INFO    : Gen at bus 126	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 127	: Pg=39.02, Qg=25.99 -> Pg=84.535, Qg=22.365
% INFO    : Gen at bus 127	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 135	: Pg=133.92, Qg=21.46 -> Pg=290.16, Qg=76.78
% INFO    : Gen at bus 135	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 136	: Pg=133.92, Qg=25.06 -> Pg=290.16, Qg=76.78
% INFO    : Gen at bus 136	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 147	: Pg=92.4, Qg=8.79 -> Pg=92.4, Qg=3.47
% INFO    : Gen at bus 147	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 151	: Pg=1.62, Qg=0.02 -> Pg=3.51, Qg=0.93
% INFO    : Gen at bus 151	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 152	: Pg=23.17, Qg=0.27 -> Pg=50.195, Qg=13.285
% INFO    : Gen at bus 152	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 153	: Pg=23.17, Qg=0.02 -> Pg=50.195, Qg=13.285
% INFO    : Gen at bus 153	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 154	: Pg=23.17, Qg=0.14 -> Pg=50.195, Qg=13.285
% INFO    : Gen at bus 154	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 155	: Pg=23.17, Qg=0.13 -> Pg=50.195, Qg=13.285
% INFO    : Gen at bus 155	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 161	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 164	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 165	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 166	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 167	: Pg=2.82, Qg=-1.04 -> Pg=6.11, Qg=1.87
% INFO    : Gen at bus 167	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 168	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 169	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 170	: Pg=2.82, Qg=-0.99 -> Pg=6.11, Qg=1.87
% INFO    : Gen at bus 170	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 182	: Pg=5.25, Qg=2.15 -> Pg=11.375, Qg=3.01
% INFO    : Gen at bus 182	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 183	: Pg=7.98, Qg=5.73 -> Pg=17.29, Qg=4.575
% INFO    : Gen at bus 183	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 189	: Pg=384.37, Qg=-24.15 -> Pg=369.95, Qg=81.39
% INFO    : Gen at bus 189	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 196	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 197	: Vg=1.04 -> Vg=1.0
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
