%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   This network data stems from the Nordic32 test system initially developed
%   by CIGRE Task Force 38.02.08, “Long-term dynamics, phase II” in 1995. These
%   data were further enriched by the research group of Thierry Van Cutsem and
%   then by Florin Capitanescu to include: (i) OPF-related data (physical
%   limits, cost functions); (ii) definition of various AC-OPF/SCOPF problems;
%   and (iii) data conversion from initial format into the MATPOWER (.m)
%   format. Note that AC-OPF formulations of this dataset have traditionally
%   modeled thermal limits in terms of current but this version of the dataset
%   uses MVA limits.
%
%   This power system model contains 60 buses, 23 generators, 57 lines,
%   31 transformers (out of which 8 OLTCs, the last 8 branch records),
%   22 loads, and 12 shunt elements.
%
%   Historically, this data has been used to solve various instances of
%   AC-OPF/SCOPF problems with different objective functions, sets of decision
%   variables including, generators active/reactive powers, ratio of LTC
%   transformers, reactance of shunt capacitors/reactors) and constraints. Some
%   of the OPF results can be found at:
%
%      https://people.montefiore.uliege.be/capitane
%
%   Researchers looking to include control variables like transformer tap ratio
%   and shunt reactance or N-1 contingencies can contact Florin Capitanescu for
%   the associated data.
%
%   When publishing results based on this data a suitable reference is:
%
%   [1] F. Capitanescu, "Suppressing ineffective control actions in optimal
%       power flow problems", IET Generation, Transmission & Distribution, 2020.
%
%   February, 2021
%
%   Copyright (c) 2021 by Florin Capitanescu <fcapitanescu@yahoo.com>
%   Licensed under the Creative Commons Attribution 4.0
%   International license, http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case60_c
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	1	 1	 200.0	 80.0	 0.0	 -340.12	 1	    1.00000	    0.00000	 130.0	 1	    1.10000	    0.90000;
	2	 1	 300.0	 100.0	 0.0	 0.0	 1	    1.00000	    0.00000	 130.0	 1	    1.10000	    0.90000;
	3	 1	 100.0	 40.0	 0.0	 0.0	 1	    1.00000	    0.00000	 130.0	 1	    1.10000	    0.90000;
	4	 1	 280.0	 95.0	 0.0	 150.0	 1	    1.00000	    0.00000	 130.0	 1	    1.10000	    0.90000;
	5	 1	 402.2198	 190.111	 0.0	 200.0	 1	    1.00000	    0.00000	 130.0	 1	    1.10000	    0.90000;
	6	 1	 201.2099	 75.06049	 0.0	 0.0	 1	    1.00000	    0.00000	 130.0	 1	    1.10000	    0.90000;
	7	 1	 154.2076	 96.21037	 0.0	 100.0	 1	    1.00000	    0.00000	 130.0	 1	    1.10000	    0.90000;
	8	 1	 536.4263	 286.8214	 0.0	 200.0	 1	    1.00000	    0.00000	 130.0	 1	    1.10000	    0.90000;
	9	 1	 469.4231	 238.4712	 0.0	 200.0	 1	    1.00000	    0.00000	 130.0	 1	    1.10000	    0.90000;
	10	 1	 100.0	 30.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	11	 1	 200.0	 50.0	 0.0	 0.0	 1	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	12	 1	 300.0	 100.0	 0.0	 -400.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	13	 1	 2000.0	 500.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	14	 1	 362.0178	 151.1009	 0.0	 200.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	15	 1	 268.2132	 143.4107	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	16	 1	 603.4296	 288.1715	 0.0	 200.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	17	 1	 469.4231	 238.4712	 0.0	 100.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	18	 1	 67.0033	 48.35017	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	19	 1	 536.4263	 288.8214	 0.0	 100.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	20	 1	 500.0	 149.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	21	 1	 300.0	 100.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	22	 1	 590.0	 300.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	23	 1	 0.0	 0.0	 0.0	 -100.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	24	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 130.0	 1	    1.10000	    0.90000;
	25	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 130.0	 1	    1.10000	    0.90000;
	26	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	27	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	28	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	29	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	30	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	31	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	32	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	33	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	34	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	35	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	36	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	37	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	38	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	39	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	40	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	41	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	42	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	43	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	44	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	45	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	46	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	47	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	48	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	49	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	50	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	51	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	52	 3	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	53	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	54	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	55	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	56	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	57	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	58	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	59	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	60	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin
mpc.gen = [
	38	 365.0	 0.0	 720.0	 -720.0	 1.0	 800.0	 1	 720.0	 10.0;
	39	 275.0	 0.0	 540.0	 -540.0	 1.0	 600.0	 1	 540.0	 10.0;
	40	 320.0	 0.0	 630.0	 -630.0	 1.0	 700.0	 1	 630.0	 10.0;
	41	 275.0	 0.0	 540.0	 -540.0	 1.0	 600.0	 1	 540.0	 10.0;
	42	 242.5	 50.0	 325.0	 -225.0	 1.0	 400.0	 1	 475.0	 10.0;
	43	 285.0	 100.0	 560.0	 -360.0	 1.0	 600.0	 1	 560.0	 10.0;
	44	 195.0	 40.0	 360.0	 -280.0	 1.0	 400.0	 1	 380.0	 10.0;
	45	 487.5	 100.0	 965.0	 -765.0	 1.0	 1000.0	 1	 965.0	 10.0;
	46	 455.0	 0.0	 900.0	 -900.0	 1.0	 1000.0	 1	 900.0	 10.0;
	47	 365.0	 0.0	 720.0	 -720.0	 1.0	 800.0	 1	 720.0	 10.0;
	48	 290.0	 100.0	 570.0	 -370.0	 1.0	 600.0	 1	 570.0	 10.0;
	49	 292.5	 50.0	 515.0	 -415.0	 1.0	 600.0	 1	 575.0	 10.0;
	50	 0.0	 0.0	 570.0	 -570.0	 1.0	 600.0	 1	 0.0	 0.0;
	51	 320.0	 0.0	 630.0	 -630.0	 1.0	 700.0	 1	 630.0	 10.0;
	52	 1405.0	 650.0	 1840.0	 -540.0	 1.0	 3000.0	 1	 2800.0	 10.0;
	53	 275.0	 20.0	 580.0	 -540.0	 1.0	 600.0	 1	 540.0	 10.0;
	54	 320.0	 0.0	 630.0	 -630.0	 1.0	 700.0	 1	 630.0	 10.0;
	55	 320.0	 0.0	 630.0	 -630.0	 1.0	 700.0	 1	 630.0	 10.0;
	56	 275.0	 0.0	 540.0	 -540.0	 1.0	 600.0	 1	 540.0	 10.0;
	57	 275.0	 0.0	 540.0	 -540.0	 1.0	 600.0	 1	 540.0	 10.0;
	58	 275.0	 0.0	 540.0	 -540.0	 1.0	 600.0	 1	 540.0	 10.0;
	59	 285.0	 35.0	 520.0	 -450.0	 1.0	 600.0	 1	 560.0	 10.0;
	60	 2255.0	 975.0	 4000.0	 -2050.0	 1.0	 5000.0	 1	 4500.0	 10.0;
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	  10.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  20.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  10.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  30.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  10.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  20.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  10.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  30.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  10.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  10.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  20.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  10.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  30.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  10.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  20.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  10.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  10.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  30.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  10.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  20.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  10.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  30.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	  10.000000	   0.000000;
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	1	 3	 0.01	 0.07	 0.013804	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1	 3	 0.01	 0.07	 0.013804	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2	 24	 0.014024	 0.09	 0.018052	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2	 24	 0.014024	 0.09	 0.018052	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 24	 0.006982	 0.05	 0.010088	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 24	 0.006982	 0.05	 0.010088	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25	 4	 0.03	 0.2	 0.030263	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25	 4	 0.03	 0.2	 0.030263	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 7	 0.01	 0.06	 0.012211	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 7	 0.01	 0.06	 0.012211	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 9	 0.01497	 0.12	 0.024954	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 9	 0.01497	 0.12	 0.024954	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6	 8	 0.037988	 0.28	 0.059995	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6	 8	 0.037988	 0.28	 0.059995	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6	 9	 0.05	 0.3	 0.059995	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 8	 0.01	 0.08	 0.015928	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 8	 0.01	 0.08	 0.015928	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10	 11	 0.012004	 0.09	 0.015205	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10	 11	 0.012004	 0.09	 0.015205	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 23	 0.001	 0.008	 0.201062	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 27	 0.006	 0.06	 1.799488	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 28	 0.004	 0.04	 1.201344	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 12	 0.005	 0.045	 1.4024	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 28	 0.004	 0.035	 1.05056	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 12	 0.005	 0.05	 1.49792	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27	 29	 0.004	 0.04	 1.201344	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27	 30	 0.01	 0.1	 3.000864	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30	 15	 0.0	 -0.04	 0.0	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28	 31	 0.004	 0.04	 1.201344	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28	 31	 0.004	 0.04	 1.201344	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31	 29	 0.001	 0.01	 0.301594	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31	 32	 0.006	 0.08	 2.397664	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 14	 0.0	 -0.04	 0.0	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31	 33	 0.006	 0.08	 2.397664	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	33	 14	 0.0	 -0.04	 0.0	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29	 34	 0.01	 0.066669	 2.000576	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34	 15	 0.0	 -0.026669	 0.0	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29	 35	 0.006	 0.08	 2.397664	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 36	 0.0	 -0.03	 0.0	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14	 36	 0.003	 0.03	 0.899744	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	14	 20	 0.006	 0.045	 1.301888	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 16	 0.002	 0.015	 0.497632	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 36	 0.002	 0.02	 0.598176	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16	 36	 0.001	 0.01	 0.301594	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16	 17	 0.001	 0.01	 0.301594	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	16	 18	 0.002	 0.02	 0.598176	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36	 37	 0.002	 0.02	 0.598176	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36	 37	 0.002	 0.02	 0.598176	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37	 19	 0.004	 0.04	 1.201344	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37	 19	 0.004	 0.04	 1.201344	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37	 21	 0.011	 0.08	 2.397664	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	17	 18	 0.001	 0.015	 0.497632	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20	 21	 0.002	 0.02	 0.598176	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 22	 0.003	 0.03	 0.899744	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 22	 0.003	 0.03	 0.899744	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12	 13	 0.003	 0.03	 3.000864	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12	 13	 0.003	 0.03	 3.000864	 700.0	 700.0	 700.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2	 38	 0.0	 0.01875	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3	 39	 0.0	 0.025	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24	 40	 0.0	 0.021429	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25	 41	 0.0	 0.025	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4	 42	 0.0	 0.06	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6	 43	 0.0	 0.0375	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7	 44	 0.0	 0.075	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11	 45	 0.0	 0.017647	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26	 46	 0.0	 0.015	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23	 47	 0.0	 0.01875	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27	 48	 0.0	 0.05	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	31	 49	 0.0	 0.042857	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	14	 50	 0.0	 0.033333	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	15	 51	 0.0	 0.021429	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18	 52	 0.0	 0.025	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18	 53	 0.0	 0.025	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19	 54	 0.0	 0.021429	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	19	 55	 0.0	 0.021429	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21	 56	 0.0	 0.025	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22	 57	 0.0	 0.025	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22	 58	 0.0	 0.025	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	12	 59	 0.0	 0.03	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13	 60	 0.0	 0.003333	 0.0	 4500.0	 4500.0	 4500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26	 1	 0.0	 0.008	 0.0	 1250.0	 1250.0	 1250.0	 0.89286	 0.0	 1	 -30.0	 30.0;
	23	 2	 0.0	 0.008	 0.0	 1250.0	 1250.0	 1250.0	 0.89286	 0.0	 1	 -30.0	 30.0;
	28	 4	 0.0	 0.012	 0.0	 833.3	 833.3	 833.3	 0.93458	 0.0	 1	 -30.0	 30.0;
	31	 10	 0.0	 0.012	 0.0	 833.3	 833.3	 833.3	 0.95238	 0.0	 1	 -30.0	 30.0;
	36	 8	 0.0	 0.01	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	36	 8	 0.0	 0.01	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37	 9	 0.0	 0.01	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	37	 9	 0.0	 0.01	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Setting Flat Start
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 1	: V=1.064082, theta=-15.563001 -> V=1.0, theta=0.0
% INFO    : Bus 2	: V=1.083567, theta=-14.09203 -> V=1.0, theta=0.0
% INFO    : Bus 3	: V=1.058654, theta=-10.182816 -> V=1.0, theta=0.0
% INFO    : Bus 4	: V=1.096596, theta=-17.7009 -> V=1.0, theta=0.0
% INFO    : Bus 5	: V=1.053068, theta=-41.503713 -> V=1.0, theta=0.0
% INFO    : Bus 6	: V=1.045071, theta=-28.663263 -> V=1.0, theta=0.0
% INFO    : Bus 7	: V=1.057085, theta=-37.808583 -> V=1.0, theta=0.0
% INFO    : Bus 8	: V=1.061996, theta=-33.606318 -> V=1.0, theta=0.0
% INFO    : Bus 9	: V=1.067548, theta=-36.331543 -> V=1.0, theta=0.0
% INFO    : Bus 10	: V=1.079598, theta=-22.844109 -> V=1.0, theta=0.0
% INFO    : Bus 11	: V=1.018959, theta=-15.053383 -> V=1.0, theta=0.0
% INFO    : Bus 12	: V=0.991571, theta=-26.531716 -> V=1.0, theta=0.0
% INFO    : Bus 13	: V=1.004524, theta=-32.784826 -> V=1.0, theta=0.0
% INFO    : Bus 14	: V=1.08107, theta=-32.180729 -> V=1.0, theta=0.0
% INFO    : Bus 15	: V=1.060573, theta=-28.088084 -> V=1.0, theta=0.0
% INFO    : Bus 16	: V=1.045303, theta=-28.404205 -> V=1.0, theta=0.0
% INFO    : Bus 17	: V=1.031922, theta=-26.304401 -> V=1.0, theta=0.0
% INFO    : Bus 18	: V=1.036064, theta=-19.430476 -> V=1.0, theta=0.0
% INFO    : Bus 19	: V=1.046955, theta=-33.337959 -> V=1.0, theta=0.0
% INFO    : Bus 20	: V=1.025557, theta=-40.764411 -> V=1.0, theta=0.0
% INFO    : Bus 21	: V=1.028314, theta=-39.398039 -> V=1.0, theta=0.0
% INFO    : Bus 22	: V=1.013333, theta=-39.21771 -> V=1.0, theta=0.0
% INFO    : Bus 23	: V=0.985738, theta=-15.214764 -> V=1.0, theta=0.0
% INFO    : Bus 24	: V=1.067034, theta=-8.648865 -> V=1.0, theta=0.0
% INFO    : Bus 25	: V=1.07502, theta=-2.638356 -> V=1.0, theta=0.0
% INFO    : Bus 26	: V=0.986067, theta=-15.919696 -> V=1.0, theta=0.0
% INFO    : Bus 27	: V=1.068863, theta=-21.576377 -> V=1.0, theta=0.0
% INFO    : Bus 28	: V=1.032869, theta=-18.827698 -> V=1.0, theta=0.0
% INFO    : Bus 29	: V=1.068559, theta=-25.255516 -> V=1.0, theta=0.0
% INFO    : Bus 30	: V=0.978794, theta=-32.626173 -> V=1.0, theta=0.0
% INFO    : Bus 31	: V=1.053472, theta=-24.01627 -> V=1.0, theta=0.0
% INFO    : Bus 32	: V=1.049524, theta=-39.582141 -> V=1.0, theta=0.0
% INFO    : Bus 33	: V=1.049524, theta=-39.582141 -> V=1.0, theta=0.0
% INFO    : Bus 34	: V=1.020882, theta=-30.156834 -> V=1.0, theta=0.0
% INFO    : Bus 35	: V=1.021283, theta=-35.89561 -> V=1.0, theta=0.0
% INFO    : Bus 36	: V=1.065873, theta=-31.893982 -> V=1.0, theta=0.0
% INFO    : Bus 37	: V=1.06957, theta=-34.842542 -> V=1.0, theta=0.0
% INFO    : Bus 38	: V=1.07, theta=-10.727834 -> V=1.0, theta=0.0
% INFO    : Bus 39	: V=1.055, theta=-6.69034 -> V=1.0, theta=0.0
% INFO    : Bus 40	: V=1.06, theta=-4.765096 -> V=1.0, theta=0.0
% INFO    : Bus 41	: V=1.07, theta=1.126925 -> V=1.0, theta=0.0
% INFO    : Bus 42	: V=1.07, theta=-12.172581 -> V=1.0, theta=0.0
% INFO    : Bus 43	: V=1.063348, theta=-22.570252 -> V=1.0, theta=0.0
% INFO    : Bus 44	: V=1.05399, theta=-30.566378 -> V=1.0, theta=0.0
% INFO    : Bus 45	: V=1.0042, theta=-10.001941 -> V=1.0, theta=0.0
% INFO    : Bus 46	: V=0.9989, theta=-12.116254 -> V=1.0, theta=0.0
% INFO    : Bus 47	: V=1.0019, theta=-10.828162 -> V=1.0, theta=0.0
% INFO    : Bus 48	: V=1.0336, theta=-15.443018 -> V=1.0, theta=0.0
% INFO    : Bus 49	: V=1.0141, theta=-17.248593 -> V=1.0, theta=0.0
% INFO    : Bus 50	: V=1.0, theta=-32.180757 -> V=1.0, theta=0.0
% INFO    : Bus 51	: V=1.0113, theta=-24.187821 -> V=1.0, theta=0.0
% INFO    : Bus 52	: V=1.0611, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 53	: V=1.0611, theta=-15.560206 -> V=1.0, theta=0.0
% INFO    : Bus 54	: V=1.0447, theta=-29.738419 -> V=1.0, theta=0.0
% INFO    : Bus 55	: V=1.0369, theta=-29.376407 -> V=1.0, theta=0.0
% INFO    : Bus 56	: V=1.0116, theta=-35.252215 -> V=1.0, theta=0.0
% INFO    : Bus 57	: V=1.029, theta=-35.081723 -> V=1.0, theta=0.0
% INFO    : Bus 58	: V=1.029, theta=-35.081723 -> V=1.0, theta=0.0
% INFO    : Bus 59	: V=1.03, theta=-22.374519 -> V=1.0, theta=0.0
% INFO    : Bus 60	: V=1.0185, theta=-30.364105 -> V=1.0, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 38	: Pg=362.8692, Qg=-66.767236 -> Pg=365.0, Qg=0.0
% INFO    : Gen at bus 38	: Vg=1.07 -> Vg=1.0
% INFO    : Gen at bus 39	: Pg=272.1519, Qg=-7.123284 -> Pg=275.0, Qg=0.0
% INFO    : Gen at bus 39	: Vg=1.055 -> Vg=1.0
% INFO    : Gen at bus 40	: Pg=357.5106, Qg=-22.670573 -> Pg=320.0, Qg=0.0
% INFO    : Gen at bus 40	: Vg=1.06 -> Vg=1.0
% INFO    : Gen at bus 41	: Pg=302.1519, Qg=-11.549816 -> Pg=275.0, Qg=0.0
% INFO    : Gen at bus 41	: Vg=1.07 -> Vg=1.0
% INFO    : Gen at bus 42	: Pg=188.3966, Qg=-38.335054 -> Pg=242.5, Qg=50.0
% INFO    : Gen at bus 42	: Vg=1.07 -> Vg=1.0
% INFO    : Gen at bus 43	: Pg=314.5454, Qg=68.564837 -> Pg=285.0, Qg=100.0
% INFO    : Gen at bus 43	: Vg=1.063348 -> Vg=1.0
% INFO    : Gen at bus 44	: Pg=187.2727, Qg=7.501724 -> Pg=195.0, Qg=40.0
% INFO    : Gen at bus 44	: Vg=1.05399 -> Vg=1.0
% INFO    : Gen at bus 45	: Pg=510.5485, Qg=-61.467132 -> Pg=487.5, Qg=100.0
% INFO    : Gen at bus 45	: Vg=1.0042 -> Vg=1.0
% INFO    : Gen at bus 46	: Pg=435.5865, Qg=99.922135 -> Pg=455.0, Qg=0.0
% INFO    : Gen at bus 46	: Vg=0.9989 -> Vg=1.0
% INFO    : Gen at bus 47	: Pg=402.8692, Qg=101.789384 -> Pg=365.0, Qg=0.0
% INFO    : Gen at bus 47	: Vg=1.0019 -> Vg=1.0
% INFO    : Gen at bus 48	: Pg=236.0759, Qg=-60.248316 -> Pg=290.0, Qg=100.0
% INFO    : Gen at bus 48	: Vg=1.0336 -> Vg=1.0
% INFO    : Gen at bus 49	: Pg=293.7553, Qg=-75.795423 -> Pg=292.5, Qg=50.0
% INFO    : Gen at bus 49	: Vg=1.0141 -> Vg=1.0
% INFO    : Gen at bus 50	: Pg=0.0, Qg=-243.210921 -> Pg=0.0, Qg=0.0
% INFO    : Gen at bus 50	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 51	: Pg=340.4546, Qg=-220.947271 -> Pg=320.0, Qg=0.0
% INFO    : Gen at bus 51	: Vg=1.0113 -> Vg=1.0
% INFO    : Gen at bus 52	: Pg=1462.875622, Qg=356.714649 -> Pg=1405.0, Qg=650.0
% INFO    : Gen at bus 52	: Vg=1.0611 -> Vg=1.0
% INFO    : Gen at bus 53	: Pg=296.8182, Qg=116.288946 -> Pg=275.0, Qg=20.0
% INFO    : Gen at bus 53	: Vg=1.0611 -> Vg=1.0
% INFO    : Gen at bus 54	: Pg=320.4545, Qg=-0.927939 -> Pg=320.0, Qg=0.0
% INFO    : Gen at bus 54	: Vg=1.0447 -> Vg=1.0
% INFO    : Gen at bus 55	: Pg=350.0, Qg=-36.553736 -> Pg=320.0, Qg=0.0
% INFO    : Gen at bus 55	: Vg=1.0369 -> Vg=1.0
% INFO    : Gen at bus 56	: Pg=300.8182, Qg=-56.742588 -> Pg=275.0, Qg=0.0
% INFO    : Gen at bus 56	: Vg=1.0116 -> Vg=1.0
% INFO    : Gen at bus 57	: Pg=300.8182, Qg=75.346059 -> Pg=275.0, Qg=0.0
% INFO    : Gen at bus 57	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 58	: Pg=300.8182, Qg=75.346059 -> Pg=275.0, Qg=0.0
% INFO    : Gen at bus 58	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 59	: Pg=246.7932, Qg=140.896249 -> Pg=285.0, Qg=35.0
% INFO    : Gen at bus 59	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 60	: Pg=1296.3868, Qg=454.44114 -> Pg=2255.0, Qg=975.0
% INFO    : Gen at bus 60	: Vg=1.0185 -> Vg=1.0
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
