%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  			 	  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow with HVDC Lines - v23.09     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf-hvdc)      				  %%%%%
%%%%               Benchmark Group - Typical Operations               				  %%%%%
%%%%                         23 - August - 2023                       				  %%%%%
%%%%                                                                  				  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Optimal Power Flow data for the Synthetic National Electricity Market (SNEM)
%   Australia - Mainland subnetwork.
%
%   This dataset is derived by complementing and extending the S-NEM2300bus
%   benchmark data and software as part the following works and expands them with
%   representation of the HVDC connections:
%      - F. Arraño-Vargas and G. Konstantinou, "Modular Design and Real-Time
%        Simulators Toward Power System Digital Twins Implementation," in IEEE
%        Transactions on Industrial Informatics, doi: 10.1109/TII.2022.3178713
%      - F. Arraño-Vargas and G. Konstantinou, "Synthetic Grid Modeling for
%        Real-Time Simulations," 2021 IEEE PES Innovative Smart Grid
%        Technologies - Asia (ISGT Asia), 2021,
%        doi: 10.1109/ISGTAsia49270.2021.9715654
%   
%   A technical report about the AC grid representation of this dataset is available at:
%   https://arxiv.org/abs/2306.08176
%   
%   Following modifications with respect to the SNEM1803 and SNEM197 systems have been made:
%	The BASS Link connects the SNEM1803 and the SNEM197 networks. 
%   - Representation of the BASS Link: 
%                                       Deletion of AC branch 543, deletion of intermediate bus 2113,
%                                      	deletion of "dummy" generators 264 & 265, adding two converter stations,
%                                      	and one DC branch.
%   - Representation of the TERRANORA link: 
%										Addition of two converter stations and three DC branches
%   - Representation of the MURRAYLINK: 
%										Addition of two converter stations and one DC branch
%   
%   Copyright (c) 2023 by Rahmat Heidari (rahmat.heidarihaei@csiro.au), Ghulam Mohy-ud-din (Ghulam.Mohyuddin@csiro.au) & Hakan Ergun (hakan.ergun@kuleuven.be)
%   Licensed under the Creative Commons Attribution 4.0
%   International license, http://creativecommons.org/licenses/by/4.0/
%
%% MATPOWER Case Format : Version 2
function mpc = NEM
mpc.version = '2';

%%-----  Power Flow Data  -----%%
%% system MVA base
mpc.baseMVA = 100;
%% bus data
%    bus_i    type    Pd    Qd    Gs    Bs    area    Vm    Va    baseKV    zone    Vmax    Vmin
mpc.bus = [
	1	1	0.0	0.0	0.0	0.0	1	1.056829623424886	-8.977279952476998	0.55	1	1.1	0.9				
	2	1	0.0	0.0	0.0	0.0	1	1.0568506101320916	-8.977575858894927	0.55	1	1.1	0.9				
	3	3	27.214341009702498	22.9900319056034	0.0	0.0	1	1.0155600000008822	-1.439043540934142e-10	23.0	1	1.1	0.9				
	4	2	35.305539065715095	25.536955754316597	0.0	0.0	1	1.0262600000008077	1.588803403263192	23.0	1	1.1	0.9				
	5	2	36.3464705546116	25.4527938492952	0.0	0.0	1	0.9990000000006636	4.90539022138185	23.0	1	1.1	0.9				
	6	2	36.153696760668204	25.952019776483105	0.0	0.0	1	1.0025100000006752	4.630940988078049	23.0	1	1.1	0.9				
	7	1	0.0	0.0	0.0	0.0	1	1.0207790301336637	0.7936873380854174	11.0	1	1.1	0.9				
	8	1	34.3079817598438	6.892727246839408	0.0	28.232458521239447	1	1.029636867007994	20.96864875685241	22.0	1	1.1	0.9				
	10	1	0.0	0.0	0.0	0.0	1	1.029636322187869	20.96862041943449	11.0	1	1.1	0.9				
	11	1	0.0	0.0	0.0	0.0	1	1.0296362949894846	20.96861778084282	11.0	1	1.1	0.9				
	12	2	0.0	0.0	0.0	0.0	1	1.0604999999995164	14.928388508866282	330.0	1	1.1	0.9				
	13	2	0.0	0.0	0.0	0.0	1	1.0154599999998417	9.416426090630896	0.6899999999999998	1	1.1	0.9				
	14	2	0.0	0.0	0.0	0.0	1	1.0172899999998444	9.353362528474202	0.6899999999999998	1	1.1	0.9				
	15	2	0.0	0.0	0.0	0.0	1	1.0125999999998783	8.373941651475816	0.6899999999999998	1	1.1	0.9				
	16	1	0.567323553623725	0.0	0.0	-2.2564771930617287	1	1.0018381174899345	10.2815415588037	0.6899999999999998	1	1.1	0.9				
	17	1	-0.23610117125269	0.0	0.0	-3.91829091666266	1	1.0015320800829315	10.33207482353905	0.6899999999999998	1	1.1	0.9				
	18	2	32.9123161610551	24.711783958261503	0.0	0.0	1	1.0112200000000926	12.41045145354788	23.0	1	1.1	0.9				
	19	2	32.7047949975725	24.864146277261202	0.0	0.0	1	1.0183700000000653	13.05452814535401	23.0	1	1.1	0.9				
	20	2	32.937722768523706	24.8430852986128	0.0	0.0	1	1.0233200000000091	13.64244859824255	23.0	1	1.1	0.9				
	21	2	33.7906400303283	25.010466589327603	0.0	0.0	1	1.0157699999999812	14.31259158148057	23.0	1	1.1	0.9				
	22	1	-83.0623847517897	0.0	0.0	-11.7381837877338	1	0.9985824609075477	17.43380828303851	33.0	1	1.1	0.9				
	23	2	0.041755911774933284	0.0395732937566936	0.0	0.0	1	1.026690000000016	5.144119136486958	16.0	1	1.1	0.9				
	24	2	0.0	0.0	0.0	0.0	1	1.0771299999990986	11.018302557921771	0.6899999999999998	1	1.1	0.9				
	25	2	0.0	0.0	0.0	0.0	1	1.0770499999990981	11.01290645295916	0.6899999999999998	1	1.1	0.9				
	26	2	0.0	-14.681676562177001	0.0	0.0	1	1.0875899999991359	9.937250975429427	0.6899999999999998	1	1.1	0.9				
	27	1	0.0	0.0	0.0	0.0	1	1.0485275537482068	8.88228979593709	132.0	1	1.1	0.9				
	28	2	0.0	0.0	0.0	0.0	1	1.0244899999992303	10.70340308382816	132.0	1	1.1	0.9				
	29	1	0.0	0.0	0.0	0.0	1	1.0226182481800343	-0.003946260780785413	16.0	1	1.1	0.9				
	30	2	0.07874156961217518	0.07739421614632008	0.0	0.0	1	1.0191300000000325	4.706373784984359	16.0	1	1.1	0.9				
	31	2	0.0	0.0	0.0	0.0	1	0.9528199999982646	24.86836490130132	11.0	1	1.1	0.9				
	32	1	176.73390301466	-4.11325372574511	0.0	0.0	1	1.0566003811438103	-23.14241163171997	33.0	1	1.1	0.9				
	33	1	-3.33792712396276	0.0	0.0	13.0353994753305	1	0.9282436337437064	14.875080974479731	11.0	1	1.1	0.9				
	34	2	18.341554469353003	10.3636909979163	0.0	0.0	1	0.9734900000000558	13.12980784018663	22.0	1	1.1	0.9				
	35	2	17.4121562782648	10.893810214865999	0.0	0.0	1	0.9320500000000145	14.13026797802986	22.0	1	1.1	0.9				
	36	2	18.582245540429103	10.5566776532596	0.0	0.0	1	0.9755800000000123	14.19604504955022	22.0	1	1.1	0.9				
	37	2	0.0943259037151933	0.08743726937780161	0.0	0.0	1	0.9789699999983338	29.43261390478714	15.4	1	1.1	0.9				
	38	2	0.0876203157609328	0.09076399877332152	0.0	0.0	1	0.9780499999983339	29.06043145060584	15.4	1	1.1	0.9				
	39	2	0.09111050326647241	0.0927051996761467	0.0	0.0	1	0.9840699999983344	29.46882876351581	15.4	1	1.1	0.9				
	40	2	0.0894937716460321	0.0930797259162646	0.0	0.0	1	0.9818599999983345	29.682318977868132	15.4	1	1.1	0.9				
	41	2	0.09191597477369938	0.0946137851933017	0.0	0.0	1	0.9837699999983311	29.512251251851044	15.4	1	1.1	0.9				
	42	2	0.0944379383103922	0.0882814010351896	0.0	0.0	1	0.9855599999983311	29.38278188549631	15.4	1	1.1	0.9				
	43	2	31.518040437391004	25.972870391560697	0.0	0.0	1	0.9989400000003716	5.781007638305895	23.0	1	1.1	0.9				
	44	1	0.0	0.0	0.0	0.0	1	1.0269357353109256	-1.021279768640452	23.0	1	1.1	0.9				
	45	1	0.0	0.0	0.0	0.0	1	0.989968319942511	-6.42680705590938	17.5	1	1.1	0.9				
	46	1	-6.321807256489991	0.0	0.0	0.062422145700082164	1	1.0024784261968391	13.51768564508145	22.0	1	1.1	0.9				
	47	1	1.02072695429423	0.733871934417821	0.0	0.0	1	1.0243680589513333	-6.460367023172039	15.0	1	1.1	0.9				
	48	1	1.1200335927479	0.730782591217384	0.0	0.0	1	1.02435291825526	-6.464954253855753	15.0	1	1.1	0.9				
	49	1	0.968675146375224	0.592623299681395	0.0	0.0	1	1.0244362425658606	-6.460279788209045	15.0	1	1.1	0.9				
	50	1	0.9397457393940071	0.5860383047368382	0.0	0.0	1	1.0244466402973187	-6.45878562638311	15.0	1	1.1	0.9				
	51	1	-3.06059989218204	0.0	0.0	0.0	1	1.0412859377372061	6.971322240952063	0.55	1	1.1	0.9				
	52	1	-20.5648680556712	0.0	0.0	-3.910596988102419	1	1.0265702099148346	23.16550479858929	22.0	1	1.1	0.9				
	53	1	-20.355388152304997	0.0	0.0	-3.6806902014426894	1	1.0272722590769332	23.07335578409237	22.0	1	1.1	0.9				
	54	1	37.3257623166889	4.58530336711928	0.0	-4.595364754858888	1	1.0153875285431972	16.16878072030653	11.0	1	1.1	0.9				
	55	1	0.0	0.0	0.0	0.0	1	1.0686762971587203	15.07249015472151	0.55	1	1.1	0.9				
	56	2	7.19655427563423	2.41647754932139	0.0	0.0	1	0.9880100000003142	3.7997444595260004	21.0	1	1.1	0.9				
	57	2	0.0	0.0	0.0	0.0	1	1.0150199999980112	26.55554402291894	11.5	1	1.1	0.9				
	58	2	0.0	0.0	0.0	0.0	1	0.9449199999981235	32.22147552893529	11.5	1	1.1	0.9				
	59	1	0.0	0.0	0.0	0.0	1	1.0134422166415877	18.68287174311193	132.0	1	1.1	0.9				
	60	1	-14.282245254126602	0.0	0.0	-4.096644248932133	1	1.0441291959448833	14.112679816441842	12.0	1	1.1	0.9				
	61	2	0.0	0.0	0.0	401.9661514088508	1	1.0270000000013784	-11.36596408286945	330.0	1	1.1	0.9				
	62	2	0.0	0.0	0.0	0.0	1	0.9160899999978572	22.04129698999879	11.0	1	1.1	0.9				
	63	2	0.0	0.0	0.0	0.0	1	1.0414899999976572	22.76213742824785	11.0	1	1.1	0.9				
	64	2	0.0	0.0	0.0	0.0	1	1.0629799999980032	35.82441718589963	15.75	1	1.1	0.9				
	65	2	0.0	0.0	0.0	0.0	1	1.0575999999980057	36.01166468070276	15.75	1	1.1	0.9				
	66	2	0.0	0.0	0.0	0.0	1	1.063539999998005	36.00342364179156	15.75	1	1.1	0.9				
	67	2	0.0	0.0	0.0	0.0	1	1.0626299999980076	36.14345972925743	15.75	1	1.1	0.9				
	68	1	0.0	0.0	0.0	0.0	1	0.9711622200555297	20.32284773310832	12.5	1	1.1	0.9				
	69	2	0.0433923930488527	0.043749541898723696	0.0	0.0	1	0.9635399999983624	22.60603055253578	12.5	1	1.1	0.9				
	70	2	0.0448706568134017	0.0477275057820603	0.0	0.0	1	0.9702499999983616	22.99129928570131	12.5	1	1.1	0.9				
	71	1	0.0	0.0	0.0	0.0	1	0.9718826269399232	20.24984244031531	12.5	1	1.1	0.9				
	72	1	0.0	0.0	0.0	0.0	1	1.017138359155176	20.41908007855816	12.5	1	1.1	0.9				
	73	2	0.0380112225227058	0.0406420744564384	0.0	0.0	1	1.00306999999828	23.33733213330934	12.5	1	1.1	0.9				
	74	2	0.0387934326939285	0.038430588806048	0.0	0.0	1	1.0127499999982816	23.4722096654911	12.5	1	1.1	0.9				
	75	2	0.0380778377875686	0.0389150532997213	0.0	0.0	1	1.0241899999982815	23.59073494107054	12.5	1	1.1	0.9				
	76	2	26.3099001010022	14.9509423831273	0.0	0.0	1	1.0188500000008487	1.114119245169003	23.0	1	1.1	0.9				
	77	2	27.959039167828397	14.5822928520143	0.0	0.0	1	1.0095500000008435	1.244714711594707	23.0	1	1.1	0.9				
	78	1	17.944003521226342	9.016822778878133	0.0	-4.9940764243723805	1	1.02542788041576	17.80184585832935	66.0	1	1.1	0.9				
	79	2	0.0	0.0	0.0	0.0	1	1.0445900000015635	-13.73592315818436	11.0	1	1.1	0.9				
	80	2	0.0	0.0	0.0	0.0	1	1.042060000001548	-13.34310763904506	11.0	1	1.1	0.9				
	81	1	0.0	0.0	0.0	0.0	1	1.0528241558378864	-19.45868148489789	11.0	1	1.1	0.9				
	82	1	0.0	0.0	0.0	0.0	1	1.053153657841849	-19.45817671796368	11.0	1	1.1	0.9				
	83	1	0.0	0.0	0.0	0.0	1	1.081583649477113	5.345717254579498	11.5	1	1.1	0.9				
	84	1	0.0	0.0	0.0	0.0	1	1.0815836494771112	5.345717254579491	11.5	1	1.1	0.9				
	85	1	0.0	0.0	0.0	0.0	1	1.0412966199698233	-2.650600156493706	500.0	1	1.1	0.9				
	86	1	0.0	0.0	0.0	0.0	1	1.019293048648907	-4.277768925890689	330.0	1	1.1	0.9				
	87	1	0.0	0.0	0.0	0.0	1	1.047427455654175	-6.089586014839488	500.0	1	1.1	0.9				
	88	1	0.0	0.0	0.0	412.0286558941007	1	1.0448957447412697	-8.899513338954277	330.0	1	1.1	0.9				
	91	1	0.0	0.0	0.0	0.0	1	1.0258919100438	-4.308838728235784	330.0	1	1.1	0.9				
	92	1	0.0	0.0	0.0	0.0	1	1.0476213533300094	0.7743583451813953	500.0	1	1.1	0.9				
	93	1	0.0	0.0	0.0	0.0	1	1.0288334040629687	0.3986422144461632	330.0	1	1.1	0.9				
	94	1	0.0	0.0	0.0	0.0	1	1.0555223434888397	6.955676388074683	500.0	1	1.1	0.9				
	95	1	0.0	0.0	0.0	0.0	1	1.034813928084693	6.610155754468517	330.0	1	1.1	0.9				
	97	1	0.0	0.0	0.0	0.0	1	1.0217327030733752	8.460477570531758	330.0	1	1.1	0.9				
	98	1	0.0	0.0	0.0	0.0	1	1.0124518368931967	11.70038682070796	330.0	1	1.1	0.9				
	99	1	0.0	0.0	0.0	0.0	1	1.0696118248711037	11.1044747219506	330.0	1	1.1	0.9				
	100	1	0.0	0.0	0.0	0.0	1	1.024377374929828	-4.012439172679424	330.0	1	1.1	0.9				
	101	1	0.0	0.0	0.0	0.0	1	1.0688982286764925	20.82992795177304	330.0	1	1.1	0.9				
	102	1	0.0	0.0	0.0	-155.26726707816096	1	1.0362767131245694	-11.87591346681503	330.0	1	1.1	0.9				
	103	1	0.104516655383632	-1.7242746998481397	0.0	0.0	1	1.0489657900475857	13.63319065873542	132.0	1	1.1	0.9				
	104	1	0.0	0.0	0.0	-62.150755693204694	1	1.0531521422773407	25.58528512930064	330.0	1	1.1	0.9				
	105	1	0.0	0.0	0.0	0.0	1	1.0512885777753689	-14.848284445144172	330.0	1	1.1	0.9				
	106	1	0.0	0.0	0.0	0.0	1	1.036875728215395	-11.7554989414603	330.0	1	1.1	0.9				
	107	1	0.0	0.0	0.0	0.0	1	1.031637882918312	-10.12925588470406	330.0	1	1.1	0.9				
	108	1	0.0	0.0	0.0	0.0	1	1.041741295716282	22.052209785024623	330.0	1	1.1	0.9				
	109	1	0.0	0.0	0.0	0.0	1	1.0226182481800357	-0.003946260780745655	330.0	1	1.1	0.9				
	110	1	0.0	0.0	0.0	0.0	1	1.0321576277803532	6.620543953291656	330.0	1	1.1	0.9				
	111	1	0.0	0.0	0.0	-100.10944619309201	1	1.047584860016429	10.31203454452455	330.0	1	1.1	0.9				
	112	1	0.0	0.0	0.0	0.0	1	1.032314710127017	-11.76521884521535	330.0	1	1.1	0.9				
	113	1	0.0	0.0	0.0	0.0	1	1.025964178568837	22.29398066546937	330.0	1	1.1	0.9				
	114	1	0.0	0.0	0.0	0.0	1	1.0263938121238003	0.4726988178013388	330.0	1	1.1	0.9				
	115	1	0.0	0.0	0.0	0.0	1	1.0357975972550688	-8.246491260547778	330.0	1	1.1	0.9				
	116	1	0.0	0.0	0.0	0.0	1	1.0552983174432637	1.218506002492175	500.0	1	1.1	0.9				
	117	1	0.0	0.0	0.0	0.0	1	1.0381355586787646	-1.021279768640452	330.0	1	1.1	0.9				
	118	1	0.0	0.0	0.0	0.0	1	1.0248202446432104	-6.426807055909307	330.0	1	1.1	0.9				
	119	1	0.0	0.0	0.0	0.0	1	1.0224948226475856	4.978460662175444	330.0	1	1.1	0.9				
	120	1	0.0	0.0	0.0	0.0	1	1.0307221646647158	6.584062680213872	330.0	1	1.1	0.9				
	121	1	52.1446072876835	-10.4186994219702	0.0	0.0	1	1.0457788243688528	-19.46389930000411	132.0	1	1.1	0.9				
	122	1	47.0702037674924	-7.42322407301534	0.0	0.0	1	1.045682106346644	-19.40236534486947	132.0	1	1.1	0.9				
	123	1	0.771102107275277	0.5350705203771591	0.0	0.0	1	1.0467036818024364	-19.17903518095962	132.0	1	1.1	0.9				
	124	1	46.8132718256355	-6.03130423971033	0.0	0.0	1	1.0469133881908312	-19.36830718059969	132.0	1	1.1	0.9				
	126	1	0.0	0.0	0.0	0.0	1	1.010927308377204	-5.261014874612455	330.0	1	1.1	0.9				
	127	1	0.0	0.0	0.0	0.0	1	1.0298510962601373	-10.13755091142178	330.0	1	1.1	0.9				
	128	1	0.0	0.0	0.0	0.0	1	1.0414933852248218	-13.54992377193754	330.0	1	1.1	0.9				
	129	1	0.0	0.0	0.0	0.0	1	1.0147465714050727	26.5886502529894	132.0	1	1.1	0.9				
	130	1	0.0	0.0	0.0	0.0	1	1.0431480182213402	10.56586515752351	132.0	1	1.1	0.9				
	131	1	0.0	0.0	0.0	0.0	1	1.0399968300576956	-12.48436238274671	330.0	1	1.1	0.9				
	132	1	14.2949130828764	5.14730489338171	0.0	0.0	1	1.0285958942025917	18.56383733712308	132.0	1	1.1	0.9				
	133	1	0.0	0.0	0.0	-246.92635576473594	1	1.034771480601476	-11.19058337365726	330.0	1	1.1	0.9				
	135	1	0.0	0.0	0.0	0.0	1	1.0590800372762637	21.55538797031457	330.0	1	1.1	0.9				
	138	1	0.0	0.0	0.0	0.0	1	1.0544860414788229	10.35642636581861	330.0	1	1.1	0.9				
	139	1	969.0150037223428	274.39628427689956	0.0	221.55104858288502	1	1.0047895627659134	-6.117208718562539	330.0	1	1.1	0.9				
	140	1	0.0	0.0	0.0	0.0	1	1.0222163923104999	-9.554664906240859	330.0	1	1.1	0.9				
	141	1	0.0	0.0	0.0	0.0	1	1.0189536952058418	20.112161152775634	330.0	1	1.1	0.9				
	142	2	0.0	0.0	0.0	192.1560231596229	1	1.0250777860011466	-5.488875077276375	330.0	1	1.1	0.9				
	143	1	0.0	0.0	0.0	0.0	1	1.0280674964539103	-11.58035221279875	330.0	1	1.1	0.9				
	144	1	0.0	0.0	0.0	0.0	1	1.052733411552958	22.59747569897063	330.0	1	1.1	0.9				
	145	1	0.0	0.0	0.0	0.0	1	1.0367940432829892	-1.715413527701392	330.0	1	1.1	0.9				
	146	1	0.0	0.0	0.0	0.0	1	1.0062080935474937	-5.906182272295832	330.0	1	1.1	0.9				
	147	1	0.0	0.0	0.0	0.0	1	1.0067568315654	10.6986678674577	330.0	1	1.1	0.9				
	148	1	0.0	0.0	0.0	-102.09912414196896	1	1.0284116779724406	-2.014981055088598	330.0	1	1.1	0.9				
	149	1	0.0	0.0	0.0	0.0	1	1.0597865293552977	3.357201427299076	500.0	1	1.1	0.9				
	150	1	0.0	0.0	0.0	0.0	1	1.0521324527610978	2.069465416832535	330.0	1	1.1	0.9				
	151	1	0.0	0.0	0.0	0.0	1	1.0153189531149125	9.66250731252819	330.0	1	1.1	0.9				
	152	1	0.0	0.0	0.0	80.07954398542638	1	1.0258323578063713	12.87029397213267	132.0	1	1.1	0.9				
	154	1	0.0	0.0	0.0	-130.99993497598902	1	0.9662250489235306	0.508715633861644	33.0	1	1.1	0.9				
	155	1	0.0	0.0	0.0	0.0	1	1.0327391500435605	0.4997470458633272	33.0	1	1.1	0.9				
	156	1	0.216529954653187	0.40220958956959696	0.0	-98.8957157963887	1	1.0519506457673893	-18.43917719764521	132.0	1	1.1	0.9				
	157	1	0.0	0.0	0.0	24.588292440399492	1	1.0540592497775523	7.473031042478997	132.0	1	1.1	0.9				
	159	1	301.5311189719217	25.095294130560866	0.0	123.898189047351	1	1.0232384724272956	-4.945411064841417	132.0	1	1.1	0.9				
	160	1	0.0	0.0	0.0	-34.6324332985561	1	1.0263186936575068	20.9028893068318	220.0	1	1.1	0.9				
	161	1	17.99162321349137	-4.0153217847230875	0.0	38.434252901338	1	1.0824015001190455	20.02358894221748	132.0	1	1.1	0.9				
	162	1	282.1231944544455	107.2458407386237	0.0	-103.90770591329796	1	1.0508568323147438	-18.43954029020352	132.0	1	1.1	0.9				
	165	1	0.0	0.0	0.0	0.0	1	1.046582155804884	20.90758867908772	132.0	1	1.1	0.9				
	166	2	0.0	0.0	0.0	30.815467547625293	1	1.0040699999992804	9.863507771527251	132.0	1	1.1	0.9				
	170	1	0.0	0.0	0.0	0.0	1	1.0281270696248392	-0.5869373359806229	132.0	1	1.1	0.9				
	171	1	139.75602702264578	20.44950474832593	0.0	0.0	1	1.0365646198609182	-13.42856220209507	132.0	1	1.1	0.9				
	172	1	0.0	0.0	0.0	0.0	1	1.0781271737794142	-4.03635933845317	132.0	1	1.1	0.9				
	174	2	0.0	0.0	0.0	0.0	1	0.9978099999996237	6.186595908266506	33.0	1	1.1	0.9				
	175	1	0.0	0.0	0.0	0.0	1	1.053454900653084	4.256303139121247	132.0	1	1.1	0.9				
	176	1	0.0	0.0	0.0	0.0	1	1.0544186483825417	-9.14614919711142	132.0	1	1.1	0.9				
	177	1	245.2666320813816	85.02624961588181	0.0	82.45979792252179	1	1.019095661508403	-12.4707361779142	132.0	1	1.1	0.9				
	178	1	632.5183891335347	-25.520239119883648	0.0	110.23872074438299	1	1.0228567733458054	-16.61128981898583	132.0	1	1.1	0.9				
	179	1	215.91967169481802	81.55375378110216	0.0	123.99600445479204	1	1.0343018150577576	-16.41523228602024	132.0	1	1.1	0.9				
	180	1	0.0	0.0	0.0	0.0	1	1.0230002811853522	-16.09922114238406	132.0	1	1.1	0.9				
	181	1	0.0	0.0	0.0	0.0	1	1.0231899205453	-16.61427713441913	132.0	1	1.1	0.9				
	182	1	78.4661207230591	3.5030830638563297	0.0	118.62339701503501	1	1.0352964786379244	-15.129063909437871	132.0	1	1.1	0.9				
	183	1	66.05197622275733	13.340704959799485	0.0	167.431074902415	1	1.0442400764898743	-15.9368489250595	132.0	1	1.1	0.9				
	184	1	24.109205815278102	6.27467704216484	0.0	160.632906526327	1	1.0436910880563068	-15.733025097866408	132.0	1	1.1	0.9				
	185	1	103.77583088981969	19.8401998823269	0.0	0.0	1	1.0283391919849387	8.131920662220686	132.0	1	1.1	0.9				
	186	1	0.0	0.0	0.0	0.0	1	1.0624417900467933	-8.251555429025876	132.0	1	1.1	0.9				
	188	1	41.184766744947	17.5264675299108	0.0	0.0	1	1.0435518438562257	-11.73648420230902	132.0	1	1.1	0.9				
	189	1	8.196319011532239	-0.7174650966227059	0.0	0.0	1	1.054876457159596	-8.678429239879797	132.0	1	1.1	0.9				
	191	1	158.3305676122174	30.76314024858066	0.0	59.59430044703179	1	1.0375730896435036	-15.4978901908185	132.0	1	1.1	0.9				
	192	1	0.0	0.0	0.0	78.97053647786379	1	1.053493328624043	24.020023125565075	132.0	1	1.1	0.9				
	193	1	18.255845924162298	8.83805388663374	0.0	0.0	1	1.076083939105193	-4.381686630838623	132.0	1	1.1	0.9				
	194	1	80.430232870505	30.824093108362604	0.0	0.0	1	1.049605311312625	-6.831170659545386	132.0	1	1.1	0.9				
	195	1	0.0	0.0	0.0	0.0	1	1.0526506377315819	-11.20293169611148	132.0	1	1.1	0.9				
	196	1	68.94908565931951	30.18862330509154	0.0	0.0	1	1.044977491001384	-9.847637440605078	132.0	1	1.1	0.9				
	197	1	0.0	0.0	0.0	0.0	1	1.0286022926971743	9.183502503579549	132.0	1	1.1	0.9				
	198	1	0.0	0.0	0.0	19.3074304163456	1	1.050322532483244	-4.9645850279442	132.0	1	1.1	0.9				
	199	1	0.0	0.0	0.0	0.0	1	1.0399560701958817	11.08251172842113	132.0	1	1.1	0.9				
	200	1	0.0	0.0	0.0	0.0	1	1.046546565943881	-8.843206218099784	132.0	1	1.1	0.9				
	201	1	0.0	0.0	0.0	0.0	1	1.043067098655384	11.52263956430804	132.0	1	1.1	0.9				
	202	1	34.19279275183901	2.2713786386044688	0.0	6.207856105919931	1	1.0458618820133856	9.752722624191225	66.0	1	1.1	0.9				
	204	1	0.0	0.0	0.0	0.0	1	1.049850634187275	21.10920861467919	220.0	1	1.1	0.9				
	205	1	0.0	0.0	0.0	0.0	1	1.0463731553350188	-19.08599005971061	132.0	1	1.1	0.9				
	208	1	27.6265726334902	14.479561446035502	0.0	0.0	1	1.0341230613104333	-16.11328844993065	132.0	1	1.1	0.9				
	210	1	17.0287468016645	1.3887771329371301	0.0	-25.30242467997598	1	1.039497299733625	20.68804724613582	220.0	1	1.1	0.9				
	211	2	85.8045954265578	0.0	0.0	0.0	1	1.037559999998999	13.19030203356221	110.0	1	1.1	0.9				
	212	1	63.495530594278094	16.168201305059952	0.0	0.0	1	1.0518313348879076	-18.12311519920622	132.0	1	1.1	0.9				
	214	1	0.0	0.0	0.0	154.11611622571905	1	1.0519563718753107	-18.43959031045461	132.0	1	1.1	0.9				
	215	1	0.0	0.0	0.0	-54.22644980493927	1	1.0293992094601976	21.8066612652898	220.0	1	1.1	0.9				
	216	1	12.1669812024641	4.18680869391607	0.0	0.0	1	1.0285329399192638	-8.56924783837962	132.0	1	1.1	0.9				
	217	1	7.503794180498131	1.24192596953921	0.0	0.0	1	1.0361221281021893	-14.50171285511423	132.0	1	1.1	0.9				
	218	1	0.0	0.0	0.0	0.0	1	1.051543035503309	16.01624463786756	132.0	1	1.1	0.9				
	219	1	2.1835738987048168	0.02881484689265501	0.0	0.0	1	1.0199411472877478	4.347970268025256	132.0	1	1.1	0.9				
	221	1	82.0316256063125	22.365053668189617	0.0	12.365361885912698	1	1.0294452597776704	-8.457462418437075	132.0	1	1.1	0.9				
	222	1	6.327268349225909	3.25207837965991	0.0	0.0	1	1.043676916824275	21.56790861139781	132.0	1	1.1	0.9				
	223	1	15.1065737890452	6.2447493016626705	0.0	0.0	1	1.0368372545868585	-14.614920292591059	132.0	1	1.1	0.9				
	225	1	19.67279429336503	5.267365830491629	0.0	0.0	1	1.0383563155346258	-16.111241662354775	132.0	1	1.1	0.9				
	227	1	0.0	0.0	0.0	0.0	1	1.032454552918072	-15.741245234460818	132.0	1	1.1	0.9				
	229	1	5.58004724041424	-6.81500044697765	0.0	0.0	1	1.036486404535581	-14.589158915862113	132.0	1	1.1	0.9				
	230	1	15.787991394305202	1.24274292333308	0.0	0.0	1	1.0158374083044128	7.711737290478137	132.0	1	1.1	0.9				
	231	1	0.0	0.0	0.0	0.0	1	1.012614550917709	25.7965188189025	132.0	1	1.1	0.9				
	232	1	0.0	0.0	0.0	0.0	1	1.0485742073906448	-9.505126285492407	132.0	1	1.1	0.9				
	233	1	97.1050388719274	-0.7245183648190019	0.0	0.0	1	1.0262378425565954	-15.218389276901771	132.0	1	1.1	0.9				
	234	1	18.503651471826366	4.52118197428509	0.0	0.0	1	1.0496382631430727	-9.402736679509347	132.0	1	1.1	0.9				
	236	1	17.788299871615905	9.62153780921083	0.0	0.0	1	1.0466350239931759	-19.17635431065033	132.0	1	1.1	0.9				
	237	1	14.2534222819245	9.3896193828518	0.0	0.0	1	1.0459112514508628	-19.41040165241186	132.0	1	1.1	0.9				
	239	1	16.3814459094408	9.99440215975335	0.0	0.0	1	1.045877786552941	-19.34922126233896	132.0	1	1.1	0.9				
	240	1	72.0668929625272	9.156617908975532	0.0	0.0	1	1.0400720111894741	19.93241939913644	132.0	1	1.1	0.9				
	242	1	47.8228401746794	8.40931931990571	0.0	0.0	1	1.0411175489529532	20.23229998054176	132.0	1	1.1	0.9				
	245	1	371.9520619000958	32.040756395817574	0.0	0.0	1	1.0354027519034812	-14.72201800829358	132.0	1	1.1	0.9				
	246	1	0.0	0.0	0.0	0.0	1	1.0437587594001059	-15.733851938666918	132.0	1	1.1	0.9				
	247	1	25.261175761547264	1.9889313295538098	0.0	0.0	1	1.030112326633225	-15.9436024403569	132.0	1	1.1	0.9				
	248	1	168.62437723047458	50.354558624401115	0.0	116.674105312675	1	1.0182241194349204	8.214289916129632	132.0	1	1.1	0.9				
	249	1	3.56522878216495	1.273702663153876	0.0	0.0	1	1.0214479622648651	4.27389723222799	132.0	1	1.1	0.9				
	250	1	21.493420448134984	-0.33719673562138586	0.0	0.0	1	1.0518960717009327	-9.354357432555146	132.0	1	1.1	0.9				
	251	1	24.174062854835704	7.0653910795226205	0.0	0.0	1	1.023523274585203	-15.147329762650818	132.0	1	1.1	0.9				
	252	1	29.176687909570802	9.886487036965278	0.0	0.0	1	1.022223159274409	-15.098501847555887	132.0	1	1.1	0.9				
	253	1	430.36496573833654	53.94334374504909	0.0	0.0	1	1.031292661911853	-17.93916385154232	132.0	1	1.1	0.9				
	254	1	50.3033259281897	9.9147898162847	0.0	0.0	1	1.0303493024148735	-17.67871443468384	132.0	1	1.1	0.9				
	255	1	0.0	0.0	0.0	0.0	1	1.0544496735296842	-8.996363330172327	132.0	1	1.1	0.9				
	256	1	0.0	0.0	0.0	0.0	1	1.045947803572013	-8.227938152816435	132.0	1	1.1	0.9				
	257	1	50.2121305000638	26.702488916025104	0.0	0.0	1	1.0348753672946296	-16.53517424419018	132.0	1	1.1	0.9				
	258	1	105.3566766039782	18.70718905585384	0.0	0.0	1	1.034586090570881	-17.61725801076986	132.0	1	1.1	0.9				
	260	1	0.0	0.0	0.0	0.0	1	1.0159627572267977	19.68135844072	132.0	1	1.1	0.9				
	262	1	0.0	0.0	0.0	0.0	1	1.0480814221050303	-19.48749610012415	132.0	1	1.1	0.9				
	266	1	0.0	0.0	0.0	0.0	1	1.0509188939258918	6.502851569373458	132.0	1	1.1	0.9				
	267	1	0.0	0.0	0.0	0.0	1	1.0321918594066757	14.231865359599182	132.0	1	1.1	0.9				
	274	1	0.0	0.0	0.0	0.0	1	1.0409000730421858	-17.47225454115026	132.0	1	1.1	0.9				
	275	1	0.0	0.0	0.0	0.0	1	1.0339117260139985	-17.25538827427879	132.0	1	1.1	0.9				
	276	1	0.0	0.0	0.0	0.0	1	1.0513606919645264	-9.54308294319524	132.0	1	1.1	0.9				
	277	1	203.87594577353522	25.62248387012746	0.0	0.0	1	1.028641930554959	-18.53098306101975	132.0	1	1.1	0.9				
	278	1	0.0	0.0	0.0	0.0	1	1.007184707162075	9.585370274474228	132.0	1	1.1	0.9				
	280	1	0.0	0.0	0.0	0.0	1	1.0375793290551727	-9.246670039598175	132.0	1	1.1	0.9				
	281	1	43.9363375970336	14.543146439644552	0.0	0.0	1	1.0152391779693697	7.674094842060058	132.0	1	1.1	0.9				
	282	1	306.330305398143	87.86621696319722	0.0	0.0	1	1.0496218862317197	-18.63898455865734	132.0	1	1.1	0.9				
	285	1	4.885595035588369	-2.2717689439412205	0.0	0.0	1	1.0794993607379386	19.69016202282113	132.0	1	1.1	0.9				
	286	1	1.2093977393467001	-1.7519469725377903	0.0	0.0	1	1.0411074268670295	11.08851785268057	132.0	1	1.1	0.9				
	287	1	40.13490334377231	12.28737227329099	0.0	0.0	1	1.014283279184269	7.612454075130282	132.0	1	1.1	0.9				
	289	1	0.0	0.0	0.0	0.0	1	1.027526367358434	4.181391619507622	132.0	1	1.1	0.9				
	290	1	0.0	0.0	0.0	0.0	1	1.0292814706209357	17.10275628896928	132.0	1	1.1	0.9				
	292	1	3.9421924761706	1.0870810351701	0.0	0.0	1	1.014696050495394	10.19036475608192	132.0	1	1.1	0.9				
	293	1	0.0	0.0	0.0	0.0	1	1.02434792616704	-4.96859239540672	132.0	1	1.1	0.9				
	294	1	70.1030697944441	-6.366211994015471	0.0	0.0	1	1.0182793447947824	-4.170840763072679	132.0	1	1.1	0.9				
	295	1	0.0	0.0	0.0	0.0	1	1.0513160273004833	-9.391358334788332	132.0	1	1.1	0.9				
	297	1	0.0	0.0	0.0	0.0	1	1.0230237477105282	-12.57301683889371	132.0	1	1.1	0.9				
	298	1	56.5302091811327	23.0592977447903	0.0	0.0	1	1.0325355755159726	-16.33377428883404	132.0	1	1.1	0.9				
	299	1	146.83071120016248	51.38690391258993	0.0	0.0	1	1.0194770127116235	8.187855035628033	132.0	1	1.1	0.9				
	300	1	45.9193398580251	15.506659145859071	0.0	0.0	1	1.0196711630929016	8.379479653519082	132.0	1	1.1	0.9				
	301	1	0.0	0.0	0.0	0.0	1	1.0319818262741114	18.719126884013	132.0	1	1.1	0.9				
	302	1	0.404248638995923	4.447667801138801	0.0	0.0	1	1.0465001204496274	-19.12595225555424	132.0	1	1.1	0.9				
	303	1	0.0	0.0	0.0	0.0	1	1.0022554055171835	-5.076054615061028	132.0	1	1.1	0.9				
	304	1	0.0	0.0	0.0	0.0	1	1.0130734023743	18.889010976380675	132.0	1	1.1	0.9				
	305	1	0.0	0.0	0.0	0.0	1	1.033280419109938	10.70698070187351	132.0	1	1.1	0.9				
	306	1	0.0	0.0	0.0	0.0	1	1.025774620014638	-13.97758682035693	132.0	1	1.1	0.9				
	307	1	39.05865040459787	10.939024256846311	0.0	0.0	1	1.013449198464946	-2.136527142239216	132.0	1	1.1	0.9				
	308	1	0.0	0.0	0.0	0.0	1	1.0483732074499053	12.27493669550901	132.0	1	1.1	0.9				
	310	1	0.0	0.0	0.0	0.0	1	1.060901708393962	17.93314744353913	132.0	1	1.1	0.9				
	311	1	74.9001360262951	14.147087198363613	0.0	15.835089740902204	1	1.0152424823007884	15.07249015472151	33.0	1	1.1	0.9				
	312	1	0.0	0.0	0.0	0.0	1	1.015261549583419	15.071751459862233	33.0	1	1.1	0.9				
	313	1	2.129260653318655	-0.9918092056268359	0.0	0.0	1	1.0356356382190652	-16.73519823153621	132.0	1	1.1	0.9				
	314	1	25.061041035414497	7.496888011842179	0.0	0.0	1	1.0274795427367598	-15.799738469232551	132.0	1	1.1	0.9				
	315	1	0.0	0.0	0.0	0.0	1	1.0097033577870758	5.248474252784806	132.0	1	1.1	0.9				
	317	1	0.0	0.0	0.0	0.0	1	1.0476037399691698	12.29367403115046	132.0	1	1.1	0.9				
	319	1	0.0	0.0	0.0	0.0	1	1.0453241536544267	-18.9207130262469	132.0	1	1.1	0.9				
	321	1	0.0	0.0	0.0	0.0	1	0.9155180434298781	21.979662673219	132.0	1	1.1	0.9				
	323	1	40.0287122888974	22.0998052462132	0.0	0.0	1	1.0502150063523605	-18.54005626946732	132.0	1	1.1	0.9				
	324	1	0.0	0.0	0.0	0.0	1	1.0360408992512666	9.940302243662513	132.0	1	1.1	0.9				
	325	1	0.0	0.0	0.0	0.0	1	1.0590709299302552	-5.232630380891593	132.0	1	1.1	0.9				
	326	1	0.0	0.0	0.0	0.0	1	1.0528726801796289	-8.271103113215371	132.0	1	1.1	0.9				
	327	1	0.0	0.0	0.0	0.0	1	1.021462269930672	0.9405103543849151	132.0	1	1.1	0.9				
	328	1	0.0	0.0	0.0	0.0	1	1.026440560604787	7.487738152566173	132.0	1	1.1	0.9				
	329	1	0.0	0.0	0.0	0.0	1	1.049858643253906	-9.726600562587835	132.0	1	1.1	0.9				
	331	1	42.58913924256489	15.75749119205894	0.0	0.0	1	1.0307667540472403	-16.09825661285475	132.0	1	1.1	0.9				
	334	1	26.454673812920205	1.9926384834664899	0.0	0.0	1	1.029040492748484	-17.69302319835029	132.0	1	1.1	0.9				
	336	1	27.067598492527402	8.24960723633594	0.0	0.0	1	1.0510810721138986	-18.529658130663474	132.0	1	1.1	0.9				
	337	1	20.8905655667963	6.68858540432662	0.0	0.0	1	1.0512621448945136	-18.50407372202234	132.0	1	1.1	0.9				
	338	1	11.543637485840819	2.373683428891138	0.0	0.0	1	1.0566278278135244	-5.54081718060678	132.0	1	1.1	0.9				
	339	1	0.0	0.0	0.0	0.0	1	1.0162100807365908	-12.76725924705626	132.0	1	1.1	0.9				
	340	1	0.0	0.0	0.0	0.0	1	1.007602287681378	9.844200666646493	132.0	1	1.1	0.9				
	342	1	19.157369922016944	5.23623543561995	0.0	0.0	1	1.0511007983904266	-18.50181158758643	132.0	1	1.1	0.9				
	343	1	24.1752477316572	11.13387104953448	0.0	0.0	1	1.0504062330208537	-18.50676487768983	132.0	1	1.1	0.9				
	344	1	0.0	0.0	0.0	0.0	1	1.0036059444412158	-4.9353447001882484	132.0	1	1.1	0.9				
	346	1	47.724204605875	10.319712196929611	0.0	0.0	1	1.0272669468470386	-15.825403250546922	132.0	1	1.1	0.9				
	348	1	7.245990201796167	-0.08933750127698303	0.0	0.0	1	1.0601256324270432	-8.49424787381099	132.0	1	1.1	0.9				
	349	1	21.3296455351594	2.4644022689636795	0.0	0.0	1	1.0141415357989325	10.82082760163383	66.0	1	1.1	0.9				
	350	1	13.1037097620226	8.37518649364309	0.0	0.0	1	1.0228208966768613	9.76819717433241	132.0	1	1.1	0.9				
	352	1	2.6718542840043105	3.5069041630016597	0.0	0.0	1	1.0238671911797608	8.415787875674646	132.0	1	1.1	0.9				
	353	1	39.39753656634649	-0.0852219480829313	0.0	0.0	1	1.0230605090969984	8.176538844779712	132.0	1	1.1	0.9				
	356	1	23.327797598638426	7.2734041226163	0.0	0.0	1	1.052186434150731	-11.20051851831504	132.0	1	1.1	0.9				
	357	1	0.0	0.0	0.0	0.0	1	1.0402902648569627	11.07610353612419	132.0	1	1.1	0.9				
	361	1	183.63824041281353	40.98910149670978	0.0	0.0	1	1.006628642900223	-19.44184024916023	33.0	1	1.1	0.9				
	363	1	39.134712248537596	16.9439584413141	0.0	0.0	1	1.0308384915831605	-15.706790133490077	132.0	1	1.1	0.9				
	364	1	28.384473654257597	8.36994347241894	0.0	0.0	1	1.0515337926068908	-18.48708741612752	132.0	1	1.1	0.9				
	365	1	17.818989703028457	9.36089918079669	0.0	0.0	1	1.0516374123336014	-18.47096612781809	132.0	1	1.1	0.9				
	366	1	12.073728368699802	3.07963048868626	0.0	0.0	1	1.0438895100287842	-18.83946414680987	132.0	1	1.1	0.9				
	367	1	0.0	0.0	0.0	0.0	1	1.0232274149931138	-7.78159471052962	132.0	1	1.1	0.9				
	369	1	0.0	0.0	0.0	0.0	1	1.0256498429380363	-8.99196532901019	132.0	1	1.1	0.9				
	370	1	12.0357959372923	0.42013064353438107	0.0	0.0	1	1.0251315983253455	-9.067183837358092	132.0	1	1.1	0.9				
	372	1	19.212638828279452	4.42512560178912	0.0	0.0	1	1.0480028044543583	-9.650099340311183	132.0	1	1.1	0.9				
	374	1	30.722141716576402	19.5349067160612	0.0	0.0	1	1.049550752634135	-18.54226025547346	132.0	1	1.1	0.9				
	375	1	0.0	0.0	0.0	0.0	1	1.0109610584767799	7.42817484387938	33.0	1	1.1	0.9				
	377	1	0.0	0.0	0.0	0.0	1	1.0361546150932957	10.31389333747962	132.0	1	1.1	0.9				
	379	1	8.925309504309018	6.697655843216932	0.0	0.0	1	1.0516787366281999	-18.49773300369048	132.0	1	1.1	0.9				
	380	1	16.78629824813605	14.91149220003895	0.0	0.0	1	1.0514478617151304	-18.501555272165184	132.0	1	1.1	0.9				
	384	1	0.0	0.0	0.0	0.0	1	1.0396008764685962	3.610925692708377	132.0	1	1.1	0.9				
	385	1	0.0	0.0	0.0	0.0	1	1.0460787631281212	-19.09353705425325	132.0	1	1.1	0.9				
	387	1	10.7727075642647	2.45386859814911	0.0	0.0	1	1.0281119220799961	18.31934141796879	132.0	1	1.1	0.9				
	388	1	53.8821275448623	13.08299100709916	0.0	0.0	1	1.0410862332897213	3.132102710802497	132.0	1	1.1	0.9				
	389	1	148.92321572476018	-3.7634940210189693	0.0	0.0	1	1.0519327339422007	-11.17472374175513	132.0	1	1.1	0.9				
	392	1	4.3180960475086705	0.5154075127252381	0.0	0.0	1	1.030713336022082	-7.71700577913575	132.0	1	1.1	0.9				
	393	1	0.0	0.0	0.0	0.0	1	1.0378809310984045	-14.697885582367558	132.0	1	1.1	0.9				
	394	1	0.0	0.0	0.0	0.0	1	1.0385623702505455	7.14420234623509	132.0	1	1.1	0.9				
	395	1	0.234253788612597	-3.2682003359179	0.0	0.0	1	1.0368139052806613	-14.43514342435828	132.0	1	1.1	0.9				
	396	1	0.0	0.0	0.0	0.0	1	1.0158392063249742	-12.75979870198953	132.0	1	1.1	0.9				
	397	1	0.0	0.0	0.0	0.0	1	1.0158356298417712	-12.75983016011087	132.0	1	1.1	0.9				
	398	1	156.3662939499472	37.8797581592831	0.0	0.0	1	1.0395868881997736	-16.60703932354687	132.0	1	1.1	0.9				
	401	1	74.2226343486775	22.05492030875552	0.0	-99.2070401832461	1	1.018939231028172	-13.25084092104278	132.0	1	1.1	0.9				
	406	1	0.0	0.0	0.0	0.0	1	1.0250213371713521	14.08237200743388	132.0	1	1.1	0.9				
	408	1	30.33861132697958	9.55786679800786	0.0	0.0	1	1.044407400960956	3.419230623416775	132.0	1	1.1	0.9				
	410	1	0.0	0.0	0.0	0.0	1	1.0118513004612697	-9.75562019956776	132.0	1	1.1	0.9				
	411	1	0.0	0.0	0.0	0.0	1	1.0453251972450017	4.367140709753039	132.0	1	1.1	0.9				
	415	1	0.0	0.0	0.0	0.0	1	1.0299626682241394	4.103847323722868	132.0	1	1.1	0.9				
	420	1	108.54805770472944	-2.218421861264757	0.0	0.0	1	1.0300343287076326	-8.77262922852057	132.0	1	1.1	0.9				
	422	1	20.92114256412834	2.399831678306691	0.0	0.0	1	1.0343219627633682	-12.77334351241345	132.0	1	1.1	0.9				
	424	1	0.0	0.0	0.0	0.0	1	1.0349781850908546	-8.466269834440247	132.0	1	1.1	0.9				
	425	1	28.055727169051803	7.367766584916039	0.0	0.0	1	1.0080060671291804	-7.024139192200767	132.0	1	1.1	0.9				
	426	1	0.0	0.0	0.0	0.0	1	1.0007516510241468	-8.467735593743534	66.0	1	1.1	0.9				
	427	1	32.3023203981607	4.51745067196455	0.0	0.0	1	0.9955049805691817	-10.39160239720963	132.0	1	1.1	0.9				
	428	1	-48.5122753378341	0.0	0.0	-13.882298019035302	1	0.9948490208470722	-7.267246440178194	33.0	1	1.1	0.9				
	429	1	36.362009877435106	-3.39545045061889	0.0	0.0	1	0.9927371227350636	-10.02163501512979	132.0	1	1.1	0.9				
	430	1	80.32185143470119	3.71989239415777	0.0	0.0	1	1.0309812157510092	-17.39419905407153	132.0	1	1.1	0.9				
	436	1	0.0	0.0	0.0	0.0	1	1.004954455463716	-2.806764532363216	132.0	1	1.1	0.9				
	437	1	35.530706723075	-6.55735906660613	0.0	0.0	1	1.0345247327674325	-17.83513735014143	132.0	1	1.1	0.9				
	438	1	0.0	0.0	0.0	0.0	1	1.0343276375847523	-17.59152041603848	132.0	1	1.1	0.9				
	439	1	0.0	0.0	0.0	0.0	1	1.0487362623907688	5.788569852494066	132.0	1	1.1	0.9				
	440	1	0.0	0.0	0.0	0.0	1	1.014217690469269	7.347100789078674	132.0	1	1.1	0.9				
	441	1	0.0	0.0	0.0	0.0	1	1.0233490678136015	8.170663441308735	132.0	1	1.1	0.9				
	442	1	15.413062602840503	-0.31732671870878	0.0	0.0	1	1.0436523615605757	-16.12153795916188	132.0	1	1.1	0.9				
	444	1	9.809992313347758	0.4668915359380191	0.0	0.0	1	1.0488745443039174	-9.901299637179381	132.0	1	1.1	0.9				
	445	1	0.0	0.0	0.0	0.0	1	1.0139044435716227	0.7681217718832358	132.0	1	1.1	0.9				
	446	1	57.43071290127839	23.376606220889038	0.0	0.0	1	1.0320255058131067	-16.99912743224469	132.0	1	1.1	0.9				
	447	1	124.3923881613149	53.9825750993497	0.0	0.0	1	1.0129434485409985	0.7808170436093478	132.0	1	1.1	0.9				
	449	1	0.0	0.0	0.0	0.0	1	1.0241566966026545	-14.439925018731522	132.0	1	1.1	0.9				
	450	1	247.18797321637692	51.754791627435715	0.0	0.0	1	1.014754016544965	-5.639740754371652	132.0	1	1.1	0.9				
	451	1	0.0	0.0	0.0	0.0	1	1.0516526018032673	-18.48077593997575	132.0	1	1.1	0.9				
	452	1	0.0	0.0	0.0	0.0	1	1.0516945777382576	-18.47856840265137	132.0	1	1.1	0.9				
	454	1	19.067126095181056	5.318302226226966	0.0	0.0	1	1.0415666191329191	-8.371819440360301	132.0	1	1.1	0.9				
	455	1	32.460890445612705	0.43268733118674696	0.0	0.0	1	1.0473961636197098	-9.339769092199194	132.0	1	1.1	0.9				
	458	1	5.0364285866841705	0.4205918960349169	0.0	0.0	1	1.035931190742759	-14.32278261772342	132.0	1	1.1	0.9				
	459	1	0.0	0.0	0.0	0.0	1	1.0229229621777356	-16.09850381738065	132.0	1	1.1	0.9				
	463	1	0.0	0.0	0.0	0.0	1	1.020832159543594	-4.427378014371953	132.0	1	1.1	0.9				
	464	1	0.0	0.0	0.0	0.0	1	1.0089585120727014	-9.02306932085172	132.0	1	1.1	0.9				
	465	1	1.305299085441975	0.9856024558254519	0.0	0.0	1	1.0257339491348954	10.06688515650831	132.0	1	1.1	0.9				
	466	1	11.940483781928428	2.39577703865114	0.0	0.0	1	1.0222325336821152	8.47619210711263	132.0	1	1.1	0.9				
	468	1	90.3345316032439	30.22093022731833	0.0	0.0	1	1.0593802208492682	-8.54616893829809	132.0	1	1.1	0.9				
	469	1	0.0	0.0	0.0	0.0	1	1.0461152400004554	-19.08932297484541	132.0	1	1.1	0.9				
	470	1	62.84958307602702	-1.04273484141156	0.0	0.0	1	1.0465681569769199	22.74569212361742	132.0	1	1.1	0.9				
	471	1	0.0	0.0	0.0	0.0	1	1.072160829147553	29.004668172114044	132.0	1	1.1	0.9				
	472	1	0.0	0.0	0.0	0.0	1	1.0493989935322592	23.14880640379408	132.0	1	1.1	0.9				
	473	1	36.30416601743712	14.165393191207	0.0	0.0	1	1.029174137805738	22.19175957394336	66.0	1	1.1	0.9				
	474	1	0.0	0.0	0.0	0.0	1	1.01963583316007	-12.14985495255223	132.0	1	1.1	0.9				
	477	1	17.325075152052328	2.7241302967316	0.0	0.0	1	1.0511296108968446	-18.50823936564544	132.0	1	1.1	0.9				
	479	1	44.2435090154991	24.8742950293424	0.0	0.0	1	1.0285529976080636	-17.65652100476579	132.0	1	1.1	0.9				
	487	1	0.0	0.0	0.0	0.0	1	1.0360002483400574	-9.909998158581045	132.0	1	1.1	0.9				
	488	1	0.0	0.0	0.0	0.0	1	1.0650080243646038	20.2372633709533	132.0	1	1.1	0.9				
	489	1	14.443465738655197	3.79346401580512	0.0	0.0	1	1.0126033666070855	10.76957711131875	66.0	1	1.1	0.9				
	490	1	35.6361231990842	-0.331702422385104	0.0	0.0	1	1.037815755554562	-25.50903545193301	11.0	1	1.1	0.9				
	491	1	37.37692512202407	3.7867029066234	0.0	0.0	1	1.0267196963505532	-10.04887797553116	66.0	1	1.1	0.9				
	492	1	32.9085874354015	7.71436849643532	0.0	0.0	1	1.0289679231930744	-13.875879017939722	66.0	1	1.1	0.9				
	493	1	0.0	0.0	0.0	0.0	1	1.0411074268670266	11.08851785268057	66.0	1	1.1	0.9				
	494	1	13.651130227223781	-4.989302688580609	0.0	0.0	1	1.0318492322536719	3.456715512140338	66.0	1	1.1	0.9				
	495	1	0.0	0.0	0.0	0.0	1	1.0316426307550872	3.52800553229522	11.0	1	1.1	0.9				
	496	1	0.0	0.0	0.0	0.0	1	1.0312614872042782	3.581537797173044	11.0	1	1.1	0.9				
	497	1	41.0646288599506	4.40060743623958	0.0	0.0	1	1.0245259455094715	14.995087306203612	66.0	1	1.1	0.9				
	498	1	27.815235608459105	-1.7848497562562122	0.0	0.0	1	1.0023953277132447	-6.518084795103473	66.0	1	1.1	0.9				
	499	1	96.0030458944804	20.01090188098545	0.0	0.0	1	1.0176131943167885	-15.806668512466391	66.0	1	1.1	0.9				
	500	1	23.338663735989	6.34700787033336	0.0	0.0	1	1.003201335710484	3.9466348307671386	66.0	1	1.1	0.9				
	502	1	9.49779156317864	0.399902283367887	0.0	0.0	1	1.0358432940454203	9.683835757968618	66.0	1	1.1	0.9				
	503	1	19.847578751075687	2.84812939842175	0.0	0.0	1	1.0571853819271804	-7.510133486124051	66.0	1	1.1	0.9				
	504	1	0.46670351488785805	-0.0161115990020335	0.0	0.0	1	1.0710368295255164	-4.449806545715478	11.0	1	1.1	0.9				
	505	1	0.0	0.0	0.0	0.0	1	1.0709969968476019	-4.381686630838724	11.0	1	1.1	0.9				
	506	1	0.09922998319845651	-0.8004367714114021	0.0	0.0	1	1.0424746515345518	11.0576118297646	66.0	1	1.1	0.9				
	507	1	67.7720564088253	18.27091536921027	0.0	0.0	1	0.9839575640532763	-27.81877086447464	11.0	1	1.1	0.9				
	508	1	9.102645609357394	3.427544322311509	0.0	0.0	1	1.0566940544985464	-8.975895841387652	11.0	1	1.1	0.9				
	510	1	0.0	0.0	0.0	0.0	1	1.0568296234248873	-8.977279952476954	11.0	1	1.1	0.9				
	511	1	3.7967742685195995	2.63118592091161	0.0	0.0	1	1.0760494684867072	-12.58361880055687	33.0	1	1.1	0.9				
	512	1	0.0	0.0	0.0	0.0	1	1.0232744868170418	-3.916635651416714	33.0	1	1.1	0.9				
	513	1	3.85065853295568	2.52628405379481	0.0	0.0	1	1.0760827356218572	-12.58470553393038	33.0	1	1.1	0.9				
	514	1	0.0	0.0	0.0	-137.936744852876	1	0.9813426339615521	-8.62230703347504	33.0	1	1.1	0.9				
	515	1	0.0	0.0	0.0	0.0	1	1.0440921782497927	-7.994786650079369	33.0	1	1.1	0.9				
	516	1	22.5639777740427	1.8923875535509498	0.0	0.0	1	1.044202846042891	11.64723971182789	66.0	1	1.1	0.9				
	517	1	23.3330353536967	9.00891567383017	0.0	0.0	1	1.0505783583882635	-18.50183453301836	132.0	1	1.1	0.9				
	518	1	50.6840043149452	18.048215211899297	0.0	0.0	1	1.05031089251085	-18.534902557911472	132.0	1	1.1	0.9				
	519	1	9.355660670996603	-1.7874206358314504	0.0	0.0	1	1.0465550815576476	-19.17381604488395	132.0	1	1.1	0.9				
	520	1	3.5502610337775695	2.8275296573007496	0.0	0.0	1	1.1002243906109235	5.311216981104636	33.0	1	1.2	0.8				
	521	1	0.0	0.0	0.0	0.0	1	1.0369462108878549	6.65536285875706	33.0	1	1.1	0.9				
	522	1	0.0	0.0	0.0	0.0	1	1.0391055552600832	6.701446959032117	33.0	1	1.1	0.9				
	523	1	53.85062851631311	12.04049320483581	0.0	0.0	1	1.0083281576238008	-25.84871266009927	11.0	1	1.1	0.9				
	524	1	45.5423067038432	-6.839752753830511	0.0	0.0	1	1.0360717978119516	6.207058384217887	66.0	1	1.1	0.9				
	525	1	0.0	0.0	0.0	0.0	1	1.0688984331974718	20.82992726308251	33.0	1	1.1	0.9				
	526	1	0.0	0.0	0.0	0.0	1	1.0689221962244269	20.829845949904	33.0	1	1.1	0.9				
	527	1	135.974627707605	40.91939113078279	0.0	0.0	1	0.9671337198179258	-13.07296560783813	66.0	1	1.1	0.9				
	528	1	0.0	0.0	0.0	0.0	1	1.027205639581501	-9.920771162257552	11.0	1	1.1	0.9				
	529	1	0.0	0.0	0.0	0.0	1	1.0277058832719672	-9.789413469626034	11.0	1	1.1	0.9				
	531	1	0.0	0.0	0.0	0.0	1	1.029453834974849	-13.8084177539412	11.0	1	1.1	0.9				
	532	1	0.0	0.0	0.0	0.0	1	1.0295308009336817	-13.785751867952811	11.0	1	1.1	0.9				
	533	1	3.3696771344079197	2.47858467733115	0.0	0.0	1	1.1057845099743844	5.553380158826604	33.0	1	1.2	0.8				
	535	1	3.26798870377522	2.66659293284044	0.0	0.0	1	1.058691260790381	6.333300075717504	33.0	1	1.1	0.9				
	536	1	32.2083603870078	8.09771245413106	0.0	0.0	1	1.0011916569608263	-15.439886065166851	11.0	1	1.1	0.9				
	537	1	153.59928812735942	5.487337296940128	0.0	0.0	1	1.0028156799442678	-14.737944035605421	66.0	1	1.1	0.9				
	538	1	15.192086924542703	6.423160151273009	0.0	0.0	1	1.0499405313663484	-4.923378661416018	66.0	1	1.1	0.9				
	539	1	15.6083108045605	6.58579114412889	0.0	0.0	1	1.0499850616010789	-4.919596750602012	66.0	1	1.1	0.9				
	540	1	0.0	0.0	0.0	0.0	1	1.0558754035717912	-6.426807055909417	33.0	1	1.1	0.9				
	541	1	0.0	0.0	0.0	0.0	1	1.055875403571792	-6.426807055909367	33.0	1	1.1	0.9				
	542	1	53.2578253711913	15.640309677941403	0.0	0.0	1	1.0149270869086617	-23.91597332016291	11.0	1	1.1	0.9				
	543	1	1.34021784564555	1.1810020390162201	0.0	0.0	1	1.0130665024515986	9.465810642716674	66.0	1	1.1	0.9				
	544	1	25.7212677929139	10.439146023329	0.0	0.0	1	1.0237536618595764	-21.78839755752464	11.0	1	1.1	0.9				
	545	1	37.54978946485959	4.9914600100955	0.0	0.0	1	1.017497121319449	-26.064819987216435	11.0	1	1.1	0.9				
	546	1	30.111314873995305	5.82582067433736	0.0	0.0	1	1.0220030298603473	-15.463749695878452	11.0	1	1.1	0.9				
	547	1	41.997228306665306	6.2927107429560305	0.0	0.0	1	0.98746343512484	-22.7699852026382	11.0	1	1.1	0.9				
	548	1	7.17046313801035	1.20565092250966	0.0	0.0	1	0.9877625010040227	-5.905387490347916	66.0	1	1.1	0.9				
	549	1	27.932951948812203	11.41139221383081	0.0	0.0	1	1.0379081420829392	-5.851266270110924	66.0	1	1.1	0.9				
	550	1	2.93367640063595	0.029366440789774097	0.0	0.0	1	0.9996661302223264	20.41000841858588	22.0	1	1.1	0.9				
	552	1	6.990865571744742	0.6859382097322956	0.0	0.0	1	1.0442253229940843	-9.761954056487546	33.0	1	1.1	0.9				
	553	1	0.0	0.0	0.0	0.0	1	1.022209967588398	9.710835676708164	33.0	1	1.1	0.9				
	554	1	0.0	0.0	0.0	15.134582585189499	1	1.077231076045599	9.35543921457831	33.0	1	1.1	0.9				
	555	1	83.45928648693999	35.6848109782537	0.0	0.0	1	1.0309852351271538	-12.76506580984674	33.0	1	1.1	0.9				
	556	1	74.1393060408265	0.577643759458047	0.0	10.332089640665801	1	1.061479973635079	-10.27607847331658	66.0	1	1.1	0.9				
	557	1	0.0	0.0	0.0	0.0	1	1.0575418070326135	-14.979925851150629	330.0	1	1.1	0.9				
	558	1	0.0	0.0	0.0	0.0	1	1.0400141769924005	-8.469905402965368	33.0	1	1.1	0.9				
	559	1	0.0	0.0	0.0	0.0	1	1.0399947577198563	-8.469140965826021	33.0	1	1.1	0.9				
	560	1	2.94860928124757	-0.572537157348078	0.0	0.0	1	1.050829557087914	6.277706787141387	66.0	1	1.1	0.9				
	561	1	9.75895882505178	1.5392968715541069	0.0	0.0	1	1.0471041781489974	5.500133343113689	11.0	1	1.1	0.9				
	562	1	45.5537968621744	12.07180622033943	0.0	0.0	1	1.0749817574599954	-17.00388021213094	33.0	1	1.1	0.9				
	563	1	126.7509534700803	1.534280079327383	0.0	0.0	1	1.0336023379953743	-19.57255995768467	33.0	1	1.1	0.9				
	564	1	38.0968672390442	-0.618437246588059	0.0	0.0	1	1.0393146009526613	-20.10065346110864	33.0	1	1.1	0.9				
	565	1	91.7722501381676	-6.61124917732179	0.0	0.0	1	1.0324422381518732	-23.60290115742714	33.0	1	1.1	0.9				
	566	1	18.41371809935859	5.44221468107821	0.0	0.0	1	1.038945468012293	8.479234100944907	66.0	1	1.1	0.9				
	567	1	0.0	0.0	0.0	0.0	1	1.0299692314781874	5.35448399919629	66.0	1	1.1	0.9				
	568	1	0.0	0.0	0.0	0.0	1	1.0450795543580365	8.33046755894779	66.0	1	1.1	0.9				
	569	1	16.58481589836977	11.51249269012911	0.0	0.0	1	1.0768673729687939	-12.57300249641485	33.0	1	1.1	0.9				
	570	2	0.0	0.0	0.0	0.0	1	1.0237899999982232	12.8918724508514	22.0	1	1.1	0.9				
	571	1	15.03801773753818	0.4457876790164971	0.0	0.0	1	1.0311466422483186	17.95286937122486	66.0	1	1.1	0.9				
	572	1	1.4796473837323492	0.35627091424968	0.0	0.0	1	1.007188782357549	10.62012192756138	66.0	1	1.1	0.9				
	573	1	19.0122171183966	7.134572004421059	0.0	0.0	1	1.0053046156105172	-16.63448364343378	33.0	1	1.1	0.9				
	575	1	0.0	0.0	0.0	0.0	1	1.0297917236103422	19.68795067059084	66.0	1	1.1	0.9				
	576	1	0.0	0.0	0.0	0.0	1	1.0414879338390448	22.70457796758403	66.0	1	1.1	0.9				
	577	1	23.1764743361951	1.19117251305445	0.0	0.0	1	1.0457949631597403	-0.2192699448673284	33.0	1	1.1	0.9				
	578	1	40.9980201621959	12.847746295046	0.0	0.0	1	1.0089011988128895	-13.98140463865956	66.0	1	1.1	0.9				
	579	1	37.97760783812062	7.856519432982438	0.0	8.110014498606322	1	1.039361395814962	6.089028381070766	66.0	1	1.1	0.9				
	580	1	106.64518520172169	10.807601357026952	0.0	0.0	1	1.0331225812225149	-14.81451941995178	33.0	1	1.1	0.9				
	581	1	7.0778117353734595	6.2130347762391	0.0	0.0	1	1.0224735878110327	9.233997502845527	132.0	1	1.1	0.9				
	582	1	-1.88206920590084	11.076387805541788	0.0	0.0	1	1.0449298087153656	8.335613097762915	66.0	1	1.1	0.9				
	583	1	5.56851138662919	0.129723592539411	0.0	0.0	1	1.0282594504516043	7.435916890431748	66.0	1	1.1	0.9				
	584	1	14.94754650877956	0.27306994068129	0.0	0.0	1	1.0216717216856033	7.22825709029067	66.0	1	1.1	0.9				
	585	1	0.0	0.0	0.0	0.0	1	1.0149999411157071	10.93893380169249	66.0	1	1.1	0.9				
	586	1	8.91972071331111	2.7283711471001197	0.0	0.0	1	1.0318384685139366	7.626234868211164	66.0	1	1.1	0.9				
	587	1	1.01595722773056	0.355317011995241	0.0	0.0	1	1.0138023160347798	10.86542807824181	66.0	1	1.1	0.9				
	588	1	19.468998386882973	3.4559436402873605	0.0	0.0	1	1.011370490214601	10.68697729467902	66.0	1	1.1	0.9				
	589	1	7.449695584312079	3.14453355850857	0.0	0.0	1	1.0424389191789956	8.17214121128923	66.0	1	1.1	0.9				
	590	1	6.488551926604201	4.97643151054973	0.0	0.0	1	1.1010644458909908	5.345717254579542	33.0	1	1.2	0.8				
	592	1	20.005432422843757	3.19648576191929	0.0	0.0	1	1.0511528260054765	-18.51449729451857	132.0	1	1.1	0.9				
	595	1	0.0	0.0	0.0	0.0	1	0.9537639575112281	10.29780569634634	33.0	1	1.1	0.9				
	598	1	70.0829089402803	-5.051231327439799	0.0	0.0	1	1.0512446140416734	-21.031284985157413	33.0	1	1.1	0.9				
	599	1	6.846033021336421	1.185359802347422	0.0	0.0	1	1.030132168364289	1.363034304310109	11.0	1	1.1	0.9				
	600	1	0.0	0.0	0.0	0.0	1	1.0267662977467609	3.610925692708378	11.0	1	1.1	0.9				
	601	1	22.913041498983006	1.011646005088091	0.0	0.0	1	1.0069522126167116	7.545775962451765	66.0	1	1.1	0.9				
	602	1	2.0035288930170205	-0.46453521557678495	0.0	0.0	1	1.0063033731049589	10.32712524214749	33.0	1	1.1	0.9				
	603	1	2.3568789448263106	-0.21428434385871503	0.0	0.0	1	1.0057496165660929	10.29219490034425	33.0	1	1.1	0.9				
	604	1	0.0	0.0	0.0	0.0	1	1.0085473387607082	10.28442367896564	66.0	1	1.1	0.9				
	605	1	0.0	0.0	0.0	0.0	1	1.0244897674761004	10.70339065258721	66.0	1	1.1	0.9				
	606	1	3.70438534856513	2.6696586556825803	0.0	0.0	1	1.0520874491568473	10.04625231238241	11.0	1	1.1	0.9				
	607	1	0.0	0.0	0.0	0.0	1	1.0617439408388654	10.703390652587192	11.0	1	1.1	0.9				
	608	1	29.3065270345151	5.258572018114851	0.0	0.0	1	1.0455851845856803	12.46984939563466	66.0	1	1.1	0.9				
	609	1	103.4451249093471	41.51260807489379	0.0	0.0	1	1.0520311634265047	-9.933757900580444	132.0	1	1.1	0.9				
	610	1	4.857283283434299	1.24628288624436	0.0	7.911372354999177	1	1.0144000389983332	4.084458765839569	66.0	1	1.1	0.9				
	611	1	34.719912809279705	2.4519014964825	0.0	12.5185407319479	1	1.065935879196778	2.229525871797688	66.0	1	1.1	0.9				
	612	1	36.17865755324917	6.922959991360182	0.0	0.0	1	0.9974164126990372	-22.50043958215343	11.0	1	1.1	0.9				
	613	1	57.7295707898397	14.189142892166739	0.0	8.030441348254676	1	1.0213552826944767	-10.10562911358669	66.0	1	1.1	0.9				
	614	1	24.80032472406043	3.5370488904160435	0.0	9.5067632580176	1	1.0006856153596175	-8.46530616993768	66.0	1	1.1	0.9				
	615	1	0.0	0.0	0.0	0.0	1	1.0274557959597728	-15.809040491317639	132.0	1	1.1	0.9				
	617	1	52.21132499656661	7.139697763894361	0.0	0.0	1	1.0379786067167078	-4.644930240996764	33.0	1	1.1	0.9				
	618	1	30.950897495025302	3.04136474914048	0.0	0.0	1	1.0518629825662682	-10.71338420442562	132.0	1	1.1	0.9				
	619	1	7.44858465061114	0.333228652507067	0.0	0.0	1	1.01854219856075	3.370911953244217	11.0	1	1.1	0.9				
	620	1	0.0	0.0	0.0	0.0	1	1.0357889011266816	5.78856985249424	11.0	1	1.1	0.9				
	621	1	57.150226817535646	11.315912317995956	0.0	7.99063875377178	1	0.9991419711921518	5.770830651494195	66.0	1	1.1	0.9				
	622	1	0.0	0.0	0.0	0.0	1	1.0383817510089612	-0.9740399852869757	33.0	1	1.1	0.9				
	623	1	0.0	0.0	0.0	0.0	1	1.0401749473564643	-0.6346132068433998	33.0	1	1.1	0.9				
	624	1	12.320100296616602	6.12015555141447	0.0	0.0	1	0.9990042788517199	-17.02590077482757	11.0	1	1.1	0.9				
	626	1	41.4392100594888	2.9868363854211233	0.0	0.0	1	1.0585930824822607	-11.119345280712801	66.0	1	1.1	0.9				
	627	1	26.64158648585211	4.58853678522222	0.0	0.0	1	1.0666765556926188	-11.1442829811721	33.0	1	1.1	0.9				
	628	1	40.238087486087	17.053646427150213	0.0	0.0	1	0.9725150409612245	-26.94346146726324	11.0	1	1.1	0.9				
	629	1	0.0	0.0	0.0	0.0	1	1.0590800372762623	21.55538797031453	33.0	1	1.1	0.9				
	630	1	14.94890711463764	7.0651868818190895	0.0	0.0	1	1.0457862225542558	21.29451410060017	66.0	1	1.1	0.9				
	632	1	28.386678739605372	7.31072880483535	0.0	0.0	1	1.0041449392673192	-20.932861160018394	11.0	1	1.1	0.9				
	633	1	2.28247238744795	0.586273124143481	0.0	0.0	1	1.029459614170877	5.373813335761616	66.0	1	1.1	0.9				
	634	1	30.0192596525771	4.37241490385612	0.0	0.0	1	1.0131780720073273	-15.60972994426417	11.0	1	1.1	0.9				
	635	1	39.10918753935455	4.2385376710117315	0.0	0.0	1	1.0586265859116335	17.90578922747738	33.0	1	1.1	0.9				
	636	1	5.71820972677711	-2.3636429420402703	0.0	19.612628245726192	1	1.0192112275241856	11.27415027476888	66.0	1	1.1	0.9				
	637	1	2.6457962595954503	2.1894860999582297	0.0	0.0	1	1.031911206741782	-16.0230238121609	33.0	1	1.1	0.9				
	638	1	19.54863211292792	5.10075168020744	0.0	0.0	1	1.0312055230014918	-16.60858078508467	11.0	1	1.1	0.9				
	639	1	0.0	0.0	0.0	0.0	1	1.0094282038713773	-19.14959557260752	33.0	1	1.1	0.9				
	640	1	0.0	0.0	0.0	0.0	1	1.009531106902081	-19.16116495606695	33.0	1	1.1	0.9				
	641	1	0.0	0.0	0.0	0.0	1	1.0073643683704692	-19.45817671796368	33.0	1	1.1	0.9				
	643	1	17.5632361167267	3.5442949379365896	0.0	0.0	1	1.0443717620104016	8.283211383537392	66.0	1	1.1	0.9				
	644	2	0.0	0.0	0.0	-11.543091140292123	2	1.0125667670305927	54.91160345397478	33.0	1	1.1	0.9				
	645	1	-12.400487943291699	0.0	0.0	0.0	2	1.0440081900042002	31.356581448973003	0.6899999999999998	1	1.1	0.9				
	646	1	-16.563881022247802	0.0	0.0	0.0	2	1.0204432641742165	33.12636861827381	0.6899999999999998	1	1.1	0.9				
	647	2	0.0	0.0	0.0	0.0	2	0.9708499999978247	36.03303953283742	13.8	1	1.1	0.9				
	648	2	0.0	0.0	0.0	0.0	2	0.9711999999978108	35.69922243360106	13.8	1	1.1	0.9				
	649	1	0.0	0.0	0.0	20.3065230660141	2	1.020646662420381	34.10973732345391	33.0	1	1.1	0.9				
	650	1	0.0	0.0	0.0	19.143381948582803	2	1.0193619055493546	34.29126527990972	33.0	1	1.1	0.9				
	651	2	0.0	0.0	0.0	0.0	2	1.0291599999976884	34.94767857052666	33.0	1	1.1	0.9				
	652	2	0.0	0.0	0.0	0.0	2	1.0302099999977177	35.39832767628959	33.0	1	1.1	0.9				
	653	1	0.0	0.0	0.0	0.0	2	0.9844423789648576	19.28179832852911	22.0	1	1.1	0.9				
	654	2	0.0	0.0	0.0	0.0	2	1.0643099999979166	42.23155053451341	0.6899999999999998	1	1.1	0.9				
	655	2	0.0	0.0	0.0	0.0	2	1.0596799999981261	45.30254358504396	0.6899999999999998	1	1.1	0.9				
	656	2	0.0	0.0	0.0	0.0	2	0.9771299999976308	29.33818903959212	11.0	1	1.1	0.9				
	657	1	0.0	0.0	0.0	0.0	2	0.9546273724859837	24.70556882601381	11.0	1	1.1	0.9				
	658	2	0.0893076585740782	0.0884848609473556	0.0	0.0	2	0.9745599999977684	34.43560842220889	15.5	1	1.1	0.9				
	659	2	0.0	0.0	0.0	0.0	2	1.0098799999972754	29.53339315146343	11.0	1	1.1	0.9				
	660	2	0.0	0.0	0.0	0.0	2	1.0121999999972753	29.51966302887628	11.0	1	1.1	0.9				
	661	2	0.0	0.0	0.0	0.0	2	1.0604899999970583	27.46729089321114	220.0	1	1.1	0.9				
	662	1	0.0	0.0	0.0	0.0	2	0.9723198803408135	22.94127794057608	17.0	1	1.1	0.9				
	663	1	0.0	0.0	0.0	0.0	2	0.9723198803408142	22.941277940576093	17.0	1	1.1	0.9				
	664	1	0.0	0.0	0.0	0.0	2	0.9697765878035888	23.80116148504987	17.0	1	1.1	0.9				
	665	2	0.07360570005029439	0.0781584249287844	0.0	0.0	2	0.9599599999981182	28.0279895582302	17.0	1	1.1	0.9				
	666	1	0.0	0.0	0.0	0.0	2	0.9723198884424313	22.941278381205393	15.0	1	1.1	0.9				
	667	1	0.0	0.0	0.0	0.0	2	0.9721070914034906	23.08003146222547	15.0	1	1.1	0.9				
	668	2	0.0433536336387042	0.0467908781440929	0.0	0.0	2	0.9663499999981113	26.93965890278896	15.0	1	1.1	0.9				
	669	1	0.0	0.0	0.0	0.0	2	0.9723198863744626	22.94127828151616	15.0	1	1.1	0.9				
	670	1	0.0	0.0	0.0	0.0	2	0.972319886374464	22.94127828151615	15.0	1	1.1	0.9				
	671	1	0.0	0.0	0.0	0.0	2	0.9720841313379412	23.21414013837256	15.0	1	1.1	0.9				
	672	2	0.046108789184317	0.0428978709062561	0.0	0.0	2	0.9724199999981106	26.93408212367382	15.0	1	1.1	0.9				
	673	1	0.0	0.0	0.0	0.0	2	0.9716384184636421	23.17742710716335	15.0	1	1.1	0.9				
	674	2	0.0429395555164665	0.04375657760538159	0.0	0.0	2	0.9636099999981107	26.89562001502277	15.0	1	1.1	0.9				
	675	1	0.0	0.0	0.0	0.0	2	0.9723198884424321	22.941278381205393	15.0	1	1.1	0.9				
	676	1	0.0	0.0	0.0	0.0	2	0.9238829380717869	35.94052528346685	10.5	1	1.1	0.9				
	677	2	0.0	0.0	0.0	0.0	2	0.9306599999980519	40.4866395761364	10.5	1	1.1	0.9				
	678	1	0.0	0.0	0.0	0.0	2	0.9238829380717869	35.94052528346685	10.5	1	1.1	0.9				
	679	1	0.0433001450244337	0.04369530380819919	0.0	0.0	2	0.9238397316871066	35.9362875367022	10.5	1	1.1	0.9				
	680	2	0.0714593282807618	0.0702238406734541	0.0	0.0	2	0.9573799999981323	43.01146496291546	10.5	1	1.1	0.9				
	681	2	0.0685315078463405	0.0689244811926037	0.0	0.0	2	0.9380299999981511	43.28991449311817	10.5	1	1.1	0.9				
	682	2	0.06858651151768859	0.0746841716375202	0.0	0.0	2	0.9476299999981398	43.1215714566309	10.5	1	1.1	0.9				
	683	2	0.0	0.0	0.0	0.0	2	1.0873399999965068	17.23265105683948	220.0	1	1.1	0.9				
	684	2	0.0	0.0	0.0	0.0	2	0.9889799999973815	31.815881017132863	15.75	1	1.1	0.9				
	685	2	0.0	0.0	0.0	0.0	2	0.9960299999974178	32.42625913596331	15.75	1	1.1	0.9				
	686	1	0.0	0.0	0.0	0.0	2	1.0233000804235475	34.67288754894098	21.0	1	1.1	0.9				
	687	2	30.7330869440481	21.546654364705102	0.0	0.0	2	1.0061799999977858	39.15915185440692	24.0	1	1.1	0.9				
	688	2	49.2048921859311	30.981598984707603	0.0	0.0	2	1.0117099999979462	41.52908692211944	21.0	1	1.1	0.9				
	689	2	44.4492790900692	29.052256582199004	0.0	0.0	2	0.9902999999979444	41.53948896540675	21.0	1	1.1	0.9				
	690	2	41.4067931137048	31.1884031072259	0.0	0.0	2	0.998909999998037	42.17255278238225	20.0	1	1.1	0.9				
	691	2	42.047680030390616	29.526598063297598	0.0	0.0	2	0.9968599999980564	42.43926823655872	20.0	1	1.1	0.9				
	692	1	0.0	0.0	0.0	0.0	2	0.9440146583825149	34.67281070600041	11.5	1	1.1	0.9				
	693	2	0.0	0.0	0.0	0.0	2	1.0652399999991415	47.13454874827759	0.6899999999999998	1	1.1	0.9				
	694	2	0.0	0.0	0.0	0.0	2	1.0729099999991267	46.81207520780323	0.6899999999999998	1	1.1	0.9				
	695	2	0.0	0.0	0.0	0.0	2	1.0777299999991428	47.18461940394756	0.6899999999999998	1	1.1	0.9				
	696	2	0.0	0.0	0.0	0.0	2	1.0746099999989962	43.90409885117123	0.6899999999999998	1	1.1	0.9				
	697	2	0.0	0.0	0.0	0.0	2	1.0769399999990095	44.18965188047179	0.6899999999999998	1	1.1	0.9				
	698	2	0.0	0.0	0.0	0.0	2	1.08352999999907	45.5835315952499	0.6899999999999998	1	1.1	0.9				
	699	2	0.0822368995671161	0.0853392213732936	0.0	0.0	2	0.9751699999977564	34.31917518272204	11.5	1	1.1	0.9				
	700	2	0.0805542713109404	0.0812393866575323	0.0	0.0	2	0.9754199999977287	33.56167681857859	11.5	1	1.1	0.9				
	701	2	0.0	0.0	0.0	0.0	2	0.9701499999977297	33.55668488525704	11.5	1	1.1	0.9				
	702	2	2.0279785892623496	0.89940664539272	0.0	0.0	2	0.9941299999987611	40.18689004000372	20.0	1	1.1	0.9				
	703	2	1.9344733449239297	0.8359173977880741	0.0	0.0	2	0.9889999999987391	39.67633770818622	20.0	1	1.1	0.9				
	704	1	6.791062040939461	2.2136897100674027	0.0	0.0	2	0.9956018013365409	29.60773248237458	11.0	1	1.1	0.9				
	705	1	2.83867607538979	2.416459847174211	0.0	0.0	2	0.9958640840472536	29.809952745723365	11.0	1	1.1	0.9				
	706	1	0.0	0.0	0.0	0.0	2	1.0328773553760164	35.46971271017249	11.0	1	1.1	0.9				
	707	2	0.0	0.0	0.0	0.0	2	0.9999037036198694	41.92749055026056	66.0	1	1.1	0.9				
	708	2	0.0	0.0	0.0	0.0	2	0.9908099999982619	46.854459611699276	11.0	1	1.1	0.9				
	709	1	0.0	0.0	0.0	0.0	2	0.9999037036198672	41.92749055026052	11.0	1	1.1	0.9				
	711	1	-12.5581507745981	0.0	0.0	-1.9958203605422684	2	1.0552499312936745	50.2389461678242	0.6899999999999998	1	1.1	0.9				
	712	2	28.389421854219798	19.7755909688836	0.0	0.0	2	0.9662499999974996	32.90632772292987	24.0	1	1.1	0.9				
	713	1	-13.584044715054297	0.0	0.0	-5.082986681889742	2	0.979023669211708	46.09390031785861	0.65	1	1.1	0.9				
	714	1	-16.4040159864128	0.0	0.0	-2.9745974592603703	2	1.017614294475345	45.82380734240311	0.65	1	1.1	0.9				
	715	2	0.0	0.0	0.0	0.0	2	1.0691399999989415	57.38148838321469	0.6899999999999998	1	1.1	0.9				
	716	1	0.0	0.0	0.0	0.0	2	1.0313920301998214	30.863070930945714	220.0	1	1.1	0.9				
	717	1	-60.403543384554204	0.0	0.0	-0.6417840429851788	2	0.981516098615954	36.56741257036473	22.0	1	1.1	0.9				
	718	1	-43.084699273509	0.0	0.0	-0.40307864109473296	2	0.9759932953439804	41.451500221194	22.0	1	1.1	0.9				
	719	1	-20.8482984288689	0.0	0.0	-0.26953107667714393	2	0.9764956066180019	40.40992160856489	22.0	1	1.1	0.9				
	720	1	-24.5875283879838	0.0	0.0	-0.2815214428454639	2	0.9760565815877845	41.26451501799774	22.0	1	1.1	0.9				
	721	2	0.0	0.0	0.0	75.03373719449161	2	0.9972699999967205	24.816746253643164	165.0	1	1.1	0.9				
	724	2	0.0	0.0	0.0	0.0	2	0.9586299999966199	20.80942034119419	10.5	1	1.1	0.9				
	725	2	0.0	0.0	0.0	0.0	2	0.9645799999966496	22.21838945690041	10.5	1	1.1	0.9				
	726	1	0.0	0.0	0.0	0.0	2	1.0150109127884628	26.58319509075113	11.0	1	1.1	0.9				
	727	1	0.0	0.0	0.0	0.0	2	1.0150109127884628	26.58319509075112	11.0	1	1.1	0.9				
	728	2	0.0	0.0	0.0	0.0	2	0.9999999999979367	39.68812411209097	12.0	1	1.1	0.9				
	729	2	0.04727787645086649	0.0465347684986889	0.0	0.0	2	0.9702899999976017	30.088147525788745	11.5	1	1.1	0.9				
	730	2	21.994129019313295	17.1773928644646	0.0	0.0	2	0.9918499999980335	43.63191105269308	20.0	1	1.1	0.9				
	731	2	21.5008671013484	17.558730970256	0.0	0.0	2	0.9728599999974434	35.343216259525896	20.0	1	1.1	0.9				
	732	2	33.5007157789878	19.0538795878291	0.0	0.0	2	0.9922299999974175	34.96328667073386	20.0	1	1.1	0.9				
	733	2	37.6543846465889	20.2329956645221	0.0	0.0	2	0.989559999997476	35.85982026824793	20.0	1	1.1	0.9				
	734	1	-22.867481542127198	0.0	0.0	0.0	2	1.1191266001439897	35.5899537369535	66.0	1	1.2	0.8				
	735	1	138.099319126361	35.2016740600468	0.0	0.0	2	1.046062291307949	16.20969543638537	66.0	1	1.1	0.9				
	737	1	0.0	0.0	0.0	0.0	2	1.0095543391989312	29.10012030614417	132.0	1	1.1	0.9				
	738	1	0.0	0.0	0.0	0.0	2	1.0318398199133303	31.7529122001448	132.0	1	1.1	0.9				
	739	1	0.0	0.0	0.0	0.0	2	0.9877167902374099	37.10649123661702	132.0	1	1.1	0.9				
	740	1	0.0	0.0	0.0	0.0	2	1.0114836927303446	24.97335347818883	132.0	1	1.1	0.9				
	741	1	29.9978272767177	6.303746532732291	0.0	0.0	2	1.0148599516209122	18.19745242804396	22.0	1	1.1	0.9				
	742	1	0.0	0.0	0.0	199.495642418042	2	1.02389479359291	22.7062448301524	220.0	1	1.1	0.9				
	743	1	0.0	0.0	0.0	0.0	2	1.0270836908151615	25.95824270988785	220.0	1	1.1	0.9				
	744	1	0.0	0.0	0.0	0.0	2	1.0364941520231346	30.30743375485155	220.0	1	1.1	0.9				
	745	1	0.0	0.0	0.0	0.0	2	1.066206279180686	27.6918245432317	220.0	1	1.1	0.9				
	746	1	0.0	0.0	0.0	0.0	2	1.0391178703768236	17.84691117420372	220.0	1	1.1	0.9				
	747	1	0.0	0.0	0.0	0.0	2	1.03180031538688	26.47749815790402	220.0	1	1.1	0.9				
	749	1	0.0	0.0	0.0	194.833526173606	2	1.029753439583925	21.92099424467876	220.0	1	1.1	0.9				
	751	1	0.0	0.0	0.0	0.0	2	1.0293753296471237	22.136262020715733	220.0	1	1.1	0.9				
	752	1	0.0	0.0	0.0	0.0	2	1.0389037801581105	19.703761638329322	220.0	1	1.1	0.9				
	753	1	0.0	0.0	0.0	0.0	2	0.9994914159174169	20.05967313949104	220.0	1	1.1	0.9				
	754	1	0.0	0.0	0.0	0.0	2	1.0104222156038478	22.31956694471671	220.0	1	1.1	0.9				
	756	1	0.0	0.0	0.0	0.0	2	1.0635490338094427	23.583242021674614	220.0	1	1.1	0.9				
	757	1	0.0	0.0	0.0	410.5885448865589	2	1.0123657147415706	22.10901272835968	220.0	1	1.1	0.9				
	758	1	0.0	0.0	0.0	0.0	2	1.0493858638064606	25.264576870873	220.0	1	1.1	0.9				
	761	1	0.0	0.0	0.0	0.0	2	1.037898864250145	17.86418898556296	220.0	1	1.1	0.9				
	762	1	0.0	0.0	0.0	0.0	2	1.04073141734993	20.40041453916079	220.0	1	1.1	0.9				
	763	1	0.0	0.0	0.0	0.0	2	1.0079366816836282	15.50217211884917	220.0	1	1.1	0.9				
	764	1	0.0	0.0	0.0	143.079156232998	2	1.0265782328339241	25.3393868590297	220.0	1	1.1	0.9				
	765	1	0.0	0.0	0.0	0.0	2	1.0445815582714937	27.48169870035374	220.0	1	1.1	0.9				
	772	1	0.0	0.0	0.0	0.0	2	1.0052295701868754	27.92287652112974	220.0	1	1.1	0.9				
	775	1	0.0	0.0	0.0	0.0	2	1.0150109127884652	26.58319509075114	132.0	1	1.1	0.9				
	776	1	27.3934093581763	10.801121262319391	0.0	0.0	2	1.008872442469117	21.63019381147092	220.0	1	1.1	0.9				
	779	1	0.0	0.0	0.0	0.0	2	1.0262361061788796	37.4852669461066	220.0	1	1.1	0.9				
	781	1	0.0	0.0	0.0	0.0	2	1.0561441579753095	17.26166088250239	220.0	1	1.1	0.9				
	782	1	0.0	0.0	0.0	198.91213114373397	2	1.0276028619264685	23.12183371095452	220.0	1	1.1	0.9				
	783	1	0.0	0.0	0.0	0.0	2	1.0306345320551191	21.962561083387623	220.0	1	1.1	0.9				
	786	1	0.0	0.0	0.0	0.0	2	0.9869244155817227	34.67281070600041	220.0	1	1.1	0.9				
	787	1	0.0	0.0	0.0	0.0	2	1.0177457459013304	38.68124101234562	132.0	1	1.1	0.9				
	794	1	0.0	0.0	0.0	0.0	2	1.0096840375413823	20.34051146536893	220.0	1	1.1	0.9				
	796	1	0.0	0.0	0.0	0.0	2	1.0271275880037158	25.33408697907297	220.0	1	1.1	0.9				
	797	1	0.0	0.0	0.0	0.0	2	1.0271614222991463	25.333766482279223	220.0	1	1.1	0.9				
	798	1	0.0	0.0	0.0	0.0	2	1.0277318422118547	21.99755949819509	220.0	1	1.1	0.9				
	800	1	0.0	0.0	0.0	199.19887247495387	2	1.014455037066262	20.80928458387114	220.0	1	1.1	0.9				
	803	1	0.0	0.0	0.0	0.0	2	0.9990847049426628	20.06211604797862	220.0	1	1.1	0.9				
	804	1	0.0	0.0	0.0	192.38662167452298	2	1.0214304760171413	19.63697966385608	220.0	1	1.1	0.9				
	805	1	0.0	0.0	0.0	0.0	2	1.0302542807874677	18.40282113120909	220.0	1	1.1	0.9				
	806	1	0.0	0.0	0.0	196.31135710515096	2	1.0396984866971068	20.35696920052357	220.0	1	1.1	0.9				
	807	1	0.0	0.0	0.0	0.0	2	1.03060497409165	21.324314908608052	220.0	1	1.1	0.9				
	811	1	0.0	0.0	0.0	0.0	2	1.0124597568092257	37.2004959694069	132.0	1	1.1	0.9				
	812	1	0.0	0.0	0.0	0.0	2	1.0134841085503254	24.895319586964042	220.0	1	1.1	0.9				
	813	1	0.0	0.0	0.0	0.0	2	1.032437238217559	29.07454790895678	220.0	1	1.1	0.9				
	814	1	0.0	0.0	0.0	0.0	2	1.0281879523224695	19.47406634584833	220.0	1	1.1	0.9				
	815	1	0.0	0.0	0.0	0.0	2	1.042083523181313	20.48239357937288	220.0	1	1.1	0.9				
	817	1	0.0	0.0	0.0	0.0	2	1.029314972054619	22.13660060782198	220.0	1	1.1	0.9				
	822	1	0.0	0.0	0.0	0.0	2	1.0024287945958177	29.478330400262283	220.0	1	1.1	0.9				
	823	1	0.0	0.0	0.0	0.0	2	1.0237023120942723	37.53049662600816	220.0	1	1.1	0.9				
	824	1	0.0	0.0	0.0	0.0	2	1.0371206736088459	21.85600290246651	220.0	1	1.1	0.9				
	825	1	0.0	0.0	0.0	0.0	2	1.0222625848284896	23.08795710721897	220.0	1	1.1	0.9				
	826	1	0.0	0.0	0.0	0.0	2	1.0344594764285133	23.23994614176192	330.0	1	1.1	0.9				
	827	1	0.0	0.0	0.0	-151.66557784192293	2	1.0194626718985782	22.9412784282054	330.0	1	1.1	0.9				
	828	1	0.0	0.0	0.0	0.0	2	1.0322008155706763	24.94292674169931	330.0	1	1.1	0.9				
	831	1	0.0	0.0	0.0	0.0	2	1.038048778886522	22.46915688797933	330.0	1	1.1	0.9				
	832	1	0.0	0.0	0.0	0.0	2	1.0620907885731898	34.91491099726692	275.0	1	1.1	0.9				
	833	1	212.5117920743858	34.8243513141602	0.0	0.0	2	1.010734627959485	16.13577497921416	66.0	1	1.1	0.9				
	834	1	0.0	0.0	0.0	0.0	2	1.0418947584691465	28.20503940120956	500.0	1	1.1	0.9				
	835	1	0.0	0.0	0.0	0.0	2	1.0365619856178674	33.9747944537383	500.0	1	1.1	0.9				
	836	1	0.0	0.0	0.0	0.0	2	1.0312955996739888	33.17666136415863	500.0	1	1.1	0.9				
	837	1	0.0	0.0	0.0	0.0	2	1.04037655437862	27.53245904221117	500.0	1	1.1	0.9				
	838	1	0.0	0.0	0.0	0.0	2	1.0360913314288451	34.67288754894098	500.0	1	1.1	0.9				
	839	1	0.0	0.0	0.0	-207.82212244812408	2	1.0442912206410735	28.54135580972614	500.0	1	1.1	0.9				
	840	1	0.0	0.0	0.0	0.0	2	1.0447962211422892	32.99501329840256	500.0	1	1.1	0.9				
	841	1	0.0	0.0	0.0	-198.46591675654045	2	1.026360517721799	32.88042429896562	500.0	1	1.1	0.9				
	842	1	0.0	0.0	0.0	0.0	2	1.0426310460289758	27.86101284893167	500.0	1	1.1	0.9				
	843	1	0.0	0.0	0.0	0.0	2	1.0422310028446866	28.12246210071431	500.0	1	1.1	0.9				
	844	1	0.0	0.0	0.0	0.0	2	1.042455349871639	27.89603724097199	500.0	1	1.1	0.9				
	845	1	0.0	0.0	0.0	0.0	2	1.0391495489857399	32.8819587412754	500.0	1	1.1	0.9				
	846	1	40.49919950362565	3.174785178791083	0.0	0.0	2	1.0440004550199131	18.9505362300869	66.0	1	1.1	0.9				
	847	1	6.343594905504779	0.5443504580912648	0.0	0.0	2	1.042730986394065	18.79311797788591	66.0	1	1.1	0.9				
	849	1	1.1293788691031281	1.962782475738642	0.0	0.0	2	1.009067985406847	27.71765611455102	66.0	1	1.1	0.9				
	850	1	57.801017255999895	15.277143267882419	0.0	0.0	2	1.0017018149568493	22.4984582561719	66.0	1	1.1	0.9				
	851	1	58.38449101720601	14.123100403187602	0.0	0.0	2	0.9900208978318991	21.70156601885226	66.0	1	1.1	0.9				
	852	1	10.836691047943201	3.12044231271967	0.0	0.0	2	0.9822646387116701	26.06769202330654	66.0	1	1.1	0.9				
	854	1	0.204617755515501	-0.5711166389006191	0.0	0.0	2	1.0421770232598715	18.72610953091215	66.0	1	1.1	0.9				
	855	1	10.5265827927633	5.5661581038584	0.0	0.0	2	1.0064267947848775	22.61392011046245	66.0	1	1.1	0.9				
	856	1	118.55678211398079	14.13131995403571	0.0	49.25613838480789	2	1.0168899464275707	14.01818471668398	66.0	1	1.1	0.9				
	857	1	152.55996295632195	46.6389730812297	0.0	0.0	2	1.0400164024998542	18.50703855879237	66.0	1	1.1	0.9				
	858	1	2.5417889700699874	9.361101481391444	0.0	0.0	2	1.0602018289298907	22.32458675301465	66.0	1	1.1	0.9				
	859	1	330.69317943798796	104.07458328287461	0.0	0.0	2	1.0089384409055828	16.38771233342114	66.0	1	1.1	0.9				
	860	1	17.0879305822702	0.872600366437994	0.0	0.0	2	0.9726980524251206	17.62304658070587	66.0	1	1.1	0.9				
	861	1	0.0	0.0	0.0	0.0	2	0.9834928899077741	19.28590360297999	66.0	1	1.1	0.9				
	862	1	0.0	0.0	0.0	0.0	2	1.0086895549935988	39.84824180904815	33.0	1	1.1	0.9				
	863	1	0.0	0.0	0.0	0.0	2	1.0031212843556419	42.93900262745468	33.0	1	1.1	0.9				
	864	1	0.0	0.0	0.0	0.0	2	1.030997562284866	24.70556882601372	66.0	1	1.1	0.9				
	865	1	0.0	0.0	0.0	0.0	2	0.994340766423584	19.87504502296836	66.0	1	1.1	0.9				
	866	1	189.14303184906544	51.9688561840335	0.0	51.1720506520942	2	1.0054889043166146	16.76137535338799	66.0	1	1.1	0.9				
	867	1	226.57980219011802	53.20424326505001	0.0	43.382317634834905	2	1.0197371656717902	16.04371500300585	66.0	1	1.1	0.9				
	868	1	243.0495142466644	66.2045387597053	0.0	0.0	2	1.0242701684405455	17.55672807328677	66.0	1	1.1	0.9				
	869	1	36.2239385383779	8.35585038005672	0.0	0.0	2	1.0200330277634329	15.50217806150692	66.0	1	1.1	0.9				
	870	1	43.33486306107266	16.846471228743198	0.0	0.0	2	0.9838416523871392	13.87751952419292	66.0	1	1.1	0.9				
	871	1	103.47999373875709	15.980379844340142	0.0	0.0	2	1.0144860053343752	22.0696106473285	66.0	1	1.1	0.9				
	872	1	187.3983877116477	41.528475597832596	0.0	0.0	2	1.0149024172158505	19.783991717961484	66.0	1	1.1	0.9				
	873	1	12.0520965928636	3.06284855525251	0.0	0.0	2	0.9934385199584951	19.88947528393453	66.0	1	1.1	0.9				
	874	1	28.873070921786002	-2.418692135308307	0.0	0.0	2	0.9899854249849279	26.75495362562794	66.0	1	1.1	0.9				
	875	1	9.355448515778589	-1.4468051014922598	0.0	0.0	2	0.9823000859441028	25.45260873627879	66.0	1	1.1	0.9				
	876	1	289.74397982934295	39.00720513859349	0.0	45.6182533805026	2	1.0465266443236003	14.419610587345861	66.0	1	1.1	0.9				
	877	1	0.0	0.0	0.0	0.0	2	1.0207784393983206	38.15336562601352	66.0	1	1.1	0.9				
	878	1	44.9090622685368	-2.120350672316546	0.0	30.4957432779484	2	0.9929464572834751	13.47736772214057	66.0	1	1.1	0.9				
	879	1	0.0	0.0	0.0	0.0	2	1.0334726412811348	43.93625273823322	66.0	1	1.1	0.9				
	880	1	0.0	0.0	0.0	0.0	2	1.0352174218420755	46.19102037039049	66.0	1	1.1	0.9				
	881	2	0.0	0.0	0.0	-0.333975848741801	2	0.9828999999985949	50.44299153697933	33.0	1	1.1	0.9				
	882	2	0.0	0.0	0.0	1.318796384148289	2	0.9813499999983485	47.11107476842814	33.0	1	1.1	0.9				
	883	1	267.49271304763005	116.570094811121	0.0	51.58451083106921	2	1.0034837956231455	15.645557642982332	66.0	1	1.1	0.9				
	884	1	208.06737457771402	70.02451123098248	0.0	0.0	2	1.0250912621878734	17.43748616138789	66.0	1	1.1	0.9				
	885	1	0.0	0.0	0.0	0.0	2	1.0480396348051662	23.12183371095448	66.0	1	1.1	0.9				
	886	1	1.1865668324528298	-3.4068777325794595	0.0	0.0	2	1.0234818229410212	24.28921748044828	66.0	1	1.1	0.9				
	887	1	74.98616880916622	20.1776398486976	0.0	0.0	2	1.0368412117913928	18.22598436085524	66.0	1	1.1	0.9				
	889	1	0.0	0.0	0.0	0.0	2	1.0248053419219398	41.47045029788891	66.0	1	1.1	0.9				
	890	1	19.938752185966038	0.0	0.0	0.0	2	1.0027719353896971	31.19766485557558	66.0	1	1.1	0.9				
	891	1	6.493231088791969	0.450657078794064	0.0	0.0	2	0.9909058445427912	21.46190690142074	66.0	1	1.1	0.9				
	892	1	13.219266937566271	6.411625216933709	0.0	0.0	2	0.956721029311477	17.31475481386906	66.0	1	1.1	0.9				
	895	1	157.8125694470862	21.81459971450883	0.0	0.0	2	1.004046668779776	31.65802373614381	66.0	1	1.1	0.9				
	897	1	92.77153486373922	8.48054292231733	0.0	0.0	2	1.0042217700329454	31.265046062620158	66.0	1	1.1	0.9				
	899	1	125.77465858915482	45.68180110603382	0.0	0.0	2	0.9873657562884449	16.83788388493356	66.0	1	1.1	0.9				
	900	1	0.0	0.0	0.0	0.0	2	1.0599256241955863	45.78398339413841	66.0	1	1.1	0.9				
	901	1	6.635115039953961	0.390992249250412	0.0	0.0	2	1.0043201676527163	37.99559874584768	66.0	1	1.1	0.9				
	902	1	0.0	0.0	0.0	0.0	2	1.0264971197130366	41.87904649139582	33.0	1	1.1	0.9				
	903	1	0.0	0.0	0.0	0.0	2	1.0045153899908688	41.37540915782636	33.0	1	1.1	0.9				
	904	1	0.0	0.0	0.0	0.0	2	1.050742958373633	49.70018696988218	66.0	1	1.1	0.9				
	905	1	0.0	0.0	0.0	0.0	2	0.9523186751263246	36.24247442575655	66.0	1	1.1	0.9				
	906	1	91.90029740851605	13.412241179768053	0.0	0.0	2	1.0451146862222669	19.9964389024704	66.0	1	1.1	0.9				
	907	1	307.208814631559	61.2424471180361	0.0	0.0	2	1.0808866504511971	15.09831657190064	66.0	1	1.1	0.9				
	908	1	163.97825275055789	36.2119666882158	0.0	44.516296207150404	2	1.0212060874260451	15.34236202208589	66.0	1	1.1	0.9				
	909	1	240.76320201148502	47.6937070925918	0.0	0.0	2	1.032251576882189	13.69521649577802	66.0	1	1.1	0.9				
	910	1	238.101766685382	38.2602275855889	0.0	0.0	2	1.0241546034001432	13.87934250315215	66.0	1	1.1	0.9				
	911	1	199.44462688039056	36.832832694997705	0.0	0.0	2	1.0250012222154299	17.86161383407409	66.0	1	1.1	0.9				
	912	1	196.2046264271701	39.8853895251268	0.0	0.0	2	1.0468356772716632	14.93847795870431	66.0	1	1.1	0.9				
	913	1	153.14663026529198	8.3328513422484	0.0	0.0	2	1.021743985416701	15.663733020389632	66.0	1	1.1	0.9				
	914	1	152.3938899810094	37.2278137360008	0.0	43.47567628626712	2	1.029642074635952	18.872649309863	66.0	1	1.1	0.9				
	915	1	108.91684699110061	17.73653415581519	0.0	24.27965605585369	2	1.0198456073735385	23.46524044354473	66.0	1	1.1	0.9				
	916	1	0.0	0.0	0.0	0.0	2	0.999581958136914	33.96466443327799	66.0	1	1.1	0.9				
	917	1	0.0	0.0	0.0	0.0	2	1.006706870991193	22.6096303717601	66.0	1	1.1	0.9				
	918	1	0.0	0.0	0.0	0.0	2	1.0201535774737627	23.45233102680564	66.0	1	1.1	0.9				
	919	1	177.64074572847602	42.2609093818087	0.0	52.29641066631301	2	1.0280937093990465	14.59288740815882	66.0	1	1.1	0.9				
	920	1	94.9355080157034	24.9918920543734	0.0	0.0	2	1.0181708498123823	14.522462018172092	66.0	1	1.1	0.9				
	921	1	8.93522284454042	-8.45543114831485	0.0	0.0	2	1.020285855125506	19.33642045859443	66.0	1	1.1	0.9				
	922	1	65.7025899507664	12.462136546823	0.0	0.0	2	1.0201940927978503	19.58099084861805	66.0	1	1.1	0.9				
	924	1	203.21835046518396	47.0125214305811	0.0	46.854393570073896	2	1.0275325541063658	14.67984123190643	66.0	1	1.1	0.9				
	925	1	250.886682327865	75.2659098594328	0.0	44.461175359315206	2	1.016996213047065	16.37123543133147	66.0	1	1.1	0.9				
	926	1	312.7942262876151	59.2539502974479	0.0	45.310513414409904	2	1.0167588102434768	15.79571614712965	66.0	1	1.1	0.9				
	927	1	0.0	0.0	0.0	0.0	2	1.0293437913519699	21.69717112830263	66.0	1	1.1	0.9				
	928	1	49.9697314549242	9.64136439354392	0.0	0.0	2	1.013106228624794	19.07545843587636	66.0	1	1.1	0.9				
	929	1	0.0956941313669085	-1.9854985006687202	0.0	0.0	2	1.0422473760135194	18.71967670027178	66.0	1	1.1	0.9				
	930	1	106.0663012333978	25.040631644287135	0.0	0.0	2	1.0253267938219868	19.19727433184988	66.0	1	1.1	0.9				
	931	1	0.0	0.0	0.0	0.0	2	0.9902773824518327	30.905097577846853	22.0	1	1.1	0.9				
	932	1	0.0	0.0	0.0	0.0	2	1.015037704632389	29.93835924583253	22.0	1	1.1	0.9				
	933	1	26.0975788163319	4.072104130566631	0.0	0.0	2	1.004845833725415	14.63998035148811	22.0	1	1.1	0.9				
	934	1	23.114235410739298	5.50902029942246	0.0	0.0	2	1.0025409596344017	15.078718003777972	22.0	1	1.1	0.9				
	935	1	53.900646728779506	29.37012123502397	0.0	0.0	2	1.0383508179735683	17.48871226576282	22.0	1	1.1	0.9				
	937	1	2.2201449029556897	0.542116818691604	0.0	0.0	2	1.0622110551393678	34.62262240089535	22.0	1	1.1	0.9				
	938	1	0.0	0.0	0.0	0.0	2	1.0628296706267668	34.67467386258773	22.0	1	1.1	0.9				
	940	1	17.247020462386782	12.065841074548189	0.0	0.0	2	0.9774371490262691	12.65642246330446	22.0	1	1.1	0.9				
	941	1	0.0	0.0	0.0	0.0	2	0.9962468899464141	28.56176492452555	22.0	1	1.1	0.9				
	943	1	0.0	0.0	0.0	0.0	2	0.9955470278351464	28.423061670635743	22.0	1	1.1	0.9				
	944	1	0.0	0.0	0.0	0.0	2	0.982494449820574	29.971079617994235	22.0	1	1.1	0.9				
	945	1	9.811215991287451	-0.540092039891565	0.0	0.0	2	0.9955203572134046	28.42368474690392	22.0	1	1.1	0.9				
	946	1	27.073185452813412	1.079881497351173	0.0	0.0	2	0.984515358635046	14.847211160462429	22.0	1	1.1	0.9				
	947	1	0.0	0.0	0.0	-1.0618595293047797	2	1.05844663542012	48.43322195969778	22.0	1	1.1	0.9				
	948	1	34.23133999622613	4.73765838458621	0.0	0.0	2	1.02338565120246	28.12182014808716	22.0	1	1.1	0.9				
	949	1	14.660295680244632	6.05878974450347	0.0	8.063901408016678	2	1.0326011007466669	19.91669396349026	22.0	1	1.1	0.9				
	951	1	74.54525855479466	12.14236255814922	0.0	0.0	2	1.0123753361747323	4.320499896510863	22.0	1	1.1	0.9				
	952	1	0.0	0.0	0.0	0.0	2	1.0612264685892367	19.63697966385606	22.0	1	1.1	0.9				
	953	2	0.21807601773063695	0.130920571727213	0.0	0.0	2	1.026439999996941	27.1117353954366	10.5	1	1.1	0.9				
	954	2	0.209234947958402	0.12278174251318	0.0	0.0	2	1.026019999996918	26.69461719421727	10.5	1	1.1	0.9				
	955	2	0.21457886436600204	0.12258108298135899	0.0	0.0	2	1.02718999999696	27.43262359814512	10.5	1	1.1	0.9				
	956	2	0.19329879948198803	0.122600849593244	0.0	0.0	2	1.0259199999969058	26.45833992671238	10.5	1	1.1	0.9				
	957	1	25.9747980747282	7.58698890198376	0.0	0.0	2	1.04094063737427	19.75589518093936	22.0	1	1.1	0.9				
	959	1	32.1558352832839	16.132912043721202	0.0	0.0	2	1.0457491038039424	19.35263664691344	22.0	1	1.1	0.9				
	963	1	25.327284327243504	8.39289081714982	0.0	0.0	2	1.0271109281661308	17.76062082854305	22.0	1	1.1	0.9				
	964	1	0.10484938732814	-0.0988192678010091	0.0	0.0	2	1.0052258933470455	17.6979459811081	11.0	1	1.1	0.9				
	965	1	0.09597261495422568	-0.0960365208331496	0.0	0.0	2	1.0051733381364847	17.70438910983491	11.0	1	1.1	0.9				
	966	1	11.15172447323142	5.853280208103355	0.0	0.0	2	0.9734332564936632	26.718712669612803	22.0	1	1.1	0.9				
	967	1	11.41564694619775	5.66524828921654	0.0	0.0	2	0.9742936359062858	26.6702798300567	22.0	1	1.1	0.9				
	968	1	10.4022201158452	2.55236077642562	0.0	0.0	2	1.03196577838679	16.77748930730352	11.0	1	1.1	0.9				
	969	1	0.0	0.0	0.0	0.0	2	1.048177281807741	21.63003876724637	33.0	1	1.1	0.9				
	970	1	0.0	0.0	0.0	0.0	2	0.9774371490262664	12.65642246330444	11.0	1	1.1	0.9				
	971	1	0.0	0.0	0.0	0.0	2	0.9774371490262654	12.65642246330444	11.0	1	1.1	0.9				
	972	1	0.0	0.0	0.0	0.0	2	0.9774371490262654	12.65642246330443	11.0	1	1.1	0.9				
	973	1	0.0	0.0	0.0	0.0	2	1.0593435272358536	44.0620933379448	33.0	1	1.1	0.9				
	974	1	0.0	0.0	0.0	0.0	2	1.0666246310560952	42.25668209568913	33.0	1	1.1	0.9				
	975	1	3.8686182659591104	2.4089230521896807	0.0	0.0	2	0.9824948747098253	29.971101819039085	11.0	1	1.1	0.9				
	977	1	0.0	0.0	0.0	0.0	2	1.0173106910649374	31.05561774737869	33.0	1	1.1	0.9				
	978	1	0.0	0.0	0.0	0.0	2	1.0173512496597543	31.06814280400861	33.0	1	1.1	0.9				
	979	1	464.72986456197435	94.32538326115818	0.0	67.6782710010186	2	1.024317297553892	26.43416040924381	33.0	1	1.1	0.9				
	980	1	0.0	0.0	0.0	0.0	2	1.0171196839677776	31.008755966722255	33.0	1	1.1	0.9				
	981	1	0.0	0.0	0.0	0.0	2	1.0326011007466647	19.91669396349024	11.0	1	1.1	0.9				
	982	1	0.0	0.0	0.0	0.0	2	1.0617154866256109	44.60612067907391	66.0	1	1.1	0.9				
	983	1	0.254900651419349	0.0515559675523546	0.0	0.0	2	0.9587081510669317	29.44380666743905	11.0	1	1.1	0.9				
	986	2	138.552599392959	0.0	0.0	73.68624611408448	2	1.011030000001766	22.7519887597966	165.0	1	1.1	0.9				
	987	1	0.260013003669307	-3.3239035728246007	0.0	-8.583069842379542	3	1.0283495431315726	45.75779211914119	132.0	1	1.1	0.9				
	988	1	0.0	0.0	0.0	-10.5808031294541	3	1.0234824138305105	40.94239479860202	132.0	1	1.1	0.9				
	989	1	0.0	0.0	0.0	-5.466385317603131	3	1.0262077023790948	39.30522634044053	132.0	1	1.1	0.9				
	990	1	0.0	0.0	0.0	0.0	3	1.0323362813760746	38.86660400542053	33.0	1	1.1	0.9				
	991	1	9.73569056401728	2.3500431913510003	0.0	0.0	3	1.0586627881895136	30.77614367913499	66.0	1	1.1	0.9				
	992	1	4.62348153453078	7.25765923178541	0.0	0.0	3	1.0537960653691603	30.62492093333232	66.0	1	1.1	0.9				
	993	1	8.780934178645722	-5.299832362078181	0.0	0.0	3	1.0446542061095188	27.22771519276427	66.0	1	1.1	0.9				
	994	1	24.827333741672504	5.52732802267294	0.0	5.08659301069565	3	1.0215070340372057	31.32765125900843	33.0	1	1.1	0.9				
	995	1	2.48683959767888	-0.959026231092867	0.0	0.0	3	1.02753720033805	50.55992324203639	6.6	1	1.1	0.9				
	996	1	0.0	0.0	0.0	0.0	3	1.0289021717767772	29.622987808735715	132.0	1	1.1	0.9				
	997	1	0.0	0.0	0.0	0.0	3	1.0290967552575576	29.971679460034263	132.0	1	1.1	0.9				
	998	1	37.9361193551301	5.13911492054295	0.0	0.0	3	0.9854764171626507	27.95464847398957	33.0	1	1.1	0.9				
	999	1	5.58108820901439	2.29674421937484	0.0	0.0	3	1.01323122252231	28.104051214675174	11.0	1	1.1	0.9				
	1000	1	7.04322950319638	2.45981465268456	0.0	0.0	3	1.0101745327894491	27.10776107644316	11.0	1	1.1	0.9				
	1001	1	0.0	0.0	0.0	0.0	3	1.0364131468162001	29.534620764806192	110.0	1	1.1	0.9				
	1003	1	15.3900378169748	11.8335031690924	0.0	0.0	3	1.098498381805655	27.510239652520784	33.0	1	1.1	0.9				
	1004	1	0.0	0.0	0.0	0.0	3	1.0337479247836963	21.4550658855622	110.0	1	1.1	0.9				
	1005	1	0.0	0.0	0.0	0.0	3	1.0337348764814718	21.49832949332153	110.0	1	1.1	0.9				
	1006	1	7.668817096640631	-0.295914825022407	0.0	0.0	3	1.0310037495537765	21.10553697414875	110.0	1	1.1	0.9				
	1007	1	79.8823462888885	36.8842467795345	0.0	19.640499741388506	3	1.0581579622983175	18.51431517412484	33.0	1	1.1	0.9				
	1008	1	0.0	0.0	0.0	0.0	3	1.036592902205884	33.04821078908506	132.0	1	1.1	0.9				
	1009	1	7.07437783976272	1.35382590689184	0.0	0.0	3	1.0703509781409957	31.70227678403744	66.0	1	1.1	0.9				
	1010	1	24.9157356170635	11.467470581965571	0.0	0.0	3	1.0161907348636712	38.50224444475263	132.0	1	1.1	0.9				
	1011	1	0.0	0.0	0.0	0.0	3	1.0292877452362879	37.65607415889777	132.0	1	1.1	0.9				
	1012	1	0.0	0.0	0.0	0.0	3	0.9778845414990055	37.13408634844784	110.0	1	1.1	0.9				
	1013	1	16.1757864933852	3.3093469356075897	0.0	0.0	3	0.9989475650532188	36.25593565346536	33.0	1	1.1	0.9				
	1015	1	0.0	0.0	0.0	0.0	3	1.0411693327675773	25.76635222234563	132.0	1	1.1	0.9				
	1016	1	33.430511216844096	1.8258550293195972	0.0	10.094007574953102	3	1.0211827130168332	24.2506086654335	33.0	1	1.1	0.9				
	1019	1	14.062288434931599	-2.45112358235521	0.0	0.0	3	1.0714553370537367	49.55557873105622	66.0	1	1.1	0.9				
	1020	1	1.81125079850936	-2.60214330289713	0.0	0.0	3	1.03316103799518	50.74518529860106	6.6	1	1.1	0.9				
	1021	1	1.04031343215331	-0.9063463668111709	0.0	0.0	3	1.0212929361904561	36.86754915883498	132.0	1	1.1	0.9				
	1022	1	68.7480104352174	12.9866376084909	0.0	0.0	3	1.0215092870672045	34.29862080376996	66.0	1	1.1	0.9				
	1025	1	54.0118393974642	33.022617220802196	0.0	0.0	3	0.9975638041247428	46.91580946814413	11.0	1	1.1	0.9				
	1026	1	3.1275597804050905	-0.457766438181046	0.0	0.0	3	1.0248520074786522	55.74274286325458	132.0	1	1.1	0.9				
	1027	1	0.0	0.0	0.0	0.0	3	1.0074816344705388	55.7427428632545	11.8	1	1.1	0.9				
	1028	1	0.0	0.0	0.0	0.0	3	1.0074816344705388	55.74274286325449	11.8	1	1.1	0.9				
	1029	1	0.0	0.0	0.0	0.0	3	1.0074816344705388	55.7427428632545	11.8	1	1.1	0.9				
	1030	1	0.0	0.0	0.0	0.0	3	1.0074816344705388	55.74274286325451	11.8	1	1.1	0.9				
	1031	1	0.0	0.0	0.0	0.0	3	1.007439738157707	55.03948696843567	132.0	1	1.1	0.9				
	1033	1	62.21852749079271	22.9226375778034	0.0	0.0	3	1.064421591900786	53.13763170160473	66.0	1	1.1	0.9				
	1034	1	0.0	0.0	0.0	0.0	3	1.0468016831212672	19.06582801863048	110.0	1	1.1	0.9				
	1035	1	45.2972273315787	12.83239761444702	0.0	19.8922508135438	3	1.0134216642931417	16.94209535398425	33.0	1	1.1	0.9				
	1036	1	0.0	0.0	0.0	0.0	3	1.023206773303602	54.60409346566247	132.0	1	1.1	0.9				
	1037	1	0.0	0.0	0.0	0.0	3	1.0222648268900538	55.34124902886768	132.0	1	1.1	0.9				
	1039	1	17.7377452820672	-0.8120322605654601	0.0	0.0	3	1.0303159512429807	54.72078797760354	66.0	1	1.1	0.9				
	1040	1	0.0	0.0	0.0	20.358571957796794	3	1.0194107442405447	50.74917924664204	132.0	1	1.1	0.9				
	1041	1	47.7676601507822	9.02384231187385	0.0	0.0	3	1.0431672150883524	49.1591221259502	66.0	1	1.1	0.9				
	1042	1	0.0	0.0	0.0	0.0	3	1.0392825932556982	28.48233169071439	110.0	1	1.1	0.9				
	1043	1	23.836942642017902	8.62703598491233	0.0	0.0	3	1.0142974767316926	26.7921035543806	33.0	1	1.1	0.9				
	1044	1	4.524596690456799	0.590389267816907	0.0	0.0	3	1.042331573253571	20.8215591176968	110.0	1	1.1	0.9				
	1045	1	46.575210781880806	3.59709528598431	0.0	0.0	3	0.991223694991717	18.65385899196391	33.0	1	1.1	0.9				
	1046	1	0.0	0.0	0.0	0.0	3	1.0303570833809834	50.49597206016549	132.0	1	1.1	0.9				
	1048	1	61.5488392405573	4.59941439625202	0.0	0.0	3	1.0535151153106497	44.4378885139007	66.0	1	1.1	0.9				
	1050	1	2.3649401822946	-0.29877703061956	0.0	0.0	3	1.0416891859997695	39.25737681721278	66.0	1	1.1	0.9				
	1052	1	30.311047289708597	8.8233872045598	0.0	0.0	3	1.0499607605595767	40.02795473513356	66.0	1	1.1	0.9				
	1053	1	0.0	0.0	0.0	0.0	3	1.0273243291009568	36.00097184961647	132.0	1	1.1	0.9				
	1054	1	0.0	0.0	0.0	0.0	3	1.0266838376064782	36.0217220201322	132.0	1	1.1	0.9				
	1055	1	0.0	0.0	0.0	0.0	3	1.024493312990593	40.08933527896806	132.0	1	1.1	0.9				
	1056	1	67.4622559882222	15.451166156671007	0.0	15.7340733902575	3	1.0366247011697007	38.21560410732545	33.0	1	1.1	0.9				
	1057	1	30.9270289011029	8.522199174101647	0.0	0.0	3	1.0159928878285334	37.31245430273157	66.0	1	1.1	0.9				
	1058	1	0.0	0.0	0.0	0.0	3	1.0413748054288365	25.81511537221735	132.0	1	1.1	0.9				
	1060	1	17.37223573912071	2.0510445618240634	0.0	97.57045597303662	3	1.047329904668432	29.750449733635985	110.0	1	1.1	0.9				
	1061	1	56.633872172239194	40.263844985512996	0.0	18.573954906286698	3	1.0249873341804951	27.33894437529215	33.0	1	1.1	0.9				
	1062	1	25.905260132948445	8.45952076368862	0.0	19.85385090457281	3	1.0384628061631807	34.99006249978731	66.0	1	1.1	0.9				
	1063	1	0.0	0.0	0.0	0.0	3	1.0212063782331802	36.54988833945719	132.0	1	1.1	0.9				
	1064	1	0.0	0.0	0.0	0.0	3	1.0212842280787977	36.54906690285328	132.0	1	1.1	0.9				
	1065	1	0.0	0.0	0.0	0.0	3	1.0264331222195273	31.70751254785534	132.0	1	1.1	0.9				
	1066	1	9.526357261584142	2.6105207456925896	0.0	0.0	3	1.0575627461405919	29.963924124791532	22.0	1	1.1	0.9				
	1067	1	0.00515912280860357	0.0	0.0	0.0	3	0.997850105726095	32.68541545755578	22.0	1	1.1	0.9				
	1068	1	0.0	0.0	0.0	0.0	3	1.0180851316148378	29.64688000636582	132.0	1	1.1	0.9				
	1069	1	21.2390310211436	5.22193309465209	0.0	0.0	3	1.008849898415756	27.9290705787977	22.0	1	1.1	0.9				
	1071	1	45.6369155925745	14.148172489705999	0.0	6.978748843073836	3	1.0115117476719027	26.72465753668957	22.0	1	1.1	0.9				
	1072	1	0.0	0.0	0.0	0.0	3	1.0196292363902562	29.105331174102165	132.0	1	1.1	0.9				
	1073	1	0.0	0.0	0.0	0.0	3	1.023034492430331	29.561620521970916	132.0	1	1.1	0.9				
	1074	1	17.70906807249	-1.9028282424610101	0.0	0.0	3	1.0901210780310295	26.39292939168941	22.0	1	1.1	0.9				
	1075	1	18.549044800223598	-1.9804959816422298	0.0	0.0	3	1.0936450954111403	26.8578646673499	22.0	1	1.1	0.9				
	1078	1	0.0	0.0	0.0	0.0	3	1.0102681581421296	28.22545208811799	132.0	1	1.1	0.9				
	1079	1	51.3048517856447	0.9297110162096099	0.0	0.0	3	1.081486589213846	26.656296315806703	66.0	1	1.1	0.9				
	1080	1	0.0	0.0	0.0	51.7095351498574	3	1.027317057971494	35.8890908200455	132.0	1	1.1	0.9				
	1083	1	0.0	0.0	0.0	0.0	3	1.0313869276633363	28.598825910750953	110.0	1	1.1	0.9				
	1084	1	22.558757561094303	5.17920890124691	0.0	0.0	3	1.0455294172575964	27.11446790336613	33.0	1	1.1	0.9				
	1085	1	0.0	0.0	0.0	0.0	3	1.0136379584724031	33.01765248073568	132.0	1	1.1	0.9				
	1086	1	0.0	0.0	0.0	0.0	3	1.0243597437509022	34.02583064908369	132.0	1	1.1	0.9				
	1087	1	72.6027510219411	10.985017106572899	0.0	0.0	3	1.0225923496178846	31.35512042153047	66.0	1	1.1	0.9				
	1088	1	0.0	0.0	0.0	0.0	3	1.016679520434572	55.14488917867374	132.0	1	1.1	0.9				
	1089	1	22.5466758786639	-1.34588007259518	0.0	0.0	3	1.0252066812969278	53.6069258528664	66.0	1	1.1	0.9				
	1090	2	0.0	0.0	0.0	0.0	3	1.0344986467366872	40.20674789519302	132.0	1	1.1	0.9				
	1092	1	18.3283448005316	0.650674314169446	0.0	0.0	3	1.0460629147986389	39.14433103939276	33.0	1	1.1	0.9				
	1093	1	0.0	0.0	0.0	0.0	3	1.0255512138954759	41.5825290536579	132.0	1	1.1	0.9				
	1094	1	7.181646446851831	1.6746792132735298	0.0	0.0	3	1.0126201381793694	39.23135199977052	66.0	1	1.1	0.9				
	1095	1	6.2870313187832	3.1347044809380495	0.0	0.0	3	1.0531889083605417	39.84118828410897	66.0	1	1.1	0.9				
	1096	1	0.0	0.0	0.0	0.0	3	1.0141913476922	37.50327822678154	132.0	1	1.1	0.9				
	1097	1	24.8067275092972	-0.5984451652383431	0.0	0.0	3	0.9998645367487932	36.43685474133478	66.0	1	1.1	0.9				
	1098	1	58.70961496656689	13.681620119169768	0.0	0.0	3	1.0319209151355748	26.579913698678364	132.0	1	1.1	0.9				
	1099	1	0.0	0.0	0.0	0.0	3	1.0408894579565917	45.65066377101419	132.0	1	1.1	0.9				
	1100	1	12.2861720269851	0.29849594164732807	0.0	0.0	3	1.0404445611433248	45.02887758678633	66.0	1	1.1	0.9				
	1102	1	0.0	0.0	0.0	0.0	3	1.0599303152185673	46.92156644353499	132.0	1	1.1	0.9				
	1103	1	-4.56934893494523	5.906820303325768	0.0	0.0	3	1.0169509322959618	47.46036041328733	66.0	1	1.1	0.9				
	1104	1	30.0722346170119	4.050884320829811	0.0	0.0	3	1.0480804123600096	49.63096099906772	66.0	1	1.1	0.9				
	1105	1	0.0	0.0	0.0	0.0	3	1.04772728170845	16.95590542439684	110.0	1	1.1	0.9				
	1106	1	18.59483333485271	7.6610123497149	0.0	0.0	3	1.0441488815471944	12.07539573425848	11.0	1	1.1	0.9				
	1107	1	17.34450142873451	8.71794102822826	0.0	0.0	3	1.0217436437971528	12.00919269166288	11.0	1	1.1	0.9				
	1108	1	7.051195327467939	-0.193884178765817	0.0	0.0	3	0.9835045549732372	33.92018810361537	66.0	1	1.1	0.9				
	1109	1	0.0	0.0	0.0	0.0	3	1.0491399569891955	34.52486879571266	66.0	1	1.1	0.9				
	1110	1	1.3590159784473437	0.43579084110618904	0.0	0.0	3	1.0699679469431158	43.52730765991906	132.0	1	1.1	0.9				
	1111	1	0.0	0.0	0.0	0.0	3	1.020704761077681	24.24573818044697	110.0	1	1.1	0.9				
	1112	1	27.349202350283598	9.1831444198072	0.0	0.0	3	1.0542428532878692	21.95670588571198	33.0	1	1.1	0.9				
	1113	1	0.0	0.0	0.0	0.0	3	1.0532851732957473	21.99747540660223	110.0	1	1.1	0.9				
	1114	1	7.888747577803771	2.14984633136205	0.0	0.0	3	1.0241429947101037	19.34932014718032	11.0	1	1.1	0.9				
	1115	1	5.95127617658847	0.006979453062498941	0.0	0.0	3	1.0130808754495464	19.94984622089441	11.0	1	1.1	0.9				
	1116	1	0.0	0.0	0.0	0.0	3	1.0394759467047827	16.68564221105027	110.0	1	1.1	0.9				
	1117	1	23.17025865262	2.8409243628874403	0.0	0.0	3	1.019262856524462	6.947765580099907	11.0	1	1.1	0.9				
	1118	1	25.058154548830398	5.5447061880223405	0.0	0.0	3	1.0037296582453854	6.42085975454264	11.0	1	1.1	0.9				
	1119	1	46.1540881953276	-4.7034400108929795	0.0	0.0	3	1.0132171713919789	32.98067877723273	132.0	1	1.1	0.9				
	1120	1	0.0	0.0	0.0	0.0	3	0.9885045574555876	32.98067877723275	10.5	1	1.1	0.9				
	1121	1	0.0	0.0	0.0	0.0	3	0.9885045574555876	32.98067877723278	10.5	1	1.1	0.9				
	1122	1	0.0	0.0	0.0	0.0	3	1.0226912664881447	36.64904498408047	132.0	1	1.1	0.9				
	1123	1	0.0	0.0	0.0	0.0	3	1.0226651991514544	36.65659176871951	132.0	1	1.1	0.9				
	1124	1	35.137669799740294	1.842055573573844	0.0	0.0	3	1.0378711659414113	35.28955534430562	66.0	1	1.1	0.9				
	1125	1	0.0	0.0	0.0	0.0	3	1.021431058605197	29.395006038583343	132.0	1	1.1	0.9				
	1126	1	0.0	0.0	0.0	0.0	3	1.0217126032794825	29.38577007791071	132.0	1	1.1	0.9				
	1127	1	29.795506208285698	8.59285198678589	0.0	0.0	3	0.8998054977563738	26.15989531348355	22.0	1	1.2	0.8				
	1129	1	0.0	0.0	0.0	0.0	3	1.0406817513844733	35.05479822945552	66.0	1	1.1	0.9				
	1130	1	0.0	0.0	0.0	0.0	3	0.9912296672925697	34.03255750709513	132.0	1	1.1	0.9				
	1131	1	1.35133675814392	-14.844862023360998	0.0	6.23699988043867	3	1.0244626095491665	46.88309668300533	132.0	1	1.1	0.9				
	1132	1	0.0	0.0	0.0	8.938981215453241	3	1.0412072312580054	47.54846061796451	132.0	1	1.1	0.9				
	1133	1	0.0	0.0	0.0	0.0	3	1.03816112705531	47.62970741575047	132.0	1	1.1	0.9				
	1134	1	1.34802927457504	-7.41469687042199	0.0	2.5864903407110793	3	1.0379228081903622	55.15336289634793	132.0	1	1.1	0.9				
	1135	1	0.0	0.0	0.0	0.0	3	1.0205736616202894	55.7762222232534	132.0	1	1.1	0.9				
	1136	2	0.176659434401989	0.0	0.0	0.0	3	0.9978300000004909	45.5451256170516	11.0	1	1.1	0.9				
	1137	2	4.54275251405905	0.0	0.0	0.0	3	1.0006000000004565	48.12732426204948	11.0	1	1.1	0.9				
	1138	2	0.169302481564041	0.0	0.0	0.0	3	0.9718800000005282	41.30584359631707	11.0	1	1.1	0.9				
	1139	1	0.7257241182010621	-2.56847391403113	0.0	0.0	3	1.0250303845508895	50.54857013996198	132.0	1	1.1	0.9				
	1140	2	0.0	0.0	0.0	0.0	3	1.0554790935884322	42.1222829621194	275.0	1	1.1	0.9				
	1141	1	1.92557989855413	-22.203619719165403	0.0	1.7474708075104297	3	1.0438531915860265	39.88063695528397	132.0	1	1.1	0.9				
	1142	1	2.783507180151714	-14.38635413850714	0.0	0.0	3	1.0397368055003409	43.15414825857802	132.0	1	1.1	0.9				
	1143	1	0.0	0.0	0.0	0.0	3	1.032789804352927	39.79848874379057	132.0	1	1.1	0.9				
	1144	1	9.343474606749409	-12.0552097676729	0.0	-3.7005941644907003	3	1.03525990207259	39.33677003256161	132.0	1	1.1	0.9				
	1145	1	11.48143100589393	2.2075569995827458	0.0	0.0	3	1.0371078426096563	17.39585787812911	110.0	1	1.1	0.9				
	1146	1	0.0	0.0	0.0	0.0	3	1.026257734190062	39.30383214106011	132.0	1	1.1	0.9				
	1147	1	2.5342752929753605	-18.7195328405197	0.0	0.0	3	1.0333453208008818	39.70202062544742	132.0	1	1.1	0.9				
	1149	1	0.0	0.0	0.0	0.0	3	1.0305333547113553	43.94413851000795	132.0	1	1.1	0.9				
	1150	1	1.5532976658708	-15.693653757575898	0.0	0.0	3	1.0358121268195037	43.74950654373978	132.0	1	1.1	0.9				
	1151	1	0.0951937989192083	-6.814040370354431	0.0	-0.8002068692017351	3	1.0378525164901766	38.96519688536949	132.0	1	1.1	0.9				
	1152	1	3.49248374232836	1.0473580844592298	0.0	0.0	3	1.0496325421037545	29.96695288430593	110.0	1	1.1	0.9				
	1153	1	21.888100493378897	9.40893772218851	0.0	0.0	3	1.0445828389285827	29.635828779376745	110.0	1	1.1	0.9				
	1154	1	0.0	0.0	0.0	20.174160785973104	3	1.0323362813759733	38.86660400542051	132.0	1	1.1	0.9				
	1155	1	0.19611612309236082	0.16626221270877825	0.0	0.0	3	1.040143631965375	32.83717708462579	132.0	1	1.1	0.9				
	1156	1	0.20641770398709902	-1.2159039770923492	0.0	0.0	3	1.0305140831513082	28.77485595896547	132.0	1	1.1	0.9				
	1158	1	33.658736857120694	11.636886774293	0.0	0.0	3	1.0187018298070747	53.17557044397789	66.0	1	1.1	0.9				
	1159	1	0.182544517193129	1.2962265603502299	0.0	0.0	3	1.0493864438536065	16.49255704038972	110.0	1	1.1	0.9				
	1160	1	19.15264023672161	3.1950424376910096	0.0	0.0	3	1.0165859720335708	9.30091197733762	11.0	1	1.1	0.9				
	1161	1	17.524457348929808	3.01862131888792	0.0	0.0	3	1.0170855839339736	9.482382314938354	11.0	1	1.1	0.9				
	1162	1	0.0	0.0	0.0	0.0	3	1.0191050474895318	27.70495656098056	132.0	1	1.1	0.9				
	1165	1	23.9166722361866	0.453496168584423	0.0	0.0	3	1.0167344459480199	25.7403741002012	22.0	1	1.1	0.9				
	1166	1	0.0	0.0	0.0	0.0	3	1.0335096765157539	54.25450112947032	132.0	1	1.1	0.9				
	1168	1	34.9562463221899	8.25452116908095	0.0	0.0	3	1.036757457812439	53.25498909670616	66.0	1	1.1	0.9				
	1169	1	0.0	0.0	0.0	0.0	3	1.0248033998463584	35.390725058038534	132.0	1	1.1	0.9				
	1170	1	22.879167634881796	1.7685788617710598	0.0	0.0	3	0.9849387996774257	34.03354902371757	66.0	1	1.1	0.9				
	1171	1	0.0	0.0	0.0	0.0	3	1.0276365114212522	32.94372885972802	132.0	1	1.1	0.9				
	1172	1	0.0	0.0	0.0	0.0	3	1.0260256752433605	35.81883511038492	132.0	1	1.1	0.9				
	1173	1	2.28789075901932	0.458745499039627	0.0	0.0	3	1.039026865397719	32.56972654858251	22.0	1	1.1	0.9				
	1174	1	0.0	0.0	0.0	0.0	3	1.0442693846390336	22.72828223354602	110.0	1	1.1	0.9				
	1175	1	80.1908816720433	32.1475637420714	0.0	19.289397814664998	3	0.9967310027679218	20.21379085600111	33.0	1	1.1	0.9				
	1176	1	6.6942436916975305	8.05902804560214	0.0	0.0	3	1.014317652655015	38.45351023625432	132.0	1	1.1	0.9				
	1177	1	0.0	0.0	0.0	0.0	3	1.0155621430116106	38.4696399421366	132.0	1	1.1	0.9				
	1178	1	0.0	0.0	0.0	0.0	3	1.0261596695477804	40.76904824517558	132.0	1	1.1	0.9				
	1179	1	0.0	0.0	0.0	0.0	3	1.0524714559464388	40.76904824517559	22.0	1	1.1	0.9				
	1180	1	0.0	0.0	0.0	0.0	3	1.0256015392868196	35.70046084937339	132.0	1	1.1	0.9				
	1181	1	0.0	0.0	0.0	0.0	3	1.025680809310325	35.69963070517357	132.0	1	1.1	0.9				
	1182	1	66.0952625848762	10.59970777000645	0.0	0.0	3	0.9689230902119994	33.44644269135942	33.0	1	1.1	0.9				
	1183	1	0.0	0.0	0.0	0.0	3	1.0281710210677515	40.87788612631435	132.0	1	1.1	0.9				
	1184	2	42.79061005538263	-0.06698267616359033	0.0	0.0	3	1.0021652453554195	40.43711192745238	66.0	1	1.1	0.9				
	1185	1	0.102365530282259	-2.8625196651248297	0.0	0.0	3	1.045692882580452	21.14605777134162	110.0	1	1.1	0.9				
	1186	1	0.0	0.0	0.0	0.0	3	1.0455776822444391	21.171050639048534	110.0	1	1.1	0.9				
	1187	1	0.0970198737503961	-2.7096045556994204	0.0	0.0	3	1.0460479933504254	21.18450177134814	110.0	1	1.1	0.9				
	1188	1	103.7581789375725	21.28857134139375	0.0	0.0	3	1.0184615036829838	18.13934698267039	33.0	1	1.1	0.9				
	1191	1	0.0	0.0	0.0	0.0	3	1.0260032432359902	35.81910158334162	132.0	1	1.1	0.9				
	1193	1	0.102551670945249	-0.5272472120760939	0.0	0.0	3	1.0247363026510183	38.49187187609643	132.0	1	1.1	0.9				
	1195	1	0.0	0.0	0.0	0.0	3	1.0430845012079455	33.30165676307784	110.0	1	1.1	0.9				
	1196	1	0.0	0.0	0.0	0.0	3	1.0439937622318372	32.46056515741679	110.0	1	1.1	0.9				
	1197	1	18.524456110622	6.646697860769929	0.0	0.0	3	0.9831928999241609	33.44335330520353	11.0	1	1.1	0.9				
	1199	1	0.0	0.0	0.0	0.0	3	1.0293831318153166	55.66472357200335	132.0	1	1.1	0.9				
	1200	1	0.0	0.0	0.0	0.0	3	1.0294163002118872	55.66713352185436	132.0	1	1.1	0.9				
	1202	1	0.0	0.0	0.0	50.20244928775348	3	1.021101225570297	49.91134395747619	132.0	1	1.1	0.9				
	1203	1	30.727547099402596	11.604889750015	0.0	0.0	3	1.0203253915524473	46.55831254470409	11.0	1	1.1	0.9				
	1204	1	0.0	0.0	0.0	0.0	3	1.0499312414050945	21.209366453210485	110.0	1	1.1	0.9				
	1205	1	0.0	0.0	0.0	0.0	3	1.027738328718888	34.49323769070913	132.0	1	1.1	0.9				
	1206	1	0.103413162226789	0.879647608219832	0.0	0.0	3	1.0253462665385389	34.482811873276	66.0	1	1.1	0.9				
	1207	1	1.7217933044072202	-5.24911324217031	0.0	0.0	3	1.0111342091242483	27.5497438078246	132.0	1	1.1	0.9				
	1208	1	0.0	0.0	0.0	0.0	3	1.0479708469732791	21.19877066858959	110.0	1	1.1	0.9				
	1209	1	12.1454156660772	1.72283460565293	0.0	0.0	3	1.0030293460008037	15.92580062220035	11.0	1	1.1	0.9				
	1210	1	12.3075833534053	6.865138002198192	0.0	5.125302518252278	3	1.0028711575743727	15.833594416490618	11.0	1	1.1	0.9				
	1211	1	0.0	0.0	0.0	0.0	3	1.0438479914377945	19.36568387588791	110.0	1	1.1	0.9				
	1212	1	44.9811176767618	15.102049957584171	0.0	0.0	3	1.0180872999920778	17.49191727289301	33.0	1	1.1	0.9				
	1213	1	0.0	0.0	0.0	0.0	3	1.0442771788481782	22.45831707440489	110.0	1	1.1	0.9				
	1214	1	9.95151141101746	1.46882421436533	0.0	0.0	3	1.0294897149655908	44.3832848830308	132.0	1	1.1	0.9				
	1215	1	0.726656483295933	0.7167468789480594	0.0	0.0	3	1.0334069699704416	40.63221674412546	132.0	1	1.1	0.9				
	1218	1	9.21318542173556	0.9387142295474191	0.0	0.0	3	1.0369037601897055	28.1910561113422	11.0	1	1.1	0.9				
	1219	1	0.0	0.0	0.0	0.0	3	1.0421800287062937	20.03810820737127	110.0	1	1.1	0.9				
	1220	1	0.0	0.0	0.0	0.0	3	1.0422072976536199	20.04102471533434	110.0	1	1.1	0.9				
	1221	1	31.9131568962841	6.25424287305344	0.0	0.0	3	1.003129192107567	18.90980934254479	33.0	1	1.1	0.9				
	1222	1	3.25400810175017	-1.031853577980213	0.0	0.0	3	1.0237657358023062	30.880086119699598	132.0	1	1.1	0.9				
	1223	1	6.80520660248659	-18.930748061146218	0.0	0.0	3	1.0431882012334865	43.03580654199349	132.0	1	1.1	0.9				
	1224	1	18.904157862329598	-12.077994841615398	0.0	0.0	3	1.0411988496748878	41.67431234206057	132.0	1	1.1	0.9				
	1225	1	0.0	0.0	0.0	0.0	3	1.0331436936848408	40.06667933131912	132.0	1	1.1	0.9				
	1227	1	0.0950277280062437	-1.74882541350164	0.0	0.0	3	1.0310066092958416	37.8130674208948	132.0	1	1.1	0.9				
	1229	1	0.20103762829676242	2.8471073731231997	0.0	0.0	3	1.0290503937424909	38.68677373514718	132.0	1	1.1	0.9				
	1230	1	6.66833033374446	0.8268768872350452	0.0	0.0	3	1.0385916052356507	39.02020477241932	132.0	1	1.1	0.9				
	1233	1	3.2766448979673393	2.2751195251138	0.0	0.0	3	0.9989959688440605	49.16743809922104	33.0	1	1.1	0.9				
	1235	1	0.0	0.0	0.0	0.0	3	1.0440477133117936	32.46012735930412	110.0	1	1.1	0.9				
	1239	1	16.1554269528498	6.293710968911551	0.0	0.0	3	1.0091696553557727	31.8803021178654	33.0	1	1.1	0.9				
	1240	1	1.88305620952323	-7.53246026804019	0.0	0.0	3	1.036419001025182	40.13049148312319	132.0	1	1.1	0.9				
	1241	1	0.0	0.0	0.0	19.572136157192297	3	1.0223933312724258	36.23120903075176	132.0	1	1.1	0.9				
	1242	1	39.09994929755929	34.8980633722483	0.0	0.0	3	0.9925142706191995	35.15304867615908	66.0	1	1.1	0.9				
	1243	1	53.7102691888801	10.44727609174233	0.0	0.0	3	1.0365651457876486	37.7242006274802	132.0	1	1.1	0.9				
	1244	1	20.396758080548363	9.35078423141688	0.0	0.0	3	1.0180065325638106	38.71997889961138	132.0	1	1.1	0.9				
	1245	1	77.2411993972098	16.30479746015821	0.0	0.0	3	1.036470356172734	54.58896611831107	132.0	1	1.1	0.9				
	1246	2	0.682281481850985	0.0	0.0	0.0	3	1.0537899999995666	60.27900067766138	15.0	1	1.1	0.9				
	1249	1	29.0899719892396	4.04375306206564	0.0	0.0	3	1.0417517919463866	37.59092472338595	66.0	1	1.1	0.9				
	1250	1	11.30536029942794	3.54950763737481	0.0	0.0	3	1.0350468100250783	35.09297823420983	66.0	1	1.1	0.9				
	1251	1	90.1242680461896	17.66737634370252	0.0	19.291643046475905	3	1.0349811421624557	14.335762088390279	33.0	1	1.1	0.9				
	1252	2	0.0966405550064519	-17.0233461857289	0.0	0.0	3	1.0336999999991696	45.64948603320174	132.0	1	1.1	0.9				
	1253	2	0.10333018196281002	-3.2851672337662396	0.0	0.0	3	1.0319199999992439	48.69653068829225	132.0	1	1.1	0.9				
	1254	1	0.0	0.0	0.0	0.0	3	1.0320365934262394	48.69952186944492	132.0	1	1.1	0.9				
	1255	2	0.10394214028026899	9.26709345893375	0.0	0.0	3	1.0302399999994265	55.46123279518401	132.0	1	1.1	0.9				
	1256	1	29.9439579344742	8.03079409989151	0.0	0.0	3	1.034834466598855	34.92853014649904	66.0	1	1.1	0.9				
	1257	1	0.099417752684094	0.205582980806753	0.0	0.0	3	1.025893687193441	39.89660343372032	132.0	1	1.1	0.9				
	1258	1	29.913913178193802	6.975198404238791	0.0	0.0	3	1.0341371793262377	37.29855655895503	132.0	1	1.1	0.9				
	1259	1	45.2016528647367	8.2941497480426	0.0	0.0	3	1.0288908584322645	36.52634211532258	132.0	1	1.1	0.9				
	1260	1	43.400861253205164	7.029376699498299	0.0	0.0	3	1.0248922984275333	36.11894914821009	132.0	1	1.1	0.9				
	1262	1	140.8635729475022	13.92318414939568	0.0	0.0	3	1.0373641283680364	34.08799504665938	132.0	1	1.1	0.9				
	1263	1	8.50773922660946	0.292446078457776	0.0	0.0	3	1.037946953243329	35.07409290390879	66.0	1	1.1	0.9				
	1264	1	1.2226403057556599	-5.955085278113041	0.0	0.0	3	1.0250638811143742	50.56609946152889	132.0	1	1.1	0.9				
	1265	2	17.01773650425808	-21.22309669469145	0.0	0.0	3	1.031229999998896	39.39964948271269	132.0	1	1.1	0.9				
	1266	1	64.2013557200355	11.18227022510906	0.0	0.0	3	1.034434088164897	33.71989319942847	132.0	1	1.1	0.9				
	1267	1	39.234817159559604	7.07621844213763	0.0	0.0	3	1.0352842296870872	33.64045896974612	132.0	1	1.1	0.9				
	1268	1	11.75675897219698	3.62558787259711	0.0	0.0	3	1.0348222161511544	33.75575188463417	132.0	1	1.1	0.9				
	1271	1	-19.4134494967556	0.0	0.0	-6.942509448652159	3	1.0967309833931174	45.49873852950223	22.0	1	1.1	0.9				
	1273	1	0.0	0.0	0.0	0.0	3	0.9401318211991349	36.23120863471525	33.0	1	1.1	0.9				
	1274	2	60.9454535714666	13.5787788652693	0.0	0.0	3	1.074829999999569	51.38252936598116	21.0	1	1.1	0.9				
	1276	1	9.25038510654196	-3.8128744977400704	0.0	0.0	3	1.0322427112451167	43.70965470549856	132.0	1	1.1	0.9				
	1277	1	0.0	0.0	0.0	0.0	3	1.0497464753396863	17.32438137669743	110.0	1	1.1	0.9				
	1278	1	19.09524059923301	5.61871198750679	0.0	0.0	3	1.0361876812149728	33.5706716547318	132.0	1	1.1	0.9				
	1280	1	11.10570671984134	-17.21502321180606	0.0	0.0	3	1.0429622252629553	17.94360080031794	110.0	1	1.1	0.9				
	1281	1	23.681219827117637	18.76434723406099	0.0	13.499712382471198	3	0.9978932441865108	11.83320995056476	11.0	1	1.1	0.9				
	1282	1	15.20818631760552	17.736786945767513	0.0	14.308682867739398	3	1.0086513957216607	13.6461217870787	11.0	1	1.1	0.9				
	1283	1	15.394311405665889	5.81711229393343	0.0	0.0	3	1.0338959970782755	35.03182067405302	66.0	1	1.1	0.9				
	1284	1	0.0	0.0	0.0	0.0	3	1.0452266848180753	15.66663749490328	110.0	1	1.1	0.9				
	1285	1	0.0	0.0	0.0	0.0	3	1.0451510693659691	15.66712402743231	110.0	1	1.1	0.9				
	1286	1	22.7357010856109	7.66170123200538	0.0	0.0	3	0.9637916277304373	8.202973170430138	11.0	1	1.1	0.9				
	1287	1	25.4447445138996	9.085184641203469	0.0	0.0	3	0.9666584791979699	7.529707757351723	11.0	1	1.1	0.9				
	1288	1	0.0	0.0	0.0	0.0	3	1.0398279138845585	36.20531273306918	66.0	1	1.1	0.9				
	1289	1	4.053372667485152	4.218553694326152	0.0	0.0	3	1.049486009129081	22.02650933695852	110.0	1	1.1	0.9				
	1290	1	0.0	0.0	0.0	0.0	3	1.0375448374861882	22.66866527038326	110.0	1	1.1	0.9				
	1292	1	0.0	0.0	0.0	0.0	3	1.0409391994852273	23.36303671717137	110.0	1	1.1	0.9				
	1293	1	0.0	0.0	0.0	0.0	3	1.0395509659643336	23.216052466249245	110.0	1	1.1	0.9				
	1294	1	29.071899126922702	9.197310541373119	0.0	0.0	3	1.0429859442227658	21.72075739091327	33.0	1	1.1	0.9				
	1297	1	0.0	0.0	0.0	101.936927339993	3	1.0513699560314136	22.19589012319988	110.0	1	1.1	0.9				
	1298	1	110.536595894477	28.829399584920502	0.0	19.915813833670704	3	1.0302797090629745	18.86185580839238	33.0	1	1.1	0.9				
	1300	1	0.0	0.0	0.0	0.0	3	1.0352876483080564	18.20381201794981	110.0	1	1.1	0.9				
	1301	1	74.8234722356486	25.1633395032228	0.0	0.0	3	1.0399011615353024	15.375263636650168	33.0	1	1.1	0.9				
	1302	1	0.0	0.0	0.0	0.0	3	1.0482300312947954	16.18418140533386	110.0	1	1.1	0.9				
	1303	1	0.0	0.0	0.0	0.0	3	1.0484301645581464	16.15247267154109	110.0	1	1.1	0.9				
	1304	1	59.5318720024433	11.936541435354801	0.0	0.0	3	1.023356249397257	13.55902435682065	33.0	1	1.1	0.9				
	1305	1	20.0074444905052	6.466879342899561	0.0	0.0	3	1.0075902780154382	10.55384064761041	11.0	1	1.1	0.9				
	1306	1	22.762457042679703	2.1088492207054004	0.0	0.0	3	1.0021679713726617	9.423982537840784	11.0	1	1.1	0.9				
	1307	2	0.0	0.0	0.0	0.0	3	1.0215757674662667	29.3922499819191	132.0	1	1.1	0.9				
	1309	1	41.3555862885761	13.248952871302599	0.0	14.534653943404546	3	1.0206866397967513	25.28784696421376	22.0	1	1.1	0.9				
	1310	1	12.750372715092201	1.7354742952440902	0.0	0.0	3	1.0085726181355212	27.31192413849865	132.0	1	1.1	0.9				
	1312	1	0.0	0.0	0.0	0.0	3	1.041196059758098	20.69201070336237	110.0	1	1.1	0.9				
	1313	1	47.8593792935728	9.81929683832801	0.0	4.708829063824377	3	1.0064314224784454	6.135367120957797	11.0	1	1.1	0.9				
	1314	1	48.3210758652001	10.219973561534669	0.0	4.8699781581992285	3	1.0037608586078228	5.773427196636116	11.0	1	1.1	0.9				
	1316	1	0.0	0.0	0.0	0.0	3	1.046278241714451	18.00954417125059	110.0	1	1.1	0.9				
	1317	1	104.1093392708211	23.32518540986683	0.0	19.958314133808	3	1.0040749388446246	13.69813546456388	33.0	1	1.1	0.9				
	1318	1	0.0	0.0	0.0	0.0	3	1.0321125855093827	16.35513693747566	110.0	1	1.1	0.9				
	1319	1	56.0804144815625	5.82388020603033	0.0	0.0	3	1.034919248904768	13.39588317019679	33.0	1	1.1	0.9				
	1320	1	0.0	0.0	0.0	0.0	3	1.0247578348022273	26.09004238672427	110.0	1	1.1	0.9				
	1321	1	19.086440305060894	5.331949782405049	0.0	0.0	3	0.9934474114597048	25.00376275564901	33.0	1	1.1	0.9				
	1322	1	0.0	0.0	0.0	52.0860902871937	3	1.0470805309525526	18.65739780925614	110.0	1	1.1	0.9				
	1325	1	107.94109815911499	27.914614622156797	0.0	19.6476664897613	3	1.014210976705052	11.22493714019077	33.0	1	1.1	0.9				
	1329	1	97.04232031456361	14.332656739203017	0.0	20.189369810856896	3	0.9435560488939911	17.53052824469642	33.0	1	1.1	0.9				
	1331	1	9.74856156277284	0.305403592210449	0.0	0.0	3	1.0312336797608994	16.07404310341975	33.0	1	1.1	0.9				
	1332	1	31.545768153968396	9.05926745744138	0.0	0.0	3	1.0483204427834454	21.76857093955834	110.0	1	1.1	0.9				
	1333	1	71.85817074920371	30.5613856263202	0.0	20.116392718628	3	1.0295155944026646	14.36769827491641	33.0	1	1.1	0.9				
	1334	1	25.8624559360833	7.64724010672546	0.0	0.0	3	1.0250271483598279	15.425184775362878	33.0	1	1.1	0.9				
	1335	1	0.0	0.0	0.0	0.0	3	1.04400021643653	18.27683957721631	110.0	1	1.1	0.9				
	1337	1	5.877856170647407	0.21233071371032985	0.0	0.0	3	1.0411083938234091	20.68491686595521	110.0	1	1.1	0.9				
	1338	1	22.753646574994	3.2959093168854694	0.0	0.0	3	1.001028591535081	13.68028484236858	11.0	1	1.1	0.9				
	1339	1	35.58093685796829	11.6210159024319	0.0	9.8082661879342	3	0.9989796118776082	10.60120865046724	11.0	1	1.1	0.9				
	1341	1	22.2687546157686	5.71199900061488	0.0	0.0	3	1.0020635122644654	9.50363234178738	11.0	1	1.1	0.9				
	1342	1	16.43514620613977	4.7143562789193805	0.0	0.0	3	1.0120861617613555	11.35417779118374	11.0	1	1.1	0.9				
	1343	1	101.4238378615926	22.73428051188439	0.0	19.597627417482403	3	1.0075034421260247	14.348579603007	33.0	1	1.1	0.9				
	1344	1	0.0	0.0	0.0	0.0	3	1.0891521454634427	17.32452653993501	11.0	1	1.1	0.9				
	1345	1	31.02529086318668	11.17391885830433	0.0	5.017243832582611	3	0.9885604306035383	3.457003071002805	11.0	1	1.1	0.9				
	1347	1	0.0	0.0	0.0	0.0	3	1.041980510275131	20.02906778448137	110.0	1	1.1	0.9				
	1348	1	36.235787898863705	0.793718510266626	0.0	0.0	3	1.0271254331740118	18.36632852124515	33.0	1	1.1	0.9				
	1350	1	14.496104635615497	2.4174096078637097	0.0	0.0	3	1.0031043788709273	13.61654387343577	11.0	1	1.1	0.9				
	1351	1	22.415421451861	-1.4695271447021498	0.0	0.0	3	1.0190894871686673	11.49326287475241	11.0	1	1.1	0.9				
	1353	1	1.5583918698150698	1.48272143783811	0.0	0.0	3	1.0372968806134701	34.98947263089051	66.0	1	1.1	0.9				
	1354	1	2.83483461229373	-3.49736086111814	0.0	0.0	3	1.0381470649105926	35.09578364787673	66.0	1	1.1	0.9				
	1355	1	0.0	0.0	0.0	0.0	3	1.0369333370546192	18.502967949422395	110.0	1	1.1	0.9				
	1357	1	17.25097708871439	6.36992486758567	0.0	0.0	3	1.088135030485199	15.415224014752528	11.0	1	1.1	0.9				
	1358	1	18.090055528848062	6.82603415663894	0.0	0.0	3	1.0967643017001083	15.35556515105139	11.0	1	1.1	0.9				
	1359	1	0.0	0.0	0.0	0.0	3	1.0423502883623337	20.08906564741954	110.0	1	1.1	0.9				
	1360	1	107.300479373141	25.418252542894	0.0	0.0	3	1.0350109637673206	17.55073821667922	33.0	1	1.1	0.9				
	1362	1	0.0	0.0	0.0	0.0	3	1.0354401604178536	17.49938837894836	110.0	1	1.1	0.9				
	1363	1	0.0	0.0	0.0	0.0	3	1.0483519049452519	17.12291016999059	110.0	1	1.1	0.9				
	1364	1	17.60028372945305	4.76784836505111	0.0	0.0	3	1.0164258861873445	11.938501093782	11.0	1	1.1	0.9				
	1365	1	16.38338281021752	6.13471313947738	0.0	4.821861840123312	3	1.0243753141854863	12.30663158491507	11.0	1	1.1	0.9				
	1366	1	17.73243922921531	4.33363734017499	0.0	5.028170838393271	3	1.0083072566693327	11.78571792045683	11.0	1	1.1	0.9				
	1367	1	0.0	0.0	0.0	0.0	3	1.0472670667608863	22.23631931677856	110.0	1	1.1	0.9				
	1369	1	67.2083458008327	21.8413372465082	0.0	0.0	3	1.0506835294658923	19.20048856385577	33.0	1	1.1	0.9				
	1371	1	49.69651194655221	10.87197296586628	0.0	0.0	3	1.0254579463844986	19.82305737089537	33.0	1	1.1	0.9				
	1372	1	0.0	0.0	0.0	0.0	3	1.0477034673644974	22.14097706417282	110.0	1	1.1	0.9				
	1373	1	112.676631413872	30.754711900695202	0.0	19.9099069869984	3	0.9964747835014494	17.79297456984449	33.0	1	1.1	0.9				
	1374	1	0.0	0.0	0.0	0.0	3	1.04478752402215	15.641033046071168	110.0	1	1.1	0.9				
	1375	1	14.84276607464216	3.6845196400964104	0.0	0.0	3	1.0061761213303282	11.08226151761387	11.0	1	1.1	0.9				
	1376	1	16.3801842965368	4.1768566359076695	0.0	0.0	3	1.00164245091789	10.47156716820291	11.0	1	1.1	0.9				
	1377	1	11.674597249693331	4.07840301825218	0.0	0.0	3	1.06063937447748	12.34331713531324	11.0	1	1.1	0.9				
	1378	1	14.57394484963557	6.409892567894559	0.0	0.0	3	1.0377671163881246	34.99654677581663	66.0	1	1.1	0.9				
	1379	1	31.4660676440551	3.41863613006812	0.0	0.0	3	1.0426827070742364	17.90637164056395	110.0	1	1.1	0.9				
	1380	1	45.7350926702756	29.57481014764076	0.0	0.0	3	1.0097214445611988	16.32126694822714	33.0	1	1.1	0.9				
	1381	1	12.172761701020098	2.8710756106516797	0.0	0.0	3	1.051310129278051	16.43561574395005	110.0	1	1.1	0.9				
	1382	1	12.3855966533225	3.65095673603481	0.0	48.4592487080954	3	1.0512913618528192	16.435737029155344	110.0	1	1.1	0.9				
	1384	1	4.81612260274971	2.43793865752146	0.0	0.0	3	1.0250698538813603	38.13739789637824	33.0	1	1.1	0.9				
	1386	1	25.4537800816761	10.0932771249217	0.0	4.895951707595956	3	1.0151996378476156	13.215261857642181	11.0	1	1.1	0.9				
	1387	1	23.2236697571632	9.61550984016564	0.0	5.03156535469927	3	1.0076096171469764	13.93738848040431	11.0	1	1.1	0.9				
	1388	1	0.0	0.0	0.0	0.0	3	1.0479226025787682	18.59317475106528	110.0	1	1.1	0.9				
	1389	1	0.0	0.0	0.0	0.0	3	1.0478903356401428	18.58427271440657	110.0	1	1.1	0.9				
	1390	1	0.0	0.0	0.0	0.0	3	1.0440330782904845	18.08863569919086	110.0	1	1.1	0.9				
	1391	1	22.732030197049397	6.79666306806505	0.0	0.0	3	1.0079256763359792	9.231873374118367	11.0	1	1.1	0.9				
	1392	1	20.518076762198227	3.9936515609244796	0.0	0.0	3	1.02167317150474	9.508310538365455	11.0	1	1.1	0.9				
	1394	2	14.456884345612696	8.42000324605801	0.0	0.0	3	1.0023799999995555	59.09906510977143	15.75	1	1.1	0.9				
	1395	2	12.7361008552631	9.92302420080034	0.0	0.0	3	1.0172499999995441	58.9484070559895	15.75	1	1.1	0.9				
	1396	2	11.4064740076987	11.8983676339285	0.0	0.0	3	1.0800999999993974	55.19016981922213	15.75	1	1.1	0.9				
	1397	2	12.1766680779361	11.5626962856162	0.0	0.0	3	1.0769899999994146	55.42864634998276	15.75	1	1.1	0.9				
	1398	2	10.049256748452601	11.755369411478299	0.0	0.0	3	1.0139599999994744	56.58877387362834	15.75	1	1.1	0.9				
	1399	2	15.073614745303402	7.24901046796725	0.0	0.0	3	1.0173799999995594	59.49917136195606	15.75	1	1.1	0.9				
	1400	2	27.6728557136479	13.4088585201418	0.0	0.0	3	1.015249999999339	45.62356858475162	20.0	1	1.1	0.9				
	1401	2	28.8361392401487	13.382845060530101	0.0	0.0	3	1.011229999999337	45.67360900575508	20.0	1	1.1	0.9				
	1402	2	28.7166802448972	12.4940651509694	0.0	0.0	3	1.0118199999993385	45.74925792485324	20.0	1	1.1	0.9				
	1403	2	29.321948719048198	13.137712262780399	0.0	0.0	3	1.010539999999349	46.20456932648645	20.0	1	1.1	0.9				
	1404	1	2.75289610125721	2.24967369426005	0.0	-5.634113970437088	3	1.002510079355983	37.5143543122381	6.6	1	1.1	0.9				
	1405	1	0.0	0.0	0.0	0.0	3	1.020969549337439	28.14056124626192	13.8	1	1.1	0.9				
	1406	1	0.0	0.0	0.0	0.0	3	1.0340588777558761	28.14056156626189	13.8	1	1.1	0.9				
	1407	2	23.513236102598498	16.190581050045598	0.0	0.0	3	1.0172599999997485	66.84978196301266	20.0	1	1.1	0.9				
	1408	2	26.225068797685005	12.0761956744568	0.0	0.0	3	1.0188599999997756	67.77077823727289	20.0	1	1.1	0.9				
	1409	1	0.0	0.0	0.0	0.0	3	1.0286920201106267	55.49386838451557	132.0	1	1.1	0.9				
	1410	1	0.41239805203457397	0.416703374318778	0.0	0.0	3	1.0253764146936677	55.33134400907505	6.6	1	1.1	0.9				
	1411	2	5.12143868251629	0.0	0.0	0.0	3	1.0193399999995307	47.17505949262104	15.0	1	1.1	0.9				
	1412	2	5.21447525225747	0.0	0.0	0.0	3	1.0163699999995293	47.71318212791171	15.0	1	1.1	0.9				
	1413	2	5.01822873109775	0.0	0.0	0.0	3	1.0089999999995294	48.21372668997206	15.0	1	1.1	0.9				
	1414	2	0.118153763497621	0.0	0.0	0.0	3	1.069549999999528	48.51644578254065	15.0	1	1.1	0.9				
	1415	2	1.87367143145632	0.857158603200316	0.0	0.0	3	0.9673799999994654	47.91709668301664	15.75	1	1.1	0.9				
	1416	2	2.4217664189948698	0.996772907746676	0.0	0.0	3	0.9663399999994686	49.69610622975691	15.75	1	1.1	0.9				
	1417	1	0.0	0.0	0.0	0.0	3	0.9715759171825454	42.12228296211942	15.75	1	1.1	0.9				
	1418	1	10.892607133415378	4.314982315206899	0.0	0.0	3	1.0471303962595127	15.78527893183841	110.0	1	1.1	0.9				
	1419	2	18.8268303699326	20.8671664316095	0.0	0.0	3	0.9883099999997641	67.0817005609974	19.5	1	1.1	0.9				
	1420	2	19.521483236579503	21.7099463751859	0.0	0.0	3	0.9884899999997543	66.78082797311396	19.5	1	1.1	0.9				
	1421	2	21.731545117715488	14.383426771216968	0.0	0.0	3	0.9774799999993746	46.93681370888073	20.5	1	1.1	0.9				
	1422	1	0.0	0.0	0.0	0.0	3	1.0193808958839734	24.85239564464129	21.0	1	1.1	0.9				
	1423	1	-12.616180889459711	0.0	0.0	-5.369636244967109	3	1.0046025253698427	21.51795761055102	11.0	1	1.1	0.9				
	1424	1	0.0	0.0	0.0	0.0	3	1.1012263010515755	46.92156643081694	11.0	1	1.2	0.8				
	1425	2	0.0	0.0	0.0	0.0	3	1.0197399999983627	29.1043561812813	11.0	1	1.1	0.9				
	1426	2	1.04091281344453	0.0	0.0	0.0	3	1.0237399999985672	34.47051882665803	11.0	1	1.1	0.9				
	1428	1	0.14758767950721097	-2.54461793536078	0.0	0.0	3	1.0343955523560409	35.9677078069995	11.0	1	1.1	0.9				
	1429	2	0.788296720283572	0.0	0.0	0.0	3	0.9424499999986964	33.37665394315824	11.0	1	1.1	0.9				
	1430	2	0.8006804691935889	0.0	0.0	0.0	3	0.9397999999988091	36.663809917413	11.0	1	1.1	0.9				
	1431	2	0.0	0.0	0.0	0.0	3	0.9426699999988117	36.71392972244347	11.0	1	1.1	0.9				
	1432	2	0.5021486751968038	0.0	0.0	0.0	3	0.9353699999986873	33.17846303398768	11.0	1	1.1	0.9				
	1433	2	0.0	0.0	0.0	0.0	3	1.0151799999985862	32.57811253004834	6.6	1	1.1	0.9				
	1434	1	0.0	0.0	0.0	0.0	3	1.0273200096005515	35.8890555536203	13.8	1	1.1	0.9				
	1435	1	0.0	0.0	0.0	0.0	3	1.027319967845163	35.88905480868922	13.8	1	1.1	0.9				
	1436	1	0.0	0.0	0.0	0.0	3	1.009371052870988	35.81883511038478	15.0	1	1.1	0.9				
	1437	2	5.91607474051416	0.0	0.0	0.0	3	1.0034699999990409	44.5273448022159	11.0	1	1.1	0.9				
	1438	2	3.27980087365531	0.0	0.0	0.0	3	0.9201099999992431	47.11766138337475	10.5	1	1.1	0.9				
	1439	2	5.03742613884914	0.0	0.0	0.0	3	1.004909999999242	38.22854098576123	10.5	1	1.1	0.9				
	1440	1	0.0	0.0	0.0	0.0	3	0.98632121972982	32.4601628171152	10.5	1	1.1	0.9				
	1441	2	0.0	0.0	0.0	0.0	3	0.9980499999992299	39.70092278869352	33.0	1	1.1	0.9				
	1442	1	0.0	0.0	0.0	0.0	3	1.0408467884179144	22.95093502681199	110.0	1	1.1	0.9				
	1444	1	0.0	0.0	0.0	0.0	3	1.0557505026495	22.92336349491181	110.0	1	1.1	0.9				
	1445	1	0.0	0.0	0.0	152.123979663011	3	1.0535089489250082	19.19781308576698	110.0	1	1.1	0.9				
	1446	1	84.98436224133272	23.3338597885831	0.0	0.0	3	1.013621720520845	16.78463222706954	33.0	1	1.1	0.9				
	1448	1	10.9305069311259	2.41305729810256	0.0	0.0	3	1.0342244483505283	15.54844041384345	33.0	1	1.1	0.9				
	1449	1	0.0	0.0	0.0	0.0	3	1.0381878521793053	32.89359601606139	132.0	1	1.1	0.9				
	1450	1	0.0	0.0	0.0	0.0	3	1.0330303792594357	40.71055030515336	132.0	1	1.1	0.9				
	1451	1	824.950087082608	474.5463662596344	0.0	231.513366488926	3	1.0074265592053895	47.07726379687529	132.0	1	1.1	0.9				
	1452	1	154.51473176872398	38.6609055055009	0.0	0.0	3	1.0363987764622986	24.39932151800859	132.0	1	1.1	0.9				
	1453	1	0.0	0.0	0.0	99.87174930516629	3	1.0472669530587848	25.65811627240885	132.0	1	1.1	0.9				
	1456	1	0.0	0.0	0.0	0.0	3	1.02049328440315	55.77837796525403	132.0	1	1.1	0.9				
	1457	1	0.0	0.0	0.0	0.0	3	1.0309429234681395	43.51905507682435	132.0	1	1.1	0.9				
	1458	1	0.0	0.0	0.0	0.0	3	1.0698253450016801	43.71979306036337	19.1	1	1.1	0.9				
	1459	1	0.0	0.0	0.0	0.0	3	1.069328822227333	43.78284490451789	19.1	1	1.1	0.9				
	1460	1	0.0	0.0	0.0	0.0	3	1.0263641792535871	36.91975966063638	132.0	1	1.1	0.9				
	1461	1	0.0	0.0	0.0	0.0	3	0.994436562273276	36.98473816766024	19.1	1	1.1	0.9				
	1462	1	0.0	0.0	0.0	0.0	3	0.9925539671352446	38.58295150270426	19.1	1	1.1	0.9				
	1463	1	0.0	0.0	0.0	0.0	3	0.9924961577326329	38.46915465985149	19.1	1	1.1	0.9				
	1464	1	0.0	0.0	0.0	0.0	3	1.060882608976029	31.64126219652176	275.0	1	1.1	0.9				
	1467	1	56.4152170908384	46.5694678054377	0.0	0.0	3	1.0287838894328356	45.15803211278955	66.0	1	1.1	0.9				
	1468	1	0.0	0.0	0.0	0.0	3	1.0686272418450484	47.25257409474731	19.0	1	1.1	0.9				
	1469	1	0.0	0.0	0.0	0.0	3	1.0691732151806248	47.0621249905163	19.0	1	1.1	0.9				
	1470	1	56.8872802143828	25.1588416623013	0.0	48.61590218264612	3	1.0477999490967573	21.40572189758677	110.0	1	1.1	0.9				
	1471	1	0.0	0.0	0.0	0.0	3	1.0082411253773038	38.59053272814866	132.0	1	1.1	0.9				
	1472	1	0.0	0.0	0.0	0.0	3	1.0084549554835758	38.57887383274819	132.0	1	1.1	0.9				
	1474	1	31.004154564417114	13.504624262113548	0.0	0.0	3	1.0249158890345662	37.84087157663759	66.0	1	1.1	0.9				
	1478	1	62.2668370596695	16.057171547404685	0.0	51.731997113674886	3	1.0433466205221438	18.66281007818736	110.0	1	1.1	0.9				
	1479	1	73.5215354724242	25.4928457282003	0.0	20.52208836255601	3	0.9920343784965888	16.29624369064781	33.0	1	1.1	0.9				
	1480	1	0.0	0.0	0.0	0.0	3	1.0466991902690372	21.5581360508439	110.0	1	1.1	0.9				
	1490	1	0.0	0.0	0.0	0.0	3	1.0142144909771507	32.51290096515185	132.0	1	1.1	0.9				
	1491	1	0.0	0.0	0.0	-19.2753567408957	3	1.0029663225584273	32.63091635771534	19.1	1	1.1	0.9				
	1492	1	0.0	0.0	0.0	0.0	3	1.037014828936919	39.34764498428517	132.0	1	1.1	0.9				
	1493	1	0.0	0.0	0.0	51.53415665961797	3	1.0561730206506255	21.76534869494239	110.0	1	1.1	0.9				
	1494	1	82.7507469730852	9.92978359590308	0.0	19.006196053698705	3	1.0344406876825278	18.45453480356411	33.0	1	1.1	0.9				
	1499	2	1.76030605698377	0.904580109712109	0.0	0.0	3	0.986989999999454	47.78282822738797	15.75	1	1.1	0.9				
	1500	2	1.9630475288871698	0.994991600480862	0.0	0.0	3	0.983809999999454	47.96404616489788	15.75	1	1.1	0.9				
	1501	2	1.6544086688960897	0.77545108136083	0.0	0.0	3	0.9966199999994526	46.97946732581958	15.75	1	1.1	0.9				
	1502	1	0.0	0.0	0.0	0.0	3	1.0254758714941408	37.22434166369779	132.0	1	1.1	0.9				
	1503	1	0.0	0.0	0.0	0.0	3	1.038462198390625	54.38167452408498	132.0	1	1.1	0.9				
	1505	1	0.0	0.0	0.0	0.0	3	1.038753641400372	35.5765034795347	132.0	1	1.1	0.9				
	1507	1	0.0	0.0	0.0	0.0	3	1.0502354939871437	22.44046900554892	110.0	1	1.1	0.9				
	1508	1	168.4172231187763	24.0559888990575	0.0	0.0	3	1.0358619472165576	39.77232962367019	132.0	1	1.1	0.9				
	1509	1	0.0	0.0	0.0	0.0	3	1.039204601596509	34.52486879571265	132.0	1	1.1	0.9				
	1512	1	34.8237002832999	7.3837219953615705	0.0	0.0	3	1.0382599197656872	34.37599932605168	132.0	1	1.1	0.9				
	1513	1	26.239211317897997	6.01115613494553	0.0	0.0	3	1.0360699531968802	33.92622981444452	132.0	1	1.1	0.9				
	1514	1	6.33466533076837	-11.27047371755102	0.0	0.0	3	1.01336248949766	40.96601311641192	22.0	1	1.1	0.9				
	1515	1	1.35882550641554	-1.4752681215880399	0.0	0.0	3	1.0317034245921772	27.31838142066543	132.0	1	1.1	0.9				
	1516	2	0.0	0.0	0.0	125.11007490009098	3	1.063932517287146	26.59818856829151	275.0	1	1.1	0.9				
	1518	1	0.0	0.0	0.0	121.18082758784301	3	1.0601934803605564	22.91806657444025	275.0	1	1.1	0.9				
	1519	1	0.0	0.0	0.0	0.0	3	1.0537634095323822	21.21678253617705	275.0	1	1.1	0.9				
	1520	2	0.0	0.0	0.0	0.0	3	1.0621993293262253	34.31231128117722	275.0	1	1.1	0.9				
	1522	1	0.0	0.0	0.0	116.28660899028192	3	1.0576701309892378	42.39712760456703	275.0	1	1.1	0.9				
	1523	1	0.0	0.0	0.0	0.0	3	1.0333039205606782	52.89924228670433	275.0	1	1.1	0.9				
	1527	1	0.0	0.0	0.0	0.0	3	1.0272074711095325	50.77006063006336	275.0	1	1.1	0.9				
	1529	1	0.0	0.0	0.0	0.0	3	1.0600477040099225	27.8581169670347	275.0	1	1.1	0.9				
	1530	1	0.0	0.0	0.0	0.0	3	1.0385447236287	57.53344901565255	275.0	1	1.1	0.9				
	1531	2	0.0	0.0	0.0	-140.68239138708032	3	1.0556265742422064	45.68396321629584	275.0	1	1.1	0.9				
	1533	1	0.0	0.0	0.0	122.31071220897095	3	1.063197518908151	28.1405826206547	275.0	1	1.1	0.9				
	1534	2	0.0	0.0	0.0	-189.68407547394764	3	1.0395799062155262	38.73486877143426	275.0	1	1.1	0.9				
	1536	1	0.0	0.0	0.0	0.0	3	1.0602516925140375	32.43045224921606	330.0	1	1.1	0.9				
	1538	1	0.0	0.0	0.0	0.0	3	1.0588278986088457	48.83105476874821	275.0	1	1.1	0.9				
	1540	1	0.0	0.0	0.0	0.0	3	1.0600727481481458	25.08851595035804	275.0	1	1.1	0.9				
	1541	1	0.0	0.0	0.0	0.0	3	1.0508630566964587	38.79918223725528	275.0	1	1.1	0.9				
	1542	1	0.0	0.0	0.0	-50.1496852527559	3	1.0523621819234963	51.27406749117126	275.0	1	1.1	0.9				
	1543	1	0.0	0.0	0.0	0.0	3	1.0594247540177588	22.55470329297056	275.0	1	1.1	0.9				
	1545	1	0.0	0.0	0.0	0.0	3	1.0598842077039574	22.83950721667241	275.0	1	1.1	0.9				
	1546	1	0.0	0.0	0.0	-60.1898302757554	3	1.0302235388848124	60.81827595975565	275.0	1	1.1	0.9				
	1555	1	0.0	0.0	0.0	0.0	3	1.0611959350441298	22.19941333624091	275.0	1	1.1	0.9				
	1556	1	0.0	0.0	0.0	0.0	3	1.0612735152405322	22.14263116269521	275.0	1	1.1	0.9				
	1557	1	0.0	0.0	0.0	-61.28309358106928	3	1.053299234493907	33.08765315740141	275.0	1	1.1	0.9				
	1558	2	24.5770346607918	13.020185481211902	0.0	0.0	3	1.0064999999997681	65.7572461306955	20.0	1	1.1	0.9				
	1559	2	25.869081946544696	12.3137372527523	0.0	0.0	3	1.0042299999997855	66.31674391369118	20.0	1	1.1	0.9				
	1560	2	15.719781461235499	18.498657379614	0.0	0.0	3	0.9947799999996391	61.77912072250083	20.0	1	1.1	0.9				
	1561	2	25.175595185420402	12.379340618205099	0.0	0.0	3	1.00247999999979	66.45830299405657	20.0	1	1.1	0.9				
	1562	2	0.0	0.0	0.0	122.41095479764002	3	1.0648617155123072	24.36680084440276	275.0	1	1.1	0.9				
	1564	2	0.0	0.0	0.0	-80.1927778260782	3	1.0536492981037135	41.91438266637671	275.0	1	1.1	0.9				
	1566	2	0.0	0.0	0.0	0.0	3	1.0610454520109465	26.4496801004002	275.0	1	1.1	0.9				
	1568	1	0.0	0.0	0.0	0.0	3	1.0585753021155468	24.96877522930973	275.0	1	1.1	0.9				
	1569	1	0.0	0.0	0.0	-21.171742991246298	3	1.0501800287903813	31.18842803677279	275.0	1	1.1	0.9				
	1570	1	0.0	0.0	0.0	-19.828121023764794	3	1.0504407502734079	31.074274648254395	275.0	1	1.1	0.9				
	1571	1	0.0	0.0	0.0	240.97411633282886	3	1.0312093938003979	51.10208795732373	275.0	1	1.1	0.9				
	1574	1	0.0	0.0	0.0	0.0	3	1.0638629713407313	24.85239564464127	275.0	1	1.1	0.9				
	1577	1	0.0	0.0	0.0	0.0	3	1.0335553205756436	53.68600083111744	275.0	1	1.1	0.9				
	1578	1	0.0	0.0	0.0	0.0	3	1.0624804034763125	25.70240708198427	275.0	1	1.1	0.9				
	1579	1	0.0	0.0	0.0	0.0	3	1.0570367995882426	36.40693869459176	275.0	1	1.1	0.9				
	1580	1	0.0	0.0	0.0	0.0	3	1.0561485638956767	42.29033408840755	275.0	1	1.1	0.9				
	1582	1	0.0	0.0	0.0	0.0	3	1.059126456398943	42.45910063322171	275.0	1	1.1	0.9				
	1584	1	1.92798706148141	-16.89329836739043	0.0	0.0	3	1.0370597321930695	55.06669231497421	275.0	1	1.1	0.9				
	1585	1	0.0	0.0	0.0	0.0	3	1.054828266288986	41.87198339319462	275.0	1	1.1	0.9				
	1586	1	0.0	0.0	0.0	0.0	3	1.0547772558188189	41.87013702235428	275.0	1	1.1	0.9				
	1587	1	0.0	0.0	0.0	0.0	3	1.0436368126672984	36.45205883065152	275.0	1	1.1	0.9				
	1588	1	0.0	0.0	0.0	0.0	3	1.048452835790591	39.09350126656414	275.0	1	1.1	0.9				
	1589	1	0.0	0.0	0.0	0.0	3	1.0543145967770917	41.195543716859	275.0	1	1.1	0.9				
	1590	1	0.0	0.0	0.0	0.0	3	1.042144855951937	35.66489977487463	275.0	1	1.1	0.9				
	1591	1	0.0	0.0	0.0	0.0	3	1.0382246113267681	34.08034251702445	132.0	1	1.1	0.9				
	1596	1	0.0	0.0	0.0	0.0	3	1.0417897728865064	19.94218162981679	110.0	1	1.1	0.9				
	1597	1	1.6198231538217511	2.1814317388640196	0.0	0.0	3	1.052099348636059	39.82132911136394	275.0	1	1.1	0.9				
	1598	1	0.0	0.0	0.0	0.0	3	1.0385644359497237	33.03658640787222	110.0	1	1.1	0.9				
	1599	1	0.0	0.0	0.0	0.0	3	0.9685350983831894	38.17223528104676	132.0	1	1.1	0.9				
	1601	1	0.0	0.0	0.0	0.0	3	1.0155212294358598	32.66352583050478	132.0	1	1.1	0.9				
	1602	1	0.0	0.0	0.0	0.0	3	1.0152639613016816	32.65894630217722	132.0	1	1.1	0.9				
	1606	1	0.0	0.0	0.0	97.92839353438467	3	1.0497379833164973	17.3245265399351	110.0	1	1.1	0.9				
	1607	1	0.0	0.0	0.0	0.0	3	1.03017765229874	34.73843853215104	132.0	1	1.1	0.9				
	1608	1	42.2648624581646	15.1932559387964	0.0	0.0	3	1.0303045144144383	16.6406002922427	110.0	1	1.1	0.9				
	1613	1	0.0	0.0	0.0	0.0	3	1.037183002392764	58.91846904723762	275.0	1	1.1	0.9				
	1615	1	28.315677173559603	10.95326979663102	0.0	15.527084234760203	3	1.0374447783493908	35.23900078944889	66.0	1	1.1	0.9				
	1616	1	0.0	0.0	0.0	0.0	3	1.0222185219794357	36.66939195479564	132.0	1	1.1	0.9				
	1617	1	14.21740148220184	3.6956643617024603	0.0	0.0	3	1.00848467674769	16.74462430665344	11.0	1	1.1	0.9				
	1618	1	13.47432170222955	4.6428086301568	0.0	0.0	3	1.002265944978008	16.71576290239653	11.0	1	1.1	0.9				
	1620	1	96.82306136139582	28.79118343236604	0.0	0.0	3	1.0233697290315265	17.09678302557383	33.0	1	1.1	0.9				
	1621	1	0.0	0.0	0.0	0.0	3	1.0580095268548524	41.15203940580296	330.0	1	1.1	0.9				
	1623	1	0.0	0.0	0.0	-120.16715040989196	3	1.0546694817107265	35.93526786892599	330.0	1	1.1	0.9				
	1624	1	13.259884733595301	-4.17517940491866	0.0	0.0	3	1.0473121158018779	35.08092241280293	132.0	1	1.1	0.9				
	1625	1	0.0	0.0	0.0	0.0	3	1.0597339806218262	36.18866672435539	330.0	1	1.1	0.9				
	1628	2	26.1777880304224	19.7905713920539	0.0	0.0	3	1.0036599999993978	40.19598800764921	19.0	1	1.1	0.9				
	1629	2	26.528018161945	19.9169200363876	0.0	0.0	3	1.0050999999994	40.31779462739448	19.0	1	1.1	0.9				
	1632	1	21.8225086853667	4.555951919110489	0.0	0.0	3	0.979196900196547	38.97032582458279	33.0	1	1.1	0.9				
	1633	1	0.0	0.0	0.0	0.0	4	0.94445728953853	52.35901531218943	33.0	1	1.1	0.9				
	1634	1	16.295529192293298	6.81198767242939	0.0	6.520032971944659	4	0.9863055770445682	42.89001669521288	11.0	1	1.1	0.9				
	1635	1	0.0	0.0	0.0	0.0	4	1.0512629330519043	53.547523316339706	275.0	1	1.1	0.9				
	1636	2	0.0	0.0	0.0	0.0	4	0.9935200000002254	72.92697190793405	0.6899999999999998	1	1.1	0.9				
	1637	1	-43.459951306032	0.0	0.0	-0.9790376942120489	4	1.0092104161837474	69.19341708786708	0.4	1	1.1	0.9				
	1638	1	0.0	0.0	0.0	0.0	4	0.9909615768386981	64.6964057326151	11.0	1	1.1	0.9				
	1639	1	0.0	0.0	0.0	0.0	4	0.9736434434321901	63.61663208570954	11.0	1	1.1	0.9				
	1640	2	0.0	0.0	0.0	0.0	4	0.9987299999997172	60.66039863289914	1.0	1	1.1	0.9				
	1641	2	0.0	0.0	0.0	0.0	4	0.9940999999997856	58.59620798321743	1.0	1	1.1	0.9				
	1642	2	0.0	0.0	0.0	0.0	4	0.9949299999998024	58.0237884817624	0.48	1	1.1	0.9				
	1643	2	-2.00688195452094	0.0	0.0	0.0	4	1.036030000000822	61.3731300326585	0.6899999999999998	1	1.1	0.9				
	1644	1	-23.3537939124182	0.0	0.0	0.0	4	1.0311857454804045	60.82301985102499	0.6899999999999998	1	1.1	0.9				
	1645	1	-19.8507007576697	0.0	0.0	0.0	4	1.034276813976932	60.0738053195134	0.6899999999999998	1	1.1	0.9				
	1646	2	0.0	0.0	0.0	0.0	4	1.0328200000000323	61.62564986720208	0.6899999999999998	1	1.1	0.9				
	1647	1	0.0	0.0	0.0	1.7233732483209998	4	1.0170651391973642	58.39248015327402	0.48	1	1.1	0.9				
	1648	1	0.0	0.0	0.0	1.72064088531537	4	1.0170456246516886	58.39248015327531	0.48	1	1.1	0.9				
	1649	1	0.0	0.0	0.0	1.1054837101418495	4	1.0137635157707445	59.06881288957025	0.48	1	1.1	0.9				
	1650	1	0.0	0.0	0.0	1.1279398342058997	4	1.0137875449325429	59.068812889557236	0.48	1	1.1	0.9				
	1651	2	0.0	0.0	0.0	0.0	4	1.0218500000006283	59.86718730921766	0.6899999999999998	1	1.1	0.9				
	1652	2	0.0	0.0	0.0	0.0	4	1.0170300000004575	65.0333551466579	0.6899999999999998	1	1.1	0.9				
	1653	2	0.0	0.0	0.0	0.0	4	1.0256100000006032	60.63975021018911	0.6899999999999998	1	1.1	0.9				
	1654	2	0.0	0.0	0.0	0.0	4	1.0126300000006265	64.14645310855214	0.6899999999999998	1	1.1	0.9				
	1655	2	0.0	0.0	0.0	0.0	4	1.013580000000674	62.77678109184895	0.6899999999999998	1	1.1	0.9				
	1656	2	0.0	0.0	0.0	0.0	4	1.0154400000006538	63.46612667210331	0.6899999999999998	1	1.1	0.9				
	1657	1	14.997183499787997	0.0	0.0	1.4999104982083695	4	1.0937370890369211	55.41172330050858	33.0	1	1.1	0.9				
	1658	2	0.0	0.0	0.0	0.0	4	0.9931800000007519	53.30864143939517	0.6899999999999998	1	1.1	0.9				
	1659	2	0.0	0.0	0.0	0.0	4	0.9806400000009817	45.72081981118047	11.5	1	1.1	0.9				
	1660	2	0.0	0.0	0.0	0.0	4	0.98165000000098	45.72081981118059	11.5	1	1.1	0.9				
	1661	2	0.0	0.0	0.0	0.0	4	0.9734700000009826	45.72082029116851	11.5	1	1.1	0.9				
	1662	2	0.0	0.0	0.0	0.0	4	0.9827700000009835	45.72082029116941	11.5	1	1.1	0.9				
	1663	2	3.8027889899666363	-0.11290805393992895	0.0	0.0	4	1.0142843700010258	45.72082194938371	66.0	1	1.1	0.9				
	1664	1	8.771568784897259	2.5900974000758	0.0	0.0	4	0.9870118041005609	46.42391816341129	33.0	1	1.1	0.9				
	1665	2	0.0	0.0	0.0	0.0	4	0.9760600000009765	46.36182285100745	11.5	1	1.1	0.9				
	1666	2	0.0	0.0	0.0	0.0	4	0.9660300000009765	46.361822851006536	11.5	1	1.1	0.9				
	1667	2	0.0	0.0	0.0	0.0	4	0.9779000000009739	46.36182338453956	11.5	1	1.1	0.9				
	1668	2	0.0	0.0	0.0	0.0	4	0.9769300000009765	46.36182338453956	11.5	1	1.1	0.9				
	1669	2	0.0	0.0	0.0	0.0	4	0.9742700000009783	46.361824738545636	11.5	1	1.1	0.9				
	1670	1	0.0	0.0	0.0	0.0	4	1.0192644126273442	46.36182037532137	66.0	1	1.1	0.9				
	1671	1	0.0	0.0	0.0	0.0	4	0.9914046356263303	54.879566556325514	13.2	1	1.1	0.9				
	1672	1	0.0	0.0	0.0	0.0	4	0.9914046356263319	54.87956655632571	13.2	1	1.1	0.9				
	1673	1	0.0	0.0	0.0	0.0	4	0.9914046653959466	54.87956825269018	10.5	1	1.1	0.9				
	1674	1	0.0	0.0	0.0	0.0	4	0.9914046653959447	54.87956825269018	10.5	1	1.1	0.9				
	1675	1	0.0	0.0	0.0	0.0	4	0.9914046309508321	54.87956652331518	9.5	1	1.1	0.9				
	1676	1	0.0	0.0	0.0	0.0	4	0.9914046309508338	54.87956652331521	9.5	1	1.1	0.9				
	1677	1	0.0	0.0	0.0	0.0	4	0.9914046491591257	54.87956733135307	10.5	1	1.1	0.9				
	1678	1	0.0	0.0	0.0	0.0	4	0.9914046491591247	54.87956733135304	10.5	1	1.1	0.9				
	1679	2	0.0	0.0	0.0	0.0	4	1.0673300000006525	62.43744041359419	0.6899999999999998	1	1.1	0.9				
	1680	2	0.0	0.0	0.0	0.0	4	1.0115800000007096	59.74649711708915	33.0	1	1.1	0.9				
	1681	2	0.0	0.0	0.0	0.0	4	1.067800000000662	58.931880737057114	0.6899999999999998	1	1.1	0.9				
	1682	2	0.0	0.0	0.0	0.0	4	1.00795000000033	66.15732570350232	0.6899999999999998	1	1.1	0.9				
	1683	2	-11.7696274001151	0.0	0.0	0.0	4	1.0941099999998292	79.06193762855276	0.6899999999999998	1	1.1	0.9				
	1684	2	4.17243404168356	0.0695106546308845	0.0	0.0	4	0.9955300000007796	53.50431222617049	15.75	1	1.1	0.9				
	1685	2	4.31874350848887	0.07453176079317932	0.0	0.0	4	0.9975900000007835	53.41580038189267	15.75	1	1.1	0.9				
	1686	2	0.0	0.0	0.0	0.0	4	0.9960700000007556	54.28064251343056	15.75	1	1.1	0.9				
	1687	1	0.0	0.0	0.0	0.0	4	0.9866765013154609	47.65139149400753	11.0	1	1.1	0.9				
	1688	1	0.0	0.0	0.0	0.0	4	0.9866765125729899	47.65139119527944	11.0	1	1.1	0.9				
	1689	1	0.0	0.0	0.0	0.0	4	1.0110221539263593	47.65152390781769	15.0	1	1.1	0.9				
	1690	2	1.55235963503504	1.30523845625692	0.0	0.0	4	1.0010100000008255	51.4068585934224	13.8	1	1.1	0.9				
	1691	2	1.5344769597681198	1.2750447002085898	0.0	0.0	4	0.9952600000008217	51.497386937533484	13.8	1	1.1	0.9				
	1692	2	1.56282342983242	1.29331962912083	0.0	0.0	4	1.0017400000008283	51.2272391267264	13.8	1	1.1	0.9				
	1693	2	2.94927706166124	1.38589267322733	0.0	0.0	4	1.0054100000008381	51.4059649655502	16.0	1	1.1	0.9				
	1694	2	3.03088349851444	1.5085992015189	0.0	0.0	4	1.0118400000008263	51.82712641339661	16.0	1	1.1	0.9				
	1695	2	2.94676093480042	1.50007566219997	0.0	0.0	4	1.008770000000835	51.52051070541105	16.0	1	1.1	0.9				
	1696	2	1.20571279134895	0.6298188150809151	0.0	0.0	4	1.0173800000008273	53.04710910379702	15.75	1	1.1	0.9				
	1697	2	1.7496757498833397	0.8731592510128391	0.0	0.0	4	1.0172100000008155	53.3275802613909	11.5	1	1.1	0.9				
	1698	1	-20.060326442148266	3.53206910181539	0.0	0.0	4	1.014811006728427	46.8421626437288	66.0	1	1.1	0.9				
	1699	2	0.0	0.0	0.0	0.0	4	1.00360000000228	50.764172983186036	11.0	1	1.1	0.9				
	1700	1	0.0	0.0	0.0	0.0	4	1.0056628108986574	46.43111878287116	11.0	1	1.1	0.9				
	1701	1	2.7865335258937436	-3.94276456530718	0.0	0.0	4	1.003388142084436	58.08124466358543	33.0	1	1.1	0.9				
	1702	1	0.0	0.0	0.0	0.0	4	0.9954912852088296	55.12274239455157	11.5	1	1.1	0.9				
	1703	1	0.0	0.0	0.0	0.0	4	0.9186016769906531	55.12274239455155	11.5	1	1.1	0.9				
	1704	1	0.0	0.0	0.0	0.0	4	0.9070031709680417	55.12274239455135	11.5	1	1.1	0.9				
	1705	2	0.0	0.0	0.0	0.0	4	1.0024000000023752	62.3882160837622	0.6899999999999998	1	1.1	0.9				
	1706	2	0.0	0.0	0.0	0.0	4	1.0026700000023439	62.57083086290698	0.6899999999999998	1	1.1	0.9				
	1707	1	-75.9788742111806	0.0	0.0	0.0	4	0.9814035742623649	72.50993146516927	0.6899999999999998	1	1.1	0.9				
	1708	2	0.0	0.0	0.0	0.0	4	1.012529999999742	73.00613259326956	1.0	1	1.1	0.9				
	1709	2	0.0	0.0	0.0	0.0	4	0.9623100000026901	73.86612688520232	1.0	1	1.1	0.9				
	1710	2	0.0	0.0	0.0	0.0	4	0.9821300000028351	73.51043064392638	1.0	1	1.1	0.9				
	1711	2	0.0	0.0	0.0	0.0	4	1.0643600000005915	60.91712489332004	0.6899999999999998	1	1.1	0.9				
	1712	2	0.0	0.0	0.0	0.0	4	1.009970000000618	59.09330176223546	33.0	1	1.1	0.9				
	1713	1	1.1981462610094802	-11.4274928615361	0.0	0.0	4	1.0127009651993502	51.79088890632951	132.0	1	1.1	0.9				
	1715	2	0.0	0.0	0.0	-49.60047858466942	4	1.0310000000009543	48.61714902333333	275.0	1	1.1	0.9				
	1717	1	0.0	0.0	0.0	40.37174403327519	4	0.9846347505404891	68.78078956153306	33.0	1	1.1	0.9				
	1718	1	1.7163797946842392	-3.137962159964353	0.0	0.0	4	1.0108116520669153	61.0387078778352	66.0	1	1.1	0.9				
	1720	2	0.0	0.0	0.0	-31.195545157883288	4	1.051740000000749	40.05305818722874	275.0	1	1.1	0.9				
	1722	1	0.0	0.0	0.0	13.361749854055201	4	1.0018388432699485	68.28275863088453	33.0	1	1.1	0.9				
	1723	1	0.0	0.0	0.0	0.0	4	1.0533674654903433	54.87956845858551	275.0	1	1.1	0.9				
	1724	1	0.0	0.0	0.0	0.0	4	1.0515441901776699	56.01179337091768	275.0	1	1.1	0.9				
	1725	1	0.0	0.0	0.0	-143.46044840058298	4	1.0307728244421488	52.12117318170489	275.0	1	1.1	0.9				
	1726	1	0.0	0.0	0.0	0.0	4	1.0497557112770244	53.90961046449688	275.0	1	1.1	0.9				
	1727	1	0.0	0.0	0.0	0.0	4	1.045087042934149	53.20082297218437	275.0	1	1.1	0.9				
	1728	1	0.0	0.0	0.0	0.0	4	1.0240839875867278	51.95258076336581	275.0	1	1.1	0.9				
	1729	1	0.0	0.0	0.0	50.221603235526516	4	1.0406718804876574	48.77661686136304	275.0	1	1.1	0.9				
	1730	1	0.0	0.0	0.0	0.0	4	1.016067558714497	42.56037569325197	275.0	1	1.1	0.9				
	1731	1	0.0	0.0	0.0	0.0	4	1.0456053455762444	54.48279807400525	275.0	1	1.1	0.9				
	1732	1	0.0	0.0	0.0	0.0	4	1.0398434958082252	52.69141110258693	275.0	1	1.1	0.9				
	1733	1	0.0	0.0	0.0	0.0	4	1.0439415808359032	50.6194384774533	275.0	1	1.1	0.9				
	1734	1	0.0	0.0	0.0	0.0	4	1.0525380716279742	51.09893400663061	275.0	1	1.1	0.9				
	1740	1	19.98980572863193	8.886522006962592	0.0	-0.3184112219999999	4	1.0144731168291932	46.40021428541366	66.0	1	1.1	0.9				
	1742	1	0.0	0.0	0.0	-1.267404975000003	4	1.040031698496496	48.75609023970389	275.0	1	1.1	0.9				
	1743	1	0.0	0.0	0.0	0.0	4	1.0024232896306886	58.0259024953352	132.0	1	1.1	0.9				
	1744	1	5.459146496424319	2.3426339661463595	0.0	0.0	4	0.9993675762719262	57.65171468461086	33.0	1	1.1	0.9				
	1745	1	0.0	0.0	0.0	-21.805389491999996	4	1.0407798896005183	49.08460804433789	275.0	1	1.1	0.9				
	1747	1	0.0	0.0	0.0	100.69504581857498	4	1.0571477181747104	47.7612479874282	275.0	1	1.1	0.9				
	1748	1	4.19199413618487	0.158280233575124	0.0	0.0	4	1.0118198239026805	46.49192409781957	66.0	1	1.1	0.9				
	1749	1	0.0	0.0	0.0	-1.7160530640000013	4	1.0387360565117372	48.59599316167847	275.0	1	1.1	0.9				
	1751	1	0.0	0.0	0.0	36.498784492996734	4	1.0447721912234567	47.78047415664753	275.0	1	1.1	0.9				
	1752	1	0.0	0.0	0.0	29.097992239909747	4	1.0446225641827658	47.73761420153554	275.0	1	1.1	0.9				
	1753	1	0.0	0.0	0.0	11.102380594603916	4	1.048193041801558	47.33986125973458	275.0	1	1.1	0.9				
	1754	1	0.0	0.0	0.0	0.0	4	1.0623972172262666	45.20992914626921	275.0	1	1.1	0.9				
	1755	1	0.0	0.0	0.0	0.0	4	1.0636350732821178	44.95060761009401	275.0	1	1.1	0.9				
	1758	1	0.0	0.0	0.0	0.0	4	1.0485248834422327	47.28635388300722	275.0	1	1.1	0.9				
	1759	1	0.0	0.0	0.0	-0.7396117650000029	4	1.0402915457108286	48.9583892402059	275.0	1	1.1	0.9				
	1760	1	0.0	0.0	0.0	0.0	4	1.0513971297174207	53.54655304929123	275.0	1	1.1	0.9				
	1761	1	0.0	0.0	0.0	0.0	4	1.0534779727970653	47.49516954923805	275.0	1	1.1	0.9				
	1763	1	0.0	0.0	0.0	-36.698709251077936	4	1.033861945066547	48.40540558833329	275.0	1	1.1	0.9				
	1764	1	0.0	0.0	0.0	-28.164524657999973	4	1.0406274480653928	48.99959616899397	275.0	1	1.1	0.9				
	1765	1	0.0	0.0	0.0	-29.823167354799796	4	1.062471148027493	44.89719789693641	275.0	1	1.1	0.9				
	1766	1	0.0	0.0	0.0	0.0	4	1.0434651639778583	48.96691129725713	275.0	1	1.1	0.9				
	1768	2	0.0	0.0	0.0	0.0	4	0.9844900000047887	68.78119752407109	33.0	1	1.1	0.9				
	1769	2	0.0	0.0	0.0	0.0	4	1.0020800000008054	68.28221148561603	33.0	1	1.1	0.9				
	1770	1	0.0	0.0	0.0	0.0	4	1.052370252284896	53.19124532514424	275.0	1	1.1	0.9				
	1771	1	5.5764885174343295	2.4664500844943795	0.0	0.0	4	1.0043943705638387	51.35705923650857	132.0	1	1.1	0.9				
	1772	1	0.0	0.0	0.0	0.0	4	0.9969416014732227	51.02723127496215	132.0	1	1.1	0.9				
	1773	1	12.143518523715601	-0.6574198765127919	0.0	0.0	4	1.0081364614109256	54.48578801172171	132.0	1	1.1	0.9				
	1775	1	2.85607749935892	-10.4268151640077	0.0	0.0	4	1.0188641075154787	61.16684429698489	132.0	1	1.1	0.9				
	1777	1	0.0	0.0	0.0	0.0	4	1.011205567754147	66.02011977000765	132.0	1	1.1	0.9				
	1780	1	0.0	0.0	0.0	0.0	4	1.0063544174367105	51.5183361655963	132.0	1	1.1	0.9				
	1781	1	0.0	0.0	0.0	0.0	4	1.002785550198709	64.69640573261495	132.0	1	1.1	0.9				
	1782	1	0.0	0.0	0.0	0.0	4	1.0427803442764758	50.65816911325551	132.0	1	1.1	0.9				
	1783	1	0.8770092328009201	2.26961497681802	0.0	0.0	4	1.0421126300352257	50.660449464817255	132.0	1	1.1	0.9				
	1784	1	39.6890873266188	-12.842692461545699	0.0	0.0	4	0.9993210326214045	39.54606582728265	132.0	1	1.1	0.9				
	1785	1	0.0	0.0	0.0	0.0	4	1.0394429915916916	50.80080340438947	132.0	1	1.1	0.9				
	1786	1	0.0	0.0	0.0	0.0	4	1.0002844266855877	52.76848185520777	132.0	1	1.1	0.9				
	1787	1	2.2540113800525696	-1.13636884448351	0.0	0.0	4	1.0010206983293426	52.6592298323832	132.0	1	1.1	0.9				
	1789	1	0.0	0.0	0.0	0.0	4	1.0176134654812703	51.40087508250831	132.0	1	1.1	0.9				
	1791	1	0.10452713104896198	-0.4642657675569411	0.0	0.0	4	1.0241909344120061	49.07395635949062	132.0	1	1.1	0.9				
	1792	1	1.2486985527869299	0.909505742653459	0.0	0.0	4	1.0198042537637826	47.06861332640816	132.0	1	1.1	0.9				
	1793	1	1.1849798901025699	-0.41461733782701204	0.0	0.0	4	1.0096925776512176	43.33521957927879	132.0	1	1.1	0.9				
	1794	1	0.8780088202960789	-1.8302522195253499	0.0	0.0	4	1.0008666252530667	39.23318046459984	132.0	1	1.1	0.9				
	1795	1	0.0	0.0	0.0	0.0	4	0.9995730188613575	38.42116446507779	132.0	1	1.1	0.9				
	1797	1	0.0	0.0	0.0	0.0	4	1.047830382464256	50.55991116247288	132.0	1	1.1	0.9				
	1798	1	0.0	0.0	0.0	0.0	4	1.013819110475272	52.06020609821797	132.0	1	1.1	0.9				
	1799	1	0.0	0.0	0.0	0.0	4	1.0241487717932833	48.23745514895119	132.0	1	1.1	0.9				
	1800	1	0.0	0.0	0.0	18.348260864149808	4	1.0115021193844083	25.47360716993378	132.0	1	1.1	0.9				
	1803	1	0.0	0.0	0.0	0.0	4	1.0152900072439068	52.34000733940182	132.0	1	1.1	0.9				
	1804	1	0.0	0.0	0.0	0.0	4	1.0049030252240545	48.09861967813537	132.0	1	1.1	0.9				
	1805	1	0.0	0.0	0.0	0.0	4	1.0220867303838597	51.30781766441622	132.0	1	1.1	0.9				
	1807	1	13.818737279837716	5.09050166397347	0.0	0.0	4	1.0137523398236978	48.02536173910236	132.0	1	1.1	0.9				
	1808	1	8.828925544474181	6.241431146037209	0.0	0.0	4	1.0113088183501295	48.3397822591901	132.0	1	1.1	0.9				
	1809	1	0.0	0.0	0.0	0.0	4	1.025132081419084	47.59743696620179	132.0	1	1.1	0.9				
	1810	1	0.0	0.0	0.0	0.0	4	1.006160606793215	58.03209749043845	132.0	1	1.1	0.9				
	1811	1	0.0	0.0	0.0	0.0	4	1.0051099104030174	58.27043878630552	132.0	1	1.1	0.9				
	1812	1	0.0	0.0	0.0	0.0	4	1.0054383499249433	63.11405878132874	132.0	1	1.1	0.9				
	1813	1	0.0	0.0	0.0	0.0	4	1.0236512990929916	70.37594507251664	132.0	1	1.1	0.9				
	1815	1	0.0	0.0	0.0	0.0	4	1.019258511405663	51.2599306800884	132.0	1	1.1	0.9				
	1816	1	0.0	0.0	0.0	0.0	4	1.023609329340016	46.55863288607458	132.0	1	1.1	0.9				
	1817	1	0.0	0.0	0.0	0.0	4	1.0218545672489499	46.0189725317209	132.0	1	1.1	0.9				
	1818	1	0.0	0.0	0.0	0.0	4	1.0128230236856377	51.79002622026866	132.0	1	1.1	0.9				
	1819	1	2.2291842697188304	0.11965946782752901	0.0	0.0	4	1.023050206940531	46.84117769620081	132.0	1	1.1	0.9				
	1821	1	0.0	0.0	0.0	0.0	4	1.0197211652870053	46.23572634569064	132.0	1	1.1	0.9				
	1822	1	0.2016957704303782	1.9209270617867862	0.0	0.0	4	1.0172327333403517	45.65074513482542	132.0	1	1.1	0.9				
	1824	1	5.07065556205446	2.821128374923114	0.0	0.0	4	1.015700233495428	45.14308149397594	132.0	1	1.1	0.9				
	1825	1	2.5110759851943705	1.7956627605275202	0.0	0.0	4	1.0161697322806114	44.7880603875188	132.0	1	1.1	0.9				
	1826	1	5.84056378774121	3.1336567850844905	0.0	0.0	4	1.0162335579623598	44.89086029065047	132.0	1	1.1	0.9				
	1827	1	6.761213582798842	3.9948183225933453	0.0	0.0	4	1.0181696426463736	45.39378529504289	132.0	1	1.1	0.9				
	1828	1	0.0	0.0	0.0	0.0	4	1.0313389643681259	44.46730512184057	132.0	1	1.1	0.9				
	1830	1	0.0	0.0	0.0	0.0	4	1.0438487351258332	43.96543171400331	132.0	1	1.1	0.9				
	1831	1	0.0	0.0	0.0	0.0	4	1.0325991827352645	45.73012178478934	132.0	1	1.1	0.9				
	1832	1	0.0	0.0	0.0	14.339210506528602	4	1.056347701514769	44.94899844942206	132.0	1	1.1	0.9				
	1833	1	0.0	0.0	0.0	0.0	4	1.0176441982504325	46.94176153775634	132.0	1	1.1	0.9				
	1834	1	0.0	0.0	0.0	0.0	4	1.0101086539589106	48.93295591776706	132.0	1	1.1	0.9				
	1835	1	0.0	0.0	0.0	0.0	4	1.0203785673390493	55.1227423945513	132.0	1	1.1	0.9				
	1836	1	0.0	0.0	0.0	0.0	4	1.017403885050437	58.36388344238617	132.0	1	1.1	0.9				
	1838	1	0.0	0.0	0.0	0.0	4	1.0063985851630832	51.51786274617766	132.0	1	1.1	0.9				
	1839	1	0.0	0.0	0.0	0.0	4	1.0437560991902743	46.43111878287129	132.0	1	1.1	0.9				
	1840	1	0.0	0.0	0.0	0.0	4	1.0129659712989703	46.42824838583885	66.0	1	1.1	0.9				
	1841	1	6.50685915285917	4.731886475687386	0.0	-0.7577322419999993	4	1.0236313626706184	47.65173646025263	66.0	1	1.1	0.9				
	1842	1	1.3086852590056601	-0.912121922529535	0.0	0.0	4	1.0218370370296206	51.0009004849281	33.0	1	1.1	0.9				
	1843	1	10.96351240602322	3.7878342734426296	0.0	0.0	4	1.0123162544198345	37.79144865348827	66.0	1	1.1	0.9				
	1844	1	0.0	0.0	0.0	0.0	4	0.9875839377386504	24.01284864759567	66.0	1	1.1	0.9				
	1845	1	56.26913765792122	10.689801385721575	0.0	0.0	4	0.9856989629502306	23.72627033589045	66.0	1	1.1	0.9				
	1846	1	0.0	0.0	0.0	0.0	4	1.0105915029713868	46.19323665694053	66.0	1	1.1	0.9				
	1847	1	0.0	0.0	0.0	0.0	4	1.0097195360942486	46.12153341260368	66.0	1	1.1	0.9				
	1848	1	2.12344028916326	-2.13890913547511	0.0	-0.7244873610000009	4	1.0214517544261588	47.10896062602893	66.0	1	1.1	0.9				
	1849	1	0.0	0.0	0.0	-0.5104303260000007	4	1.0190465030629594	46.89752439683022	66.0	1	1.1	0.9				
	1850	1	0.0	0.0	0.0	0.0	4	1.0161825070249157	46.65999943798435	66.0	1	1.1	0.9				
	1851	1	0.0	0.0	0.0	-0.21405703500000017	4	1.0183687797308527	46.46961067067278	66.0	1	1.1	0.9				
	1853	1	6.75007713092677	2.03506389457122	0.0	0.0	4	1.0234463867094654	46.79220889392055	66.0	1	1.1	0.9				
	1855	1	0.0	0.0	0.0	0.0	4	1.018297082509497	46.32612683124693	66.0	1	1.1	0.9				
	1856	1	0.0	0.0	0.0	0.0	4	1.019467545408807	46.4742884893979	66.0	1	1.1	0.9				
	1857	1	10.13656589943971	0.1691696807596832	0.0	0.0	4	1.0029068037867832	56.68872217155588	33.0	1	1.1	0.9				
	1858	1	0.0	0.0	0.0	-0.12347417700000003	4	1.02290769319254	47.71888146986824	66.0	1	1.1	0.9				
	1860	1	0.0	0.0	0.0	0.0	4	1.0117678906130299	46.4607151396679	66.0	1	1.1	0.9				
	1861	1	0.0	0.0	0.0	0.0	4	1.0170879792837024	46.98219124408761	66.0	1	1.1	0.9				
	1863	1	13.453758310799312	4.711496790331882	0.0	0.0	4	1.0172843226158692	46.34176045001419	66.0	1	1.1	0.9				
	1864	1	19.296613620424743	14.86667231412451	0.0	0.0	4	1.0176224845909145	47.27036072492376	66.0	1	1.1	0.9				
	1866	1	4.85123441168344	4.44555931147006	0.0	0.0	4	1.0133891809905313	46.83481518713367	66.0	1	1.1	0.9				
	1867	1	0.0	0.0	0.0	-0.3608711279999991	4	1.0203628583552165	47.48819208334712	66.0	1	1.1	0.9				
	1868	1	0.0	0.0	0.0	0.0	4	1.0176006133764464	47.42039991227378	66.0	1	1.1	0.9				
	1869	1	0.0	0.0	0.0	0.0	4	1.0127063925646622	46.68975650339608	66.0	1	1.1	0.9				
	1870	1	0.0	0.0	0.0	0.0	4	1.0128435006969732	46.42235111681238	66.0	1	1.1	0.9				
	1872	1	0.0	0.0	0.0	0.0	4	1.0133323221374182	46.46106195096482	66.0	1	1.1	0.9				
	1873	1	0.0	0.0	0.0	0.0	4	1.0124620566971405	46.32715299547922	66.0	1	1.1	0.9				
	1875	1	0.0	0.0	0.0	30.25994172273199	4	1.0159345385074052	46.09838918096411	66.0	1	1.1	0.9				
	1876	1	0.0	0.0	0.0	0.0	4	1.0193714486743721	45.740200268333	66.0	1	1.1	0.9				
	1877	1	0.0	0.0	0.0	0.0	4	1.023676870114796	47.65139149400738	66.0	1	1.1	0.9				
	1880	1	0.0	0.0	0.0	0.0	4	1.013864589769762	46.16493450662407	66.0	1	1.1	0.9				
	1881	1	7.06217190745063	3.0790575548005803	0.0	0.0	4	1.015371675829677	46.76319247542721	66.0	1	1.1	0.9				
	1882	1	0.0	0.0	0.0	0.0	4	1.0132766235667061	46.37959014017441	66.0	1	1.1	0.9				
	1883	1	0.0	0.0	0.0	0.0	4	1.0125503598255505	46.28515018356856	66.0	1	1.1	0.9				
	1885	1	0.0	0.0	0.0	0.0	4	1.0139896418954444	46.68878798690832	66.0	1	1.1	0.9				
	1886	1	0.0	0.0	0.0	0.0	4	1.0130723789650553	46.65325713023748	66.0	1	1.1	0.9				
	1887	1	0.0	0.0	0.0	0.0	4	1.0134299381865317	46.5517190064117	66.0	1	1.1	0.9				
	1888	1	0.0	0.0	0.0	0.0	4	1.01367922130643	46.59447777239713	66.0	1	1.1	0.9				
	1889	1	0.0	0.0	0.0	0.0	4	1.0103988397303865	46.18975012624465	66.0	1	1.1	0.9				
	1890	1	0.0	0.0	0.0	-0.3202699560000007	4	1.0124294572288566	46.37411533542441	66.0	1	1.1	0.9				
	1891	1	0.0	0.0	0.0	-0.4998647309999986	4	1.0156076445958928	46.0384121272925	66.0	1	1.1	0.9				
	1892	1	0.0	0.0	0.0	-0.6726054719999993	4	1.016638771161683	46.7547854634497	66.0	1	1.1	0.9				
	1893	1	0.0	0.0	0.0	0.0	4	1.0147770871272799	45.12618748305751	66.0	1	1.1	0.9				
	1894	1	0.0	0.0	0.0	-0.33366009899999943	4	1.0147371065457174	45.40198225221371	66.0	1	1.1	0.9				
	1895	1	0.0	0.0	0.0	-0.16620463199999916	4	1.015011979916346	45.33747056756031	66.0	1	1.1	0.9				
	1900	1	0.0	0.0	0.0	-0.8982786989999987	4	1.0157180982873784	46.55616892196327	66.0	1	1.1	0.9				
	1901	1	0.0	0.0	0.0	-0.22567322699999937	4	1.0133301852488363	46.04582827955495	66.0	1	1.1	0.9				
	1902	1	0.0	0.0	0.0	0.0	4	1.0087303359984023	45.89846786972909	66.0	1	1.1	0.9				
	1903	1	0.0	0.0	0.0	0.0	4	1.01503050518731	45.39875296249025	66.0	1	1.1	0.9				
	1904	1	0.0	0.0	0.0	-0.3202699560000007	4	1.0126051665769529	46.08441223605081	66.0	1	1.1	0.9				
	1905	1	0.0	0.0	0.0	-0.3920352869999998	4	1.0148973122901432	46.58152147457151	66.0	1	1.1	0.9				
	1907	1	0.0	0.0	0.0	0.0	4	1.0142211606167597	45.11883433467752	66.0	1	1.1	0.9				
	1908	1	5.040421211574877	-2.6259862799038607	0.0	-2.634301847999995	4	1.015338466247688	45.13165067123445	66.0	1	1.1	0.9				
	1910	1	0.0	0.0	0.0	0.0	4	1.0200382515808772	45.7771241107346	66.0	1	1.1	0.9				
	1912	1	1.9464628310788448	-0.22322793607302	0.0	0.0	4	1.017589124516057	46.048006018188815	66.0	1	1.1	0.9				
	1913	1	0.0	0.0	0.0	0.0	4	1.013913547043891	45.537231612423476	66.0	1	1.1	0.9				
	1914	1	4.92893099567778	2.44484811107517	0.0	0.0	4	1.0149966254700715	45.56593903439094	66.0	1	1.1	0.9				
	1915	1	0.0	0.0	0.0	0.0	4	1.0167297927547956	45.59943660424678	66.0	1	1.1	0.9				
	1917	1	0.0	0.0	0.0	0.0	4	1.0148118280813296	45.49336124201191	66.0	1	1.1	0.9				
	1918	1	0.0	0.0	0.0	0.0	4	1.016797285950203	45.59762510133046	66.0	1	1.1	0.9				
	1919	1	0.0	0.0	0.0	0.0	4	1.0142649095340062	45.70412909300296	66.0	1	1.1	0.9				
	1921	1	0.0	0.0	0.0	0.0	4	1.0138395594483125	45.64791290495494	66.0	1	1.1	0.9				
	1923	1	0.0	0.0	0.0	0.0	4	1.0149403132238908	45.70819691964608	66.0	1	1.1	0.9				
	1924	1	0.0	0.0	0.0	0.0	4	1.0147517711716025	45.62113370615803	66.0	1	1.1	0.9				
	1925	1	0.0	0.0	0.0	0.0	4	1.014924306880902	45.535397789525	66.0	1	1.1	0.9				
	1926	1	0.0	0.0	0.0	0.0	4	1.016845711316536	45.61531378168821	66.0	1	1.1	0.9				
	1929	1	0.0	0.0	0.0	0.0	4	1.0136718309544634	45.64513207582932	66.0	1	1.1	0.9				
	1930	1	0.0	0.0	0.0	0.0	4	1.0143294645966325	45.64570940297119	66.0	1	1.1	0.9				
	1931	1	5.09806911463403	-0.293986052025576	0.0	0.0	4	1.0168463925479674	46.19814337077504	66.0	1	1.1	0.9				
	1932	1	0.0	0.0	0.0	0.0	4	1.014260677706131	45.82381755353743	66.0	1	1.1	0.9				
	1933	1	0.0	0.0	0.0	0.0	4	1.0116671609554975	45.85650240535184	66.0	1	1.1	0.9				
	1934	1	0.5981500482698899	-0.447915480848216	0.0	0.0	4	1.0169462639455746	46.15953308005096	66.0	1	1.1	0.9				
	1935	1	0.0	0.0	0.0	0.0	4	1.0118480240942755	45.75786109379697	66.0	1	1.1	0.9				
	1936	1	0.0	0.0	0.0	0.0	4	1.014619163325037	46.58757526826969	66.0	1	1.1	0.9				
	1937	1	0.0	0.0	0.0	0.0	4	1.0124286013130117	46.3126813420765	66.0	1	1.1	0.9				
	1938	1	0.0	0.0	0.0	-0.19976287200000037	4	1.023676099374492	47.65139757892608	66.0	1	1.1	0.9				
	1941	1	14.197918590656945	3.7203230835887613	0.0	0.0	4	1.007789064052989	46.35361867201718	66.0	1	1.1	0.9				
	1943	1	0.0	0.0	0.0	0.0	4	1.0145022614042054	46.65318344697879	66.0	1	1.1	0.9				
	1945	1	0.0	0.0	0.0	-2.634301847999995	4	1.0180711441037225	45.42952760769271	66.0	1	1.1	0.9				
	1946	1	0.0	0.0	0.0	0.0	4	1.024359092176964	47.762168315629005	66.0	1	1.1	0.9				
	1947	1	10.150695884424078	1.4594235155991278	0.0	0.0	4	1.0145347542783552	44.81957768854379	33.0	1	1.1	0.9				
	1948	1	2.69901307592168	0.39332804782316105	0.0	0.0	4	1.0156737457570573	46.38213682257845	66.0	1	1.1	0.9				
	1949	1	0.0	0.0	0.0	0.0	4	1.0118759096107686	45.99095016186793	66.0	1	1.1	0.9				
	1950	1	0.0	0.0	0.0	0.0	4	1.0148922709240782	45.71011046708255	66.0	1	1.1	0.9				
	1951	1	3.48388253204711	1.00154139901698	0.0	0.0	4	1.0056026261992783	45.93383884212972	33.0	1	1.1	0.9				
	1953	1	0.0	0.0	0.0	0.0	4	1.014782842832906	45.59133108260392	66.0	1	1.1	0.9				
	1954	1	0.0	0.0	0.0	0.0	4	1.0096144000161302	46.5281242154114	66.0	1	1.1	0.9				
	1955	1	0.0	0.0	0.0	0.0	4	1.0126780501745705	46.75210087796196	66.0	1	1.1	0.9				
	1956	1	0.101287985821255	-2.53105233221892	0.0	0.0	4	1.022334892640949	50.99398345514913	33.0	1	1.1	0.9				
	1957	1	5.71487122002896	0.6839430433690551	0.0	0.0	4	1.00259921711196	52.84697134217551	33.0	1	1.1	0.9				
	1958	1	0.0	0.0	0.0	0.0	4	1.0068771028978034	67.68241468657118	33.0	1	1.1	0.9				
	1959	1	0.0	0.0	0.0	0.0	4	0.9902487153976425	69.28937585580724	33.0	1	1.1	0.9				
	1960	1	14.354127977560601	0.6193185119805861	0.0	0.0	4	1.0111134129858428	50.74065567282114	33.0	1	1.1	0.9				
	1961	1	0.0	0.0	0.0	12.590930928848696	4	0.9929955298437443	58.023791009847514	33.0	1	1.1	0.9				
	1967	1	10.825255572725101	2.9569984704723598	0.0	-6.02867170181125	4	0.9858139864750984	63.61663208570949	33.0	1	1.1	0.9				
	1968	1	0.0	0.0	0.0	-5.1662712919060105	4	1.0161113451428676	58.39248015426224	33.0	1	1.1	0.9				
	1969	1	0.0	0.0	0.0	-4.910241533536461	4	1.013156526222936	59.06881289020408	33.0	1	1.1	0.9				
	1972	1	0.103133109123446	-0.16612729416657201	0.0	0.0	4	1.0395919826579585	50.78927746959474	33.0	1	1.1	0.9				
	1974	1	0.0	0.0	0.0	13.158405933156597	4	1.022908616305847	58.38861837532408	33.0	1	1.1	0.9				
	1975	1	3.5330562149372	1.8401226834797804	0.0	0.0	4	1.0172562450164322	50.79497780363021	33.0	1	1.1	0.9				
	1976	1	9.9763220013611	4.29637412003218	0.0	0.0	4	1.010321089140466	49.68614430513185	33.0	1	1.1	0.9				
	1977	1	31.665514492417934	6.213712242047026	0.0	0.0	4	1.0123486124975203	49.57518231035023	33.0	1	1.1	0.9				
	1978	1	0.0	0.0	0.0	12.371176076703701	4	1.0113316787946525	60.7785700470763	33.0	1	1.1	0.9				
	1979	1	0.0	0.0	0.0	15.402845868142343	4	1.0139811151267066	60.05690251324137	33.0	1	1.1	0.9				
	1980	1	0.0	0.0	0.0	15.274630187335408	4	1.0145246331800029	60.31844480206734	33.0	1	1.1	0.9				
	1982	1	15.65741383527699	8.07652210311396	0.0	0.0	4	0.9950263435066339	46.92493169500239	33.0	1	1.1	0.9				
	1983	2	0.0	0.0	0.0	-7.701346375793216	4	1.0139400000006884	57.1391526530677	33.0	1	1.1	0.9				
	1984	2	0.0	0.0	0.0	0.6512590869702422	4	0.9566200000003648	64.46088773629441	33.0	1	1.1	0.9				
	1985	1	1.63484782455815	-0.20946032363339298	0.0	0.0	4	1.005761994770748	62.88919986424969	33.0	1	1.1	0.9				
	1986	1	2.3350719569223	1.74021095311227	0.0	0.0	4	1.0192101279920953	70.07231880504163	33.0	1	1.1	0.9				
	1987	2	0.0	0.0	0.0	0.0	4	1.0725799999999204	76.449332437167	22.0	1	1.1	0.9				
	1988	1	1.90222201185566	1.3158317076039001	0.0	0.0	4	0.9843006602083773	46.40752783365761	33.0	1	1.1	0.9				
	1989	1	2.8205973120147396	1.31034160763598	0.0	0.0	4	0.9730958707570999	45.03310754203201	11.0	1	1.1	0.9				
	1990	1	1.541569736731471	0.635675921807158	0.0	0.0	4	1.0001923850414542	46.38673962864324	33.0	1	1.1	0.9				
	1991	1	6.38352066995758	-4.864378894874547	0.0	0.0	4	1.0144889412227853	44.73095690234167	33.0	1	1.1	0.9				
	1992	1	3.5907431839976502	0.76878279276453	0.0	0.0	4	0.9999741089872188	44.60306693638635	33.0	1	1.1	0.9				
	1993	1	3.6906752113828	17.9814802803077	0.0	0.0	4	1.0178960401353152	47.07925075555378	66.0	1	1.1	0.9				
	1994	1	4.8296695143838395	1.981793874748377	0.0	0.0	4	1.0164538322853864	50.92341161035201	33.0	1	1.1	0.9				
	1995	1	0.0	0.0	0.0	0.0	4	1.0513971297174185	53.54655304929119	33.0	1	1.1	0.9				
	1996	1	12.8972580348789	5.80114821606176	0.0	0.0	4	0.9996011638098953	42.89923297934651	33.0	1	1.1	0.9				
	1997	1	12.660377474866799	5.35345746759851	0.0	0.0	4	1.0011941263297812	42.9781394003024	33.0	1	1.1	0.9				
	1998	1	5.35157284631748	1.1219982267125002	0.0	0.0	4	1.0234627246208237	43.07113214124319	33.0	1	1.1	0.9				
	1999	1	5.69182668264369	1.0291609048767	0.0	0.0	4	1.0239988111783433	43.01807390190032	33.0	1	1.1	0.9				
	2000	1	5.99516321515925	2.52893867921261	0.0	0.0	4	0.9943534704494282	42.32891233999462	33.0	1	1.1	0.9				
	2001	1	5.15964921649806	1.9974763753036502	0.0	0.0	4	1.070423013040781	42.64973065961549	33.0	1	1.1	0.9				
	2002	1	9.013346729853929	3.5031237248720597	0.0	0.0	4	1.0464457047106261	43.7531491575007	33.0	1	1.1	0.9				
	2003	1	14.04526267254013	3.2493310412839094	0.0	0.0	4	1.0102522541856167	45.50569627953477	33.0	1	1.1	0.9				
	2004	1	26.823696826955295	9.231327538137558	0.0	0.0	4	1.0140553446518001	46.96937282926182	33.0	1	1.1	0.9				
	2005	1	3.4902833956447403	0.907984854025021	0.0	0.0	4	1.015303206530919	54.25330285270621	33.0	1	1.1	0.9				
	2009	1	50.0110210370732	36.100344932582	0.0	0.0	4	0.9352615421386037	48.23863406811081	33.0	1	1.1	0.9				
	2010	1	0.0	0.0	0.0	0.0	4	1.0126776164448257	46.7520805403354	33.0	1	1.1	0.9				
	2011	1	0.0	0.0	0.0	-5.310486417617648	4	0.9816919912337283	61.15609942532665	11.0	1	1.1	0.9				
	2012	1	0.0	0.0	0.0	-5.056744600497189	4	0.9833989508611245	61.14681295426931	11.0	1	1.1	0.9				
	2013	1	16.65690244254144	1.29427581817019	0.0	0.0	4	1.0040879055931027	36.42157987099492	11.0	1	1.1	0.9				
	2014	1	17.965401431407642	1.44501982107405	0.0	0.0	4	1.002436287212111	35.94171258246839	11.0	1	1.1	0.9				
	2015	1	7.627068112920568	-0.42944338569538987	0.0	0.0	4	0.99926335803193	38.08632217495659	11.0	1	1.1	0.9				
	2016	1	9.74211438536667	1.4643493473040896	0.0	0.0	4	1.0176680951782928	37.63257789390335	11.0	1	1.1	0.9				
	2017	1	15.209935962905409	4.361125776556041	0.0	0.0	4	1.00581517117673	36.50989931206967	11.0	1	1.1	0.9				
	2018	1	11.029366726801726	1.2458597064009003	0.0	0.0	4	1.0180599433595054	37.37802480054028	11.0	1	1.1	0.9				
	2019	1	14.9731870472066	4.558599505613372	0.0	0.0	4	1.0042741653304346	36.41924245783762	11.0	1	1.1	0.9				
	2020	1	8.0534561468652	3.10801802081298	0.0	0.0	4	0.9935468830988563	44.04848428665456	11.0	1	1.1	0.9				
	2021	1	0.2780681447465898	-0.200592596638575	0.0	0.0	4	0.9913698284058673	45.581320742873444	11.0	1	1.1	0.9				
	2022	1	0.2529728813969496	-0.160422459266894	0.0	0.0	4	0.9909460630906083	45.60038933727937	11.0	1	1.1	0.9				
	2023	1	0.30699140784554024	-0.212704603088647	0.0	0.0	4	0.99141074926467	45.57088870937304	11.0	1	1.1	0.9				
	2024	1	0.29082793343160995	-0.163117179154046	0.0	0.0	4	0.9909447976851863	45.58264842293233	11.0	1	1.1	0.9				
	2025	1	0.08670604601501997	-0.0777118948905263	0.0	0.0	4	0.9902868146930291	45.68349167739478	11.0	1	1.1	0.9				
	2026	1	0.005816270550709657	-0.15940522497128704	0.0	0.0	4	0.9910499605931936	45.72689352355152	11.0	1	1.1	0.9				
	2027	1	5.35642264007088	2.04645719330711	0.0	0.0	4	0.9811669875468682	45.23682736720306	11.0	1	1.1	0.9				
	2028	1	13.69966151804924	4.19945957499728	0.0	0.0	4	0.9797649510027046	42.98698151943668	11.0	1	1.1	0.9				
	2029	1	5.054600388681045	1.4158233749844138	0.0	0.0	4	1.0076750628989937	45.7753602013894	11.0	1	1.1	0.9				
	2030	1	8.36778367828513	2.5890406616586694	0.0	0.0	4	0.9796083962396008	44.07575017289	11.0	1	1.1	0.9				
	2031	1	9.23653643496986	1.6285408646186799	0.0	0.0	4	0.9951913992615309	43.91253297141746	11.0	1	1.1	0.9				
	2032	1	4.83301326559531	-0.64754867747426	0.0	0.0	4	1.0928911430713608	45.46452391445172	11.0	1	1.1	0.9				
	2033	1	24.23846854848349	4.824177519214159	0.0	0.0	4	0.9852744849062272	42.04259978596235	11.0	1	1.1	0.9				
	2034	1	0.0	0.0	0.0	0.0	4	1.079505122177093	74.25037855790762	1.0	1	1.1	0.9				
	2035	1	10.352476997643382	3.8385998511577	0.0	0.0	4	0.9916961146821528	43.73588436872317	11.0	1	1.1	0.9				
	2036	1	9.83670557822781	3.8813555237436694	0.0	0.0	4	1.0042213925269117	43.95558152671481	11.0	1	1.1	0.9				
	2037	1	4.51464072968904	0.813854366145097	0.0	0.0	4	0.9986720191214257	45.58774769999206	7.6	1	1.1	0.9				
	2038	1	1.107569647770003	1.501365976547822	0.0	0.0	4	1.0021200067732672	47.30722597331921	7.6	1	1.1	0.9				
	2039	1	2.62008775810725	-2.23964109666436	0.0	0.0	4	0.9822045441481309	46.29134870685647	7.6	1	1.1	0.9				
	2040	1	12.531975879854329	6.27256211167202	0.0	0.0	4	0.9994681455271491	44.19190044073833	11.0	1	1.1	0.9				
	2041	1	9.25383924798877	4.881216024212909	0.0	0.0	4	1.0029399974874091	44.97202037856237	11.0	1	1.1	0.9				
	2042	1	0.101179745025001	-0.31782638497673904	0.0	0.0	4	1.02379443374948	47.46278399361712	11.0	1	1.1	0.9				
	2043	1	0.104108264190145	0.0121706651737914	0.0	0.0	4	0.9851556449294735	46.431224722917	7.6	1	1.1	0.9				
	2044	1	7.26515795047507	2.7904987871246902	0.0	0.0	4	1.0099860594272718	44.53122949697082	11.0	1	1.1	0.9				
	2045	1	0.0	0.0	0.0	0.0	4	1.0003106051580206	46.3950602109168	7.6	1	1.1	0.9				
	2046	1	15.03247665478466	5.0971205591396505	0.0	0.0	4	1.0099294690495828	42.44850244576087	11.0	1	1.1	0.9				
	2047	1	7.06565607123962	2.7289453376017	0.0	0.0	4	0.9956220266247235	44.37262900958335	11.0	1	1.1	0.9				
	2048	1	14.961123161664599	7.36583667364628	0.0	0.0	4	1.0013939620482846	42.20708313733664	11.0	1	1.1	0.9				
	2049	1	32.03763642093009	15.022891364196841	0.0	0.0	4	1.0080576459827537	42.56467132470042	11.0	1	1.1	0.9				
	2050	1	1.4109509079734799	0.63448354619192	0.0	0.0	4	1.0034059643221	45.352226871319594	11.0	1	1.1	0.9				
	2051	1	15.48018194392882	7.562215009022269	0.0	6.404270726582039	4	1.0019697428053718	42.15760820671508	11.0	1	1.1	0.9				
	2052	1	8.07236222105394	4.574013431291471	0.0	0.0	4	1.002599251837088	44.04134507806573	11.0	1	1.1	0.9				
	2053	1	12.94363136836216	3.39736201884672	0.0	0.0	4	1.0049108535936082	42.88487027633526	11.0	1	1.1	0.9				
	2054	1	7.41324904771149	2.30137294231076	0.0	0.0	4	1.0102548704810208	42.32512604379844	11.0	1	1.1	0.9				
	2055	1	5.78397217995366	1.57657965494506	0.0	0.0	4	0.9921862704248082	45.16098639527603	11.0	1	1.1	0.9				
	2056	1	5.4546318201422705	1.86374262012611	0.0	0.0	4	0.9899775437934027	45.22817354745659	11.0	1	1.1	0.9				
	2057	1	8.46790593026625	4.542128824828191	0.0	0.0	4	1.0118463532149826	44.1266812065424	11.0	1	1.1	0.9				
	2058	1	12.60869469165569	5.311659317529481	0.0	0.0	4	0.998934053579429	43.42114869966145	11.0	1	1.1	0.9				
	2059	1	7.76646407800341	1.5947539887529327	0.0	0.0	4	0.9798511362447881	44.74231229352196	11.0	1	1.1	0.9				
	2060	1	1.22793174504116	0.659180604384653	0.0	0.0	4	1.0038779729947171	45.53546020649767	11.0	1	1.1	0.9				
	2061	1	14.751268680197931	6.17857638104511	0.0	0.0	4	1.0025699581668281	42.41211371319507	11.0	1	1.1	0.9				
	2062	1	18.173941410299157	6.30852069486659	0.0	0.0	4	0.9854358689187436	41.99482474582877	11.0	1	1.1	0.9				
	2063	1	14.351080166066993	4.8297562069088205	0.0	0.0	4	0.9889321003885154	41.68713270609133	11.0	1	1.1	0.9				
	2064	1	2.2276353253920598	0.588735844992427	0.0	0.0	4	1.0209448766855829	44.77309042418896	11.0	1	1.1	0.9				
	2065	1	6.763917906812718	3.14218619408779	0.0	0.0	4	0.9985266441247365	44.20701810343555	11.0	1	1.1	0.9				
	2066	1	11.54596722310376	5.177285787047031	0.0	0.0	4	0.9794778065913419	42.63173562758456	11.0	1	1.1	0.9				
	2067	1	12.7073198784918	4.01615223692181	0.0	0.0	4	0.9920889404088218	42.95854545182068	11.0	1	1.1	0.9				
	2068	1	26.606119815995218	37.4750416557602	0.0	0.0	4	1.0878849371629626	41.47599640970355	11.0	1	1.1	0.9				
	2069	1	10.29926802053908	3.6588513867616603	0.0	0.0	4	1.002272046533859	41.97735374211011	11.0	1	1.1	0.9				
	2070	1	30.523209602929995	8.09479625406768	0.0	0.0	4	0.9926298575409909	39.32441222901203	11.0	1	1.1	0.9				
	2071	1	25.25577467254199	5.54697978735888	0.0	0.0	4	0.9770744032275963	40.10988352781665	11.0	1	1.1	0.9				
	2072	1	33.7484809163647	4.29561025180333	0.0	0.0	4	0.9722464149782972	37.50562909489814	11.0	1	1.1	0.9				
	2073	1	0.0	0.0	0.0	0.0	4	0.9843986688498726	37.50558551442078	66.0	1	1.1	0.9				
	2074	1	16.25890782797532	5.242041934324661	0.0	0.0	4	0.9867027717708319	41.51200272619859	11.0	1	1.1	0.9				
	2075	1	10.2681210531095	3.7292921931214105	0.0	0.0	4	1.0072094364127526	42.790639036253395	11.0	1	1.1	0.9				
	2076	1	7.609967843447901	2.56851554650422	0.0	0.0	4	0.9984864157545545	43.21737140998624	11.0	1	1.1	0.9				
	2077	1	2.5096522673906296	1.065303192409873	0.0	0.0	4	0.9959887173864382	45.00917959773827	11.0	1	1.1	0.9				
	2078	1	7.293867577355731	3.06889022315601	0.0	0.0	4	0.9944889903428883	43.48036194440835	11.0	1	1.1	0.9				
	2079	1	4.69843236100227	2.0483416797407	0.0	0.0	4	0.9962824266799473	43.1771424833977	11.0	1	1.1	0.9				
	2080	1	5.003949049258599	3.19993379993993	0.0	0.0	4	0.9962103538920045	44.27763583582131	11.0	1	1.1	0.9				
	2081	1	3.64998104112223	1.39485329723191	0.0	0.0	4	0.9817333628321583	44.55952640595968	11.0	1	1.1	0.9				
	2082	1	14.302363582266029	4.68434814116666	0.0	0.0	4	0.9853554282554836	41.62965801625751	11.0	1	1.1	0.9				
	2083	1	7.61145394013934	3.3316030972668	0.0	0.0	4	0.9960378312755728	43.35126217900061	11.0	1	1.1	0.9				
	2084	1	20.9627419086049	7.30465038572508	0.0	0.0	4	1.003977502047599	40.4728062047666	11.0	1	1.1	0.9				
	2085	1	3.2940962409182495	0.8451467556908729	0.0	0.0	4	0.9967325803842637	44.74855787350085	11.0	1	1.1	0.9				
	2086	1	8.10787455773614	1.8154555411851039	0.0	0.0	4	0.9939887652584599	44.11357084842206	11.0	1	1.1	0.9				
	2088	1	10.6396922554962	3.07428525462979	0.0	0.0	4	0.9918671043298354	42.6976836292818	11.0	1	1.1	0.9				
	2089	1	8.26616495036222	4.1235905870272305	0.0	0.0	4	1.0007311423184946	43.57208282325615	11.0	1	1.1	0.9				
	2090	1	1.1044391018457203	-0.21271927563455	0.0	0.0	4	0.9893603571060909	45.16483313522086	11.0	1	1.1	0.9				
	2091	1	3.20633513126215	0.955240384535677	0.0	0.0	4	0.9914230510430972	45.08167855491193	11.0	1	1.1	0.9				
	2092	1	2.6673895262580403	0.838730720978882	0.0	0.0	4	1.008043405963309	46.32096617642549	11.0	1	1.1	0.9				
	2093	1	0.0959064914658666	-0.6381049964600239	0.0	0.0	4	1.0041344540710244	47.64656012850973	11.0	1	1.1	0.9				
	2094	1	7.85187370762462	2.9315077269669603	0.0	0.0	4	0.9706152564485565	44.19573293978289	7.6	1	1.1	0.9				
	2095	1	6.44027588314866	1.1092409330569208	0.0	0.0	4	1.0032997946940874	45.82739383591538	11.0	1	1.1	0.9				
	2096	1	12.944638185298071	4.48511734599243	0.0	0.0	4	1.01446636512431	42.93053657411796	11.0	1	1.1	0.9				
	2097	1	10.86834700245257	2.67710046144575	0.0	0.0	4	0.9885900180955318	43.11048830674416	11.0	1	1.1	0.9				
	2098	1	5.95045176579752	2.56236065968051	0.0	0.0	4	0.99591405201102	44.3905243513695	11.0	1	1.1	0.9				
	2099	1	3.10879923370513	1.0675315790179198	0.0	0.0	4	1.002488798346629	43.86130010491277	11.0	1	1.1	0.9				
	2100	1	5.0391577204961795	3.02881362562781	0.0	0.0	4	0.9981392393085409	45.62260410528631	11.0	1	1.1	0.9				
	2101	1	11.005922963579838	4.91273303378597	0.0	0.0	4	0.9874496203287908	43.88834986015117	11.0	1	1.1	0.9				
	2102	1	0.0	0.0	0.0	0.0	4	0.9873593117884655	63.69334910850618	11.0	1	1.1	0.9				
	2103	1	0.0	0.0	0.0	0.0	4	0.9869808796315364	63.663282764860305	11.0	1	1.1	0.9				
	2104	1	13.669975704628182	-2.62818708385853	0.0	0.0	4	1.0880006061480592	37.0388063843391	11.0	1	1.1	0.9				
	2105	1	0.0	0.0	0.0	0.0	4	0.9866444734912517	23.84029764088626	11.0	1	1.1	0.9				
	2106	1	0.0	0.0	0.0	0.0	4	0.9871898603216346	23.95426785814588	11.0	1	1.1	0.9				
	2107	1	0.0	0.0	0.0	0.0	4	1.0109129095842655	45.60828041655103	11.0	1	1.1	0.9				
	2108	1	0.0	0.0	0.0	0.0	4	1.0163742753962737	54.41214258186715	11.0	1	1.1	0.9				
	2109	1	0.0	0.0	0.0	4.78175006550737	4	1.014283369980379	57.34816381323806	11.0	1	1.1	0.9				
	2110	1	0.0	0.0	0.0	4.77737188013271	4	1.0147274410972027	57.49216336769608	11.0	1	1.1	0.9				
	2111	1	2.63684411429353	1.132840416689124	0.0	0.0	4	1.0370145513826667	50.94052629029358	33.0	1	1.1	0.9				
	2112	1	-18.45662472600812	0.0	0.0	10.795830222758003	5	0.9892710496475579	-16.21300726626961	33.0	1	1.1	0.9				
	2113	2	0.0	0.0	0.0	303.01106154592713	5	1.0365999999974678	34.74333441354511	500.0	1	1.1	0.9				
	2114	2	0.0	0.0	0.0	0.0	5	0.988029999999963	-9.489058153242349	13.8	1	1.1	0.9				
	2115	2	0.0	0.0	0.0	0.0	5	0.9828199999999624	-9.475048074851928	13.8	1	1.1	0.9				
	2116	2	0.0	0.0	0.0	0.0	5	0.9881999999999609	-8.41596206661469	13.8	1	1.1	0.9				
	2117	2	0.0	0.0	0.0	0.0	5	1.0551099999999674	-15.20584568837946	11.0	1	1.1	0.9				
	2118	2	1.43784302386409	0.0	0.0	0.0	5	0.9815899999999754	-21.24889756639202	13.8	1	1.1	0.9				
	2119	2	0.0	0.0	0.0	0.0	5	0.9472699999999736	-23.12029656061829	11.0	1	1.1	0.9				
	2120	1	0.0	0.0	0.0	0.0	5	0.9867540138761887	-25.77252436975623	11.5	1	1.1	0.9				
	2121	1	0.0	0.0	0.0	0.0	5	0.9873162444127156	-25.97406112335485	11.5	1	1.1	0.9				
	2122	1	0.0	0.0	0.0	0.0	5	0.9873162444127166	-25.974061123354872	11.5	1	1.1	0.9				
	2123	2	0.0	0.0	0.0	0.0	5	0.9930699999999739	-19.50710126875388	11.5	1	1.1	0.9				
	2124	2	5.34111425835183	1.84528285784936	0.0	0.0	5	1.055739999999976	-19.35097242029227	14.5	1	1.1	0.9				
	2125	2	0.0	0.0	0.0	0.0	5	1.052709999999975	-19.84216304873227	13.2	1	1.1	0.9				
	2126	2	0.0	0.0	0.0	0.0	5	1.0549499999999845	-5.957068761405664	11.0	1	1.1	0.9				
	2127	2	0.0	0.0	0.0	0.0	5	1.0482099999999845	-5.97390143805796	11.0	1	1.1	0.9				
	2128	2	0.0	0.0	0.0	0.0	5	1.0503499999999855	-6.117747198316691	11.0	1	1.1	0.9				
	2129	2	0.0	0.0	0.0	0.0	5	1.0057099999999846	-4.956388096476981	11.0	1	1.1	0.9				
	2130	2	0.0	0.0	0.0	0.0	5	1.0063999999999846	-5.163580510229564	11.0	1	1.1	0.9				
	2131	2	0.0	0.0	0.0	0.0	5	1.0036499999999855	-5.132106409468764	11.0	1	1.1	0.9				
	2132	2	0.0	0.0	0.0	0.0	5	1.0319899999999682	-8.50321338915992	11.0	1	1.1	0.9				
	2133	2	0.0	0.0	0.0	0.0	5	0.9613799999999837	-7.330784215862151	11.0	1	1.1	0.9				
	2134	2	0.0	0.0	0.0	0.0	5	0.9564499999999666	1.383629340060046	18.0	1	1.1	0.9				
	2135	2	0.0	0.0	0.0	0.0	5	0.9563999999999667	1.484562050913067	18.0	1	1.1	0.9				
	2136	3	0.0	0.0	0.0	0.0	5	0.9491999999999672	-2.566064614410412e-12	18.0	1	1.1	0.9				
	2137	1	0.0	0.0	0.0	0.0	5	0.9989284558399221	-17.17576131378201	6.6	1	1.1	0.9				
	2138	2	0.0	0.0	0.0	0.0	5	1.0235599999999774	-17.06932269618163	11.0	1	1.1	0.9				
	2139	2	0.0	0.0	0.0	0.0	5	1.0172099999999782	-18.2516958498589	11.0	1	1.1	0.9				
	2140	2	0.0	0.0	0.0	0.0	5	0.9884199999999744	-11.52684528788591	16.0	1	1.1	0.9				
	2141	1	0.0	0.0	0.0	0.0	5	0.9851027127018712	-17.160558437709515	16.0	1	1.1	0.9				
	2142	2	0.0	0.0	0.0	0.0	5	0.98836999999997	-12.26099282348346	16.0	1	1.1	0.9				
	2143	2	0.0	0.0	0.0	0.0	5	0.9868499999999706	-12.30471471464168	16.0	1	1.1	0.9				
	2144	2	0.0	0.0	0.0	0.0	5	0.9899399999999694	-11.80968315810109	16.0	1	1.1	0.9				
	2145	1	0.0	0.0	0.0	0.0	5	0.9814537163638125	-18.05794123151719	16.0	1	1.1	0.9				
	2146	1	-7.48757228344437	0.0	0.0	0.0	5	1.0458064099536146	-22.62885027498207	0.6899999999999998	1	1.1	0.9				
	2147	1	0.0	0.0	0.0	0.0	5	1.0291574124903669	-23.27718797868486	22.0	1	1.1	0.9				
	2148	2	0.0	0.0	0.0	0.0	5	1.072739999999978	-22.83921961218258	1.0	1	1.1	0.9				
	2149	1	0.0	0.0	0.0	-5.707333615810607	5	0.9917766232329166	-16.15057865453107	13.8	1	1.1	0.9				
	2150	1	0.0	0.0	0.0	-6.037795464042566	5	0.9915434003621789	-16.1500205260412	13.8	1	1.1	0.9				
	2152	1	0.0	0.0	0.0	0.0	5	1.0322179518767036	-18.62283211417683	110.0	1	1.1	0.9				
	2153	1	0.0	0.0	0.0	0.0	5	1.0296384456928327	-18.71443108763672	110.0	1	1.1	0.9				
	2155	1	0.0	0.0	0.0	0.0	5	1.029358766737101	-18.53481022092111	110.0	1	1.1	0.9				
	2156	1	0.0	0.0	0.0	0.0	5	1.0321434824700746	-18.62190247396134	110.0	1	1.1	0.9				
	2157	1	0.0	0.0	0.0	0.0	5	1.0246072245334255	-19.39283891011664	110.0	1	1.1	0.9				
	2158	1	0.0	0.0	0.0	0.0	5	1.0280800159212082	-18.80424427533249	110.0	1	1.1	0.9				
	2160	1	0.0	0.0	0.0	0.0	5	1.030239148425398	-23.25155278564667	110.0	1	1.1	0.9				
	2161	1	0.0	0.0	0.0	0.0	5	1.0298979163191582	-23.43188183267197	110.0	1	1.1	0.9				
	2162	1	0.0	0.0	0.0	0.0	5	1.0273426353222792	-24.683561703395	110.0	1	1.1	0.9				
	2163	1	0.0	0.0	0.0	0.0	5	1.025492267571251	-24.85682165470057	110.0	1	1.1	0.9				
	2164	1	0.0	0.0	0.0	30.2475361833349	5	1.0381236669216882	-24.22099710888998	110.0	1	1.1	0.9				
	2165	1	0.0	0.0	0.0	0.0	5	1.0369786690845	-24.21526118327334	110.0	1	1.1	0.9				
	2166	1	0.0	0.0	0.0	29.894232766237096	5	1.0302264649004873	-23.25144886630597	110.0	1	1.1	0.9				
	2167	1	0.0	0.0	0.0	0.0	5	1.0307168732910854	-23.96898772933274	110.0	1	1.1	0.9				
	2168	1	0.0	0.0	0.0	0.0	5	1.0231642600894901	-23.87794214220728	110.0	1	1.1	0.9				
	2169	1	0.0	0.0	0.0	0.0	5	1.025611277320098	-23.70912916683793	110.0	1	1.1	0.9				
	2170	1	0.0	0.0	0.0	0.0	5	1.0262321341501854	-23.55802313083818	110.0	1	1.1	0.9				
	2171	1	0.0	0.0	0.0	0.0	5	1.0054221923977726	-21.08921997921235	110.0	1	1.1	0.9				
	2172	1	0.0	0.0	0.0	0.0	5	1.0155911786184337	-20.28243072670865	110.0	1	1.1	0.9				
	2173	1	0.0	0.0	0.0	27.5769489619415	5	1.0321907632602818	-25.97404479212958	110.0	1	1.1	0.9				
	2174	1	0.0	0.0	0.0	0.0	5	1.0294664820108792	-26.23850866449881	110.0	1	1.1	0.9				
	2175	1	109.5607387713567	5.564466014368461	0.0	0.0	5	1.0286410735762936	-26.387783469711355	110.0	1	1.1	0.9				
	2176	1	0.0	0.0	0.0	0.0	5	1.0180320222085428	-19.17667219695734	110.0	1	1.1	0.9				
	2177	1	0.0	0.0	0.0	0.0	5	1.017275017169279	-19.29365856979451	110.0	1	1.1	0.9				
	2178	1	0.0	0.0	0.0	0.0	5	1.0208968671416527	-18.44168455785722	110.0	1	1.1	0.9				
	2180	1	0.0	0.0	0.0	0.0	5	1.0521049759471799	-9.441695589474312	110.0	1	1.1	0.9				
	2183	1	0.0	0.0	0.0	0.0	5	1.0444188451714136	-10.94629438897348	110.0	1	1.1	0.9				
	2186	1	0.0	0.0	0.0	0.0	5	1.02615968379474	-11.57154785635901	110.0	1	1.1	0.9				
	2189	1	0.0	0.0	0.0	0.0	5	1.052307147666922	-9.453442420842276	110.0	1	1.1	0.9				
	2190	1	0.0	0.0	0.0	0.0	5	1.0213898975106936	-13.33567831722176	110.0	1	1.1	0.9				
	2192	1	0.0	0.0	0.0	0.0	5	1.02363142854976	-14.57547963894572	110.0	1	1.1	0.9				
	2193	1	0.0	0.0	0.0	0.0	5	1.0258335709655355	-14.01541046414393	110.0	1	1.1	0.9				
	2194	1	0.0	0.0	0.0	0.0	5	1.024653767082861	-14.26339022835959	110.0	1	1.1	0.9				
	2195	1	0.0	0.0	0.0	39.442905746400385	5	1.0229353069516054	-14.77813671605134	110.0	1	1.1	0.9				
	2198	1	0.0	0.0	0.0	0.0	5	1.0224268429166419	-14.924995913322961	110.0	1	1.1	0.9				
	2199	1	4.1484034366929	1.226811962736258	0.0	0.0	5	1.0943243991903566	-14.79895571287288	33.0	1	1.1	0.9				
	2200	1	0.0	0.0	0.0	0.0	5	1.0219940718710745	-15.05154039045583	110.0	1	1.1	0.9				
	2201	1	0.0	0.0	0.0	0.0	5	1.0219387283862174	-15.051271561860638	110.0	1	1.1	0.9				
	2202	1	0.0	0.0	0.0	0.0	5	1.0172684773958582	-15.44987718779515	110.0	1	1.1	0.9				
	2203	1	0.0	0.0	0.0	0.0	5	1.0215047718264618	-15.14638016724107	110.0	1	1.1	0.9				
	2204	1	0.0	0.0	0.0	0.0	5	1.0217819050202008	-14.426166370243312	110.0	1	1.1	0.9				
	2205	1	0.0	0.0	0.0	0.0	5	1.0218661369411564	-14.38137789435048	110.0	1	1.1	0.9				
	2206	1	0.0	0.0	0.0	0.0	5	1.0224164644898102	-14.3862573666353	110.0	1	1.1	0.9				
	2207	1	0.0	0.0	0.0	0.0	5	1.0185261848798728	-14.57533945520683	110.0	1	1.1	0.9				
	2208	1	0.0	0.0	0.0	0.0	5	0.9660015711330783	-20.04516282897815	110.0	1	1.1	0.9				
	2209	1	0.0	0.0	0.0	0.0	5	1.0161858248134827	-14.71933780818137	110.0	1	1.1	0.9				
	2210	1	0.0	0.0	0.0	0.0	5	1.0142969916955673	-14.83693599742162	110.0	1	1.1	0.9				
	2212	1	0.0	0.0	0.0	0.0	5	1.020436692358242	-15.17894251112132	110.0	1	1.1	0.9				
	2214	1	0.0	0.0	0.0	0.0	5	1.0147684000122736	-19.783825492362723	110.0	1	1.1	0.9				
	2215	1	0.0	0.0	0.0	0.0	5	1.0318104127705299	-16.62470997300982	110.0	1	1.1	0.9				
	2217	1	0.0	0.0	0.0	0.0	5	1.0390372764710192	-12.36198411891142	110.0	1	1.1	0.9				
	2219	1	0.0	0.0	0.0	0.0	5	1.0298569916179592	-17.16019818490092	110.0	1	1.1	0.9				
	2220	1	0.0	0.0	0.0	0.0	5	1.01631743605445	-19.72431678165227	110.0	1	1.1	0.9				
	2221	1	25.5331817143029	4.24297217381746	0.0	0.0	5	1.0993393044559845	-22.72160099609777	22.0	1	1.1	0.9				
	2222	1	0.0	0.0	0.0	0.0	5	1.01893794075006	-18.11864827298163	110.0	1	1.1	0.9				
	2223	1	0.0	0.0	0.0	0.0	5	1.0145842993272518	-20.00032214736967	110.0	1	1.1	0.9				
	2224	1	0.0	0.0	0.0	0.0	5	1.0162348517264008	-19.7156126169275	110.0	1	1.1	0.9				
	2225	1	0.0	0.0	0.0	0.0	5	1.0147477475748472	-20.00135541294635	110.0	1	1.1	0.9				
	2226	1	0.844463851361163	0.8114868596294891	0.0	0.0	5	1.0375979610570718	-24.2535844568909	110.0	1	1.1	0.9				
	2227	1	0.0	0.0	0.0	0.0	5	1.0162345576105354	-20.29594515332106	110.0	1	1.1	0.9				
	2228	1	1.2457492680387598	-0.664264286632184	0.0	0.0	5	1.032214299252591	-25.988549521459692	110.0	1	1.1	0.9				
	2229	1	0.0	0.0	0.0	0.0	5	1.0300101706900573	-23.95959433065251	110.0	1	1.1	0.9				
	2231	1	0.0	0.0	0.0	0.0	5	1.0145211168227537	-18.67274615403304	110.0	1	1.1	0.9				
	2232	1	0.0	0.0	0.0	0.0	5	1.0220519473997536	-15.026956258304992	110.0	1	1.1	0.9				
	2233	1	0.0	0.0	0.0	0.0	5	1.0220251670322253	-15.022579552431917	110.0	1	1.1	0.9				
	2234	1	6.30917010282744	0.35239491717051696	0.0	0.0	5	1.0199072659910848	-16.36817405275658	33.0	1	1.1	0.9				
	2235	1	6.39434930019695	0.321420691079041	0.0	0.0	5	1.0200819582369638	-16.36394690394274	33.0	1	1.1	0.9				
	2237	1	0.0	0.0	0.0	0.0	5	1.0145790484582364	-14.811271931403812	110.0	1	1.1	0.9				
	2238	1	0.0	0.0	0.0	0.0	5	1.0259983244759345	-17.0772235418764	110.0	1	1.1	0.9				
	2239	1	0.0	0.0	0.0	0.0	5	1.0637339871937446	-15.87506937968792	220.0	1	1.1	0.9				
	2240	1	0.0	0.0	0.0	0.0	5	1.062747550173364	-15.84778324294497	220.0	1	1.1	0.9				
	2241	1	0.0	0.0	0.0	0.0	5	1.0601433689426427	-16.75045808479722	220.0	1	1.1	0.9				
	2242	1	0.0	0.0	0.0	0.0	5	1.060235533640715	-17.26621151697347	220.0	1	1.1	0.9				
	2243	1	0.0	0.0	0.0	0.0	5	1.0586963749674714	-17.25549734359493	220.0	1	1.1	0.9				
	2244	1	0.0	0.0	0.0	0.0	5	1.051989765801392	-20.217224680694912	220.0	1	1.1	0.9				
	2247	1	0.0	0.0	0.0	0.0	5	1.0490206172661318	-21.16650701683569	220.0	1	1.1	0.9				
	2249	1	0.0	0.0	0.0	0.0	5	1.0483912402037672	-21.15965469998395	220.0	1	1.1	0.9				
	2250	2	761.8020958286986	94.39828227146313	0.0	269.6068504415632	5	1.0296740373743591	-24.79276502758318	220.0	1	1.1	0.9				
	2255	1	0.0	0.0	0.0	0.0	5	1.0492486487961408	-13.85483362343923	220.0	1	1.1	0.9				
	2259	1	0.0	0.0	0.0	0.0	5	1.0494538948179386	-13.01435494173578	220.0	1	1.1	0.9				
	2261	1	0.0	0.0	0.0	0.0	5	1.0442256085593427	-4.58558146103813	220.0	1	1.1	0.9				
	2262	1	0.0	0.0	0.0	0.0	5	1.0385769617593068	-11.76041861268009	220.0	1	1.1	0.9				
	2263	1	0.0	0.0	0.0	0.0	5	1.057482072980616	-15.30154127270596	220.0	1	1.1	0.9				
	2268	1	0.0	0.0	0.0	0.0	5	1.0507835169384796	-15.609004081076431	220.0	1	1.1	0.9				
	2269	1	0.0	0.0	0.0	0.0	5	1.0482670120936812	-18.05762958780429	220.0	1	1.1	0.9				
	2270	1	0.0	0.0	0.0	0.0	5	1.0384657423396055	-20.59648558559417	220.0	1	1.1	0.9				
	2272	1	0.10003649929077371	-0.13330990294576628	0.0	0.0	5	1.03948985613994	-23.72507962489301	11.0	1	1.1	0.9				
	2273	1	19.95778869203848	4.7859495971716	0.0	0.0	5	1.0320083393996549	-23.18020473619859	22.0	1	1.1	0.9				
	2274	1	14.10490769878494	9.04776996574207	0.0	0.0	5	0.9893770164696383	-15.852177747092682	6.6	1	1.1	0.9				
	2275	1	11.186850288082379	5.37348015239737	0.0	0.0	5	1.0003140403536441	-14.73528726991567	6.6	1	1.1	0.9				
	2276	1	1.233107867487501	0.521934969551628	0.0	0.0	5	1.006913043171447	-13.81231004796215	6.6	1	1.1	0.9				
	2277	1	38.265644643644194	12.083769897586519	0.0	0.0	5	1.0291138385409988	-17.47754323953622	33.0	1	1.1	0.9				
	2278	1	15.34797100767754	0.1797803614181466	0.0	0.0	5	1.0205120788874265	-16.58551465997508	33.0	1	1.1	0.9				
	2279	1	28.122039634649198	17.094118758766264	0.0	0.0	5	0.9898081629000567	-22.85508646581636	44.0	1	1.1	0.9				
	2280	1	2.2926686986223803	-0.21934176889881496	0.0	0.0	5	1.0179220678337146	-18.85216240169621	22.0	1	1.1	0.9				
	2281	1	-5.28103313928014	1.57365585478968	0.0	0.0	5	0.97826138118871	-17.02817873313822	11.0	1	1.1	0.9				
	2282	1	0.5954664766365659	0.164574361555371	0.0	0.0	5	1.023478271707599	-19.57698287577192	22.0	1	1.1	0.9				
	2283	1	2.86565043062568	0.9180621844714512	0.0	0.0	5	1.0379494520603652	-20.74992107161404	22.0	1	1.1	0.9				
	2284	1	0.10215504828840499	-0.07624182731648911	0.0	0.0	5	1.0288519284694282	-18.87106231725888	11.0	1	1.1	0.9				
	2285	1	14.893968516166831	5.50440336707248	0.0	0.0	5	1.0126491102834432	-26.63273906627095	22.0	1	1.1	0.9				
	2286	1	12.79405631512897	4.23152802724112	0.0	0.0	5	1.0349952719353563	-26.1648963914646	22.0	1	1.1	0.9				
	2287	1	32.8164347707108	4.9383484389306895	0.0	0.0	5	1.0130604950687556	-27.08084241175583	22.0	1	1.1	0.9				
	2288	1	4.969286691016694	2.3123035960519642	0.0	0.0	5	1.016874463217968	-25.01162006421151	11.0	1	1.1	0.9				
	2289	1	11.88898872021139	2.2430057880878502	0.0	0.0	5	1.0384908056954192	-25.49902500551748	22.0	1	1.1	0.9				
	2290	1	35.35571077000594	11.43917336843214	0.0	0.0	5	1.0270033105596745	-27.01666436722938	22.0	1	1.1	0.9				
	2291	1	37.048781804362804	13.56316755613722	0.0	0.0	5	1.0260119302617132	-28.48501465345068	22.0	1	1.1	0.9				
	2292	1	9.25709532036334	1.285278495783359	0.0	0.0	5	1.0017941132817687	-27.43024545821921	22.0	1	1.1	0.9				
	2293	1	6.8196875432964	1.66570804022136	0.0	0.0	5	1.0147294794956867	-19.77631315623392	22.0	1	1.1	0.9				
	2294	1	0.0	0.0	0.0	0.0	5	0.9727459429648896	-18.44168455785723	22.0	1	1.1	0.9				
	2295	1	1.1277204405401802	-0.131104909685906	0.0	0.0	5	1.0494280836513314	-10.34519887787562	22.0	1	1.1	0.9				
	2296	1	3.9179577825922496	1.1294581421904302	0.0	0.0	5	1.0580704245854142	-12.5845079323363	22.0	1	1.1	0.9				
	2297	1	0.09845539502799511	-0.15901145197441802	0.0	0.0	5	1.0545103994331686	-9.540796081465645	22.0	1	1.1	0.9				
	2298	1	7.005330225560809	0.63426609095335	0.0	0.0	5	1.0044474991618326	-17.03709829323878	11.0	1	1.1	0.9				
	2299	1	4.767843117410499	-0.3576221538626119	0.0	0.0	5	1.012203943225241	-16.34714669718289	11.0	1	1.1	0.9				
	2300	1	6.817376398877331	1.5293180603922338	0.0	0.0	5	1.038812822175421	-15.35276088742803	11.0	1	1.1	0.9				
	2301	1	6.357613794678221	1.104834498306596	0.0	0.0	5	1.0399753945290047	-15.272840932079617	11.0	1	1.1	0.9				
	2302	1	10.55584310108414	3.51356873629801	0.0	0.0	5	1.0138327049493927	-18.11172750639554	11.0	1	1.1	0.9				
	2303	1	7.9547446200374505	1.73341208708589	0.0	0.0	5	1.0172671035658574	-17.89192492916023	11.0	1	1.1	0.9				
	2304	1	2.9145850639238504	-0.20232489533424403	0.0	0.0	5	1.0225808913461591	-16.15903916275169	11.0	1	1.1	0.9				
	2305	1	3.2008208254247896	-0.0306372322946787	0.0	0.0	5	1.0212443829924935	-16.22066674625251	11.0	1	1.1	0.9				
	2306	1	1.23069639581465	0.148527247897536	0.0	0.0	5	1.0162222870716586	-15.820213942756112	22.0	1	1.1	0.9				
	2307	1	1.22012735772375	0.141469365238398	0.0	0.0	5	1.016307987487936	-15.793751163848842	22.0	1	1.1	0.9				
	2308	1	2.6974127487645	-0.518176212407649	0.0	0.0	5	1.0245676077218244	-15.449493600804193	11.0	1	1.1	0.9				
	2309	1	3.66248952773656	0.268230288469139	0.0	0.0	5	1.031752446014549	-15.687149755072268	11.0	1	1.1	0.9				
	2310	1	4.38782797689875	1.244169953752356	0.0	0.0	5	1.0150932963810873	-15.151429561216371	11.0	1	1.1	0.9				
	2311	1	11.31460263487744	3.43865919710733	0.0	0.0	5	1.0036387772072972	-20.04512183919965	11.0	1	1.1	0.9				
	2312	1	3.43738724450884	1.2064342375681738	0.0	0.0	5	1.0072495865048146	-15.78069558698501	11.0	1	1.1	0.9				
	2313	1	12.75081507823046	0.9336974987668458	0.0	0.0	5	1.0413966986936072	-17.34855046066847	22.0	1	1.1	0.9				
	2314	1	10.675037461534181	2.7200189300431	0.0	0.0	5	1.012240650937867	-15.13074029559587	22.0	1	1.1	0.9				
	2315	1	29.58494142791117	5.385695343371239	0.0	0.0	5	0.998542019939164	-22.4252541529333	22.0	1	1.1	0.9				
	2316	1	5.992160853297911	2.30522543602036	0.0	0.0	5	1.0042987916872037	-18.04160455186867	22.0	1	1.1	0.9				
	2317	1	9.06709590132348	2.28521256108359	0.0	0.0	5	1.0440482200674108	-21.2137352165843	22.0	1	1.1	0.9				
	2318	1	10.36757488414203	-0.0485898785246537	0.0	0.0	5	1.0153113249765695	-21.17308954131714	22.0	1	1.1	0.9				
	2319	1	0.0	0.0	0.0	0.0	5	1.030197587981174	-23.02342283597318	22.0	1	1.1	0.9				
	2320	1	16.1407656256639	3.3981742264056507	0.0	0.0	5	1.0001537058556877	-22.44012098543217	22.0	1	1.1	0.9				
	2321	1	5.512170804402	-0.297153097662144	0.0	0.0	5	1.019865223461809	-20.05441067998382	22.0	1	1.1	0.9				
	2322	1	0.268542500051344	0.31925762779302896	0.0	0.0	5	1.064091140262729	-14.8854324976392	11.0	1	1.1	0.9				
	2323	1	0.0	0.0	0.0	0.0	5	1.0491067870017945	-9.694714627305673	110.0	1	1.1	0.9				
	2324	1	0.0	0.0	0.0	0.0	5	1.042291805924153	-15.64890063897033	1.0	1	1.1	0.9				
	2325	1	0.0	0.0	0.0	0.0	5	1.0422805039944618	-15.62348805623716	1.0	1	1.1	0.9				
	2326	1	0.0	0.0	0.0	0.0	5	1.042130127935355	-15.65609747471875	1.0	1	1.1	0.9				
	2328	1	0.0	0.0	0.0	0.0	5	1.0665132681809018	-15.29579955773213	22.0	1	1.1	0.9				
	2329	2	0.0	0.0	0.0	0.0	5	0.9862199999999701	-15.80443024403233	11.0	1	1.1	0.9				
	2330	2	0.0	0.0	0.0	0.0	5	0.9872699999999744	-21.180699409873	11.0	1	1.1	0.9				
	2331	2	0.0	0.0	0.0	0.0	5	0.9815299999999673	-7.768191487317035	11.0	1	1.1	0.9				
	2332	2	0.0	0.0	0.0	0.0	5	1.0140299999999682	-7.444253160684965	11.0	1	1.1	0.9				
	2333	2	0.0	0.0	0.0	0.0	5	1.0059899999999709	-12.15077499929403	11.0	1	1.1	0.9				
	2334	2	0.0	0.0	0.0	0.0	5	0.9981299999999681	-9.011952406890899	11.0	1	1.1	0.9				
	2335	2	0.0	0.0	0.0	0.0	5	1.0040799999999674	-8.872694444094716	11.0	1	1.1	0.9				
	2336	1	32.703308165349604	10.65448662680355	0.0	0.0	5	1.0000838389073212	-16.1032481711975	33.0	1	1.1	0.9				
	2337	1	49.53378236982485	16.2479222760927	0.0	0.0	5	1.0705438206043782	-18.22239436310862	11.0	1	1.1	0.9				
	2338	1	1.71129514994603	2.6494563332431	0.0	0.0	5	1.0182916508617224	-18.523394344049212	22.0	1	1.1	0.9				
	2339	1	15.716992921065811	-4.31763789598276	0.0	0.0	5	1.019843252188255	-16.73850262245381	6.6	1	1.1	0.9					
	10001	1	0.0	0.0	0.0	0.0	1	1.0	0.0	500.0	1	1.1	0.9				
	10002	1	0.0	0.0	0.0	0.0	1	1.0	0.0	500.0	1	1.1	0.9				
	10003	1	0.0	0.0	0.0	0.0	1	1.0	0.0	500.0	1	1.1	0.9				
	10004	1	0.0	0.0	0.0	0.0	1	1.0	0.0	500.0	1	1.1	0.9				
	10005	1	0.0	0.0	0.0	0.0	1	1.0	0.0	500.0	1	1.1	0.9				
	10006	1	0.0	0.0	0.0	0.0	1	1.0	0.0	500.0	1	1.1	0.9				
	10007	1	0.0	0.0	0.0	0.0	1	1.0	0.0	500.0	1	1.1	0.9				
	10008	1	0.0	0.0	0.0	0.0	1	1.0	0.0	330.0	1	1.1	0.9				
	10009	1	0.0	0.0	0.0	0.0	1	1.0	0.0	330.0	1	1.1	0.9				
	10010	1	0.0	0.0	0.0	0.0	1	1.0	0.0	330.0	1	1.1	0.9				
	10011	1	0.0	0.0	0.0	0.0	1	1.0	0.0	330.0	1	1.1	0.9				
	10012	1	0.0	0.0	0.0	0.0	1	1.0	0.0	330.0	1	1.1	0.9				
	10013	1	0.0	0.0	0.0	0.0	1	1.0	0.0	500.0	1	1.1	0.9				
	10014	1	0.0	0.0	0.0	0.0	1	1.0	0.0	500.0	1	1.1	0.9				
	10015	1	0.0	0.0	0.0	0.0	1	1.0	0.0	330.0	1	1.1	0.9				
	10016	1	0.0	0.0	0.0	0.0	1	1.0	0.0	330.0	1	1.1	0.9				
	10017	1	0.0	0.0	0.0	0.0	1	1.0	0.0	330.0	1	1.1	0.9				
	10018	1	0.0	0.0	0.0	0.0	1	1.0	0.0	330.0	1	1.1	0.9				
	10019	1	0.0	0.0	0.0	0.0	1	1.0	0.0	132.0	1	1.1	0.9				
	10020	1	0.0	0.0	0.0	0.0	1	1.0	0.0	132.0	1	1.1	0.9				
	10021	1	0.0	0.0	0.0	0.0	1	1.0	0.0	132.0	1	1.1	0.9				
	10022	1	0.0	0.0	0.0	0.0	1	1.0	0.0	132.0	1	1.1	0.9				
	10023	1	0.0	0.0	0.0	0.0	1	1.0	0.0	132.0	1	1.1	0.9				
	10024	1	0.0	0.0	0.0	0.0	1	1.0	0.0	132.0	1	1.1	0.9				
	10025	1	0.0	0.0	0.0	0.0	1	1.0	0.0	132.0	1	1.1	0.9				
	10026	1	0.0	0.0	0.0	0.0	1	1.0	0.0	132.0	1	1.1	0.9				
	10027	1	0.0	0.0	0.0	0.0	1	1.0	0.0	66.0	1	1.1	0.9				
	10028	1	0.0	0.0	0.0	0.0	1	1.0	0.0	66.0	1	1.1	0.9				
	10029	1	0.0	0.0	0.0	0.0	1	1.0	0.0	66.0	1	1.1	0.9				
	10030	1	0.0	0.0	0.0	0.0	1	1.0	0.0	66.0	1	1.1	0.9				
	10031	1	0.0	0.0	0.0	0.0	2	1.0	0.0	220.0	1	1.1	0.9				
	10032	1	0.0	0.0	0.0	0.0	2	1.0	0.0	220.0	1	1.1	0.9				
	10033	1	0.0	0.0	0.0	0.0	2	1.0	0.0	220.0	1	1.1	0.9				
	10034	1	0.0	0.0	0.0	0.0	2	1.0	0.0	220.0	1	1.1	0.9				
	10035	1	0.0	0.0	0.0	0.0	2	1.0	0.0	220.0	1	1.1	0.9				
	10036	1	0.0	0.0	0.0	0.0	2	1.0	0.0	220.0	1	1.1	0.9				
	10037	1	0.0	0.0	0.0	0.0	2	1.0	0.0	220.0	1	1.1	0.9				
	10038	1	0.0	0.0	0.0	0.0	2	1.0	0.0	330.0	1	1.1	0.9				
	10039	1	0.0	0.0	0.0	0.0	2	1.0	0.0	330.0	1	1.1	0.9				
	10040	1	0.0	0.0	0.0	0.0	2	1.0	0.0	330.0	1	1.1	0.9				
	10041	1	0.0	0.0	0.0	0.0	2	1.0	0.0	330.0	1	1.1	0.9				
	10042	1	0.0	0.0	0.0	0.0	2	1.0	0.0	330.0	1	1.1	0.9				
	10043	1	0.0	0.0	0.0	0.0	2	1.0	0.0	330.0	1	1.1	0.9				
	10044	1	0.0	0.0	0.0	0.0	2	1.0	0.0	330.0	1	1.1	0.9				
	10045	1	0.0	0.0	0.0	0.0	2	1.0	0.0	330.0	1	1.1	0.9				
	10046	1	0.0	0.0	0.0	0.0	2	1.0	0.0	330.0	1	1.1	0.9				
	10047	1	0.0	0.0	0.0	0.0	2	1.0	0.0	500.0	1	1.1	0.9				
	10048	1	0.0	0.0	0.0	0.0	2	1.0	0.0	500.0	1	1.1	0.9				
	10049	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10050	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10051	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10052	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10053	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10054	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10055	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10056	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10057	1	0.0	0.0	0.0	0.0	3	1.0	0.0	132.0	1	1.1	0.9				
	10058	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10059	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10060	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10061	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10062	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10063	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10064	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10065	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10066	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10067	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10068	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10069	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10070	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10071	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10072	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10073	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10074	1	0.0	0.0	0.0	0.0	3	1.0	0.0	132.0	1	1.1	0.9				
	10075	1	0.0	0.0	0.0	0.0	3	1.0	0.0	132.0	1	1.1	0.9				
	10076	1	0.0	0.0	0.0	0.0	3	1.0	0.0	132.0	1	1.1	0.9				
	10077	1	0.0	0.0	0.0	0.0	3	1.0	0.0	132.0	1	1.1	0.9				
	10078	1	0.0	0.0	0.0	0.0	3	1.0	0.0	132.0	1	1.1	0.9				
	10079	1	0.0	0.0	0.0	0.0	3	1.0	0.0	132.0	1	1.1	0.9				
	10080	1	0.0	0.0	0.0	0.0	3	1.0	0.0	132.0	1	1.1	0.9				
	10081	1	0.0	0.0	0.0	0.0	3	1.0	0.0	132.0	1	1.1	0.9				
	10082	1	0.0	0.0	0.0	0.0	3	1.0	0.0	132.0	1	1.1	0.9				
	10083	1	0.0	0.0	0.0	0.0	3	1.0	0.0	132.0	1	1.1	0.9				
	10084	1	0.0	0.0	0.0	0.0	3	1.0	0.0	110.0	1	1.1	0.9				
	10085	1	0.0	0.0	0.0	0.0	4	1.0	0.0	66.0	1	1.1	0.9				
	10086	1	0.0	0.0	0.0	0.0	4	1.0	0.0	66.0	1	1.1	0.9				
	10087	1	0.0	0.0	0.0	0.0	4	1.0	0.0	66.0	1	1.1	0.9				
	10088	1	0.0	0.0	0.0	0.0	4	1.0	0.0	66.0	1	1.1	0.9				
	10089	1	0.0	0.0	0.0	0.0	4	1.0	0.0	275.0	1	1.1	0.9				
	10090	1	0.0	0.0	0.0	0.0	4	1.0	0.0	275.0	1	1.1	0.9				
	10091	1	0.0	0.0	0.0	0.0	4	1.0	0.0	275.0	1	1.1	0.9				
	10092	1	0.0	0.0	0.0	0.0	4	1.0	0.0	275.0	1	1.1	0.9				
	10093	1	0.0	0.0	0.0	0.0	4	1.0	0.0	275.0	1	1.1	0.9				
	10094	1	0.0	0.0	0.0	0.0	4	1.0	0.0	132.0	1	1.1	0.9				
	10095	1	0.0	0.0	0.0	0.0	4	1.0	0.0	132.0	1	1.1	0.9				
	10096	1	0.0	0.0	0.0	0.0	4	1.0	0.0	132.0	1	1.1	0.9				
	10097	1	0.0	0.0	0.0	0.0	4	1.0	0.0	132.0	1	1.1	0.9				
	10098	1	0.0	0.0	0.0	0.0	4	1.0	0.0	132.0	1	1.1	0.9				
	10099	1	0.0	0.0	0.0	0.0	4	1.0	0.0	132.0	1	1.1	0.9				
	10100	1	0.0	0.0	0.0	0.0	4	1.0	0.0	132.0	1	1.1	0.9				
	10101	1	0.0	0.0	0.0	0.0	4	1.0	0.0	132.0	1	1.1	0.9				
	10102	1	0.0	0.0	0.0	0.0	4	1.0	0.0	132.0	1	1.1	0.9				
	10103	1	0.0	0.0	0.0	0.0	4	1.0	0.0	132.0	1	1.1	0.9				
	10104	1	0.0	0.0	0.0	0.0	4	1.0	0.0	66.0	1	1.1	0.9				
	10105	1	0.0	0.0	0.0	0.0	4	1.0	0.0	66.0	1	1.1	0.9				
	10106	1	0.0	0.0	0.0	0.0	4	1.0	0.0	66.0	1	1.1	0.9				
	10107	1	0.0	0.0	0.0	0.0	4	1.0	0.0	66.0	1	1.1	0.9				
	10108	1	0.0	0.0	0.0	0.0	5	1.0	0.0	110.0	1	1.1	0.9				
	10109	1	0.0	0.0	0.0	0.0	5	1.0	0.0	110.0	1	1.1	0.9				
	10110	1	0.0	0.0	0.0	0.0	5	1.0	0.0	110.0	1	1.1	0.9				
	10111	1	0.0	0.0	0.0	0.0	5	1.0	0.0	110.0	1	1.1	0.9				
	10112	1	0.0	0.0	0.0	0.0	5	1.0	0.0	110.0	1	1.1	0.9				
	10113	1	0.0	0.0	0.0	0.0	5	1.0	0.0	110.0	1	1.1	0.9			
];

%% generator data
%    bus    Pg    Qg    Qmax    Qmin    Vg    mBase    status    Pmax    Pmin    Pc1    Pc2    Qc1min    Qc1max    Qc2min    Qc2max    ramp_agc    ramp_10    ramp_30    ramp_q    apf
mpc.gen = [
	3	431.89334232400006	-24.521463397999998	370.0	-240.0	1.01556	848.605419222452	1	850.0	0.0															
	4	624.40737834601	64.8168883589584	450.0	-190.0	1.02626	911.2691769853241	1	919.9999999999999	0.0															
	5	650.401460230983	17.1883693068953	390.0	-260.0	0.999	914.521020424575	1	919.9999999999999	0.0															
	6	631.7539076734402	37.213374197097096	450.0	-190.0	1.00251	915.047054038756	1	919.9999999999999	0.0															
	13	30.2265357711347	2.1328312649857297	10.0	-10.0	1.01546	41.1012975615542	1	50.0	0.0															
	14	32.1221972278725	3.847882429963349	10.0	-10.0	1.01729	45.4628463133704	1	50.0	0.0															
	15	19.277781191996898	0.46368514422499607	10.0	-10.0	1.0126	28.477100057434303	1	30.0	0.0															
	18	565.935071064465	76.76821743240511	440.00000000000006	-280.0	1.01122	853.1517461942509	1	860.0	0.0															
	19	664.1802905846021	116.850947170548	430.0	-280.0	1.01837	828.587737327442	1	830.0000000000001	0.0															
	20	630.779430353494	123.09915439605301	430.0	-270.0	1.02332	824.9557847308	1	830.0000000000001	0.0															
	21	660.810311423638	92.7982150761187	430.0	-280.0	1.01577	815.543500367366	1	819.9999999999999	0.0															
	23	81.9568333770882	3.7421545503518496	50.0	-30.0	1.02669	100.1029132	1	110.00000000000001	0.0															
	30	77.3267838781388	-3.50851274594665	50.0	-30.0	1.01913	99.5320069049927	1	100.0	0.0															
	31	55.970990066540104	-7.30109434132907	30.0	-30.0	0.95282	90.5889255829901	1	100.0	0.0															
	34	405.05126933506904	36.0377353830287	210.0	-110.00000000000001	0.97349	643.693602205161	1	650.0	0.0															
	35	407.77499201904703	-93.8426247742008	220.00000000000003	-120.0	0.93205	645.28666725168	1	650.0	0.0															
	36	426.5161774322531	42.1066275972186	210.0	-100.0	0.97558	628.9849849482072	1	630.0	0.0															
	37	246.36371654223402	1.1105895665460301	90.0	-90.0	0.97897	343.073364149896	1	350.0	0.0															
	38	246.53546941532	-1.1678426247423999	90.0	-90.0	0.97805	338.426626157714	1	340.0	0.0															
	39	248.465284474285	13.4766408302221	90.0	-90.0	0.98407	341.42365312634496	1	350.0	0.0															
	40	256.48333277373905	9.456149262328069	90.0	-90.0	0.98186	336.309318444924	1	340.0	0.0															
	41	245.36307114282198	13.794420346358402	90.0	-90.0	0.98377	333.510404178291	1	340.0	0.0															
	42	242.463117731816	17.971023596443196	90.0	-90.0	0.98556	340.135576679022	1	350.0	0.0															
	43	641.205869383868	-79.2208985881729	420.0	-180.0	0.99894	832.440999925509	1	840.0	0.0															
	56	409.952588354057	8.71409053639974	280.0	-130.0	0.98801	546.171568101272	1	550.0	0.0															
	57	0.0	3.29022754875435	20.0	-20.0	1.01502	46.1062790306169	1	50.0	0.0															
	58	30.3989596087625	-9.75506422682516	20.0	-20.0	0.94492	46.5332684993628	1	50.0	0.0															
	62	22.5934707990981	11.096846189928302	20.0	-30.0	0.91609	30.5123773106886	1	40.0	0.0															
	63	20.5592082879526	-0.16138491215324	20.0	-20.0	1.04149	29.6002670221357	1	30.0	0.0															
	64	151.99882825729298	-1.97199990038797	100.0	-50.0	1.06298	210.894545504451	1	220.00000000000003	0.0															
	65	147.744403827981	-8.13028176963227	100.0	-50.0	1.0576	207.096134014428	1	210.0	0.0															
	66	157.04825788377198	-1.2465739881142999	100.0	-50.0	1.06354	209.43448703438	1	210.0	0.0															
	67	150.91881079843	-2.21712468539341	100.0	-50.0	1.06263	210.867295503616	1	220.00000000000003	0.0															
	69	45.5453139887114	-11.7293045770481	30.0	-30.0	0.96354	108.81484992434301	1	110.00000000000001	0.0															
	70	49.67218813880051	-3.45493803172465	30.0	-30.0	0.97025	110.332978322869	1	120.0	0.0															
	73	43.2331766436034	-13.684934688052799	40.0	-30.0	1.00307	96.48768505742771	1	100.0	0.0															
	74	41.671530701732294	-6.34282647466175	40.0	-40.0	1.01275	98.0252477621194	1	100.0	0.0															
	75	43.07847587842049	2.7352948936936903	40.0	-40.0	1.02419	96.5074638390634	1	100.0	0.0															
	76	601.9228605073649	68.4206095867701	409.99999999999994	-160.0	1.01885	835.11956340652	1	840.0	0.0															
	77	594.185006502323	28.983092414969803	409.99999999999994	-160.0	1.00955	829.493444249593	1	830.0000000000001	0.0															
	79	33.6224140786135	-1.7698750120983504	10.0	-20.0	1.04459	52.3175148501992	1	60.0	0.0															
	80	34.037052000734604	-2.4237874515906	10.0	-20.0	1.04206	51.9722352538258	1	60.0	0.0															
	647	64.58350418747361	0.37462820608019803	40.0	-30.0	0.97085	86.4684665810317	1	90.0	0.0															
	648	58.69554476671941	0.366359938384267	40.0	-40.0	0.9712	90.0339754913002	1	100.0	0.0															
	654	50.990623193234306	-3.24980309639736	10.0	-10.0	1.06431	98.9588547302624	1	100.0	0.0															
	655	112.97404027993099	-3.9362810441209	10.0	-10.0	1.05968	179.468505843356	1	180.0	0.0															
	656	12.718660331978601	3.0661311341823496	10.0	0.0	0.97713	23.38719214	1	30.0	0.0															
	658	165.978187592202	0.343592807862908	80.0	-50.0	0.97456	189.47538619999997	1	190.0	0.0															
	659	51.46347397016579	-11.530151942175001	40.0	-30.0	1.00988	70.2652235693065	1	80.0	0.0															
	660	53.7882164716721	-9.82455924073085	40.0	-30.0	1.0122	71.0795632928889	1	80.0	0.0															
	665	115.27907018156999	-15.398137622243501	50.0	-50.0	0.95996	152.586644802825	1	160.0	0.0															
	668	69.7121333398338	-6.70421066225446	50.0	-50.0	0.96635	108.100446894949	1	110.00000000000001	0.0															
	672	65.804614318345	-0.900903784301877	50.0	-50.0	0.97242	110.470307527771	1	120.0	0.0															
	674	69.5386755602799	-9.84916305486169	50.0	-50.0	0.96361	108.17915012921699	1	110.00000000000001	0.0															
	680	71.3839554087347	2.32638627378177	40.0	-40.0	0.95738	107.325694307219	1	110.00000000000001	0.0															
	681	72.45267330743368	-12.0128617628943	50.0	-40.0	0.93803	107.571180567611	1	110.00000000000001	0.0															
	682	71.4069515075775	-4.6704606956616	40.0	-40.0	0.94763	108.142809283454	1	110.00000000000001	0.0															
	684	136.046296661597	-7.368156470804339	110.00000000000001	-40.0	0.98898	201.368655754533	1	210.0	0.0															
	685	143.32652905182	-2.03017769778478	110.00000000000001	-40.0	0.99603	201.766158744693	1	210.0	0.0															
	687	346.95005454379395	-36.692059481947396	330.0	-210.0	1.00618	630.7525659587229	1	640.0	0.0															
	688	545.601412348538	6.578139153325649	310.0	-200.0	1.01171	692.4764770461251	1	700.0	0.0															
	689	526.740899209748	-74.9163160444217	340.0	-110.00000000000001	0.9903	743.727576350409	1	750.0	0.0															
	690	511.886080085132	55.344790299059795	330.0	-110.00000000000001	0.99891	651.18307242021	1	660.0	0.0															
	691	529.759362199972	47.88466473868031	330.0	-110.00000000000001	0.99686	647.149878913164	1	650.0	0.0															
	693	90.0189063795386	4.446300647875949	10.0	-10.0	1.06524	115.622949829081	1	120.0	0.0															
	694	51.7755913180758	9.89028119585291	20.0	-30.0	1.07291	69.6506796327507	1	70.0	0.0															
	695	27.502320582569702	7.64712922532787	10.0	-10.0	1.07773	46.581592120633	1	50.0	0.0															
	696	50.68418794423341	9.82985949239228	20.0	-20.0	1.07461	114.864380666002	1	120.0	0.0															
	697	30.970484672293104	6.60865617792485	10.0	-10.0	1.07694	73.23516054158162	1	80.0	0.0															
	698	43.3489842760144	8.974411675248342	20.0	-30.0	1.08353	113.018319971292	1	120.0	0.0															
	699	50.769790687559	-0.870072425790271	20.0	-20.0	0.97517	100.974593	1	110.00000000000001	0.0															
	700	46.9121250839084	-0.8867070204496379	20.0	-20.0	0.97542	100.3645848	1	110.00000000000001	0.0															
	701	49.47508432327339	-0.909071200627182	20.0	-20.0	0.97015	100.148673	1	110.00000000000001	0.0															
	702	259.780769472675	29.380438943110498	130.0	-70.0	0.99413	352.29798341787	1	360.0	0.0															
	703	247.87455000916	16.7708194425677	130.0	-70.0	0.989	353.577216341277	1	360.0	0.0															
	708	31.694694625116902	-3.30541775477491	30.0	-20.0	0.99081	51.6119330540299	1	60.0	0.0															
	712	473.373842322757	45.6580550539587	260.0	-170.0	0.96625	626.956900197733	1	630.0	0.0															
	729	28.8376042157381	-3.44932537813294	20.0	-20.0	0.97029	100.8087346	1	110.00000000000001	0.0															
	730	348.993836114038	-78.07564414404922	190.0	-120.0	0.99185	476.643849198753	1	480.0	0.0															
	731	315.80497244537196	-44.2295903584657	190.0	-120.0	0.97286	413.478915313189	1	420.0	0.0															
	732	326.010094955155	13.7888998626748	200.0	-150.0	0.99223	481.327456929814	1	490.00000000000006	0.0															
	733	384.30129750208005	11.433909835405599	200.0	-150.0	0.98956	475.496667556395	1	480.0	0.0															
	953	34.37087262522778	1.0014128042542398	20.0	-20.0	1.02644	47.1338866906008	1	50.0	0.0															
	954	32.5579225848377	0.6666875720855779	20.0	-20.0	1.02602	46.1283384356648	1	50.0	0.0															
	955	34.989074655062	0.8944543812100769	20.0	-20.0	1.02719	53.539829139953895	1	60.0	0.0															
	956	33.0022717441131	0.408944916197751	20.0	-20.0	1.02592	66.5378691187571	1	70.0	0.0															
	1136	38.15006813653801	-1.78708623269442	30.0	-20.0	0.99783	56.4829927750938	1	60.0	0.0															
	1137	54.78896249383889	0.188969746815553	40.0	-20.0	1.0006	70.4010887629353	1	80.0	0.0															
	1138	37.3852416237806	-2.2534103836764596	50.0	-20.0	0.97188	55.8495727342218	1	60.0	0.0															
	1246	158.62248344307702	10.879602374576299	20.0	-20.0	1.05379	240.12185123283402	1	250.0	0.0															
	1274	672.011629407089	11.8418634473528	390.0	-220.00000000000003	1.07483	989.914190588519	1	990.0	0.0															
	1184	32.325133014311604	3.76301686895667	20.0	-20.0	1.0021652453554195	47.830978430458394	1	50.0	0.0															
	1394	233.79768106916902	15.3889585213543	150.0	-40.0	1.00238	327.941066311374	1	330.0	0.0															
	1395	228.99522333410803	18.305990717556302	150.0	-50.0	1.01725	328.221132472344	1	330.0	0.0															
	1396	181.826398928217	2.92992144144773	150.0	-70.0	1.0801	333.52684475354897	1	340.0	0.0															
	1397	193.42773506570302	20.8648841696903	150.0	-60.0	1.07699	335.174992911071	1	340.0	0.0															
	1398	143.62341807961803	8.5770152216617	150.0	-90.0	1.01396	323.952838555873	1	330.0	0.0															
	1399	252.81525112172497	20.5288921560526	150.0	-80.0	1.01738	321.767278076075	1	330.0	0.0															
	1400	339.36660236744706	9.45069326332528	180.0	-100.0	1.01525	422.530060780491	1	430.0	0.0															
	1401	328.650323317071	1.83437086554319	190.0	-100.0	1.01123	422.44099449906497	1	430.0	0.0															
	1402	333.605957972587	3.30725365806478	190.0	-90.0	1.01182	416.57544194585597	1	420.0	0.0															
	1403	352.540245030636	28.1103395883693	190.0	-100.0	1.01054	411.61222137440905	1	420.0	0.0															
	1407	291.08311794626997	-1.2139723646659397	190.0	-110.00000000000001	1.01726	428.869098612061	1	430.0	0.0															
	1408	337.08405474398	2.37235024599703	190.0	-110.00000000000001	1.01886	413.432336428249	1	420.0	0.0															
	1411	97.7013988349731	4.29467949318355	70.0	-50.0	1.01934	158.354711054701	1	160.0	0.0															
	1412	99.9689406776247	1.1591755747586	70.0	-50.0	1.01637	157.83937821052	1	160.0	0.0															
	1413	107.51995301137498	-6.630803831098969	70.0	-50.0	1.009	153.609530652668	1	160.0	0.0															
	1414	254.35082605878102	114.02582900406999	160.0	-90.0	1.06955	375.605614145869	1	380.0	0.0															
	1415	133.617273394639	1.6690695347473001	90.0	-60.0	0.96738	209.356691142824	1	210.0	0.0															
	1416	167.280394055444	3.2157747441737397	90.0	-60.0	0.96634	205.18749745981802	1	210.0	0.0															
	1419	392.37162271625607	15.8635004029665	229.99999999999997	-120.0	0.98831	628.052562262723	1	630.0	0.0															
	1420	389.17365927410503	16.542018985211897	220.00000000000003	-120.0	0.98849	638.170104924729	1	640.0	0.0															
	1421	446.095845639464	33.8465337004101	260.0	-210.0	0.97748	671.132690536673	1	680.0	0.0															
	1425	0.0	0.124195797505276	20.0	-20.0	1.01974	35.3824854665436	1	40.0	0.0															
	1426	26.060170449972205	-0.192852384490659	20.0	-20.0	1.02374	35.1063570457092	1	40.0	0.0															
	1429	0.0	2.49148080884786	20.0	-10.0	0.94245	24.0841503046104	1	30.0	0.0															
	1430	18.586411690213502	1.8555040984759998	20.0	-10.0	0.9398	24.7130107383127	1	30.0	0.0															
	1431	18.792232497129604	2.31586751971524	20.0	-10.0	0.94267	23.6974350718665	1	30.0	0.0															
	1432	0.0	0.570948067357205	20.0	-10.0	0.93537	24.5818638734054	1	30.0	0.0															
	1433	0.0958614002307877	0.777090317195049	10.0	-10.0	1.01518	8.7651425538864	1	10.0	0.0															
	1437	149.13769483177	-11.938774312788402	90.0	-70.0	1.00347	195.96899449389898	1	200.0	0.0															
	1438	78.57012764308452	7.65819148109229	50.0	-40.0	0.92011	105.795435098372	1	110.00000000000001	0.0															
	1439	122.659723240664	-4.114679432228209	80.0	-50.0	1.00491	189.74077837402	1	190.0	0.0															
	1441	28.5315465193212	-5.97646587355519	20.0	-20.0	0.99805	34.7002429670887	1	40.0	0.0															
	1499	151.481625780188	-3.1803239799808702	90.0	-60.0	0.98699	223.21536341426	1	229.99999999999997	0.0															
	1500	162.32070663892702	-6.57704077966753	100.0	-50.0	0.98381	230.990713269683	1	240.0	0.0															
	1501	134.162182604531	10.3741542792809	90.0	-60.0	0.99662	225.23718779557402	1	229.99999999999997	0.0															
	1558	333.83098638962196	18.201650020846603	190.0	-90.0	1.0065	416.378375744331	1	420.0	0.0															
	1559	331.572555586178	14.097260140581	190.0	-90.0	1.00423	426.8220308	1	430.0	0.0															
	1560	136.302122333584	-16.7380826868276	150.0	-130.0	0.99478	423.626371387602	1	430.0	0.0															
	1561	349.539415874761	9.086868038214742	190.0	-90.0	1.00248	515.843401	1	520.0	0.0															
	1628	367.584851894179	41.0305055378158	229.99999999999997	-180.0	1.00366	579.8661901449091	1	580.0	0.0															
	1629	364.29128839322004	48.745432587144	229.99999999999997	-190.0	1.0051	566.034920721082	1	570.0	0.0															
	1636	27.4967476991704	-0.197728151173517	10.0	-10.0	0.99352	36.2839481079485	1	40.0	0.0															
	1640	80.8969085377662	4.976529913062599	20.0	-30.0	0.99873	121.983711870527	1	130.0	0.0															
	1641	17.264698250152	0.655523609431461	10.0	-10.0	0.9941	21.6044311194727	1	30.0	0.0															
	1659	0.0	3.57525504164393	30.0	-10.0	0.98064	36.2619373	1	40.0	0.0															
	1660	0.0	3.75328538779309	30.0	-10.0	0.98165	37.22684	1	40.0	0.0															
	1661	0.0	0.258818292321265	30.0	-10.0	0.97347	36.524171100000004	1	40.0	0.0															
	1662	0.0	4.23996887961002	30.0	-10.0	0.98277	37.0209491	1	40.0	0.0															
	1665	0.0	1.9322701630242196	30.0	-10.0	0.97606	37.2833587994021	1	40.0	0.0															
	1666	0.0	1.952267824	30.0	-10.0	0.96603	37.528516240641	1	40.0	0.0															
	1667	0.0	3.3381552571319	30.0	-10.0	0.9779	36.3901201120326	1	40.0	0.0															
	1668	0.0	2.9525197255446596	30.0	-10.0	0.97693	36.1408798766029	1	40.0	0.0															
	1683	70.7750319602899	0.0060748899931088104	10.0	-20.0	1.09411	89.9570863413974	1	90.0	0.0															
	1684	127.264972509581	7.903512925389969	90.0	-80.0	0.99553	198.828031233628	1	200.0	0.0															
	1685	135.210093454782	11.477315202595099	90.0	-80.0	0.99759	194.91053826953302	1	200.0	0.0															
	1686	137.62957877398497	9.789118596352642	90.0	-80.0	0.99607	203.925937385531	1	210.0	0.0															
	1690	38.4946844491548	16.7631166103504	70.0	0.0	1.00101	162.35489527462101	1	170.0	0.0															
	1691	37.3084137147125	11.7401205939442	70.0	0.0	0.99526	159.27815700299098	1	160.0	0.0															
	1692	38.770804742195004	18.323136900162	70.0	0.0	1.00174	159.933895852882	1	160.0	0.0															
	1693	55.8750720689865	12.2027521266136	110.00000000000001	-50.0	1.00541	266.94065888878	1	270.0	0.0															
	1694	61.3134457642919	19.0100216837332	110.00000000000001	-50.0	1.01184	272.704311920097	1	280.0	0.0															
	1695	58.176223566194906	15.919317246771	110.00000000000001	-50.0	1.00877	262.876889418112	1	270.0	0.0															
	1696	78.7966765485445	5.715587193107	70.0	-40.0	1.01738	175.50502469390602	1	180.0	0.0															
	1697	49.6087914977608	5.56327793701654	40.0	-20.0	1.01721	88.5158615344204	1	90.0	0.0															
	1699	38.6113984149723	-1.44746811458711	30.0	-20.0	1.0036	50.093021374605605	1	60.0	0.0															
	1705	22.8188918386586	-7.02094158437103	10.0	-10.0	1.0024	34.96740921	1	40.0	0.0															
	1706	17.313522312438597	-4.97280344702303	10.0	-10.0	1.00267	100.7653224	1	110.00000000000001	0.0															
	1708	63.2268506484948	6.521236869879629	20.0	-30.0	1.01253	77.61118044	1	80.0	0.0															
	1709	93.2166602577516	-26.2550978837705	40.0	-40.0	0.96231	109.9329537	1	110.00000000000001	0.0															
	1710	38.3189882633566	-2.3943805510195904	10.0	-10.0	0.98213	50.331527630000004	1	60.0	0.0															
	2114	100.949965172718	15.8580971790647	110.00000000000001	-90.0	0.98803	147.69696593489502	1	150.0	0.0															
	2115	101.98801294916	11.2237937533833	120.0	-110.00000000000001	0.98282	147.170128862932	1	150.0	0.0															
	2116	73.44618478614161	11.7072726332725	60.0	-40.0	0.9882	99.82682290775702	1	100.0	0.0															
	2117	47.216573469236	1.2136413577921699	20.0	-20.0	1.05511	59.56099006	1	60.0	0.0															
	2118	0.0	-0.006768525156425311	90.0	-80.0	0.98159	123.24446895776799	1	130.0	0.0															
	2119	2.05432535428554	-3.6955045059300002	20.0	-20.0	0.94727	37.868305058335	1	40.0	0.0															
	2123	49.579877537453484	-7.53504049162455	50.0	-30.0	0.99307	72.60313276841859	1	80.0	0.0															
	2124	137.396424963428	23.1323326218313	120.0	-40.0	1.05574	192.64760894081599	1	200.0	0.0															
	2125	64.71147344283762	8.644864607815817	70.0	-20.0	1.05271	96.0025555250328	1	100.0	0.0															
	2126	9.82450783043848	0.050819844169588804	20.0	-10.0	1.05495	16.4278021572973	1	20.0	0.0															
	2127	34.9319525974112	0.009933722652494908	20.0	-20.0	1.04821	40.33056631	1	50.0	0.0															
	2128	32.3089076933498	0.9419516572624909	20.0	-20.0	1.05035	40.0795192	1	50.0	0.0															
	2129	24.963966136035697	0.239045050738007	20.0	-10.0	1.00571	33.6463986921869	1	40.0	0.0															
	2130	24.074777174613402	0.46368007554411894	20.0	-10.0	1.0064	33.3273031253414	1	40.0	0.0															
	2131	24.1970479211855	-0.379025940144062	20.0	-10.0	1.00365	34.233340868547096	1	40.0	0.0															
	2132	28.4679129616367	10.404304921856601	30.0	-10.0	1.03199	37.7499579498544	1	40.0	0.0															
	2133	34.3623818564035	-10.1806803593985	40.0	-20.0	0.96138	53.9771218854003	1	60.0	0.0															
	2134	105.10400928355598	3.30291061631516	70.0	-50.0	0.95645	169.174009550363	1	170.0	0.0															
	2135	104.805398459447	3.11307038174029	80.0	-70.0	0.9564	175.344738017768	1	180.0	0.0															
	2136	85.445430155	-7.1366510739999995	80.0	-60.0	0.9492	168.12110569328098	1	170.0	0.0															
	2138	26.2199891117512	-0.79302688851878	40.0	-30.0	1.02356	33.7659113864647	1	40.0	0.0															
	2139	15.9424347942778	-4.483969936649319	20.0	-10.0	1.01721	36.76534479	1	40.0	0.0															
	2140	53.38467952529129	2.89706152168536	70.0	-50.0	0.98842	67.9893259308301	1	70.0	0.0															
	2142	53.8733716477824	5.237919695317279	70.0	-40.0	0.98837	68.36997707287081	1	70.0	0.0															
	2143	55.89335614416999	4.376945288409251	70.0	-40.0	0.98685	66.6358637739904	1	70.0	0.0															
	2144	57.6238744085221	6.15992598070428	70.0	-40.0	0.98994	67.2894188493956	1	70.0	0.0															
	2148	7.435417173533231	-0.30898741889148995	10.0	-20.0	1.07274	83.72531062298448	1	90.0	0.0															
	2329	45.9946811998802	1.32156310736672	30.0	-20.0	0.98622	65.7624427797273	1	70.0	0.0															
	2330	0.0	1.59340415728837	20.0	-10.0	0.98727	36.1447293923702	1	40.0	0.0															
	2331	26.4788677188798	-4.81024136099475	20.0	-20.0	0.98153	32.9465583476471	1	40.0	0.0															
	2332	28.290144359801197	3.03866334651271	10.0	-20.0	1.01403	34.046855572122205	1	40.0	0.0															
	2333	13.345418793149303	-0.167070114086708	10.0	-10.0	1.00599	16.3866927560885	1	20.0	0.0															
	2334	21.9071191165335	-1.67227254103906	20.0	-10.0	0.99813	32.5552539895289	1	40.0	0.0															
	2335	21.9217522649333	-0.147830591569655	20.0	-10.0	1.00408	31.920388778904503	1	40.0	0.0															
	12	0.0	-21.531810070351803	320.0	-150.0	1.0605	1.08747929753736	1	110.00000000000001	0.0															
	24	38.3974242998332	0.0	0.0	0.0	1.07713	0.7938849320478039	1	80.0	0.0															
	25	33.235892587486596	0.0	0.0	0.0	1.07705	0.7164935316257183	1	80.0	0.0															
	26	20.9660063255453	0.71839715225622	10.0	-20.0	1.08759	0.500407203184462	1	60.0	0.0															
	28	79.16047462791389	8.80078784072725	60.0	-170.0	1.02449	1.0770017568	1	110.00000000000001	0.0															
	61	0.0	-97.0464803612942	330.0	-170.0	1.027	1.8038791959	1	190.0	0.0															
	142	4.349383474000001	-20.505770842999997	200.0	-200.0	1.025077786	9.0	1	900.0	0.0															
	166	0.0	-9.6411559328556	160.0	-110.00000000000001	1.00407	2.73906388320029	1	280.0	0.0															
	174	43.239112921556796	3.2959330806707	10.0	-20.0	0.99781	0.9059436245695692	1	100.0	0.0															
	211	0.0	13.6392264906736	20.0	-30.0	1.03756	1.0751540007	1	110.00000000000001	0.0															
	570	31.445522482500206	-0.5712345535201951	10.0	-20.0	1.02379	0.6034229714247631	1	70.0	0.0															
	651	54.67394886340681	-4.25643664399991	10.0	-20.0	1.02916	0.6813865119328261	1	70.0	0.0															
	652	62.799762154911306	-5.11872720987275	10.0	-10.0	1.03021	0.722928195972706	1	80.0	0.0															
	661	0.0	5.89533039835929	60.0	-30.0	1.06049	0.805258456163574	1	90.0	0.0															
	677	43.28520227	5.163886792999999	30.0	-20.0	0.93066	0.8649797139	1	90.0	0.0															
	683	0.0	11.702623445011401	60.0	-30.0	1.08734	0.8069375603401568	1	90.0	0.0															
	707	0.0	-6.01182982943631	40.0	-50.0	0.9999037036198694	0.8328711747474011	1	90.0	0.0															
	715	57.092109828077106	0.00194368854435161	10.0	-20.0	1.06914	0.7154404457942581	1	80.0	0.0															
	721	131.340468163	-143.205959938036	80.0	-240.0	0.99727	2.8083047291124204	1	290.0	0.0															
	724	0.0	-47.4318161241512	110.00000000000001	-70.0	0.95863	1.7526201493293	1	180.0	0.0															
	725	0.0	-38.64823488797929	110.00000000000001	-70.0	0.96458	1.74613961108029	1	180.0	0.0															
	728	164.359907981834	-0.9406052719579538	20.0	-20.0	1.0	1.97247388340067	1	200.0	0.0															
	881	41.1145145477321	-1.83862819433189	10.0	-20.0	0.9829	0.6404374503154663	1	70.0	0.0															
	882	29.992808700421698	-1.95109023467014	10.0	-20.0	0.98135	0.509823243989935	1	60.0	0.0															
	644	0.0	0.747743812207132	10.0	-10.0	1.0125667670305927	0.0789633095503086	1	10.0	0.0															
	986	0.0	27.8152489666941	80.0	-250.0	1.01103	2.7441684688255203	1	280.0	0.0															
	1090	0.0	-7.72207657341287	170.0	-90.0	1.0344986467366872	1.0500765809556503	1	110.00000000000001	0.0															
	1252	0.0	6.741982947666939	110.00000000000001	-80.0	1.0337	1.0997547345701597	1	110.00000000000001	0.0															
	1253	0.0	-3.60833605957087	110.00000000000001	-80.0	1.03192	1.0577576532261401	1	110.00000000000001	0.0															
	1255	0.0	15.842684771322602	110.00000000000001	-80.0	1.03024	1.09717493208591	1	110.00000000000001	0.0															
	1265	0.0	-1.87767680387045	110.00000000000001	-110.00000000000001	1.03123	1.07825675532222	1	110.00000000000001	0.0															
	1307	0.0	15.583358183604702	160.0	-90.0	1.0215757674662667	1.0500391566660299	1	110.00000000000001	0.0															
	1516	0.0	54.9862872394821	370.0	-110.00000000000001	1.063932517287146	1.0614524376113004	1	110.00000000000001	0.0															
	1520	0.0	37.1651194447423	380.0	-110.00000000000001	1.0621993293262253	1.0877079349942498	1	110.00000000000001	0.0															
	1531	0.0	-23.6637893308071	280.0	-90.0	1.0556265742422064	1.08463595104404	1	110.00000000000001	0.0															
	1534	0.0	-6.01045734745045	170.0	-90.0	1.0395799062155262	1.0608646189095496	1	110.00000000000001	0.0															
	1562	0.0	70.875570988055	380.0	-110.00000000000001	1.0648617155123072	1.06119855432771	1	110.00000000000001	0.0															
	1564	0.0	-1.6264545209257397	280.0	-80.0	1.0536492981037135	1.07012154776603	1	110.00000000000001	0.0															
	1566	0.0	47.5715600457198	280.0	-60.0	1.0610454520109465	1.0837470155907802	1	110.00000000000001	0.0															
	1140	0.0	-2.31944354030583	170.0	-90.0	1.0554790935884322	1.0724761458113798	1	110.00000000000001	0.0															
	1642	0.0	3.6312224950669303	20.0	-20.0	0.99493	0.128727573506534	1	20.0	0.0															
	1643	18.433384315473	-0.00310435854541138	10.0	-20.0	1.03603	0.28771634400000007	1	30.0	0.0															
	1646	22.2724559517577	-0.0028934032937977497	10.0	-10.0	1.03282	0.252659386300459	1	30.0	0.0															
	1651	27.8450044785054	-4.64114145218027	10.0	-10.0	1.02185	0.5888280384633691	1	60.0	0.0															
	1652	39.84141941817451	-4.8059192491940195	10.0	-10.0	1.01703	0.988983168276027	1	100.0	0.0															
	1653	93.252989115914	-4.71688636485911	10.0	-10.0	1.02561	1.33284632191574	1	140.0	0.0															
	1654	95.028833758947	-8.18644608856989	10.0	-10.0	1.01263	1.1176126014	1	120.0	0.0															
	1655	78.7630426681855	-9.68381721645947	20.0	-20.0	1.01358	1.01924695797265	1	110.00000000000001	0.0															
	1656	90.1852626517937	-7.7607135128622895	10.0	-10.0	1.01544	1.10546755904797	1	120.0	0.0															
	1658	15.112851645587503	0.0	0.0	0.0	0.99318	0.6130266438237391	1	70.0	0.0															
	1663	0.0	0.408420537	200.0	-200.0	1.01428437	9.0	1	900.0	0.0															
	1669	0.0	3.074383195	30.0	-10.0	0.97427	0.3639012011000001	1	40.0	0.0															
	1679	76.44171057008631	-0.006919910571631039	10.0	-10.0	1.06733	0.9103895200554982	1	100.0	0.0															
	1680	0.0	3.92899986826703	20.0	-20.0	1.01158	0.12825872706156197	1	20.0	0.0															
	1681	49.841511789606905	0.0	0.0	0.0	1.0678	0.5672571545146641	1	60.0	0.0															
	1682	57.700440910235805	0.0	0.0	0.0	1.00795	1.0450412263094198	1	110.00000000000001	0.0															
	1711	55.65657678132201	0.0	0.0	0.0	1.06436	0.7619784032539471	1	80.0	0.0															
	1712	0.0	7.802432329473549	20.0	-20.0	1.00997	0.108895174942445	1	20.0	0.0															
	1715	0.0	-34.017235477784595	90.0	-90.0	1.031	1.6993349549174301	1	170.0	0.0															
	1715	0.0	-35.639534139137695	90.0	-90.0	1.0310000000009543	1.74399613115937	1	180.0	0.0															
	1720	0.0	6.010928203333399	90.0	-60.0	1.051740000000749	1.3909524032296594	1	140.0	0.0															
	1720	0.0	6.19072122540185	90.0	-60.0	1.05174	1.4003431122126098	1	150.0	0.0															
	1768	0.0	-1.60272564662523	20.0	-20.0	0.98449	0.12966947583295402	1	20.0	0.0															
	1769	0.0	0.636647914386913	20.0	-20.0	1.00208	0.131987497480586	1	20.0	0.0															
	1983	0.0	1.26741441818588	10.0	-10.0	1.01394	0.04312644164264199	1	10.0	0.0															
	1984	0.0	-5.44371812789491	20.0	-20.0	0.95662	0.129645442360081	1	20.0	0.0															
	1987	0.0	-9.68102877693218	20.0	-30.0	1.07258	0.19169106867	1	20.0	0.0															
	2113	410.90327254569206	-233.17680685425904	550.0	-550.0	1.0366	5.391681234934368	1	540.0	0.0															
	2250	0.0	-198.58333244421001	550.0	-540.0	1.0296740373743591	5.4335858526174	1	550.0	0.0															
];

%% branch data
%    f_bus    t_bus    r    x    b    rateA    rateB    rateC    ratio    angle    status    angmin    angmax
mpc.branch = [
	28	292	0.0213946048670181	0.04942146980714439	0.012801024095775597	129.0	129.0	129.0	0	0	1	-59.99999999999999	59.99999999999999								
	28	350	0.020236665886361197	0.050316143305972186	0.10562471664845893	135.0	135.0	135.0	0	0	1	-59.99999999999999	59.99999999999999								
	52	8	0.026853445793652002	0.19165742354521298	5.195117468480018e-5	43.0	43.0	43.0	0	0	1	-59.99999999999999	59.99999999999999								
	53	8	0.026984079889560107	0.185702086980017	5.17387384688482e-5	42.0	42.0	42.0	0	0	1	-59.99999999999999	59.99999999999999								
	59	260	0.011122782782912299	0.0297112037291843	0.006220453130174425	141.0	141.0	141.0	0	0	1	-59.99999999999999	59.99999999999999								
	59	267	0.045772095961356514	0.120590632657148	0.025792474726494402	140.0	140.0	140.0	0	0	1	-59.99999999999999	59.99999999999999								
	59	304	0.006779413947917152	0.018607729760026597	0.004025052771484478	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	85	87	0.0011389550104285596	0.01393588748747199	1.6833172193448998	1342.0	1342.0	1342.0	0	0	1	-59.99999999999999	59.99999999999999								
	85	87	0.0011225049821915992	0.013771688338268497	1.6954215021408197	1344.0	1344.0	1344.0	0	0	1	-59.99999999999999	59.99999999999999								
	86	126	0.0006403316210620108	0.0064468902751826694	0.080071637497656	787.0	787.0	787.0	0	0	1	-59.99999999999999	59.99999999999999								
	86	126	0.000620334336382803	0.006148481834081931	0.08240736240510083	779.0	779.0	779.0	0	0	1	-59.99999999999999	59.99999999999999								
	86	142	0.0008590316504566002	0.008691190724875782	0.112796315229684	789.0	789.0	789.0	0	0	1	-59.99999999999999	59.99999999999999								
	86	143	0.0031186025418690404	0.03052345278941931	0.45626901837147793	773.0	773.0	773.0	0	0	1	-59.99999999999999	59.99999999999999								
	88	115	0.0006390014028278651	0.0064548685555730016	0.09401233060830509	788.0	788.0	788.0	0	0	1	-59.99999999999999	59.99999999999999								
	88	131	0.0014358749276801	0.014644579098475205	0.18420688904757598	793.0	793.0	793.0	0	0	1	-59.99999999999999	59.99999999999999								
	88	133	0.0006980898858401917	0.006846981908912769	0.09338147855802613	774.0	774.0	774.0	0	0	1	-59.99999999999999	59.99999999999999								
	12	99	0.00549684407743448	0.04001467715759991	0.5277011763906659	646.0	646.0	646.0	0	0	1	-59.99999999999999	59.99999999999999								
	12	104	0.0036628589148653694	0.046574779405701004	0.7304052178330444	907.0	907.0	907.0	0	0	1	-59.99999999999999	59.99999999999999								
	12	135	0.0024404891880895	0.029288513049949005	0.47137858199290905	875.0	875.0	875.0	0	0	1	-59.99999999999999	59.99999999999999								
	12	138	0.00411569981152844	0.0332833799581951	0.405787904264694	689.0	689.0	689.0	0	0	1	-59.99999999999999	59.99999999999999								
	12	138	0.005464298468891071	0.035343942727401906	0.43209820210204875	601.0	601.0	601.0	0	0	1	-59.99999999999999	59.99999999999999								
	91	100	0.00032143239948153506	0.0034259883954422506	0.039614513562890204	814.0	814.0	814.0	0	0	1	-59.99999999999999	59.99999999999999								
	91	114	0.0029789123197607697	0.0213626300034765	0.2681391625330549	640.0	640.0	640.0	0	0	1	-59.99999999999999	59.99999999999999								
	91	115	0.0011140258456952897	0.0129505473830168	0.14802050571879896	859.0	859.0	859.0	0	0	1	-59.99999999999999	59.99999999999999								
	92	116	0.0010885510705970199	0.0147748298170697	1.7006090545761405	1429.0	1429.0	1429.0	0	0	1	-59.99999999999999	59.99999999999999								
	92	116	0.0011106263382062301	0.014144395822631203	1.6346730551440307	1375.0	1375.0	1375.0	0	0	1	-59.99999999999999	59.99999999999999								
	93	114	0.0003592095476724209	0.00485193630699255	0.09552678346910695	940.0	940.0	940.0	0	0	1	-59.99999999999999	59.99999999999999								
	93	114	0.00036659299122914716	0.004587482080457733	0.09496649899752864	898.0	898.0	898.0	0	0	1	-59.99999999999999	59.99999999999999								
	93	119	0.00239067232144671	0.017843493603628604	0.21502937305927303	656.0	656.0	656.0	0	0	1	-59.99999999999999	59.99999999999999								
	93	61	0.00457242868733257	0.03418020142564271	0.4077533713723808	657.0	657.0	657.0	0	0	1	-59.99999999999999	59.99999999999999								
	94	116	0.0017476373474070298	0.0225862475770181	2.5475262015797195	1387.0	1387.0	1387.0	0	0	1	-59.99999999999999	59.99999999999999								
	94	149	0.0008477767884357367	0.011571809222622798	1.3597626684780695	1434.0	1434.0	1434.0	0	0	1	-59.99999999999999	59.99999999999999								
	95	110	0.00018765208803769203	0.0017710291671985806	0.02400285282507539	756.0	756.0	756.0	0	0	1	-59.99999999999999	59.99999999999999								
	95	110	0.00018309565764572502	0.0017152461362816408	0.025621291051786402	753.0	753.0	753.0	0	0	1	-59.99999999999999	59.99999999999999								
	95	127	0.005062739744205489	0.047457793328152004	0.6801827127528468	753.0	753.0	753.0	0	0	1	-59.99999999999999	59.99999999999999								
	95	61	0.005640994447898819	0.054073627863782496	0.7772919484522188	764.0	764.0	764.0	0	0	1	-59.99999999999999	59.99999999999999								
	109	23	0.0037399777384898416	0.11522154571351088	0.006938854755392411	275.0	275.0	275.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	97	98	0.00244661896547396	0.019350938101233905	0.22834600732551413	679.0	679.0	679.0	0	0	1	-59.99999999999999	59.99999999999999								
	97	109	0.0054815638063252	0.0399409118961464	0.47973428935437484	646.0	646.0	646.0	0	0	1	-59.99999999999999	59.99999999999999								
	98	113	0.00410372099094093	0.029828231756910704	0.36499138505975703	1483.8375219635775	645.0	645.0	0	0	1	-59.99999999999999	59.99999999999999								
	98	141	0.0038084608243499	0.03183420282778101	0.37810937236825903	703.0	703.0	703.0	0	0	1	-59.99999999999999	59.99999999999999								
	98	147	0.00144971191580594	0.014868301946477504	0.19000741341426997	796.0	796.0	796.0	0	0	1	-59.99999999999999	59.99999999999999								
	98	151	0.0016278954856574497	0.0132292583637871	0.157336153255356	691.0	691.0	691.0	0	0	1	-59.99999999999999	59.99999999999999								
	99	111	0.00709601896856702	0.054174033131706496	0.65326785024438	665.0	665.0	665.0	0	0	1	-59.99999999999999	59.99999999999999								
	100	109	0.00166386096210172	0.0135379533045636	0.15520439058789107	691.0	691.0	691.0	0	0	1	-59.99999999999999	59.99999999999999								
	100	114	0.00274414111995976	0.020981657009152704	0.2617178211031481	666.0	666.0	666.0	0	0	1	-59.99999999999999	59.99999999999999								
	100	133	0.00187141090140715	0.021428806004412503	0.27130704536082195	851.0	851.0	851.0	0	0	1	-59.99999999999999	59.99999999999999								
	101	144	0.005964429343834518	0.04615595429384241	0.559919314950723	670.0	670.0	670.0	0	0	1	-59.99999999999999	59.99999999999999								
	102	106	0.000254828323430382	0.002517975235153461	1.2525606660218898	778.0	778.0	778.0	0	0	1	-59.99999999999999	59.99999999999999								
	102	106	0.000271172397340648	0.00264301669002743	1.24495918041561	771.0	771.0	771.0	0	0	1	-59.99999999999999	59.99999999999999								
	103	201	0.0342950132478122	0.09924133636807418	0.0261390999147855	148.0	148.0	148.0	0	0	1	-59.99999999999999	59.99999999999999								
	103	286	0.035639496886978414	0.10653844324564596	0.02406568979042399	151.0	151.0	151.0	0	0	1	-59.99999999999999	59.99999999999999								
	104	135	0.0013382712363200298	0.017440944915344907	0.26543850867785507	919.9999999999999	919.9999999999999	919.9999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	104	1623	0.0036576786413243995	0.044478228680670306	0.6994230854636289	882.0	882.0	882.0	0	0	1	-59.99999999999999	59.99999999999999								
	104	1623	0.00364630651943386	0.044199198991008104	0.7333035897027699	881.0	881.0	881.0	0	0	1	-59.99999999999999	59.99999999999999								
	105	133	0.0003668577104597351	0.00441661813680176	3.330163318504069	877.0	877.0	877.0	0	0	1	-59.99999999999999	59.99999999999999								
	106	61	0.00025530614959993407	0.0030419849197376512	0.0372119472607039	871.0000000000001	871.0000000000001	871.0000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	106	61	0.00026262887000595193	0.0029070965867340594	0.037134825276170895	833.0	833.0	833.0	0	0	1	-59.99999999999999	59.99999999999999								
	107	133	0.0005990839999169109	0.00585149085285217	0.08520547032542988	772.0	772.0	772.0	0	0	1	-59.99999999999999	59.99999999999999								
	107	145	0.00360740342547465	0.033197096485666905	0.514430723322602	745.0	745.0	745.0	0	0	1	-59.99999999999999	59.99999999999999								
	108	144	0.00399604540073648	0.030581321998375908	0.3795588746255081	666.0	666.0	666.0	0	0	1	-59.99999999999999	59.99999999999999								
	108	831	0.0016394406916201095	0.0128891051766779	0.15568176635422692	677.0	677.0	677.0	0	0	1	-59.99999999999999	59.99999999999999								
	110	120	0.0006616731316100336	0.004931310835531909	0.07534584023475649	655.0	655.0	655.0	0	0	1	-59.99999999999999	59.99999999999999								
	110	126	0.0030475391520839203	0.03176800784265111	0.40428603335089985	802.9999999999999	802.9999999999999	802.9999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	110	138	0.005567214432419281	0.04080208764306131	0.5366600638017708	649.0	649.0	649.0	0	0	1	-59.99999999999999	59.99999999999999								
	110	139	0.003376445538480949	0.03559826780126431	0.47936948058143286	809.0	809.0	809.0	0	0	1	-59.99999999999999	59.99999999999999								
	112	133	0.0004984658036660401	0.0052260588949895525	0.07084876054867645	806.0	806.0	806.0	0	0	1	-59.99999999999999	59.99999999999999								
	112	61	0.00048894178866595	0.004779740621322771	0.06421571918618488	773.0	773.0	773.0	0	0	1	-59.99999999999999	59.99999999999999								
	113	141	0.0016177231878188407	0.013075334178902207	0.15598860032670206	688.0	688.0	688.0	0	0	1	-59.99999999999999	59.99999999999999								
	113	144	0.004230393194225061	0.031163470459792307	0.3978532764773349	651.0	651.0	651.0	0	0	1	-59.99999999999999	59.99999999999999								
	113	151	0.00487603953066887	0.037748682541321	0.528233339417093	671.0	671.0	671.0	0	0	1	-59.99999999999999	59.99999999999999								
	113	827	0.0030880695344582204	0.022429178837193205	0.28348333942303405	645.0	645.0	645.0	0	0	1	-59.99999999999999	59.99999999999999								
	114	151	0.004608929471296258	0.03800400496403689	0.46118647054224277	697.0	697.0	697.0	0	0	1	-59.99999999999999	59.99999999999999								
	114	151	0.004585812630360851	0.03577098650301621	0.41855507495459193	674.0	674.0	674.0	0	0	1	-59.99999999999999	59.99999999999999								
	116	149	0.0008832353375784117	0.011167770984761396	1.3441456838160801	1369.0	1369.0	1369.0	0	0	1	-59.99999999999999	59.99999999999999								
	117	145	0.00022335998928956703	0.0021623495207090905	0.032297981452569395	768.0	768.0	768.0	0	0	1	-59.99999999999999	59.99999999999999								
	117	145	0.000238167415531352	0.0023182632682465006	0.0307610085719302	771.0	771.0	771.0	0	0	1	-59.99999999999999	59.99999999999999								
	117	148	0.007106177316955288	0.051405020363783506	0.6380371500890237	644.0	644.0	644.0	0	0	1	-59.99999999999999	59.99999999999999								
	118	61	0.0035206865253672006	0.036645195242716	0.506899248446147	802.9999999999999	802.9999999999999	802.9999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	118	140	0.0011094031405812098	0.012115308408995605	0.16344245562190196	827.0	827.0	827.0	0	0	1	-59.99999999999999	59.99999999999999								
	118	142	0.00020985141811380198	0.0021308087728247006	0.02607113050868731	791.0	791.0	791.0	0	0	1	-59.99999999999999	59.99999999999999								
	119	151	0.0025201892583891702	0.01983479489308781	0.25642106492965905	677.0	677.0	677.0	0	0	1	-59.99999999999999	59.99999999999999								
	120	138	0.005233336294688658	0.03793305422313649	0.4776140188000159	644.0	644.0	644.0	0	0	1	-59.99999999999999	59.99999999999999								
	121	237	0.0007342707045497373	0.0017635611776928397	0.06341918928609089	132.0	132.0	132.0	0	0	1	-59.99999999999999	59.99999999999999								
	122	239	0.0009008754581382962	0.0019385515564050494	0.07174157153103132	124.0	124.0	124.0	0	0	1	-59.99999999999999	59.99999999999999								
	123	236	0.0009037223643902689	0.0019775712276953296	0.07457003090416173	125.0	125.0	125.0	0	0	1	-59.99999999999999	59.99999999999999								
	124	366	0.003942278270581607	0.00910197651868422	0.35368702971906896	129.0	129.0	129.0	0	0	1	-59.99999999999999	59.99999999999999								
	126	139	0.000721468428298831	0.006858697729018521	0.10203571456060696	760.0	760.0	760.0	0	0	1	-59.99999999999999	59.99999999999999								
	126	139	0.0007328506571939221	0.006924745208468291	0.10565240891925098	757.0	757.0	757.0	0	0	1	-59.99999999999999	59.99999999999999								
	126	142	0.00109038195973262	0.010209810531835999	0.152121480317786	753.0	753.0	753.0	0	0	1	-59.99999999999999	59.99999999999999								
	126	146	0.000533160382474959	0.005050116726952881	0.07690113015689928	758.0	758.0	758.0	0	0	1	-59.99999999999999	59.99999999999999								
	127	61	0.000482097479462531	0.0049991164487591016	0.0731080089859739	801.0	801.0	801.0	0	0	1	-59.99999999999999	59.99999999999999								
	128	131	0.0006510614951667379	0.0063578261494319915	0.08881317310842171	772.0	772.0	772.0	0	0	1	-59.99999999999999	59.99999999999999								
	128	131	0.0006804984633834101	0.006824063138660971	0.08404103195147122	785.0	785.0	785.0	0	0	1	-59.99999999999999	59.99999999999999								
	129	231	0.0190887799974158	0.04172849446032199	0.00854633274437673	125.0	125.0	125.0	0	0	1	-59.99999999999999	59.99999999999999								
	129	775	0.0183899826684594	0.050378967693149986	0.01034528192169959	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	131	61	0.00093172233903408	0.010179013713213603	0.131859650623836	827.0	827.0	827.0	0	0	1	-59.99999999999999	59.99999999999999								
	131	140	0.00180625766765866	0.0196081123656034	0.241563580367481	824.0	824.0	824.0	0	0	1	-59.99999999999999	59.99999999999999								
	131	142	0.0024711063312795	0.026756174016029612	0.3412631819133651	822.0000000000001	822.0000000000001	822.0000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	132	240	0.050466646081768006	0.13810153952864898	0.02857858604894949	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	132	387	0.0341483374678809	0.08629042608339335	0.01829617928587369	136.0	136.0	136.0	0	0	1	-59.99999999999999	59.99999999999999								
	133	145	0.00414311490017199	0.03987566436200871	0.6107460691964353	765.0	765.0	765.0	0	0	1	-59.99999999999999	59.99999999999999								
	133	557	0.00041508565774876587	0.0033696280453614906	2.457417634188569	690.0	690.0	690.0	0	0	1	-59.99999999999999	59.99999999999999								
	61	143	0.0006007844828772356	0.0060861772845340915	0.0844447730286107	790.0	790.0	790.0	0	0	1	-59.99999999999999	59.99999999999999								
	139	146	0.000260147637901828	0.00249511185301747	0.034025754706913096	764.0	764.0	764.0	0	0	1	-59.99999999999999	59.99999999999999								
	141	151	0.006103511092722421	0.04747930508131442	0.531508752820017	673.0	673.0	673.0	0	0	1	-59.99999999999999	59.99999999999999								
	141	827	0.00174801820714213	0.0147438467117557	0.17414501094723597	707.0	707.0	707.0	0	0	1	-59.99999999999999	59.99999999999999								
	148	150	0.00470323144650012	0.035423657524215106	0.4320892225623969	660.0	660.0	660.0	0	0	1	-59.99999999999999	59.99999999999999								
	152	305	0.08482580144515732	0.21576227856217894	0.04793308662138878	137.0	137.0	137.0	0	0	1	-59.99999999999999	59.99999999999999								
	152	324	0.09216109331963636	0.252731762580634	0.053216856760745904	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	152	328	0.14660060473484895	0.4336830756503617	0.08441986633040935	150.0	150.0	150.0	0	0	1	-59.99999999999999	59.99999999999999								
	152	27	0.0816180064428365	0.24852212814153588	0.0498730454116506	153.0	153.0	153.0	0	0	1	-59.99999999999999	59.99999999999999								
	327	152	0.12212704062114056	0.38703269725507605	0.0705996104013375	78.0	78.0	78.0	1.0552410552410554	0.0	1	-59.99999999999999	59.99999999999999								
	157	266	0.0073481386190014895	0.027084312552027392	0.007304179940303788	171.0	171.0	171.0	0	0	1	-59.99999999999999	59.99999999999999								
	157	328	0.06430236821700819	0.17978284463658892	0.039188245123857594	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	157	439	0.013764156946195304	0.05547133659962558	0.013970784274740099	181.0	181.0	181.0	0	0	1	-59.99999999999999	59.99999999999999								
	157	27	0.033516937474636396	0.09253534544164307	0.019445091573066103	144.0	144.0	144.0	0	0	1	-59.99999999999999	59.99999999999999								
	248	300	0.00232129511072766	0.023596613976266195	0.00944844518988952	317.0	317.0	317.0	0	0	1	-59.99999999999999	59.99999999999999								
	248	440	0.03910356974238528	0.13724645487025394	0.027509415414333296	166.0	166.0	166.0	0	0	1	-59.99999999999999	59.99999999999999								
	248	440	0.0391109898971301	0.13332004798937094	0.028704409679621498	163.0	163.0	163.0	0	0	1	-59.99999999999999	59.99999999999999								
	248	299	0.0025969930342533594	0.02487079684794879	0.0100089951337874	306.0	306.0	306.0	0	0	1	-59.99999999999999	59.99999999999999								
	159	293	0.03849524709378881	0.10315015862777101	0.021005102677311704	141.0	141.0	141.0	0	0	1	-59.99999999999999	59.99999999999999								
	159	450	0.00504658115445636	0.04844925607439128	0.007345125751487441	306.0	306.0	306.0	0	0	1	-59.99999999999999	59.99999999999999								
	159	450	0.004984208895359191	0.0500184619898302	0.006879821772045459	314.0	314.0	314.0	0	0	1	-59.99999999999999	59.99999999999999								
	159	463	0.0011283213729495198	0.027333370479108793	0.0015231814300268895	537.0	537.0	537.0	0	0	1	-59.99999999999999	59.99999999999999								
	159	463	0.001465341174695639	0.028810969831753998	0.001940103144571188	473.00000000000006	473.00000000000006	473.00000000000006	0	0	1	-59.99999999999999	59.99999999999999								
	160	204	0.03713735064702341	0.1660244527816399	0.439467819973268	320.0	320.0	320.0	0	0	1	-59.99999999999999	59.99999999999999								
	161	285	0.011195397630292002	0.03268669014166569	0.007303788624471045	149.0	149.0	149.0	0	0	1	-59.99999999999999	59.99999999999999								
	161	310	0.028279031073711818	0.12718387141320894	0.030635143730044403	193.0	193.0	193.0	0	0	1	-59.99999999999999	59.99999999999999								
	161	488	0.017746030093096197	0.08264867896333336	0.019345907812053285	197.0	197.0	197.0	0	0	1	-59.99999999999999	59.99999999999999								
	162	214	0.0006957378639131781	0.005779441676177549	0.16339648452316902	280.0	280.0	280.0	0	0	1	-59.99999999999999	59.99999999999999								
	162	156	0.00051902065923214	0.004381330450064218	0.11307902935775599	283.0	283.0	283.0	0	0	1	-59.99999999999999	59.99999999999999								
	162	517	0.000297132604429498	0.002356686860172079	0.06092698699716479	273.0	273.0	273.0	0	0	1	-59.99999999999999	59.99999999999999								
	162	518	0.000294323009653017	0.002353190984619779	0.06092686202386017	274.0	274.0	274.0	0	0	1	-59.99999999999999	59.99999999999999								
	162	156	0.00038596826991066293	0.004704185158237808	0.05546157770449669	354.0	354.0	354.0	0	0	1	-59.99999999999999	59.99999999999999								
	165	240	0.006973423682034022	0.043420309793702296	0.00961514875106513	235.0	235.0	235.0	0	0	1	-59.99999999999999	59.99999999999999								
	165	242	0.00409676693452522	0.026501719788671493	0.005882945050857957	241.0	241.0	241.0	0	0	1	-59.99999999999999	59.99999999999999								
	170	294	0.0210587474328652	0.09115112085567419	0.020496184518050905	189.0	189.0	189.0	0	0	1	-59.99999999999999	59.99999999999999								
	170	307	0.016590047498525808	0.0765936850407127	0.009137140149995678	196.0	196.0	196.0	0	0	1	-59.99999999999999	59.99999999999999								
	170	375	0.030391143900961107	0.17911859959056917	0.020550133843278227	174.0	174.0	174.0	1.0375000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	172	193	0.00325308564902376	0.02033695205842609	0.004857836650230459	236.0	236.0	236.0	0	0	1	-59.99999999999999	59.99999999999999								
	172	256	0.10231122600006119	0.2877233056931901	0.06101108035344374	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	172	420	0.06617580714446493	0.20238403459419496	0.0488623414546065	153.0	153.0	153.0	0	0	1	-59.99999999999999	59.99999999999999								
	175	388	0.00717519660964934	0.032018284045913295	0.00883821157493535	192.0	192.0	192.0	0	0	1	-59.99999999999999	59.99999999999999								
	175	447	0.0154543988733133	0.08613837815465025	0.02134538355219359	220.00000000000003	220.00000000000003	220.00000000000003	0	0	1	-59.99999999999999	59.99999999999999								
	176	196	0.008553625925361463	0.033786346754874984	0.007538375273089858	179.0	179.0	179.0	0	0	1	-59.99999999999999	59.99999999999999								
	176	250	0.00544038066279609	0.020948259432943494	0.004336769995775069	176.0	176.0	176.0	0	0	1	-59.99999999999999	59.99999999999999								
	176	255	0.008983115842057392	0.03871692468586838	0.008628724846779375	188.0	188.0	188.0	0	0	1	-59.99999999999999	59.99999999999999								
	176	276	0.007053149099379784	0.04478358546800029	0.010932849966944203	238.0	238.0	238.0	0	0	1	-59.99999999999999	59.99999999999999								
	176	276	0.007108711922104701	0.04203454866641289	0.010280709808051597	227.99999999999997	227.99999999999997	227.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	176	329	0.005815399357252573	0.03351469937494259	0.008004333194041625	225.0	225.0	225.0	0	0	1	-59.99999999999999	59.99999999999999								
	176	329	0.005107525231549518	0.031102843950502574	0.007919455919042227	231.99999999999997	231.99999999999997	231.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	176	372	0.00565531593188061	0.023661015586769193	0.0050759720070380696	185.0	185.0	185.0	0	0	1	-59.99999999999999	59.99999999999999								
	176	250	0.0067720640180297725	0.027052260798537193	0.006463262143668721	180.0	180.0	180.0	0	0	1	-59.99999999999999	59.99999999999999								
	176	609	0.0012171551443291798	0.009988757538519327	0.00488960326646641	278.0	278.0	278.0	0	0	1	-59.99999999999999	59.99999999999999								
	176	609	0.0012414766141581302	0.009946696680473157	0.005171861472168011	274.0	274.0	274.0	0	0	1	-59.99999999999999	59.99999999999999								
	178	181	0.008649832452143541	0.05403166819817848	0.012052758680079101	236.0	236.0	236.0	0	0	1	-59.99999999999999	59.99999999999999								
	178	459	0.0042938810001961	0.028303229642584922	0.007025425069453192	244.0	244.0	244.0	0	0	1	-59.99999999999999	59.99999999999999								
	179	282	0.004904775345602758	0.030011079312870434	0.12720924780109744	233.0	233.0	233.0	0	0	1	-59.99999999999999	59.99999999999999								
	179	319	0.0046872829511284035	0.03084124885446546	0.048865348205569134	243.00000000000003	243.00000000000003	243.00000000000003	0	0	1	-59.99999999999999	59.99999999999999								
	179	366	0.0034706502315515605	0.03070345903288569	0.014691328093565499	291.0	291.0	291.0	0	0	1	-59.99999999999999	59.99999999999999								
	179	366	0.0035296349189802992	0.0307273213566653	0.015087396393315891	288.0	288.0	288.0	0	0	1	-59.99999999999999	59.99999999999999								
	180	459	0.004053060797896239	0.02446966323087459	0.006177579314075412	231.0	231.0	231.0	0	0	1	-59.99999999999999	59.99999999999999								
	182	208	0.0023407329653645894	0.01836936134374139	0.00844585873339372	271.0	271.0	271.0	0	0	1	-59.99999999999999	59.99999999999999								
	182	233	0.0020700866257841706	0.013150913127768796	0.0033372992755761398	238.0	238.0	238.0	0	0	1	-59.99999999999999	59.99999999999999								
	182	233	0.00218950656854082	0.013228976593575395	0.003144755061679518	231.0	231.0	231.0	0	0	1	-59.99999999999999	59.99999999999999								
	182	298	0.0029339056656714504	0.02280550550641679	0.011609195027105	269.0	269.0	269.0	0	0	1	-59.99999999999999	59.99999999999999								
	182	363	0.0031787034054072605	0.017121274992003995	0.0033025415008198517	216.0	216.0	216.0	0	0	1	-59.99999999999999	59.99999999999999								
	182	331	0.005222129207927498	0.023856076146907188	0.005555719114886597	195.0	195.0	195.0	0	0	1	-59.99999999999999	59.99999999999999								
	182	282	0.004794936925559121	0.028949815211568003	0.007447234167219613	231.0	231.0	231.0	0	0	1	-59.99999999999999	59.99999999999999								
	182	282	0.0030027581930302093	0.030115951823988504	0.007421462371949104	314.0	314.0	314.0	0	0	1	-59.99999999999999	59.99999999999999								
	183	257	0.005806795142293912	0.025520953612588295	0.007273383931166958	191.0	191.0	191.0	0	0	1	-59.99999999999999	59.99999999999999								
	183	253	0.0018467379422874698	0.015989768034785495	0.00783520075768698	287.0	287.0	287.0	0	0	1	-59.99999999999999	59.99999999999999								
	183	253	0.0018882742864922604	0.016113858673807692	0.008218353224019516	285.0	285.0	285.0	0	0	1	-59.99999999999999	59.99999999999999								
	183	398	0.001322063036568	0.010773364188270594	0.005464625666397621	277.0	277.0	277.0	0	0	1	-59.99999999999999	59.99999999999999								
	183	442	0.004912874445690488	0.022585303156062997	0.006337468583148898	196.0	196.0	196.0	0	0	1	-59.99999999999999	59.99999999999999								
	184	227	0.0017381451018061503	0.014092758851498395	0.00769021928546205	276.0	276.0	276.0	0	0	1	-59.99999999999999	59.99999999999999								
	184	246	0.0030266977207867403	0.013598732757643797	0.009535455419853327	193.0	193.0	193.0	0	0	1	-59.99999999999999	59.99999999999999								
	184	253	0.0017845289028622202	0.015172026048819499	0.008034618214983958	284.0	284.0	284.0	0	0	1	-59.99999999999999	59.99999999999999								
	184	253	0.0018279106239518202	0.014785468740770604	0.007691074190512769	276.0	276.0	276.0	0	0	1	-59.99999999999999	59.99999999999999								
	184	393	0.0104346547274053	0.042269580070755895	0.009269254995150496	181.0	181.0	181.0	0	0	1	-59.99999999999999	59.99999999999999								
	185	315	0.09191392315525557	0.1686962864496749	0.03189677527088669	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	185	415	0.14578223888841493	0.4262043442174878	0.08615525808284062	149.0	149.0	149.0	0	0	1	-59.99999999999999	59.99999999999999								
	186	200	0.0317457329405099	0.114024499808969	0.0286442244663388	169.0	169.0	169.0	0	0	1	-59.99999999999999	59.99999999999999								
	186	255	0.004779704814719039	0.021941347023116894	0.005955872625948858	196.0	196.0	196.0	0	0	1	-59.99999999999999	59.99999999999999								
	186	255	0.006072033718831371	0.02670510494224349	0.007018827885204931	191.0	191.0	191.0	0	0	1	-59.99999999999999	59.99999999999999								
	186	348	0.00970867300598323	0.03717241151146591	0.010912314254790504	175.0	175.0	175.0	0	0	1	-59.99999999999999	59.99999999999999								
	186	348	0.010835267894156297	0.03899883564042859	0.0116035609052656	169.0	169.0	169.0	0	0	1	-59.99999999999999	59.99999999999999								
	186	455	0.05116587169542161	0.14251912359490498	0.032109590112689906	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	186	468	0.00244328402138054	0.013916006894982397	0.00437613147669006	223.0	223.0	223.0	0	0	1	-59.99999999999999	59.99999999999999								
	186	468	0.00288290029838379	0.013459372033341797	0.00395241503307968	198.0	198.0	198.0	0	0	1	-59.99999999999999	59.99999999999999								
	188	306	0.007357981857173141	0.04230426934472749	0.009375906391495843	224.00000000000003	224.00000000000003	224.00000000000003	0	0	1	-59.99999999999999	59.99999999999999								
	188	422	0.00357568819878623	0.019820395019045107	0.003964809751138089	219.0	219.0	219.0	0	0	1	-59.99999999999999	59.99999999999999								
	189	234	0.0042069650529264506	0.019596229639109692	0.004523835593814029	197.0	197.0	197.0	0	0	1	-59.99999999999999	59.99999999999999								
	142	454	0.005483840273336411	0.10944363030558464	0.02097223435878726	289.0	289.0	289.0	0.971428571428572	0.0	1	-59.99999999999999	59.99999999999999								
	191	446	0.00276108163125534	0.016319758897069395	0.00469451094413269	227.99999999999997	227.99999999999997	227.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	191	446	0.0029489379769526403	0.016730731154773797	0.00464126763184369	222.00000000000003	222.00000000000003	222.00000000000003	0	0	1	-59.99999999999999	59.99999999999999								
	192	222	0.05348117413869782	0.14531828620785794	0.03132240254393218	142.0	142.0	142.0	0	0	1	-59.99999999999999	59.99999999999999								
	192	304	0.0649762098588217	0.17706557531654796	0.040189658294348	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	192	470	0.010082513812489802	0.027701649068162793	0.006167779100017621	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	192	471	0.014619610567353704	0.03841456131454559	0.00566760211733636	459.14668332342	139.0	139.0	0	0	1	-59.99999999999999	59.99999999999999								
	192	471	0.014425373999215702	0.037308111726120086	0.006127340246545618	466.9769533587191	138.0	138.0	0	0	1	-59.99999999999999	59.99999999999999								
	192	472	0.005577902700716071	0.023849819861333797	0.005133834691245109	187.0	187.0	187.0	0	0	1	-59.99999999999999	59.99999999999999								
	192	472	0.005665495491459499	0.02237550579809579	0.00505021986993961	179.0	179.0	179.0	0	0	1	-59.99999999999999	59.99999999999999								
	192	488	0.11138231947347506	0.307435720003582	0.06600884197591805	144.0	144.0	144.0	0	0	1	-59.99999999999999	59.99999999999999								
	193	325	0.014419173569446393	0.05632424654345958	0.0128929504747316	177.0	177.0	177.0	0	0	1	-59.99999999999999	59.99999999999999								
	193	326	0.0225312773953215	0.0805464619517326	0.0180640302773309	168.0	168.0	168.0	0	0	1	-59.99999999999999	59.99999999999999								
	193	420	0.136517850684002	0.22922476807357708	0.04432180698541921	106.0	106.0	106.0	0	0	1	-59.99999999999999	59.99999999999999								
	193	424	0.04723718132380401	0.12982034034957193	0.028453586697983587	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	196	372	0.00368005456326203	0.016416873988806695	0.003719989592422267	192.0	192.0	192.0	0	0	1	-59.99999999999999	59.99999999999999								
	197	286	0.03587354375371991	0.17341103287981796	0.0382736800781898	202.0	202.0	202.0	0	0	1	-59.99999999999999	59.99999999999999								
	197	286	0.04095787081727391	0.1855050382186889	0.04011681388674399	194.0	194.0	194.0	0	0	1	-59.99999999999999	59.99999999999999								
	197	299	0.0041509735150579395	0.03206591362042538	0.018768048088274397	268.0	268.0	268.0	0	0	1	-59.99999999999999	59.99999999999999								
	197	353	0.01680446724027861	0.045913942283461795	0.009512555195216096	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	197	466	0.00280860466930736	0.02132329152186029	0.0114445871735085	265.0	265.0	265.0	0	0	1	-59.99999999999999	59.99999999999999								
	198	221	0.022729986185668506	0.10721767936297698	0.024343088420801802	199.0	199.0	199.0	0	0	1	-59.99999999999999	59.99999999999999								
	198	256	0.04349690529778599	0.12511063591651606	0.025779621472898886	147.0	147.0	147.0	0	0	1	-59.99999999999999	59.99999999999999								
	198	221	0.021896637973982808	0.10063673010135098	0.022764525680579212	196.0	196.0	196.0	0	0	1	-59.99999999999999	59.99999999999999								
	198	425	0.09995104926900943	0.2779163375013508	0.059075677764555405	144.0	144.0	144.0	0	0	1	-59.99999999999999	59.99999999999999								
	198	392	0.06965167603690561	0.14650590312331663	0.031313226337370395	122.0	122.0	122.0	0	0	1	-59.99999999999999	59.99999999999999								
	198	420	0.077091409565908	0.2144363121672538	0.045086920210783435	144.0	144.0	144.0	0	0	1	-59.99999999999999	59.99999999999999								
	199	267	0.030365091281197992	0.09145766212802847	0.018033838921599092	152.0	152.0	152.0	0	0	1	-59.99999999999999	59.99999999999999								
	199	289	0.10105110401404103	0.27032323694201194	0.060232091926103494	141.0	141.0	141.0	0	0	1	-59.99999999999999	59.99999999999999								
	199	289	0.0946456450715289	0.25963243142533987	0.05690704128061888	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	199	317	0.0509412016317174	0.10732408037336796	0.020520344273173192	122.0	122.0	122.0	0	0	1	-59.99999999999999	59.99999999999999								
	199	406	0.0628491078339517	0.17630389469540692	0.034104918209603104	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	199	472	0.12501993471866002	0.3593189516757519	0.07592715844415221	147.0	147.0	147.0	0	0	1	-59.99999999999999	59.99999999999999								
	199	357	0.019119469877458228	0.054922040420350336	0.011705698856442006	147.0	147.0	147.0	0	0	1	-59.99999999999999	59.99999999999999								
	200	464	0.07694483679411	0.23783216376529093	0.051843554611648406	154.0	154.0	154.0	0	0	1	-59.99999999999999	59.99999999999999								
	200	552	0.008393734505149048	0.25136041669877346	0.0007497177316169812	126.0	126.0	126.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	201	286	0.07705555342587272	0.21090195182296395	0.04410709649216661	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	204	215	0.021383695335674604	0.09412714147856736	0.2615913086940159	317.0	317.0	317.0	0	0	1	-59.99999999999999	59.99999999999999								
	205	302	0.0007442872857218615	0.00309984844893403	0.10349242919800801	184.0	184.0	184.0	0	0	1	-59.99999999999999	59.99999999999999								
	205	282	0.0013409565498162998	0.005570365555323658	0.21782769745726593	184.0	184.0	184.0	0	0	1	-59.99999999999999	59.99999999999999								
	205	282	0.001291131577181631	0.0057844319736384785	0.20812776817427509	193.0	193.0	193.0	0	0	1	-59.99999999999999	59.99999999999999								
	221	216	0.003919391780208801	0.011899987087909097	0.0029638759877421007	152.0	152.0	152.0	0	0	1	-59.99999999999999	59.99999999999999								
	221	410	0.0901740825170912	0.2538321929199159	0.05625872332678317	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	208	313	0.0022923850741297905	0.015587272455402599	0.008147044783458108	248.0	248.0	248.0	0	0	1	-59.99999999999999	59.99999999999999								
	210	215	0.03905852992553959	0.16522944318791896	0.4496695266409031	310.0	310.0	310.0	0	0	1	-59.99999999999999	59.99999999999999								
	211	1382	0.030701083648665806	0.07543918535780157	0.008205477387676954	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	211	1382	0.03140418629638849	0.08142545084910925	0.007764268109877591	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	212	156	0.0016939536714636405	0.013616143439960857	0.21961523786255938	275.0	275.0	275.0	0	0	1	-59.99999999999999	59.99999999999999								
	212	225	0.00047645715381950093	0.0037641848068591193	0.05407206912217199	272.0	272.0	272.0	0	0	1	-59.99999999999999	59.99999999999999								
	212	225	0.00054450880904356	0.003878719500461408	0.053023864614134684	254.99999999999997	254.99999999999997	254.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	212	275	0.0015818328157918104	0.08431640947042132	0.16478352117402026	867.0	867.0	867.0	0	0	1	-59.99999999999999	59.99999999999999								
	214	262	0.00113981681188196	0.008620966869687658	0.3363178145783579	265.0	265.0	265.0	0	0	1	-59.99999999999999	59.99999999999999								
	214	156	0.000138285460487008	0.0012307199009638293	0.0255459336943184	292.0	292.0	292.0	0	0	1	-59.99999999999999	59.99999999999999								
	214	364	0.0007516070646801963	0.0016758111706478493	0.0680288744866475	126.0	126.0	126.0	0	0	1	-59.99999999999999	59.99999999999999								
	214	365	0.0007404927350087093	0.0016161291100121997	0.06595189028873291	125.0	125.0	125.0	0	0	1	-59.99999999999999	59.99999999999999								
	214	182	0.002237436387443911	0.016997652658335912	0.6486100710493051	266.0	266.0	266.0	0	0	1	-59.99999999999999	59.99999999999999								
	214	451	0.0005529419012116269	0.0011722320516994195	0.04379369363537761	122.0	122.0	122.0	0	0	1	-59.99999999999999	59.99999999999999								
	214	452	0.000523447964653373	0.0011645646568033796	0.045770792281005994	126.0	126.0	126.0	0	0	1	-59.99999999999999	59.99999999999999								
	215	798	0.0035491340492954495	0.015326548600584293	0.04306884769377108	314.0	314.0	314.0	0	0	1	-59.99999999999999	59.99999999999999								
	216	369	0.023811938042652806	0.069890763158923	0.017406600993864707	149.0	149.0	149.0	0	0	1	-59.99999999999999	59.99999999999999								
	217	229	0.0026898252290930595	0.011048416859561996	0.0027567979956083	183.0	183.0	183.0	0	0	1	-59.99999999999999	59.99999999999999								
	217	458	0.0036813646919176884	0.015031758168106892	0.0034567908464465283	182.0	182.0	182.0	0	0	1	-59.99999999999999	59.99999999999999								
	218	103	0.012020589203564504	0.049875391618117694	0.00420431826024875	184.0	184.0	184.0	0	0	1	-59.99999999999999	59.99999999999999								
	219	249	0.009514572216053962	0.02695772360943719	0.007153415701717598	146.0	146.0	146.0	0	0	1	-59.99999999999999	59.99999999999999								
	219	315	0.09063962822564879	0.17126629378376493	0.03374988320376721	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	221	369	0.039954174136131095	0.08972461380648986	0.017716290065014694	127.0	127.0	127.0	0	0	1	-59.99999999999999	59.99999999999999								
	222	242	0.03341241093942062	0.0971181807949324	0.02089908804586951	148.0	148.0	148.0	0	0	1	-59.99999999999999	59.99999999999999								
	223	393	0.0022737419008883606	0.014641601244770907	0.00391607910563238	240.0	240.0	240.0	0	0	1	-59.99999999999999	59.99999999999999								
	223	395	0.00217969444776177	0.013465182688251096	0.025629240785775196	234.0	234.0	234.0	0	0	1	-59.99999999999999	59.99999999999999								
	225	182	0.0004807928346097469	0.0037432386446837286	0.07913905567169187	269.0	269.0	269.0	0	0	1	-59.99999999999999	59.99999999999999								
	225	182	0.000456902439626306	0.0038646144752640284	0.06332390138704798	283.0	283.0	283.0	0	0	1	-59.99999999999999	59.99999999999999								
	229	245	0.0025794945379240897	0.010228949741609402	0.0024966471115350697	179.0	179.0	179.0	0	0	1	-59.99999999999999	59.99999999999999								
	230	248	0.006160288057459519	0.031080912667326578	0.010571547689819698	206.99999999999997	206.99999999999997	206.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	230	281	0.0057205006992258126	0.03258407891132871	0.010618550724191603	223.0	223.0	223.0	0	0	1	-59.99999999999999	59.99999999999999								
	231	740	0.015802826208318608	0.044923353904043284	0.00933202304306393	146.0	146.0	146.0	0	0	1	-59.99999999999999	59.99999999999999								
	232	234	0.005461643600495581	0.022708737375477295	0.00489062478464842	184.0	184.0	184.0	0	0	1	-59.99999999999999	59.99999999999999								
	232	250	0.002961245820830481	0.014136113673705599	0.0035818538741674284	200.0	200.0	200.0	0	0	1	-59.99999999999999	59.99999999999999								
	233	251	0.0007006486663552933	0.00373468099753931	0.03961634617047852	214.0	214.0	214.0	0	0	1	-59.99999999999999	59.99999999999999								
	233	401	0.0010739944270122797	0.006037814471609886	0.04465761461360849	221.0	221.0	221.0	0	0	1	-59.99999999999999	59.99999999999999								
	234	422	0.016672229931986398	0.06817162975556497	0.013992903959333898	182.0	182.0	182.0	0	0	1	-59.99999999999999	59.99999999999999								
	195	356	0.00047280571614880993	0.004957548370876347	0.17598060405556998	323.0	323.0	323.0	0	0	1	-59.99999999999999	59.99999999999999								
	236	366	0.0029916977852960107	0.006792727989568378	0.23717016974554903	128.0	128.0	128.0	0	0	1	-59.99999999999999	59.99999999999999								
	237	366	0.00361272130232751	0.007844617166129126	0.293027041778988	124.0	124.0	124.0	0	0	1	-59.99999999999999	59.99999999999999								
	239	366	0.0029172445823042715	0.00686460768227652	0.248039923041388	130.0	130.0	130.0	0	0	1	-59.99999999999999	59.99999999999999								
	240	242	0.00343729374374636	0.021270732143109688	0.004992778273344039	234.0	234.0	234.0	0	0	1	-59.99999999999999	59.99999999999999								
	240	10028	0.01235617777113962	0.25506785457673936	0.006895574997416703	124.0	124.0	124.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	247	363	0.00423247762415903	0.016278512369071095	0.0038815910188481203	176.0	176.0	176.0	0	0	1	-59.99999999999999	59.99999999999999								
	247	331	0.0075682298673628795	0.029366002140629982	0.006700962464417327	177.0	177.0	177.0	0	0	1	-59.99999999999999	59.99999999999999								
	249	415	0.07000146518215539	0.13030328623876009	0.026222595644984404	112.99999999999999	112.99999999999999	112.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	251	401	0.000756492727533914	0.0017266280397847296	0.05250370537708506	128.0	128.0	128.0	0	0	1	-59.99999999999999	59.99999999999999								
	252	401	0.0008014236358245831	0.0017304201981425294	0.05423056439284231	124.0	124.0	124.0	0	0	1	-59.99999999999999	59.99999999999999								
	253	254	0.000998762199008837	0.005553199999463279	0.04462852856145799	220.00000000000003	220.00000000000003	220.00000000000003	0	0	1	-59.99999999999999	59.99999999999999								
	253	277	0.0012709236452821601	0.010522639069296397	0.005745687182935889	280.0	280.0	280.0	0	0	1	-59.99999999999999	59.99999999999999								
	253	277	0.0012877033129249699	0.011321319257503395	0.005652957786878109	290.0	290.0	290.0	0	0	1	-59.99999999999999	59.99999999999999								
	254	334	0.0013933113652863502	0.006751764929871538	0.0559981557046133	202.0	202.0	202.0	0	0	1	-59.99999999999999	59.99999999999999								
	254	430	0.0007387640157672577	0.0037324303616620568	0.02846698999420088	206.99999999999997	206.99999999999997	206.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	255	329	0.011616198339904701	0.03637232933809979	0.007452932465821502	155.0	155.0	155.0	0	0	1	-59.99999999999999	59.99999999999999								
	253	258	0.0014645461196307996	0.007969011920953359	0.03420942110802509	217.0	217.0	217.0	0	0	1	-59.99999999999999	59.99999999999999								
	262	182	0.00236636475311639	0.01845265465480741	0.7138175423903389	270.0	270.0	270.0	0	0	1	-59.99999999999999	59.99999999999999								
	262	313	0.0009578933698385953	0.0476145641883463	0.006723661560735201	831.0	831.0	831.0	0	0	1	-59.99999999999999	59.99999999999999								
	262	313	0.0009878167378753432	0.04877740401111542	0.0070424928260822825	827.0	827.0	827.0	0	0	1	-59.99999999999999	59.99999999999999								
	262	374	0.00101434996706666	0.003596203458675648	0.08260976221139071	167.0	167.0	167.0	0	0	1	-59.99999999999999	59.99999999999999								
	266	411	0.020446658206488905	0.07246761136000036	0.0207590226769354	167.0	167.0	167.0	0	0	1	-59.99999999999999	59.99999999999999								
	162	342	0.00124357537909243	0.00302370443894779	0.08678121498725559	133.0	133.0	133.0	0	0	1	-59.99999999999999	59.99999999999999								
	162	156	0.0007089093996844262	0.005548115316349269	0.193107303301007	270.0	270.0	270.0	0	0	1	-59.99999999999999	59.99999999999999								
	162	592	0.0009025063662976032	0.006368898175585269	0.11875430137512702	254.0	254.0	254.0	0	0	1	-59.99999999999999	59.99999999999999								
	248	287	0.004374816685283091	0.022835982931489095	0.007517975051533431	211.0	211.0	211.0	0	0	1	-59.99999999999999	59.99999999999999								
	248	300	0.0019115656924024202	0.01701173558998389	0.007274817340775387	292.0	292.0	292.0	0	0	1	-59.99999999999999	59.99999999999999								
	274	282	0.0028848221732219706	0.016067655487494496	0.004288921089284119	220.00000000000003	220.00000000000003	220.00000000000003	0	0	1	-59.99999999999999	59.99999999999999								
	275	282	0.00281284317222722	0.016406705883922092	0.00447824334815145	225.99999999999997	225.99999999999997	225.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	276	329	0.00158422317138244	0.010025985607148794	0.0023608017916530396	238.0	238.0	238.0	0	0	1	-59.99999999999999	59.99999999999999								
	278	465	0.09299365618262441	0.2583969776919111	0.0529886266825721	144.0	144.0	144.0	0	0	1	-59.99999999999999	59.99999999999999								
	278	166	0.012159756943909503	0.03503839850273449	0.006893826754225879	148.0	148.0	148.0	0	0	1	-59.99999999999999	59.99999999999999								
	280	454	0.0024488057828312704	0.015180899834632899	0.0044354959894018185	235.0	235.0	235.0	0	0	1	-59.99999999999999	59.99999999999999								
	281	287	0.0031170697719105503	0.018529447969067796	0.005601420664658772	229.0	229.0	229.0	0	0	1	-59.99999999999999	59.99999999999999								
	281	299	0.00221367001240142	0.01995988411111759	0.007363113611609208	295.0	295.0	295.0	0	0	1	-59.99999999999999	59.99999999999999								
	282	379	0.0036848451398798694	0.007992214079283182	0.33402238464854683	124.0	124.0	124.0	0	0	1	-59.99999999999999	59.99999999999999								
	282	380	0.00359758475639811	0.008196307259946686	0.3087969402187499	128.0	128.0	128.0	0	0	1	-59.99999999999999	59.99999999999999								
	282	451	0.004151520375055261	0.008738614600472148	0.34605357216869004	122.0	122.0	122.0	0	0	1	-59.99999999999999	59.99999999999999								
	282	452	0.00403021794843022	0.009117979744274167	0.355812553781318	127.0	127.0	127.0	0	0	1	-59.99999999999999	59.99999999999999								
	285	290	0.12888339420100708	0.373017109656334	0.0741949184587225	148.0	148.0	148.0	0	0	1	-59.99999999999999	59.99999999999999								
	286	130	0.06873012635184174	0.18233457809084602	0.03779211928254752	140.0	140.0	140.0	0	0	1	-59.99999999999999	59.99999999999999								
	248	299	0.00214592500504106	0.020713098842929996	0.008435516345878129	307.0	307.0	307.0	0	0	1	-59.99999999999999	59.99999999999999								
	289	303	0.09644661032614305	0.20700070369187692	0.04082476039009629	123.0	123.0	123.0	0	0	1	-59.99999999999999	59.99999999999999								
	290	301	0.0411408462350909	0.10887627232293595	0.022182059753173992	140.0	140.0	140.0	0	0	1	-59.99999999999999	59.99999999999999								
	340	28	0.038588874091591056	0.08979017422770881	0.020713173128827034	130.0	130.0	130.0	0	0	1	-59.99999999999999	59.99999999999999								
	292	340	0.016050881460785895	0.04061533013591918	0.0115601477997373	136.0	136.0	136.0	0	0	1	-59.99999999999999	59.99999999999999								
	295	250	0.0036232487966814113	0.01613446068341561	0.003629289934062399	192.0	192.0	192.0	0	0	1	-59.99999999999999	59.99999999999999								
	298	313	0.0013093839757820603	0.010391175958142599	0.0047453662992976604	273.0	273.0	273.0	0	0	1	-59.99999999999999	59.99999999999999								
	298	331	0.00255640502510685	0.015690992213591895	0.003581316516981459	233.0	233.0	233.0	0	0	1	-59.99999999999999	59.99999999999999								
	299	466	0.0012983432622975697	0.010632759255231394	0.006013260718061588	278.0	278.0	278.0	0	0	1	-59.99999999999999	59.99999999999999								
	301	387	0.043589416200206586	0.12961316142397006	0.03348382014170799	150.0	150.0	150.0	0	0	1	-59.99999999999999	59.99999999999999								
	301	471	0.14700689736586095	0.3941065798114979	0.06233251136608416	141.0	141.0	141.0	0	0	1	-59.99999999999999	59.99999999999999								
	302	519	0.0008320188282374291	0.0039439719061925985	0.0430756885532946	199.0	199.0	199.0	0	0	1	-59.99999999999999	59.99999999999999								
	303	425	0.026011198327541306	0.0711618544052495	0.015392342193960202	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	305	377	0.030373387435702597	0.08394711273674338	0.020209530260651403	144.0	144.0	144.0	0	0	1	-59.99999999999999	59.99999999999999								
	305	465	0.07047880708610639	0.19505967614259592	0.0403395550809801	144.0	144.0	144.0	0	0	1	-59.99999999999999	59.99999999999999								
	306	449	0.00348631479510665	0.018884910847442187	0.004052505725063378	216.0	216.0	216.0	0	0	1	-59.99999999999999	59.99999999999999								
	308	317	0.03895004241232201	0.08747552234696689	0.016783968655534092	127.0	127.0	127.0	0	0	1	-59.99999999999999	59.99999999999999								
	310	488	0.03767610124522819	0.10330377717241593	0.024086144335847305	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	311	312	0.017158729515132705	0.02499549764688909	0.0015027331746798	25.0	25.0	25.0	0	0	1	-59.99999999999999	59.99999999999999								
	314	227	0.00211698447192926	0.005368595658246428	0.17901231136894807	137.0	137.0	137.0	0	0	1	-59.99999999999999	59.99999999999999								
	314	615	0.0008740281778248028	0.0026270088114142406	0.0754746440253337	151.0	151.0	151.0	0	0	1	-59.99999999999999	59.99999999999999								
	319	282	0.00019839051710674504	0.0010839280778868095	0.08045663586912122	217.0	217.0	217.0	0	0	1	-59.99999999999999	59.99999999999999								
	323	374	0.000287228722111322	0.002152012109620959	0.10928225044310101	263.0	263.0	263.0	0	0	1	-59.99999999999999	59.99999999999999								
	323	156	0.000648755147990305	0.004668261744266378	0.27312183211985996	257.0	257.0	257.0	0	0	1	-59.99999999999999	59.99999999999999								
	324	377	0.03814297837749869	0.09780554942532907	0.022491461560215798	137.0	137.0	137.0	0	0	1	-59.99999999999999	59.99999999999999								
	324	394	0.12362090695602804	0.31832405940303593	0.0721100702944398	138.0	138.0	138.0	0	0	1	-59.99999999999999	59.99999999999999								
	325	338	0.01453398166053	0.05422371096792629	0.013332588563766295	173.0	173.0	173.0	0	0	1	-59.99999999999999	59.99999999999999								
	326	474	0.022732318876536997	0.07709506143378093	0.018717137889233407	163.0	163.0	163.0	0	0	1	-59.99999999999999	59.99999999999999								
	327	384	0.04760181283115872	0.11725063018812802	0.029793010589131207	134.0	134.0	134.0	0	0	1	-59.99999999999999	59.99999999999999								
	327	436	0.036276426909391805	0.10624137507600195	0.021701982125777296	149.0	149.0	149.0	0	0	1	-59.99999999999999	59.99999999999999								
	327	436	0.03788258527938831	0.10701466567332897	0.020803340142346	146.0	146.0	146.0	0	0	1	-59.99999999999999	59.99999999999999								
	327	439	0.0732994522443041	0.17841524927206293	0.048194035600218885	133.0	133.0	133.0	0	0	1	-59.99999999999999	59.99999999999999								
	328	166	0.07452410723172502	0.20915425399537693	0.044353692216414005	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	329	444	0.010806047895587997	0.03412133571600728	0.009945933857932689	156.0	156.0	156.0	0	0	1	-59.99999999999999	59.99999999999999								
	366	385	0.0009774017991209403	0.0026117481330782196	0.287359414167437	141.0	141.0	141.0	0	0	1	-59.99999999999999	59.99999999999999								
	366	469	0.0005313733679791912	0.0017416513450816294	0.14568183624502998	159.0	159.0	159.0	0	0	1	-59.99999999999999	59.99999999999999								
	334	479	0.0005745470445882534	0.0029683484943285607	0.022780318263091105	210.0	210.0	210.0	0	0	1	-59.99999999999999	59.99999999999999								
	336	364	0.0014483217472955605	0.00317535754614742	0.10179755352903198	125.0	125.0	125.0	0	0	1	-59.99999999999999	59.99999999999999								
	337	342	0.0009507421233225613	0.0033328226084858204	0.06889433273879722	166.0	166.0	166.0	0	0	1	-59.99999999999999	59.99999999999999								
	337	365	0.0014793615760630905	0.0032215665453099594	0.09679249714594332	124.0	124.0	124.0	0	0	1	-59.99999999999999	59.99999999999999								
	339	177	0.021699498926173004	0.061001680455598985	0.013913394887596402	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	340	166	0.0036518436904010403	0.021010720062743894	0.005050807078573849	224.00000000000003	224.00000000000003	224.00000000000003	0	0	1	-59.99999999999999	59.99999999999999								
	340	166	0.007930662452728951	0.023740043823204892	0.004975411873715933	151.0	151.0	151.0	0	0	1	-59.99999999999999	59.99999999999999								
	340	166	0.00908336141134333	0.02486876024849149	0.004906518525961791	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	343	162	0.0016651488286309568	0.004637994843511946	0.10287707118341323	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	162	477	0.0005974153352510178	0.0044648367426553676	0.07493586346099149	263.0	263.0	263.0	0	0	1	-59.99999999999999	59.99999999999999								
	162	156	0.0006441535985419529	0.004531348613190927	0.17279551021631792	252.99999999999997	252.99999999999997	252.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	346	227	0.0029301066317085197	0.006867408300014856	0.182405373583687	130.0	130.0	130.0	0	0	1	-59.99999999999999	59.99999999999999								
	346	612	0.00022980025830826126	0.6636463440238731	0.011021090564107246	48.0	48.0	48.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	346	612	0.00023809344275563103	0.6534069588224	0.011320426436779014	49.0	49.0	49.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	346	615	0.0008635973377503454	0.002813362078729879	0.058472584941772716	159.0	159.0	159.0	0	0	1	-59.99999999999999	59.99999999999999								
	346	227	0.0007075521970465778	0.005807960054252297	0.07838850157195698	278.0	278.0	278.0	0	0	1	-59.99999999999999	59.99999999999999								
	348	455	0.0272935605547391	0.09687600279483008	0.026245172954499688	167.0	167.0	167.0	0	0	1	-59.99999999999999	59.99999999999999								
	350	581	0.019722662360768806	0.04963493990013379	0.11246459501206897	136.0	136.0	136.0	0	0	1	-59.99999999999999	59.99999999999999								
	352	584	0.04687413995062376	0.2561115112472731	0.0239268553599378	122.0	122.0	122.0	1.012121212121212	0.0	1	-59.99999999999999	59.99999999999999								
	352	581	0.048745057228133104	0.12344440114829697	0.028138065305739594	136.0	136.0	136.0	0	0	1	-59.99999999999999	59.99999999999999								
	353	441	0.011684428653535405	0.032137416083575204	0.017549143402374807	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	344	436	0.0180900857967185	0.049102726781666266	0.0105200733740628	142.0	142.0	142.0	0	0	1	-59.99999999999999	59.99999999999999								
	344	464	0.036025821098438486	0.10571520631108394	0.0225769796613604	149.0	149.0	149.0	0	0	1	-59.99999999999999	59.99999999999999								
	356	389	0.000262577903781552	0.0019471818651170495	0.08208329427168148	262.0	262.0	262.0	0	0	1	-59.99999999999999	59.99999999999999								
	361	639	0.0100165112780873	0.014101702543897594	0.05883913654422848	68.50268256889673	24.0	24.0	0	0	1	-59.99999999999999	59.99999999999999								
	361	640	0.010139553978564201	0.013855692271701999	0.0593223429668276	67.84528979248574	24.0	24.0	0	0	1	-59.99999999999999	59.99999999999999								
	361	641	0.009607430204399857	0.024627996704513194	0.059322998846699476	35.0	35.0	35.0	0	0	1	-59.99999999999999	59.99999999999999								
	227	615	0.0031920749836252104	0.007075955310179388	0.21120022687844903	126.0	126.0	126.0	0	0	1	-59.99999999999999	59.99999999999999								
	227	615	0.002964718168828642	0.006898245539525799	0.245415842851624	130.0	130.0	130.0	0	0	1	-59.99999999999999	59.99999999999999								
	367	392	0.019952662148415103	0.06146179928350259	0.014096710845138895	154.0	154.0	154.0	0	0	1	-59.99999999999999	59.99999999999999								
	367	425	0.0690274889828516	0.17629076618067896	0.04325238115405197	137.0	137.0	137.0	0	0	1	-59.99999999999999	59.99999999999999								
	370	369	0.004082787061340729	0.011586378622128595	0.0030583699683323497	146.0	146.0	146.0	0	0	1	-59.99999999999999	59.99999999999999								
	183	398	0.00219654771123673	0.015616286572628193	0.006666670588050037	254.99999999999997	254.99999999999997	254.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	369	427	0.150606824061144	0.3260552357895299	0.06056814510686319	124.0	124.0	124.0	0	0	1	-59.99999999999999	59.99999999999999								
	379	156	0.0009339758122255562	0.002251870211204699	0.08272936965895909	132.0	132.0	132.0	0	0	1	-59.99999999999999	59.99999999999999								
	380	156	0.0009465091789002061	0.0023172918113744793	0.0774443712010328	134.0	134.0	134.0	0	0	1	-59.99999999999999	59.99999999999999								
	156	274	0.001098381011400781	0.04599952905098251	0.11758639819872915	748.0	748.0	748.0	0	0	1	-59.99999999999999	59.99999999999999								
	282	385	0.0008286175790913399	0.0038273739463449506	0.17914848993417193	196.0	196.0	196.0	0	0	1	-59.99999999999999	59.99999999999999								
	282	469	0.0011689224636554695	0.004523454808816306	0.28478559751767585	176.0	176.0	176.0	0	0	1	-59.99999999999999	59.99999999999999								
	384	411	0.012276503425193994	0.029099043003488277	0.006986203901190304	131.0	131.0	131.0	0	0	1	-59.99999999999999	59.99999999999999								
	388	408	0.005748780005881192	0.023248943183585988	0.006961739497686737	181.0	181.0	181.0	0	0	1	-59.99999999999999	59.99999999999999								
	388	447	0.0178624114645272	0.106607670565601	0.02370791004264539	229.0	229.0	229.0	0	0	1	-59.99999999999999	59.99999999999999								
	389	609	0.0037411283114296397	0.023856857288542692	0.05009918674159797	239.0	239.0	239.0	0	0	1	-59.99999999999999	59.99999999999999								
	389	618	0.00215915112087876	0.011576462848231196	0.05224481128091688	215.0	215.0	215.0	0	0	1	-59.99999999999999	59.99999999999999								
	392	420	0.0334893359985435	0.06463384549384939	0.014941526273307392	115.99999999999999	115.99999999999999	115.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	393	171	0.00659843641026644	0.026478524130331787	0.005851851933733559	180.0	180.0	180.0	0	0	1	-59.99999999999999	59.99999999999999								
	394	415	0.11874768976762899	0.23993192542819297	0.054030616441023964	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	395	171	0.0028884971193014596	0.016499049815288692	0.035275746448976	223.0	223.0	223.0	0	0	1	-59.99999999999999	59.99999999999999								
	396	177	0.00825461320551764	0.023585540648246594	0.005036619192679409	147.0	147.0	147.0	0	0	1	-59.99999999999999	59.99999999999999								
	397	177	0.008730778335973008	0.02286352322551979	0.00488770805146778	139.0	139.0	139.0	0	0	1	-59.99999999999999	59.99999999999999								
	406	470	0.094795158620955	0.2678292111979611	0.057451448643995894	146.0	146.0	146.0	0	0	1	-59.99999999999999	59.99999999999999								
	171	458	0.0018954206181915495	0.008228015535061056	0.02390862409684059	189.0	189.0	189.0	0	0	1	-59.99999999999999	59.99999999999999								
	420	424	0.038289435693696104	0.10715865593254596	0.020816559302750993	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	422	306	0.0035748971981119804	0.021316322081421292	0.00616204565061629	229.0	229.0	229.0	0	0	1	-59.99999999999999	59.99999999999999								
	426	614	0.0171961525046164	0.0267887326136239	0.0016226696806391698	51.0	51.0	51.0	0	0	1	-59.99999999999999	59.99999999999999								
	427	429	0.0157598625634364	0.03705082481026648	0.007931456621001467	130.0	130.0	130.0	0	0	1	-59.99999999999999	59.99999999999999								
	427	410	0.05156093475249972	0.14206531134204	0.029715134199745495	144.0	144.0	144.0	0	0	1	-59.99999999999999	59.99999999999999								
	430	446	0.0009409895499944692	0.0051855925962273	0.0406854552974505	219.0	219.0	219.0	0	0	1	-59.99999999999999	59.99999999999999								
	430	446	0.0009422390287220481	0.005118649140441788	0.0394476941847103	217.0	217.0	217.0	0	0	1	-59.99999999999999	59.99999999999999								
	430	479	0.0037095079922908913	0.007820839934833347	0.023568446658155908	122.0	122.0	122.0	0	0	1	-59.99999999999999	59.99999999999999								
	258	438	0.00241448504431173	0.010425619365000596	0.009006238922636951	188.0	188.0	188.0	0	0	1	-59.99999999999999	59.99999999999999								
	258	437	0.002369159063570201	0.010979304112544296	0.011350760603386004	197.0	197.0	197.0	0	0	1	-59.99999999999999	59.99999999999999								
	177	474	0.007418747735447252	0.019242909384164994	0.004377523017636028	138.0	138.0	138.0	0	0	1	-59.99999999999999	59.99999999999999								
	445	447	0.02108537124197979	0.09026879252275725	0.0210035896870159	188.0	188.0	188.0	0	0	1	-59.99999999999999	59.99999999999999								
	449	459	0.0202525882822089	0.08961145065570247	0.0164258475431707	191.0	191.0	191.0	0	0	1	-59.99999999999999	59.99999999999999								
	450	463	0.0036263318829175112	0.022780487094031396	0.00536397421559598	237.0	237.0	237.0	0	0	1	-59.99999999999999	59.99999999999999								
	450	463	0.00357391251826435	0.02342958068493809	0.005789550052190201	243.00000000000003	243.00000000000003	243.00000000000003	0	0	1	-59.99999999999999	59.99999999999999								
	455	464	0.07047924263235177	0.2071750199247619	0.042052648542619316	149.0	149.0	149.0	0	0	1	-59.99999999999999	59.99999999999999								
	470	472	0.005445817922063079	0.015805184414930208	0.004525905392210931	148.0	148.0	148.0	0	0	1	-59.99999999999999	59.99999999999999								
	471	488	0.09098052067333831	0.2542119642994371	0.05608720647532487	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	477	592	0.000250739030344412	0.0019506809447617309	0.0322804994360497	269.0	269.0	269.0	0	0	1	-59.99999999999999	59.99999999999999								
	508	2	0.06848310573106758	0.47200710372217974	0.0012929564552877798	67.0	67.0	67.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	508	510	0.042688592525085986	0.22890253656349188	0.00112329970109789	18.0	18.0	18.0	0	0	1	-59.99999999999999	59.99999999999999								
	511	569	0.013515340456933004	0.0145933033160711	0.00209544174022973	21.0	21.0	21.0	0	0	1	-59.99999999999999	59.99999999999999								
	513	569	0.0130018172451498	0.014268408193897294	0.0021116376865804197	21.0	21.0	21.0	0	0	1	-59.99999999999999	59.99999999999999								
	520	590	0.006273660325963051	0.025456311587838003	0.0013277283443291702	46.0	46.0	46.0	0	0	1	-59.99999999999999	59.99999999999999								
	543	601	0.0373636114439364	0.10865104172449297	0.00193701912337122	74.0	74.0	74.0	0	0	1	-59.99999999999999	59.99999999999999								
	558	559	0.0174220106178301	0.024382662971986085	0.0015316003663614394	24.0	24.0	24.0	0	0	1	-59.99999999999999	59.99999999999999								
	567	633	0.203132180026919	0.29807180612417883	0.0033204907821584497	49.0	49.0	49.0	0	0	1	-59.99999999999999	59.99999999999999								
	568	582	0.14269898341631304	0.2277081227419769	0.0012585655883099	52.0	52.0	52.0	0	0	1	-59.99999999999999	59.99999999999999								
	575	928	0.0388522235676646	0.07012074033168607	0.0028613290156517196	56.00000000000001	56.00000000000001	56.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	579	633	0.429631975219399	0.5950742128886277	0.0034402117731384893	48.0	48.0	48.0	0	0	1	-59.99999999999999	59.99999999999999								
	582	583	0.12231600677910999	0.2159560443146819	0.0029895912493579104	55.00000000000001	55.00000000000001	55.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	582	589	0.011894606572005903	0.029762538286786495	0.0015310856629069899	68.0	68.0	68.0	0	0	1	-59.99999999999999	59.99999999999999								
	582	643	0.008051278869140891	0.0203844665363207	0.00030470307115931116	68.0	68.0	68.0	0	0	1	-59.99999999999999	59.99999999999999								
	582	643	0.0029017486110264395	0.010492468762508596	0.007893618487212808	85.0	85.0	85.0	0	0	1	-59.99999999999999	59.99999999999999								
	582	643	0.0030118279065568902	0.010283761422249994	0.0073047630460560285	82.0	82.0	82.0	0	0	1	-59.99999999999999	59.99999999999999								
	583	584	0.148738511637209	0.18161988672348892	0.004419750731728968	44.0	44.0	44.0	0	0	1	-59.99999999999999	59.99999999999999								
	583	584	0.050591096237324606	0.12396971742442993	0.00404169284407608	67.0	67.0	67.0	0	0	1	-59.99999999999999	59.99999999999999								
	583	586	0.047964885992434696	0.11025702141774996	0.0018927762507861495	65.0	65.0	65.0	0	0	1	-59.99999999999999	59.99999999999999								
	586	589	0.05305256603605631	0.09720114250657687	0.0015434634775291199	56.00000000000001	56.00000000000001	56.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	589	643	0.011820559564621205	0.030030659141981993	0.0004184588879905638	69.0	69.0	69.0	0	0	1	-59.99999999999999	59.99999999999999								
	595	16	0.02315846229022621	0.09654234757173367	0.03849594341219835	319.0	319.0	319.0	0.9500000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	595	17	0.016194124333773405	0.06686398701481544	0.04485727270995723	459.99999999999994	459.99999999999994	459.99999999999994	0.9500000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	609	618	0.0020143219583392095	0.014025729784490995	0.010007475533708898	252.0	252.0	252.0	0	0	1	-59.99999999999999	59.99999999999999								
	649	651	0.018048725110013	0.026878994611860288	0.0153800046887342	96.2999928279374	25.0	25.0	0	0	1	-59.99999999999999	59.99999999999999								
	650	652	0.019588109638318404	0.031389611440245116	0.0173876047174912	107.78217457156455	26.0	26.0	0	0	1	-59.99999999999999	59.99999999999999								
	707	897	0.18198002893477694	0.5451616301460748	0.0635872793281451	76.0	76.0	76.0	0	0	1	-59.99999999999999	59.99999999999999								
	734	915	0.41226039971826595	1.1316942371413596	0.0630846680544838	72.0	72.0	72.0	0	0	1	-59.99999999999999	59.99999999999999								
	737	738	0.009607968535549013	0.043988443889394414	0.012938000009162396	195.0	195.0	195.0	0	0	1	-59.99999999999999	59.99999999999999								
	742	782	0.0008046938038334249	0.008353818991296176	0.0279790688687176	534.0	534.0	534.0	0	0	1	-59.99999999999999	59.99999999999999								
	743	746	0.013431080529686099	0.08108519604572327	0.12651973004775102	385.0	385.0	385.0	0	0	1	-59.99999999999999	59.99999999999999								
	743	747	0.0029796192036420114	0.013111843587214097	0.0366202971653547	317.0	317.0	317.0	0	0	1	-59.99999999999999	59.99999999999999								
	743	764	0.009187571532729083	0.05269655591454363	0.09214342373788362	373.0	373.0	373.0	0	0	1	-59.99999999999999	59.99999999999999								
	743	764	0.009860241520312379	0.0408560810320061	0.11149033649200996	306.0	306.0	306.0	0	0	1	-59.99999999999999	59.99999999999999								
	743	812	0.016648394341745896	0.07473909750522208	0.22281211980653498	321.0	321.0	321.0	0	0	1	-59.99999999999999	59.99999999999999								
	743	813	0.0053951992275193305	0.022765985775520102	0.07127407228554598	309.0	309.0	309.0	0	0	1	-59.99999999999999	59.99999999999999								
	744	765	0.013877042790591704	0.06439637115210337	0.17726140939577895	328.0	328.0	328.0	0	0	1	-59.99999999999999	59.99999999999999								
	744	813	0.006367306272927211	0.027158378575501487	0.08241840986138209	311.0	311.0	311.0	0	0	1	-59.99999999999999	59.99999999999999								
	746	761	0.0034679520819573687	0.02033304813351019	0.034218560488963004	378.0	378.0	378.0	0	0	1	-59.99999999999999	59.99999999999999								
	746	781	0.017872952238603492	0.07174215882535087	0.231948394981083	300.0	300.0	300.0	0	0	1	-59.99999999999999	59.99999999999999								
	747	764	0.006230915575435382	0.026851199239250292	0.07606260662846272	313.0	313.0	313.0	0	0	1	-59.99999999999999	59.99999999999999								
	742	782	0.0008131730828588831	0.008924756108472726	0.031080229380257392	553.0	553.0	553.0	0	0	1	-59.99999999999999	59.99999999999999								
	751	817	0.000562120080071874	0.005577772383585759	0.021024791721033404	520.0	520.0	520.0	0	0	1	-59.99999999999999	59.99999999999999								
	752	806	0.0005562738694781439	0.006089567136086057	0.020952470819438802	552.0	552.0	552.0	0	0	1	-59.99999999999999	59.99999999999999								
	753	803	0.00037330622823536394	0.003563982158915138	0.22836601879024898	508.0	508.0	508.0	0	0	1	-59.99999999999999	59.99999999999999								
	754	757	0.00104867656389577	0.011853558385269698	0.0400783972142031	563.0	563.0	563.0	0	0	1	-59.99999999999999	59.99999999999999								
	754	757	0.0011111691968461999	0.011264201011260997	0.03697743134647612	527.0	527.0	527.0	0	0	1	-59.99999999999999	59.99999999999999								
	754	776	0.0012217929453634698	0.013437908735643	0.04452485417765558	554.0	554.0	554.0	0	0	1	-59.99999999999999	59.99999999999999								
	754	776	0.0012226914350714495	0.013482357550733591	0.04185749815809539	554.0	554.0	554.0	0	0	1	-59.99999999999999	59.99999999999999								
	754	824	0.009847702502635312	0.032676128154207534	1.6662533644206476	267.0	267.0	267.0	0	0	1	-59.99999999999999	59.99999999999999								
	745	658	0.007572553782631089	0.08441493413023607	0.05671292664591252	373.0	373.0	373.0	1.0977272727272722	0.0	1	-59.99999999999999	59.99999999999999								
	756	762	0.012510400101412108	0.05200493783319837	0.15241654734290194	307.0	307.0	307.0	0	0	1	-59.99999999999999	59.99999999999999								
	756	762	0.012808153970567495	0.05059709308527409	0.14922785345776896	297.0	297.0	297.0	0	0	1	-59.99999999999999	59.99999999999999								
	756	745	0.0049458644476989295	0.029758027096581607	0.05152112713225191	384.0	384.0	384.0	0	0	1	-59.99999999999999	59.99999999999999								
	756	745	0.00496594058944564	0.029142798756854597	0.04993934007002041	378.0	378.0	378.0	0	0	1	-59.99999999999999	59.99999999999999								
	756	805	0.02112934033975939	0.1274463215401769	0.2018123024362139	384.0	384.0	384.0	0	0	1	-59.99999999999999	59.99999999999999								
	758	745	0.020017212745891914	0.11633047975880108	0.19982756147054015	376.0	376.0	376.0	0	0	1	-59.99999999999999	59.99999999999999								
	758	745	0.019481227195430495	0.11086228768869293	0.18929906432856794	371.0	371.0	371.0	0	0	1	-59.99999999999999	59.99999999999999								
	758	817	0.00635874067770783	0.03973166105965149	0.35989286797854103	393.0	393.0	393.0	0	0	1	-59.99999999999999	59.99999999999999								
	761	805	0.01318316152333	0.07740523510854318	0.126036528490853	378.0	378.0	378.0	0	0	1	-59.99999999999999	59.99999999999999								
	762	805	0.010936901737460902	0.04356436478570102	0.128318999967095	299.0	299.0	299.0	0	0	1	-59.99999999999999	59.99999999999999								
	762	805	0.010676699938508697	0.04509400252178311	0.13045406109806199	310.0	310.0	310.0	0	0	1	-59.99999999999999	59.99999999999999								
	764	782	0.009366815684552299	0.05361450247066087	0.09534981412142518	372.0	372.0	372.0	0	0	1	-59.99999999999999	59.99999999999999								
	764	782	0.00924798332766071	0.053182785421909774	0.09334227652210277	373.0	373.0	373.0	0	0	1	-59.99999999999999	59.99999999999999								
	764	796	0.004345158005093599	0.02513548229660471	0.042561107084360415	375.0	375.0	375.0	0	0	1	-59.99999999999999	59.99999999999999								
	764	797	0.0043668032237562295	0.02528716259955239	0.044910172644454086	375.0	375.0	375.0	0	0	1	-59.99999999999999	59.99999999999999								
	764	825	0.006739115919772531	0.04214303099727491	0.06920126304184092	393.0	393.0	393.0	0	0	1	-59.99999999999999	59.99999999999999								
	765	798	0.038134001305901014	0.17352022196738	0.529795954112448	324.0	324.0	324.0	0	0	1	-59.99999999999999	59.99999999999999								
	779	835	0.0006573347019062635	0.02998643309397749	0.0068445146511321164	1054.0	1054.0	1054.0	1.0150044130626652	0.0	1	-59.99999999999999	59.99999999999999								
	779	823	0.0015683810303360201	0.010757968693808698	0.02154129301171001	416.0	416.0	416.0	0	0	1	-59.99999999999999	59.99999999999999								
	772	757	0.013075861348863698	0.08598227087504696	0.15436117734290694	405.0	405.0	405.0	0	0	1	-59.99999999999999	59.99999999999999								
	772	757	0.013171793957417799	0.09105013254806399	0.15749718136750201	418.0	418.0	418.0	0	0	1	-59.99999999999999	59.99999999999999								
	772	822	0.0015590754571557003	0.011842288122549697	0.022189217794582206	442.0	442.0	442.0	0	0	1	-59.99999999999999	59.99999999999999								
	781	815	0.025363330169625595	0.10223296750162494	0.31432492248838795	301.0	301.0	301.0	0	0	1	-59.99999999999999	59.99999999999999								
	782	825	0.00228570948153734	0.015065901232173693	0.024860506944404902	405.99999999999994	405.99999999999994	405.99999999999994	0	0	1	-59.99999999999999	59.99999999999999								
	783	807	0.0009393524110503499	0.006592382960687857	0.049219361649034496	421.0	421.0	421.0	0	0	1	-59.99999999999999	59.99999999999999								
	783	817	0.0008894545979518438	0.006284480084222737	0.045985328248385304	423.00000000000006	423.00000000000006	423.00000000000006	0	0	1	-59.99999999999999	59.99999999999999								
	783	749	0.000670636828750372	0.007230202485864979	0.024406902947346692	547.0	547.0	547.0	0	0	1	-59.99999999999999	59.99999999999999								
	783	749	0.0006666561790071429	0.0069991231961958065	0.023765066861699304	538.0	538.0	538.0	0	0	1	-59.99999999999999	59.99999999999999								
	786	838	0.00046969631431547477	0.04031940742119773	0.004434966032121751	784.0	784.0	784.0	0.9523809523809523	0.0	1	-59.99999999999999	59.99999999999999								
	787	811	0.0025266189029630303	0.021645775906711594	0.009455725739460897	286.0	286.0	286.0	0	0	1	-59.99999999999999	59.99999999999999								
	811	973	0.0032796222491745866	0.07747507801090361	0.009780294246398818	408.0	408.0	408.0	0.9625000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	764	812	0.017818977666822302	0.11337811219789096	0.18241553445353206	397.0	397.0	397.0	0	0	1	-59.99999999999999	59.99999999999999								
	794	800	0.0019743506534286802	0.011418497856808799	0.020015458426438298	375.0	375.0	375.0	0	0	1	-59.99999999999999	59.99999999999999								
	794	800	0.00196616546090613	0.0119394883109932	0.0219495316559449	386.0	386.0	386.0	0	0	1	-59.99999999999999	59.99999999999999								
	798	815	0.008971069602827533	0.03662728961556498	0.11129935167913799	303.0	303.0	303.0	0	0	1	-59.99999999999999	59.99999999999999								
	757	803	0.0016786723447857396	0.014330808020047393	0.05228309098184108	475.0	475.0	475.0	0	0	1	-59.99999999999999	59.99999999999999								
	757	803	0.0017355580345261796	0.01406910382051019	0.052790194559236996	459.99999999999994	459.99999999999994	459.99999999999994	0	0	1	-59.99999999999999	59.99999999999999								
	757	817	0.00218630816331599	0.025524773603677792	0.104655027370113	574.0	574.0	574.0	0	0	1	-59.99999999999999	59.99999999999999								
	757	822	0.0121452006932395	0.08390096510558849	0.15176848091576203	417.0	417.0	417.0	0	0	1	-59.99999999999999	59.99999999999999								
	800	842	0.00019401843710947748	0.017592014202485087	0.005991522729199671	1796.0	1796.0	1796.0	0.9638554216867466	0.0	1	-59.99999999999999	59.99999999999999								
	800	804	0.0007013533345368691	0.007748384664811848	0.026005498152980606	555.0	555.0	555.0	0	0	1	-59.99999999999999	59.99999999999999								
	800	814	0.0013416226926874395	0.012983437423920295	0.047052907961988806	512.0	512.0	512.0	0	0	1	-59.99999999999999	59.99999999999999								
	800	822	0.0120122415253893	0.08654728344094009	0.146434041872248	428.0	428.0	428.0	0	0	1	-59.99999999999999	59.99999999999999								
	800	822	0.012325610323250299	0.08456427620989267	0.15528751949276795	416.0	416.0	416.0	0	0	1	-59.99999999999999	59.99999999999999								
	800	822	0.011393775906152998	0.08247717504936736	0.1508197676508689	429.0	429.0	429.0	0	0	1	-59.99999999999999	59.99999999999999								
	804	807	0.0016720886687934399	0.011591404093527203	0.06721246806595481	418.0	418.0	418.0	0	0	1	-59.99999999999999	59.99999999999999								
	814	806	0.00112422189139295	0.006127288629370739	0.043828941658251	361.0	361.0	361.0	0	0	1	-59.99999999999999	59.99999999999999								
	826	827	0.004174791797623041	0.03486583329755811	0.44633077104978314	702.0	702.0	702.0	0	0	1	-59.99999999999999	59.99999999999999								
	826	827	0.00460780860952567	0.03353467451501821	0.45187492400221485	646.0	646.0	646.0	0	0	1	-59.99999999999999	59.99999999999999								
	826	828	0.009207378531157969	0.0668933534683892	0.906837566370204	645.0	645.0	645.0	0	0	1	-59.99999999999999	59.99999999999999								
	826	828	0.008907004134995558	0.06894730220508255	0.9332403294032083	671.0	671.0	671.0	0	0	1	-59.99999999999999	59.99999999999999								
	826	831	0.0015226911730319302	0.012573578141885802	0.158634648919081	697.0	697.0	697.0	0	0	1	-59.99999999999999	59.99999999999999								
	832	1720	0.00592414854015689	0.04034924827212471	0.16191526234181602	517.0	517.0	517.0	0	0	1	-59.99999999999999	59.99999999999999								
	832	1720	0.005904165485058912	0.040718019273029614	0.160490026934061	521.0	521.0	521.0	0	0	1	-59.99999999999999	59.99999999999999								
	834	835	0.0008084932396602817	0.012513709804180496	1.27030255614995	1548.0	1548.0	1548.0	0	0	1	-59.99999999999999	59.99999999999999								
	834	842	0.00014549082519253685	0.002254716045398259	0.22269832618809296	1549.0	1549.0	1549.0	0	0	1	-59.99999999999999	59.99999999999999								
	835	838	9.66146404063329e-5	0.0014731472514234502	0.14739113607171503	1534.0	1534.0	1534.0	0	0	1	-59.99999999999999	59.99999999999999								
	835	838	9.84816129878163e-5	0.00144476995860599	0.15937327604927112	1498.0	1498.0	1498.0	0	0	1	-59.99999999999999	59.99999999999999								
	835	838	9.87478322768584e-5	0.00148132392670959	0.156638002459677	1518.0	1518.0	1518.0	0	0	1	-59.99999999999999	59.99999999999999								
	835	842	0.0009852048872625448	0.013410903053786602	1.550909598767191	1431.0	1431.0	1431.0	0	0	1	-59.99999999999999	59.99999999999999								
	835	843	0.0010582034372207702	0.016747502789877407	1.6869757595628105	1569.0	1569.0	1569.0	0	0	1	-59.99999999999999	59.99999999999999								
	835	843	0.0011143155935034203	0.0167158546055015	1.7462998146464197	1518.0	1518.0	1518.0	0	0	1	-59.99999999999999	59.99999999999999								
	836	840	0.0008166417107926679	0.009792438009208997	1.0572590190395703	1325.0	1325.0	1325.0	0	0	1	-59.99999999999999	59.99999999999999								
	836	841	0.000269834984914353	0.0034198859473569296	0.33836025786237794	1371.0	1371.0	1371.0	0	0	1	-59.99999999999999	59.99999999999999								
	836	841	0.000259543735438026	0.0032343056194204787	0.3422953104576241	1357.0	1357.0	1357.0	0	0	1	-59.99999999999999	59.99999999999999								
	836	845	0.00040937875795466795	0.005140715212527658	0.5406758996720241	1363.0	1363.0	1363.0	0	0	1	-59.99999999999999	59.99999999999999								
	837	843	0.00019758987060747993	0.002955712306726719	0.30561534895984493	1516.0	1516.0	1516.0	0	0	1	-59.99999999999999	59.99999999999999								
	837	844	8.373439614102238e-5	0.0012538667845614297	0.12379362068258203	1517.0	1517.0	1517.0	0	0	1	-59.99999999999999	59.99999999999999								
	838	2113	1.88387455288321e-5	0.00032771514415061095	0.032249910256560904	1661.0	1661.0	1661.0	0	0	1	-59.99999999999999	59.99999999999999								
	839	840	0.0012421972407535599	0.016154443020978897	1.6789919260144195	1392.0	1392.0	1392.0	0	0	1	-59.99999999999999	59.99999999999999								
	839	844	0.00046576904945075506	0.006635297911394849	0.6585999928862141	1472.0	1472.0	1472.0	0	0	1	-59.99999999999999	59.99999999999999								
	839	844	0.000435878118721303	0.006642522415706419	0.666168343354031	1533.0	1533.0	1533.0	0	0	1	-59.99999999999999	59.99999999999999								
	839	845	0.0015578386996053198	0.0213233633661829	2.18654415476369	1436.0	1436.0	1436.0	0	0	1	-59.99999999999999	59.99999999999999								
	842	843	0.00026676386695448297	0.004148343069399709	0.4286759737035071	1552.0	1552.0	1552.0	0	0	1	-59.99999999999999	59.99999999999999								
	843	844	0.00029421087417751487	0.0044822288609286795	0.45139229901703104	1533.0	1533.0	1533.0	0	0	1	-59.99999999999999	59.99999999999999								
	843	844	0.0003057533605070781	0.004666977884052321	0.4869957687537372	1535.0	1535.0	1535.0	0	0	1	-59.99999999999999	59.99999999999999								
	846	847	0.00414097575582564	0.014217270423751293	0.000294684106861241	82.0	82.0	82.0	0	0	1	-59.99999999999999	59.99999999999999								
	846	854	0.012794191822903206	0.056027730337828395	0.0009079053337732335	95.0	95.0	95.0	0	0	1	-59.99999999999999	59.99999999999999								
	846	887	0.006902711550844832	0.02718064181751109	0.0005171574233202257	89.0	89.0	89.0	0	0	1	-59.99999999999999	59.99999999999999								
	846	929	0.0070405019762460105	0.030629577508196185	0.0007045607436681171	95.0	95.0	95.0	0	0	1	-59.99999999999999	59.99999999999999								
	847	857	0.019596892051748006	0.057640902727022776	0.0011085677714366498	75.0	75.0	75.0	0	0	1	-59.99999999999999	59.99999999999999								
	849	851	0.3917471608943681	0.6009235397919779	0.009684207905124868	51.0	51.0	51.0	0	0	1	-59.99999999999999	59.99999999999999								
	849	852	0.17912034950072403	0.23034688468254194	0.0030117383379954805	46.0	46.0	46.0	0	0	1	-59.99999999999999	59.99999999999999								
	850	851	0.018406711184140293	0.062009631505701684	0.0013492378379362602	81.0	81.0	81.0	0	0	1	-59.99999999999999	59.99999999999999								
	850	851	0.021727803222928204	0.08019225670360026	0.0015949982640892295	86.0	86.0	86.0	0	0	1	-59.99999999999999	59.99999999999999								
	850	861	0.394504793884973	0.3543366331308049	0.00230439813952055	37.0	37.0	37.0	0	0	1	-59.99999999999999	59.99999999999999								
	852	875	0.21390350429671798	0.28047697411526895	0.003936220788538462	46.0	46.0	46.0	0	0	1	-59.99999999999999	59.99999999999999								
	854	857	0.0127129042816674	0.05707519377361978	0.000957768546862062	97.0	97.0	97.0	0	0	1	-59.99999999999999	59.99999999999999								
	855	915	0.04660807284347711	0.16734299942315992	0.003359463306985801	85.0	85.0	85.0	0	0	1	-59.99999999999999	59.99999999999999								
	855	917	0.04675084506141492	0.17376344770161894	0.0032023453999999894	86.0	86.0	86.0	0	0	1	-59.99999999999999	59.99999999999999								
	857	860	0.426302390338853	0.5114142870419193	0.003963136646291241	44.0	44.0	44.0	0	0	1	-59.99999999999999	59.99999999999999								
	857	887	0.006789912884263318	0.02708109697443429	0.0005463878465546298	90.0	90.0	90.0	0	0	1	-59.99999999999999	59.99999999999999								
	857	929	0.006718167765857648	0.029265409204177587	0.0006758767614746467	95.0	95.0	95.0	0	0	1	-59.99999999999999	59.99999999999999								
	860	861	0.21869103811343704	0.17668608844657396	0.0013199890558114303	34.0	34.0	34.0	0	0	1	-59.99999999999999	59.99999999999999								
	864	886	0.04984336599081289	0.06912291402432136	0.0009482413709890094	48.0	48.0	48.0	0	0	1	-59.99999999999999	59.99999999999999								
	865	873	0.08215297167043199	0.2962112863064979	0.006127670509839431	85.0	85.0	85.0	0	0	1	-59.99999999999999	59.99999999999999								
	869	870	0.051699985245326506	0.18210695989225095	0.004084017544814391	84.0	84.0	84.0	0	0	1	-59.99999999999999	59.99999999999999								
	869	870	0.053759686052268406	0.19425224546194092	0.003934645891070369	85.0	85.0	85.0	0	0	1	-59.99999999999999	59.99999999999999								
	870	892	0.30859314014594996	0.42473962713866475	0.006043200069028877	47.0	47.0	47.0	0	0	1	-59.99999999999999	59.99999999999999								
	871	873	0.10808961807970001	0.3372671295677218	0.00674396685097506	78.0	78.0	78.0	0	0	1	-59.99999999999999	59.99999999999999								
	874	875	0.13876203175053006	0.5606868168123389	0.0100255528441472	91.0	91.0	91.0	0	0	1	-59.99999999999999	59.99999999999999								
	874	875	0.43970497993248997	0.5863463073214747	0.007939862118575716	47.0	47.0	47.0	0	0	1	-59.99999999999999	59.99999999999999								
	874	901	0.46597407659560414	0.5894904336644801	0.008036738364842264	45.0	45.0	45.0	0	0	1	-59.99999999999999	59.99999999999999								
	877	889	0.04137406627475281	0.14331378956023594	0.00282460749641061	83.0	83.0	83.0	0	0	1	-59.99999999999999	59.99999999999999								
	877	895	0.06449232662518509	0.1567741061418009	0.04184445206109428	158.27858959414095	67.0	67.0	0	0	1	-59.99999999999999	59.99999999999999								
	879	877	0.09892072473598544	0.3445357307786466	0.006935049773541779	83.0	83.0	83.0	0	0	1	-59.99999999999999	59.99999999999999								
	880	889	0.05793883064199699	0.20655022318408403	0.003829970746114851	84.0	84.0	84.0	0	0	1	-59.99999999999999	59.99999999999999								
	886	891	0.13407682881876806	0.17431724351165803	0.00225895188206574	46.0	46.0	46.0	0	0	1	-59.99999999999999	59.99999999999999								
	890	895	0.03673714879726532	0.1281672247785051	0.00221745859806146	83.0	83.0	83.0	0	0	1	-59.99999999999999	59.99999999999999								
	890	895	0.02901647938370701	0.13502918429207997	0.0023087301484867903	99.0	99.0	99.0	0	0	1	-59.99999999999999	59.99999999999999								
	890	895	0.02992070597380401	0.12511634746943603	0.00225136077685282	93.0	93.0	93.0	0	0	1	-59.99999999999999	59.99999999999999								
	890	897	0.037928071438125294	0.13155496190061805	0.0021756304308716205	83.0	83.0	83.0	0	0	1	-59.99999999999999	59.99999999999999								
	891	892	0.22372972081650497	0.30911715938119183	0.004148206139146348	48.0	48.0	48.0	0	0	1	-59.99999999999999	59.99999999999999								
	895	704	0.01764352707879256	0.3189248861882495	0.009685811434202388	99.0	99.0	99.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	897	705	0.016430586844546936	0.3178776107795522	0.009100637003153639	100.0	100.0	100.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	900	982	0.0447092064750586	0.16977234608955388	0.0032061841120999287	87.0	87.0	87.0	0	0	1	-59.99999999999999	59.99999999999999								
	904	982	0.042668622171102115	0.16043091996420897	0.0029927715897653303	87.0	87.0	87.0	0	0	1	-59.99999999999999	59.99999999999999								
	915	918	0.08005491763057651	0.10729603649792298	0.005627798592075711	47.0	47.0	47.0	0	0	1	-59.99999999999999	59.99999999999999								
	915	982	0.3511227426156889	0.43709309577012573	0.02903088657193209	140.6238037852557	45.0	45.0	0	0	1	-59.99999999999999	59.99999999999999								
	941	945	0.019901966059617707	0.0507290410523303	0.0010459750730358098	23.0	23.0	23.0	0	0	1	-59.99999999999999	59.99999999999999								
	943	945	0.0199887226659991	0.049243423604145596	0.00108806733969133	23.0	23.0	23.0	0	0	1	-59.99999999999999	59.99999999999999								
	991	992	0.039082986010014996	0.055116996301216976	0.000749086190236732	48.0	48.0	48.0	0	0	1	-59.99999999999999	59.99999999999999								
	991	993	0.662590266091758	0.8712481873167996	0.00069982177603757	46.0	46.0	46.0	0	0	1	-59.99999999999999	59.99999999999999								
	992	993	1.17680591755969	0.9342077812860947	0.011387176178842794	34.0	34.0	34.0	0	0	1	-59.99999999999999	59.99999999999999								
	996	1098	0.0320799596653027	0.08777157087743276	0.018526066608347495	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	996	1449	0.025159142369923202	0.06965216586907857	0.014893223235248096	144.0	144.0	144.0	0	0	1	-59.99999999999999	59.99999999999999								
	997	1156	0.014690838203839995	0.04136911904144147	0.008781222240338098	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	997	1449	0.02562464132659281	0.06995414279806994	0.014949379874439	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	1001	1060	0.15461694826628997	0.1799213999336859	0.015045477073918997	71.0	71.0	71.0	0	0	1	-59.99999999999999	59.99999999999999								
	1060	1003	0.18919683427592743	0.8700112611616142	0.015577734575910288	36.0	36.0	36.0	0.87955	0.0	1	-59.99999999999999	59.99999999999999								
	1004	1006	0.00298397709695203	0.015821887245664395	0.0018952511628270105	178.0	178.0	178.0	0	0	1	-59.99999999999999	59.99999999999999								
	1004	1292	0.0372333539637448	0.12684654733582895	0.013869576028140302	136.0	136.0	136.0	0	0	1	-59.99999999999999	59.99999999999999								
	1004	1297	0.034007737324748204	0.11577837264423296	0.011752202503927995	136.0	136.0	136.0	0	0	1	-59.99999999999999	59.99999999999999								
	1005	1006	0.0030161586350854496	0.01689388210033439	0.001979132091579961	184.0	184.0	184.0	0	0	1	-59.99999999999999	59.99999999999999								
	1005	1290	0.021481228611271795	0.07145989545064045	0.008034756490792152	134.0	134.0	134.0	0	0	1	-59.99999999999999	59.99999999999999								
	1005	1297	0.0348810121804178	0.113230795807176	0.011892341351202701	132.0	132.0	132.0	0	0	1	-59.99999999999999	59.99999999999999								
	1008	1449	0.017134558214049796	0.04431110751995068	0.009857900274969635	138.0	138.0	138.0	0	0	1	-59.99999999999999	59.99999999999999								
	1008	1449	0.017114923332887708	0.04440440611954219	0.009856536568298928	138.0	138.0	138.0	0	0	1	-59.99999999999999	59.99999999999999								
	1008	1607	0.055655704964381596	0.16136732815848695	0.031014980428833494	148.0	148.0	148.0	0	0	1	-59.99999999999999	59.99999999999999								
	1010	989	0.04137559159688649	0.07470332907316367	0.0145854709585523	111.00000000000001	111.00000000000001	111.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1010	989	0.0376511835474148	0.07561787106274627	0.0152007927798592	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	1010	1096	0.06177664164697381	0.11717078621731404	0.02390778167087029	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1010	1177	0.009939001650693826	0.019010038311806993	0.0038427877204692882	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1011	1243	0.04904287741418	0.09495365270018391	0.019021623890207107	115.99999999999999	115.99999999999999	115.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1011	1243	0.04896012289529669	0.09009775407090775	0.020026228219640004	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1011	1471	0.07394365082833641	0.29990715619871894	0.0656428185934732	181.0	181.0	181.0	0	0	1	-59.99999999999999	59.99999999999999								
	1011	1472	0.06891654576006899	0.30223967669572677	0.06609045766394674	190.0	190.0	190.0	0	0	1	-59.99999999999999	59.99999999999999								
	1021	1169	0.03330200055111571	0.09251268929232276	0.020107113199252607	144.0	144.0	144.0	0	0	1	-59.99999999999999	59.99999999999999								
	1021	1169	0.034141180163352707	0.0919663281575628	0.01973792096993421	142.0	142.0	142.0	0	0	1	-59.99999999999999	59.99999999999999								
	1021	1450	0.029144268726106693	0.11341811452499997	0.026382986444480706	177.0	177.0	177.0	0	0	1	-59.99999999999999	59.99999999999999								
	1021	1450	0.031160605165142612	0.11642189961294197	0.026129163735860994	173.0	173.0	173.0	0	0	1	-59.99999999999999	59.99999999999999								
	1026	1036	0.01847791048147109	0.03450809779071808	0.006890176187932486	112.99999999999999	112.99999999999999	112.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1026	1037	0.020708220542356798	0.0381667725978009	0.0409361975097656	112.99999999999999	112.99999999999999	112.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1026	1046	0.04802408723676951	0.17573335578499394	0.03953441745276379	170.0	170.0	170.0	0	0	1	-59.99999999999999	59.99999999999999								
	1026	1199	0.06068034780547492	0.19690780765227991	0.044748991992214715	159.0	159.0	159.0	0	0	1	-59.99999999999999	59.99999999999999								
	1026	1200	0.057677582859126914	0.19454005206084596	0.045623477304366014	162.0	162.0	162.0	0	0	1	-59.99999999999999	59.99999999999999								
	1031	1456	0.021093327778722602	0.052054949639306396	0.011150821473183106	134.0	134.0	134.0	0	0	1	-59.99999999999999	59.99999999999999								
	1034	1211	0.004669318862795829	0.015432219003022194	0.001613828885894731	134.0	134.0	134.0	0	0	1	-59.99999999999999	59.99999999999999								
	1034	1445	0.007736321725741957	0.025257654709656283	0.002811979905754329	133.0	133.0	133.0	0	0	1	-59.99999999999999	59.99999999999999								
	1036	1040	0.0617601541569852	0.11855014189557705	0.02384629346138099	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1040	1046	0.05266975447341102	0.10477609744294793	0.018749844859855196	118.0	118.0	118.0	0	0	1	-59.99999999999999	59.99999999999999								
	1042	1320	0.03432879619047981	0.07044564889486407	0.012872229909896898	100.0	100.0	100.0	0	0	1	-59.99999999999999	59.99999999999999								
	1042	1060	0.031042888074237895	0.06348160007296406	0.006167556372448801	100.0	100.0	100.0	0	0	1	-59.99999999999999	59.99999999999999								
	1042	1060	0.0102614711141102	0.07685326045548917	0.013676223582953206	219.0	219.0	219.0	0	0	1	-59.99999999999999	59.99999999999999								
	1044	1337	0.0013142682798933194	0.004943872395176906	0.038483826154009394	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	1044	1480	0.004621125718759369	0.02001740064266139	0.0701900533887763	157.0	157.0	157.0	0	0	1	-59.99999999999999	59.99999999999999								
	1044	1480	0.00502578327343427	0.020957491258487088	0.0688513271602727	154.0	154.0	154.0	0	0	1	-59.99999999999999	59.99999999999999								
	1046	1133	0.048961017399094996	0.17271062098860693	0.0387964333766606	167.0	167.0	167.0	0	0	1	-59.99999999999999	59.99999999999999								
	1046	1254	0.0615253766053123	0.12334464406191696	0.023520609629701796	118.0	118.0	118.0	0	0	1	-59.99999999999999	59.99999999999999								
	987	1133	0.035509793886304784	0.12913589887528695	0.0297632750571892	170.0	170.0	170.0	0	0	1	-59.99999999999999	59.99999999999999								
	987	1214	0.03247771798772741	0.12132911204315798	0.025653499182569806	173.0	173.0	173.0	0	0	1	-59.99999999999999	59.99999999999999								
	987	1252	0.00877755205777288	0.024484662505369598	0.004358881940082179	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	987	1254	0.11177960276542198	0.21751241848491495	0.04086222313811259	115.99999999999999	115.99999999999999	115.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	987	1131	0.04242106892688201	0.15812626246690695	0.033220318495985106	172.0	172.0	172.0	0	0	1	-59.99999999999999	59.99999999999999								
	987	1131	0.043069498534295717	0.16552926692364694	0.031921661774013205	176.0	176.0	176.0	0	0	1	-59.99999999999999	59.99999999999999								
	987	1131	0.0409610877723806	0.16579652542662793	0.0325186464476166	181.0	181.0	181.0	0	0	1	-59.99999999999999	59.99999999999999								
	989	1146	0.010440489120292502	0.020918377411416708	0.004661195172686128	118.0	118.0	118.0	0	0	1	-59.99999999999999	59.99999999999999								
	989	1147	0.04408821712199881	0.08275736586306516	0.01687049541714139	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	989	1151	0.08039250599004329	0.1585104823188019	0.032229289282155196	117.0	117.0	117.0	0	0	1	-59.99999999999999	59.99999999999999								
	989	1178	0.02273165998279679	0.08333478975068814	0.020241227156138505	171.0	171.0	171.0	0	0	1	-59.99999999999999	59.99999999999999								
	989	1244	0.015745784873515405	0.05897732068015729	0.014084887783913397	173.0	173.0	173.0	0	0	1	-59.99999999999999	59.99999999999999								
	989	1257	0.0368807245804928	0.06756055558631195	0.013676338747011496	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	989	1265	0.007003613443089181	0.024494154812632094	0.005588688559323548	166.0	166.0	166.0	0	0	1	-59.99999999999999	59.99999999999999								
	988	1147	0.054871032436381105	0.10129943460782499	0.019235859455312605	112.99999999999999	112.99999999999999	112.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	988	1149	0.024229609959181404	0.09474553821758827	0.018290379673289104	177.0	177.0	177.0	0	0	1	-59.99999999999999	59.99999999999999								
	988	1257	0.05933402178001221	0.11318463964821994	0.023122959966938892	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1053	1054	0.012454248260040802	0.024363330929145197	0.00471632601597812	117.0	117.0	117.0	0	0	1	-59.99999999999999	59.99999999999999								
	1054	1080	0.03552971220016012	0.08540923021642029	0.016452968145716892	132.0	132.0	132.0	0	0	1	-59.99999999999999	59.99999999999999								
	1054	1241	0.03095234394217841	0.08024687774375637	0.015975392493330895	138.0	138.0	138.0	0	0	1	-59.99999999999999	59.99999999999999								
	1055	1183	0.011901942466613807	0.0414621789717763	0.009965487304628836	165.0	165.0	165.0	0	0	1	-59.99999999999999	59.99999999999999								
	1055	1183	0.010048289025202405	0.044347734283097094	0.009551582554355259	191.0	191.0	191.0	0	0	1	-59.99999999999999	59.99999999999999								
	1058	1098	0.016934862659829207	0.048675081407565185	0.020953083468386407	147.0	147.0	147.0	0	0	1	-59.99999999999999	59.99999999999999								
	1058	1453	0.008745490803832653	0.029207171156944208	0.006743738145371903	161.0	161.0	161.0	0	0	1	-59.99999999999999	59.99999999999999								
	1015	1098	0.017418286694119198	0.04847567711204289	0.0103044195204601	144.0	144.0	144.0	0	0	1	-59.99999999999999	59.99999999999999								
	1015	1453	0.009025728295291772	0.02908129705265159	0.00680583065354358	158.0	158.0	158.0	0	0	1	-59.99999999999999	59.99999999999999								
	1062	1256	0.014086874750349697	0.026939163293316987	0.00040535680854320483	57.99999999999999	57.99999999999999	57.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1062	1263	0.012390437537967198	0.01952477877540509	0.00029845514036714986	51.0	51.0	51.0	0	0	1	-59.99999999999999	59.99999999999999								
	1062	1378	0.012172535995133205	0.019360922156572296	0.00031097338662017113	52.0	52.0	52.0	0	0	1	-59.99999999999999	59.99999999999999								
	1063	1616	0.00512523189079203	0.009210323868013308	0.0019125219211727394	111.00000000000001	111.00000000000001	111.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1064	1616	0.005003781754568221	0.009839412712978654	0.0019377757394034392	117.0	117.0	117.0	0	0	1	-59.99999999999999	59.99999999999999								
	1065	1171	0.0199603926991695	0.11066500833733896	0.021068487623440997	219.0	219.0	219.0	0	0	1	-59.99999999999999	59.99999999999999								
	1065	1222	0.010901602941397604	0.0547409973757211	0.011296400056180501	206.99999999999997	206.99999999999997	206.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	1065	1307	0.03148592768975771	0.22932751678322397	0.0856083323591836	259.0	259.0	259.0	0	0	1	-59.99999999999999	59.99999999999999								
	1065	1502	0.041225725008978	0.2793658111141169	0.13259839174473698	248.0	248.0	248.0	0	0	1	-59.99999999999999	59.99999999999999								
	1068	1162	0.038001099530775115	0.19840580978009104	0.029207783298572505	211.0	211.0	211.0	0	0	1	-59.99999999999999	59.99999999999999								
	1068	1222	0.0177594066909873	0.09358330555380318	0.017893038061695204	213.0	213.0	213.0	0	0	1	-59.99999999999999	59.99999999999999								
	1072	1425	0.020331033179324467	0.3569380887083444	0.0025787857761885424	89.0	89.0	89.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1072	1307	0.016955000473335403	0.031636461601485505	0.006951344088683838	112.99999999999999	112.99999999999999	112.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1073	1307	0.018718706401407298	0.036545954720918095	0.007368223036399109	117.0	117.0	117.0	0	0	1	-59.99999999999999	59.99999999999999								
	1078	1207	0.0625316902116388	0.12728934316843293	0.025499836776256595	120.0	120.0	120.0	0	0	1	-59.99999999999999	59.99999999999999								
	1078	1207	0.0667563403857844	0.12512973889645193	0.024911210242915004	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1078	1490	0.05345174131068208	0.22363736328897493	0.061955177296400085	185.0	185.0	185.0	0	0	1	-59.99999999999999	59.99999999999999								
	1078	1490	0.05349104045378042	0.21807715715355994	0.05224195717491489	182.0	182.0	182.0	0	0	1	-59.99999999999999	59.99999999999999								
	1080	1180	0.0030729564342564003	0.010924113591821395	0.00253761282619089	168.0	168.0	168.0	0	0	1	-59.99999999999999	59.99999999999999								
	1080	1181	0.002911785565070809	0.011279526898845095	0.00247869265701156	176.0	176.0	176.0	0	0	1	-59.99999999999999	59.99999999999999								
	1080	1434	0.0032881696725069976	0.07610990448052506	0.001139793662265493	415.00000000000006	415.00000000000006	415.00000000000006	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1080	1435	0.0032220457554217245	0.07517339771102367	0.0011753297192410278	420.0	420.0	420.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1080	1191	0.0027457404802921203	0.014020984462544295	0.0030191236327900503	209.0	209.0	209.0	0	0	1	-59.99999999999999	59.99999999999999								
	1080	1241	0.06689093523517813	0.17017158401359295	0.035846971364426404	137.0	137.0	137.0	0	0	1	-59.99999999999999	59.99999999999999								
	1080	1460	0.00668108986175503	0.036056446006401385	0.00899129443732928	216.0	216.0	216.0	0	0	1	-59.99999999999999	59.99999999999999								
	1080	1460	0.0070136780941179	0.03319389394851402	0.008532867534909862	199.0	199.0	199.0	0	0	1	-59.99999999999999	59.99999999999999								
	1083	1060	0.23109318876793097	0.25334587222283683	0.0233989811938209	69.0	69.0	69.0	0	0	1	-59.99999999999999	59.99999999999999								
	1083	1060	0.06714649715125563	0.2325604913318529	0.023958479405902303	138.0	138.0	138.0	0	0	1	-59.99999999999999	59.99999999999999								
	1085	1607	0.0284987232697271	0.07149620659757408	0.016279008347943	136.0	136.0	136.0	0	0	1	-59.99999999999999	59.99999999999999								
	1086	1607	0.0075295454894537105	0.050772298679208384	0.013197060671388202	247.00000000000003	247.00000000000003	247.00000000000003	0	0	1	-59.99999999999999	59.99999999999999								
	1088	1456	0.01979995323019149	0.04970287708301137	0.011048851805169098	136.0	136.0	136.0	0	0	1	-59.99999999999999	59.99999999999999								
	1090	1141	0.021773642413616207	0.0415300595364533	0.008258724933606573	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1090	1183	0.0194417659125067	0.08419195600774136	0.01887395203519609	189.0	189.0	189.0	0	0	1	-59.99999999999999	59.99999999999999								
	1090	1225	0.007576099841492247	0.02482601956120129	0.006400150077484549	159.0	159.0	159.0	0	0	1	-59.99999999999999	59.99999999999999								
	1090	1632	0.013393785534909957	0.200672404647453	0.006720192852046933	158.0	158.0	158.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	1090	1240	0.011414088102397498	0.02792871897464149	0.00673030182165233	134.0	134.0	134.0	0	0	1	-59.99999999999999	59.99999999999999								
	1090	1457	0.046338730531562115	0.17745641675632295	0.03842593968730891	175.0	175.0	175.0	0	0	1	-59.99999999999999	59.99999999999999								
	1093	1178	0.011989931400222703	0.045796175493476886	0.0105305295993076	175.0	175.0	175.0	0	0	1	-59.99999999999999	59.99999999999999								
	1093	1457	0.02071399734341541	0.07920171738052738	0.018820212818863803	175.0	175.0	175.0	0	0	1	-59.99999999999999	59.99999999999999								
	1096	1154	0.12073616490121902	0.22068323353870598	0.041438524228911804	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1098	1515	0.0101699612787599	0.027057570700501094	0.0054949736595526315	141.0	141.0	141.0	0	0	1	-59.99999999999999	59.99999999999999								
	1099	1102	0.3030379310825471	0.6217400208434564	0.12695848384473496	120.0	120.0	120.0	0	0	1	-59.99999999999999	59.99999999999999								
	1099	1131	0.057110149541320335	0.22282575811014496	0.046426588710998196	177.0	177.0	177.0	0	0	1	-59.99999999999999	59.99999999999999								
	1105	1382	0.006947236374976109	0.04065819933134358	0.004889541474293922	189.0	189.0	189.0	0	0	1	-59.99999999999999	59.99999999999999								
	1105	1606	0.0021355560819916394	0.012555749329328495	0.0014944461887106298	189.0	189.0	189.0	0	0	1	-59.99999999999999	59.99999999999999								
	1110	1271	0.010130375205864751	0.2114456767063215	0.0005890905442725628	150.0	150.0	150.0	0.9625000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1110	1460	0.3639044275165001	0.6850134594532318	0.141234807817385	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1111	1320	0.036468897167802786	0.07237830692277025	0.00711775597340427	98.0	98.0	98.0	0	0	1	-59.99999999999999	59.99999999999999								
	1111	1442	0.047675801253735085	0.10645635552810498	0.00964604768491723	105.0	105.0	105.0	0	0	1	-59.99999999999999	59.99999999999999								
	1113	1493	0.003883978425641079	0.012268790809691905	0.0012312350589782004	130.0	130.0	130.0	0	0	1	-59.99999999999999	59.99999999999999								
	1113	1507	0.005123431993501728	0.017423477469071698	0.0017314813138320992	136.0	136.0	136.0	0	0	1	-59.99999999999999	59.99999999999999								
	1116	1318	0.00800011759482091	0.01924892500309509	0.001957850208219611	110.00000000000001	110.00000000000001	110.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1116	1606	0.009970985651364552	0.031181418718604383	0.0036225014685527398	129.0	129.0	129.0	0	0	1	-59.99999999999999	59.99999999999999								
	1116	1606	0.009539563199536867	0.03152742421392858	0.00350860267714877	134.0	134.0	134.0	0	0	1	-59.99999999999999	59.99999999999999								
	1119	1243	0.17487653678640688	0.33651949163418976	0.07003812896645208	115.99999999999999	115.99999999999999	115.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1119	1243	0.17366002690796606	0.32845578930326114	0.0709419859305373	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1122	1460	0.008370034033402328	0.02716726374332609	0.006120785568166518	159.0	159.0	159.0	0	0	1	-59.99999999999999	59.99999999999999								
	1122	1616	0.005864571205371991	0.014664883779224001	0.0027473895399901106	135.0	135.0	135.0	0	0	1	-59.99999999999999	59.99999999999999								
	1123	1460	0.009273702076465822	0.026683437494933602	0.00614343622832419	147.0	147.0	147.0	0	0	1	-59.99999999999999	59.99999999999999								
	1123	1616	0.005113324475460688	0.014017146083411794	0.003037280065137431	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	1124	1250	0.010671524439440099	0.027411298843771192	0.00046189378544222613	69.0	69.0	69.0	0	0	1	-59.99999999999999	59.99999999999999								
	1124	1263	0.010357716564051801	0.02680555375244469	0.0004561029966990458	69.0	69.0	69.0	0	0	1	-59.99999999999999	59.99999999999999								
	1124	1288	0.030192767202341892	0.07342225605057547	0.00125462824802939	67.0	67.0	67.0	0	0	1	-59.99999999999999	59.99999999999999								
	1125	1307	0.0019298694137353403	0.005177120349979959	0.026587819510096703	141.0	141.0	141.0	0	0	1	-59.99999999999999	59.99999999999999								
	1126	1307	0.0019652879661149303	0.00549916202480067	0.025796763998050195	145.0	145.0	145.0	0	0	1	-59.99999999999999	59.99999999999999								
	1191	1129	0.005365339271635192	0.14061395913485303	0.002986684292022658	225.0	225.0	225.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1129	1378	0.013058715167576397	0.0202616184832901	0.000311701989127323	51.0	51.0	51.0	0	0	1	-59.99999999999999	59.99999999999999								
	1130	1460	0.11670704929746706	0.22963087530127194	0.0444691115324255	117.0	117.0	117.0	0	0	1	-59.99999999999999	59.99999999999999								
	1132	1133	0.015281718602455193	0.03162978373495858	0.006275270494306455	121.0	121.0	121.0	0	0	1	-59.99999999999999	59.99999999999999								
	1134	1409	0.045645615807897395	0.09083459107712835	0.019197819575477396	118.0	118.0	118.0	0	0	1	-59.99999999999999	59.99999999999999								
	1135	1456	0.012923982424428698	0.02705467050231989	0.005822171367244788	122.0	122.0	122.0	0	0	1	-59.99999999999999	59.99999999999999								
	1139	1202	0.0032961127560306304	0.019680155760482893	0.00936728873969708	229.0	229.0	229.0	0	0	1	-59.99999999999999	59.99999999999999								
	1140	1585	0.000437901498894207	0.005846167821113951	0.176215038203156	778.0	778.0	778.0	0	0	1	-59.99999999999999	59.99999999999999								
	1140	1586	0.000464982706275769	0.005803209306922743	0.17068320829988504	747.0	747.0	747.0	0	0	1	-59.99999999999999	59.99999999999999								
	1140	1597	0.00356497986308299	0.042748706352409016	0.33981039057165413	729.0	729.0	729.0	0	0	1	-59.99999999999999	59.99999999999999								
	1140	1597	0.0036506723232781505	0.04050772057776671	0.3467416617995869	696.0	696.0	696.0	0	0	1	-59.99999999999999	59.99999999999999								
	1142	1457	0.03288857487873168	0.06665566549337466	0.01358706770504359	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	1143	1144	0.031218851078934996	0.06304246583962107	0.012064736709453194	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	1143	1265	0.006830272168110591	0.025016672427929494	0.005682885293215508	171.0	171.0	171.0	0	0	1	-59.99999999999999	59.99999999999999								
	1143	1457	0.04424561573282999	0.16421677804264095	0.03555691266672171	172.0	172.0	172.0	0	0	1	-59.99999999999999	59.99999999999999								
	1145	1362	0.015449730944819698	0.03789877423884349	0.011233102402323902	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1145	1445	0.031803188227904004	0.08349790558481587	0.008508610722422604	115.99999999999999	115.99999999999999	115.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1145	1478	0.00843561891140416	0.04099647319754308	0.00718384138790891	169.0	169.0	169.0	0	0	1	-59.99999999999999	59.99999999999999								
	1145	1478	0.008601462415382273	0.044022043827471796	0.0070859808322945635	174.0	174.0	174.0	0	0	1	-59.99999999999999	59.99999999999999								
	1145	1608	0.011512416723766395	0.02493513437453659	0.0026934038234129494	103.0	103.0	103.0	0	0	1	-59.99999999999999	59.99999999999999								
	1149	1150	0.01904547234009949	0.03578988037634638	0.00796553614681587	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1149	1131	0.020278209919855003	0.0846958954063058	0.016806536077614904	185.0	185.0	185.0	0	0	1	-59.99999999999999	59.99999999999999								
	1152	1060	0.010475342055486494	0.03885795569050588	0.00548640103664109	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	1153	1060	0.010633225415090595	0.03921323239772488	0.005467601131942121	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	1154	1227	0.029075492059808195	0.09472808051986988	0.021788749277826393	159.0	159.0	159.0	0	0	1	-59.99999999999999	59.99999999999999								
	1154	1229	0.06706880715987644	0.12784358118837696	0.0266931571151712	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1154	1492	0.004264960144797341	0.013025083836897296	0.0034950468330406585	153.0	153.0	153.0	0	0	1	-59.99999999999999	59.99999999999999								
	1154	1599	0.11042546216951202	0.21210197329072697	0.043153350136483096	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1154	1599	0.11936950201506502	0.22517020328914988	0.044963941111377394	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1155	1449	0.05060293774056809	0.13479500341159292	0.032290198379134785	141.0	141.0	141.0	0	0	1	-59.99999999999999	59.99999999999999								
	1156	1515	0.018466329927488194	0.05135269149221248	0.010432329365164	144.0	144.0	144.0	0	0	1	-59.99999999999999	59.99999999999999								
	1159	1382	0.00209153213980095	0.011846062600419392	0.0014718280520727898	185.0	185.0	185.0	0	0	1	-59.99999999999999	59.99999999999999								
	1159	1606	0.007246631092801691	0.038806805664986385	0.005167118339411455	179.0	179.0	179.0	0	0	1	-59.99999999999999	59.99999999999999								
	1162	1307	0.0027306237259553698	0.013456354439331693	0.00320271434461419	204.0	204.0	204.0	0	0	1	-59.99999999999999	59.99999999999999								
	1166	1245	0.009504187290072443	0.04082627766174258	0.00262732554237172	188.0	188.0	188.0	0	0	1	-59.99999999999999	59.99999999999999								
	1169	1607	0.023575439013205496	0.06884787701221928	0.014482474056663891	149.0	149.0	149.0	0	0	1	-59.99999999999999	59.99999999999999								
	1169	1607	0.0257229469473101	0.06869018707818156	0.014402170728775702	141.0	141.0	141.0	0	0	1	-59.99999999999999	59.99999999999999								
	1171	1205	0.021342701846874302	0.12338330077495396	0.022267345438199106	225.0	225.0	225.0	0	0	1	-59.99999999999999	59.99999999999999								
	1172	1191	0.002933851098474579	0.013837448659546194	0.0031623908378747294	199.0	199.0	199.0	0	0	1	-59.99999999999999	59.99999999999999								
	1174	1213	0.005344046254027629	0.019540305698197293	0.00233181846228568	142.0	142.0	142.0	0	0	1	-59.99999999999999	59.99999999999999								
	1174	1442	0.008662486259933084	0.018853397158025788	0.0017136419937144997	104.0	104.0	104.0	0	0	1	-59.99999999999999	59.99999999999999								
	1174	1480	0.026073092356123994	0.09120197771698468	0.010689179896747203	138.0	138.0	138.0	0	0	1	-59.99999999999999	59.99999999999999								
	1174	1507	0.013088960405286398	0.044564875043610966	0.004622097480674269	136.0	136.0	136.0	0	0	1	-59.99999999999999	59.99999999999999								
	1176	1177	0.005696622015722102	0.011090990473728196	0.0022634437353983503	115.99999999999999	115.99999999999999	115.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1177	1229	0.16586064145891194	0.3040571838824658	0.0645205178227946	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1183	1457	0.040575688052549984	0.14885836108463296	0.03443229819068962	171.0	171.0	171.0	0	0	1	-59.99999999999999	59.99999999999999								
	1183	1457	0.04413288727742849	0.15638176304741191	0.03746797565599899	167.0	167.0	167.0	0	0	1	-59.99999999999999	59.99999999999999								
	1183	1457	0.03849547268077732	0.15198940559033294	0.035749628566345205	179.0	179.0	179.0	0	0	1	-59.99999999999999	59.99999999999999								
	1185	1470	0.003619355349324638	0.014733657638524193	0.00154827847404405	152.0	152.0	152.0	0	0	1	-59.99999999999999	59.99999999999999								
	1186	1470	0.0032662289991527782	0.013530636286232594	0.00886460504002869	153.0	153.0	153.0	0	0	1	-59.99999999999999	59.99999999999999								
	1187	1470	0.0032070213322900184	0.013115357146030295	0.008724059277310972	152.0	152.0	152.0	0	0	1	-59.99999999999999	59.99999999999999								
	1249	1438	0.021462725524164533	0.19819930761283303	0.0008992253100725776	159.0	159.0	159.0	1.15	0.0	1	-59.99999999999999	59.99999999999999								
	1193	1502	0.00455356810550485	0.022632147200411692	0.0053097363397385895	204.99999999999997	204.99999999999997	204.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	1193	1616	0.014748416011630098	0.07338034777290886	0.016525138122135297	204.99999999999997	204.99999999999997	204.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	1196	1235	0.0018661234326846899	0.012672679945109396	0.00310805404135259	206.99999999999997	206.99999999999997	206.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	1196	1195	0.0018061243973299902	0.012550749549405599	0.003007017904981041	210.0	210.0	210.0	0	0	1	-59.99999999999999	59.99999999999999								
	1196	1060	0.0118715735322721	0.08717362931952524	0.0165419922390506	217.0	217.0	217.0	0	0	1	-59.99999999999999	59.99999999999999								
	1196	1060	0.0119683957487298	0.08457423290470427	0.0165472685315833	212.0	212.0	212.0	0	0	1	-59.99999999999999	59.99999999999999								
	1196	1598	0.18078266686373395	0.21179060697622187	0.016859484266056695	71.0	71.0	71.0	0	0	1	-59.99999999999999	59.99999999999999								
	1196	1598	0.165569007868404	0.188021388866946	0.017410700919264915	70.0	70.0	70.0	0	0	1	-59.99999999999999	59.99999999999999								
	1202	1139	0.0036595127509063997	0.021761073728569287	0.010182354627898897	229.0	229.0	229.0	0	0	1	-59.99999999999999	59.99999999999999								
	1204	1208	0.004728284302163869	0.014470322175905992	0.0015676527905831995	128.0	128.0	128.0	0	0	1	-59.99999999999999	59.99999999999999								
	1204	1480	0.017445243665482793	0.05734789371709898	0.005895208777541293	133.0	133.0	133.0	0	0	1	-59.99999999999999	59.99999999999999								
	1204	1493	0.007395926037151371	0.022883977810961787	0.0026599287383556407	128.0	128.0	128.0	0	0	1	-59.99999999999999	59.99999999999999								
	1204	1493	0.007167281691083682	0.02386323718413711	0.002449476653567521	134.0	134.0	134.0	0	0	1	-59.99999999999999	59.99999999999999								
	1204	1596	0.007561630941554901	0.023725401745034392	0.0025878941050171897	130.0	130.0	130.0	0	0	1	-59.99999999999999	59.99999999999999								
	1205	1502	0.0398347547346074	0.21155951179098095	0.04030794653054331	214.0	214.0	214.0	0	0	1	-59.99999999999999	59.99999999999999								
	1207	1310	0.041098351074997305	0.06764336391650137	0.014535790112242094	105.0	105.0	105.0	0	0	1	-59.99999999999999	59.99999999999999								
	1207	1310	0.0367238347299714	0.06688757557775815	0.013863935458352796	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1208	1470	0.005744418728352989	0.018784407540347894	0.0019756219479371796	133.0	133.0	133.0	0	0	1	-59.99999999999999	59.99999999999999								
	1211	1445	0.012306633522771294	0.03815759199570678	0.004320006089070811	129.0	129.0	129.0	0	0	1	-59.99999999999999	59.99999999999999								
	1211	1596	0.007693698779830709	0.026027131180599287	0.0026014792394153815	136.0	136.0	136.0	0	0	1	-59.99999999999999	59.99999999999999								
	1211	1596	0.007523939245140179	0.025585541351953997	0.0026777351091862712	136.0	136.0	136.0	0	0	1	-59.99999999999999	59.99999999999999								
	1213	1507	0.008973152152765076	0.035237526432420084	0.0244780413247012	148.0	148.0	148.0	0	0	1	-59.99999999999999	59.99999999999999								
	1214	1276	0.03385350407427182	0.11607490595109898	0.02619172365858689	164.0	164.0	164.0	0	0	1	-59.99999999999999	59.99999999999999								
	1219	1359	0.0008522645230539141	0.005975373621026519	0.05288535949312292	211.0	211.0	211.0	0	0	1	-59.99999999999999	59.99999999999999								
	1220	1359	0.0007884211487643418	0.00583516034607775	0.0547091453336761	218.00000000000003	218.00000000000003	218.00000000000003	0	0	1	-59.99999999999999	59.99999999999999								
	1223	1457	0.021041971528567405	0.07292737066153109	0.011007959818571797	165.0	165.0	165.0	0	0	1	-59.99999999999999	59.99999999999999								
	1224	1457	0.046994698654816	0.14946488572751396	0.025448809956937997	157.0	157.0	157.0	0	0	1	-59.99999999999999	59.99999999999999								
	1227	1241	0.04536849382432181	0.15308254025138898	0.0364404977597296	162.0	162.0	162.0	0	0	1	-59.99999999999999	59.99999999999999								
	1230	1492	0.017158303284043396	0.08380795251899346	0.0771763112468999	202.99999999999997	202.99999999999997	202.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	1598	1441	0.024111423956932755	0.41061057175361215	0.0012109399457013359	77.0	77.0	77.0	1.01493	0.0	1	-59.99999999999999	59.99999999999999								
	1241	1492	0.06990692331961912	0.2296629810166169	0.05297197016240282	160.0	160.0	160.0	0	0	1	-59.99999999999999	59.99999999999999								
	1243	1258	0.0018724093544390103	0.013438034844268998	0.0034242722140625102	256.0	256.0	256.0	0	0	1	-59.99999999999999	59.99999999999999								
	1243	1258	0.00182140412243409	0.013989459149493797	0.0035867460652487396	267.0	267.0	267.0	0	0	1	-59.99999999999999	59.99999999999999								
	1245	1503	0.00139903513921611	0.016344718879717394	0.006753472759572321	345.0	345.0	345.0	0	0	1	-59.99999999999999	59.99999999999999								
	1245	1577	0.0016954687813496724	0.07252538484226558	0.006667275309145454	436.00000000000006	436.00000000000006	436.00000000000006	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1249	1288	0.017252369793136605	0.05430785360292338	0.0009443118953467346	78.0	78.0	78.0	0	0	1	-59.99999999999999	59.99999999999999								
	1250	1283	0.0195363171440614	0.034690004858999486	0.0005741553397066891	55.00000000000001	55.00000000000001	55.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1253	1254	0.024505690483644094	0.08197654060532517	0.012476830910444296	161.0	161.0	161.0	0	0	1	-59.99999999999999	59.99999999999999								
	1255	1409	0.00897550656925142	0.02457908967294449	0.004408421465247868	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	1256	1615	0.014424637150391897	0.027066462355945294	0.00040837547625973775	56.99999999999999	56.99999999999999	56.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1258	1259	0.007065191170344129	0.03429720408267948	0.007786186070643356	202.0	202.0	202.0	0	0	1	-59.99999999999999	59.99999999999999								
	1258	1259	0.006963484255786993	0.03247958138141079	0.007608519606873391	198.0	198.0	198.0	0	0	1	-59.99999999999999	59.99999999999999								
	1259	1260	0.013736098739894603	0.03719781579683068	0.00825047121652169	142.0	142.0	142.0	0	0	1	-59.99999999999999	59.99999999999999								
	1259	1260	0.013416487064953006	0.035797118809177984	0.008098666688406368	141.0	141.0	141.0	0	0	1	-59.99999999999999	59.99999999999999								
	1262	1509	0.0015549644490135803	0.011775862642883295	0.00279523323703557	265.0	265.0	265.0	0	0	1	-59.99999999999999	59.99999999999999								
	1262	1509	0.0014925629294873205	0.011861201916315598	0.0027023126261998005	273.0	273.0	273.0	0	0	1	-59.99999999999999	59.99999999999999								
	1264	1139	0.0027365169236529597	0.010253026636110194	0.0025866530673494593	173.0	173.0	173.0	0	0	1	-59.99999999999999	59.99999999999999								
	1264	1139	0.0027807300935359706	0.010155382588359494	0.002504280488548331	170.0	170.0	170.0	0	0	1	-59.99999999999999	59.99999999999999								
	1266	1591	0.008381368093128318	0.02221669056956279	0.004654869021292777	140.0	140.0	140.0	0	0	1	-59.99999999999999	59.99999999999999								
	1266	1591	0.008450635946240279	0.02268424522064719	0.004770795359985438	141.0	141.0	141.0	0	0	1	-59.99999999999999	59.99999999999999								
	1267	1591	0.00874356081771571	0.04223433910687269	0.009678779771081175	202.0	202.0	202.0	0	0	1	-59.99999999999999	59.99999999999999								
	1267	1591	0.008644043044256979	0.04463666849330718	0.010078768549393902	210.0	210.0	210.0	0	0	1	-59.99999999999999	59.99999999999999								
	1268	1513	0.010843601267818402	0.05605264527702698	0.013223820132622499	210.0	210.0	210.0	0	0	1	-59.99999999999999	59.99999999999999								
	1268	1513	0.0112990885190936	0.05675199203235329	0.012376855933014293	206.99999999999997	206.99999999999997	206.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	1277	1606	0.0038783450055886086	0.012383466389295593	0.0013065174873918295	131.0	131.0	131.0	0	0	1	-59.99999999999999	59.99999999999999								
	1278	1591	0.0139510076766154	0.09937118603446286	0.038585153486331895	254.99999999999997	254.99999999999997	254.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	1278	1591	0.013833290679280602	0.10343693762780097	0.03871210948381759	263.0	263.0	263.0	0	0	1	-59.99999999999999	59.99999999999999								
	1283	1615	0.015950024983504795	0.04030601114973799	0.0005616933245728719	68.0	68.0	68.0	0	0	1	-59.99999999999999	59.99999999999999								
	1284	1374	0.0013508041442185596	0.0026555809670593604	0.044612708151876006	98.0	98.0	98.0	0	0	1	-59.99999999999999	59.99999999999999								
	1284	1418	0.003091981585044411	0.005840764230750498	0.08224684056700673	95.0	95.0	95.0	0	0	1	-59.99999999999999	59.99999999999999								
	1285	1374	0.0012496132121700798	0.0025788119106739784	0.04664491614375729	101.0	101.0	101.0	0	0	1	-59.99999999999999	59.99999999999999								
	1285	1418	0.003155864781811831	0.005523627057597039	0.08531242857215934	91.0	91.0	91.0	0	0	1	-59.99999999999999	59.99999999999999								
	1288	1615	0.026858286752533198	0.07126935984419659	0.0011143847043393203	70.0	70.0	70.0	0	0	1	-59.99999999999999	59.99999999999999								
	1289	1297	0.0029156442662626493	0.013423349173917002	0.002905953581246551	163.0	163.0	163.0	0	0	1	-59.99999999999999	59.99999999999999								
	1290	1294	0.009230191898514215	0.16774216683466983	0.0006763430110292839	189.0	189.0	189.0	0.9875000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1290	1453	0.020595003032867102	0.13913957905047628	0.00641584551491439	225.0	225.0	225.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1292	1293	0.0029921128305243298	0.01628176528239719	0.002003859759360551	181.0	181.0	181.0	0	0	1	-59.99999999999999	59.99999999999999								
	1300	1478	0.0134275874616439	0.031633249885272184	0.008040851843720298	109.00000000000001	109.00000000000001	109.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1302	1382	0.003102365874499079	0.011499990357742594	0.0016296296530868895	143.0	143.0	143.0	0	0	1	-59.99999999999999	59.99999999999999								
	1303	1382	0.003205424837819299	0.011648290930534693	0.0016172144739888606	142.0	142.0	142.0	0	0	1	-59.99999999999999	59.99999999999999								
	1280	1390	0.000418922695591114	0.0030726035815179286	0.0272004715925199	217.0	217.0	217.0	0	0	1	-59.99999999999999	59.99999999999999								
	1312	1337	0.0007228074372513217	0.0011648208455555095	0.0207519428340904	87.0	87.0	87.0	0	0	1	-59.99999999999999	59.99999999999999								
	1312	1337	0.0006818577332608398	0.0011896673810295794	0.020338288963390502	91.0	91.0	91.0	0	0	1	-59.99999999999999	59.99999999999999								
	1316	1445	0.008379695626068861	0.04081398111514748	0.00505538935594726	169.0	169.0	169.0	0	0	1	-59.99999999999999	59.99999999999999								
	1318	1608	0.010965097882726696	0.025668370875064295	0.0025676956592453615	108.0	108.0	108.0	0	0	1	-59.99999999999999	59.99999999999999								
	1297	1329	0.023998382022484978	0.23362097567245763	0.0062001459054844945	135.0	135.0	135.0	1.1368	0.0	1	-59.99999999999999	59.99999999999999								
	1332	1329	0.015251254305120492	0.21666523057609682	0.006813489651811577	146.0	146.0	146.0	1.0912	0.0	1	-59.99999999999999	59.99999999999999								
	1332	1297	0.0038456535541159095	0.027296741610895816	0.0038933266623532407	212.0	212.0	212.0	0	0	1	-59.99999999999999	59.99999999999999								
	1332	1297	0.0038557777557917897	0.026421091709686408	0.004092677203112751	208.0	208.0	208.0	0	0	1	-59.99999999999999	59.99999999999999								
	1335	1322	0.0029614243204509794	0.015570627244678292	0.001816196920822369	177.0	177.0	177.0	0	0	1	-59.99999999999999	59.99999999999999								
	1335	1322	0.002792848547182049	0.015657088103531894	0.0017815504112970104	184.0	184.0	184.0	0	0	1	-59.99999999999999	59.99999999999999								
	1347	1359	0.0031865848198533095	0.005567293998859817	0.0831517347183777	91.0	91.0	91.0	0	0	1	-59.99999999999999	59.99999999999999								
	1280	1379	0.0011007620148593595	0.003433719459213319	0.06709807451337581	129.0	129.0	129.0	0	0	1	-59.99999999999999	59.99999999999999								
	1280	1379	0.0010814007652830298	0.003472797003909949	0.06787755165159702	131.0	131.0	131.0	0	0	1	-59.99999999999999	59.99999999999999								
	1280	1322	0.005005320160478349	0.028389356498569683	0.0039164842638829715	185.0	185.0	185.0	0	0	1	-59.99999999999999	59.99999999999999								
	1280	1322	0.004820144278566349	0.02922901768012999	0.003634173628999389	193.0	193.0	193.0	0	0	1	-59.99999999999999	59.99999999999999								
	1353	1378	0.012341042908444101	0.020142209916487297	0.0003025332995876672	53.0	53.0	53.0	0	0	1	-59.99999999999999	59.99999999999999								
	1354	1615	0.0362428481405135	0.04977128389924759	0.0007110950251901517	47.0	47.0	47.0	0	0	1	-59.99999999999999	59.99999999999999								
	1355	1478	0.009559467527030498	0.019222299404376194	0.00260793136940058	99.0	99.0	99.0	0	0	1	-59.99999999999999	59.99999999999999								
	1359	1297	0.007754803964618589	0.04442719499568358	0.024594790987046897	187.0	187.0	187.0	0	0	1	-59.99999999999999	59.99999999999999								
	1359	1297	0.008373609199932776	0.04833603010617429	0.0265651927965442	187.0	187.0	187.0	0	0	1	-59.99999999999999	59.99999999999999								
	1363	1606	0.00358405595122231	0.012287964207829898	0.0012778834881028202	137.0	137.0	137.0	0	0	1	-59.99999999999999	59.99999999999999								
	1367	1507	0.004077604063972829	0.013137830661050997	0.0014034990825643806	132.0	132.0	132.0	0	0	1	-59.99999999999999	59.99999999999999								
	1507	1369	0.014669722650766763	0.1953240099829099	0.0019500765875558991	162.0	162.0	162.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1289	1297	0.005051955684553829	0.02033843746747639	0.004829779958818108	151.0	151.0	151.0	0	0	1	-59.99999999999999	59.99999999999999								
	1372	1444	0.011200077490284998	0.028048637194810384	0.0513580192741938	112.99999999999999	112.99999999999999	112.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1372	1444	0.011210779256899795	0.028194520909371808	0.05034536495525391	112.99999999999999	112.99999999999999	112.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1378	1615	0.046257324535776904	0.07118809499509628	0.0010221884390786296	51.0	51.0	51.0	0	0	1	-59.99999999999999	59.99999999999999								
	1381	1382	0.0007381642567296508	0.002981099828083531	0.020015800901488405	151.0	151.0	151.0	0	0	1	-59.99999999999999	59.99999999999999								
	1312	1470	0.008273989646140487	0.022290229512269586	0.04781327414855921	118.0	118.0	118.0	0	0	1	-59.99999999999999	59.99999999999999								
	1388	1390	0.0013908597988588696	0.009551515736146826	0.06060806407002921	208.0	208.0	208.0	0	0	1	-59.99999999999999	59.99999999999999								
	1388	1445	0.0017606371358619098	0.012714297830227797	0.0025585609191576897	215.0	215.0	215.0	0	0	1	-59.99999999999999	59.99999999999999								
	1388	1322	0.00200529466810701	0.012697564141392297	0.00426939374391222	198.0	198.0	198.0	0	0	1	-59.99999999999999	59.99999999999999								
	1389	1390	0.0015131060226550295	0.009445950058237644	0.0612352192433905	196.0	196.0	196.0	0	0	1	-59.99999999999999	59.99999999999999								
	1389	1445	0.0018333235318772495	0.013207215987844396	0.0025215572214229006	214.0	214.0	214.0	0	0	1	-59.99999999999999	59.99999999999999								
	1389	1322	0.0018663952793274096	0.012230510568546092	0.00440620117369294	202.0	202.0	202.0	0	0	1	-59.99999999999999	59.99999999999999								
	1418	1382	0.005982437294794709	0.025532652198924685	0.046122669236137996	156.0	156.0	156.0	0	0	1	-59.99999999999999	59.99999999999999								
	1418	1382	0.00569777335721394	0.025976949253890696	0.04858621617261741	162.0	162.0	162.0	0	0	1	-59.99999999999999	59.99999999999999								
	1444	1480	0.012994813037183096	0.041988090584032176	0.00418855111361807	132.0	132.0	132.0	0	0	1	-59.99999999999999	59.99999999999999								
	1444	1480	0.012984015659920894	0.04168488577201216	0.004237240758695166	131.0	131.0	131.0	0	0	1	-59.99999999999999	59.99999999999999								
	1445	1322	0.014156981541743307	0.04948614583900321	0.006904756853593512	138.0	138.0	138.0	0	0	1	-59.99999999999999	59.99999999999999								
	1445	1478	0.011048924205475496	0.060731178122758855	0.00713812795780599	182.0	182.0	182.0	0	0	1	-59.99999999999999	59.99999999999999								
	1445	1478	0.011465514322402897	0.06103213957976547	0.006977799431136811	178.0	178.0	178.0	0	0	1	-59.99999999999999	59.99999999999999								
	1450	1215	0.07152849178787972	0.12991278157453395	0.026094163846492806	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1451	1139	0.005955013537603431	0.03484314448487249	0.016124314315977502	227.0	227.0	227.0	0	0	1	-59.99999999999999	59.99999999999999								
	1451	1139	0.006358403935672711	0.0340460598672149	0.0160387724410594	215.0	215.0	215.0	0	0	1	-59.99999999999999	59.99999999999999								
	1452	1453	0.006414912242791624	0.032960499426173004	0.007776179241687063	209.0	209.0	209.0	0	0	1	-59.99999999999999	59.99999999999999								
	1452	1453	0.0062031757529173	0.03187938571840988	0.0075632412277627705	209.0	209.0	209.0	0	0	1	-59.99999999999999	59.99999999999999								
	1456	1409	0.022571174564022602	0.04648096658154859	0.009510689922222869	120.0	120.0	120.0	0	0	1	-59.99999999999999	59.99999999999999								
	1460	1502	0.007321112473242921	0.05547957041885329	0.0210325603186218	265.0	265.0	265.0	0	0	1	-59.99999999999999	59.99999999999999								
	1460	1502	0.007761524042434063	0.059929981870936205	0.02195585972558991	268.0	268.0	268.0	0	0	1	-59.99999999999999	59.99999999999999								
	1464	1541	0.007607009573886171	0.057403537851146436	0.240926503727053	550.0	550.0	550.0	0	0	1	-59.99999999999999	59.99999999999999								
	1464	1562	0.0032940572445495104	0.04217226090369191	0.32579448283118695	759.0	759.0	759.0	0	0	1	-59.99999999999999	59.99999999999999								
	1464	1562	0.00329350161764864	0.04091518248744491	0.29622458030136195	745.0	745.0	745.0	0	0	1	-59.99999999999999	59.99999999999999								
	1470	1596	0.0123849741657586	0.03982524324013849	0.004400128124388872	131.0	131.0	131.0	0	0	1	-59.99999999999999	59.99999999999999								
	1490	1601	0.00476567651332915	0.01587860585815271	0.0037256601611957907	161.0	161.0	161.0	0	0	1	-59.99999999999999	59.99999999999999								
	1490	1602	0.004766553862400348	0.015584144604157192	0.0038696100481362098	159.0	159.0	159.0	0	0	1	-59.99999999999999	59.99999999999999								
	1493	1507	0.00938148335292656	0.028683312335148488	0.0032518549613938705	128.0	128.0	128.0	0	0	1	-59.99999999999999	59.99999999999999								
	1502	1616	0.010755904010639496	0.05099857421746939	0.011960990236592002	199.0	199.0	199.0	0	0	1	-59.99999999999999	59.99999999999999								
	1505	1607	0.008093672438487411	0.0543201239747992	0.013230037608263103	246.0	246.0	246.0	0	0	1	-59.99999999999999	59.99999999999999								
	1505	1607	0.007504364628388552	0.0498722189863725	0.0131302638170915	245.00000000000003	245.00000000000003	245.00000000000003	0	0	1	-59.99999999999999	59.99999999999999								
	1512	1513	0.005641324981362561	0.0443928282067138	0.0161298413419337	271.0	271.0	271.0	0	0	1	-59.99999999999999	59.99999999999999								
	1512	1513	0.00554356850761408	0.04606036417477249	0.016331687277671897	280.0	280.0	280.0	0	0	1	-59.99999999999999	59.99999999999999								
	1516	1520	0.009427140548573807	0.06796105503713337	0.41620858076989664	535.0	535.0	535.0	0	0	1	-59.99999999999999	59.99999999999999								
	1516	1529	0.00496288395694643	0.03304105668479761	0.2122094346746199	509.99999999999994	509.99999999999994	509.99999999999994	0	0	1	-59.99999999999999	59.99999999999999								
	1516	1533	0.0013443380641099097	0.015230151757626804	0.106109881692141	704.0	704.0	704.0	0	0	1	-59.99999999999999	59.99999999999999								
	1516	1540	0.0031695090445205605	0.01996492522311911	0.15823818414398305	493.0	493.0	493.0	0	0	1	-59.99999999999999	59.99999999999999								
	1516	1541	0.004934084291830663	0.05385742930310035	0.36789874735077405	689.0	689.0	689.0	0	0	1	-59.99999999999999	59.99999999999999								
	1516	1566	0.0020055177042265404	0.014099492306322806	0.09980007735782209	527.0	527.0	527.0	0	0	1	-59.99999999999999	59.99999999999999								
	1518	1543	0.0006028724553342908	0.004617515655613502	0.031983317107157794	555.0	555.0	555.0	0	0	1	-59.99999999999999	59.99999999999999								
	1518	1322	0.0014901785316210098	0.05688983440809665	0.033390618271791114	556.0	556.0	556.0	1.0136333688105013	0.0	1	-59.99999999999999	59.99999999999999								
	1518	1545	0.0012210942298318305	0.008583989801870664	0.06398051821766793	527.0	527.0	527.0	0	0	1	-59.99999999999999	59.99999999999999								
	1518	1562	0.0019073741122763606	0.014557562040816504	0.10921891577434499	554.0	554.0	554.0	0	0	1	-59.99999999999999	59.99999999999999								
	1518	1566	0.0027774627755885	0.020386617187877203	0.14064455470800197	541.0	541.0	541.0	0	0	1	-59.99999999999999	59.99999999999999								
	1518	1568	0.0020723064130805406	0.013309560759988607	0.096124772229908	499.0	499.0	499.0	0	0	1	-59.99999999999999	59.99999999999999								
	1519	1562	0.00403965944970725	0.03376462262667721	0.14288080351065097	586.0	586.0	586.0	0	0	1	-59.99999999999999	59.99999999999999								
	1519	1562	0.004117827061919961	0.03359154929086291	0.136796445519857	577.0	577.0	577.0	0	0	1	-59.99999999999999	59.99999999999999								
	1520	1522	0.008780389595515102	0.06487852262810902	0.4205570097487448	543.0	543.0	543.0	0	0	1	-59.99999999999999	59.99999999999999								
	1520	1522	0.009430621256749143	0.06270737034919113	0.428891784834686	509.99999999999994	509.99999999999994	509.99999999999994	0	0	1	-59.99999999999999	59.99999999999999								
	1520	1529	0.006076003734570001	0.040033668968667314	0.27580819283367897	507.0	507.0	507.0	0	0	1	-59.99999999999999	59.99999999999999								
	1520	1579	0.0028695368102667896	0.0194680711095929	0.12972707102078898	516.0	516.0	516.0	0	0	1	-59.99999999999999	59.99999999999999								
	1522	1571	0.00839167375770351	0.057871520935919615	0.37741561606210705	521.0	521.0	521.0	0	0	1	-59.99999999999999	59.99999999999999								
	1522	1579	0.006380787241213019	0.04254386601629571	0.28912107124773706	509.99999999999994	509.99999999999994	509.99999999999994	0	0	1	-59.99999999999999	59.99999999999999								
	1522	1523	0.008040504116408536	0.05906058688571965	0.3638900249761462	541.0	541.0	541.0	0	0	1	-59.99999999999999	59.99999999999999								
	1522	1523	0.009541474414117634	0.06339553272414024	0.4084939588181152	509.0	509.0	509.0	0	0	1	-59.99999999999999	59.99999999999999								
	1523	1398	0.0009957030768932694	0.051339822860585166	0.008367596377804234	616.0	616.0	616.0	1.0152892561983466	0.0	1	-59.99999999999999	59.99999999999999								
	1523	1399	0.0009260254422994305	0.05102859270738235	0.006966567454912346	619.0	619.0	619.0	1.0152892561983466	0.0	1	-59.99999999999999	59.99999999999999								
	1527	1571	0.000249275006318931	0.0029139086723532505	0.021440929982847502	718.0	718.0	718.0	0	0	1	-59.99999999999999	59.99999999999999								
	1571	1451	0.0007345286291805767	0.0317251836255253	0.02002880859264668	996.0000000000001	996.0000000000001	996.0000000000001	0.9849984732523661	0.0	1	-59.99999999999999	59.99999999999999								
	1530	1531	0.021799918320005805	0.16419858823293806	0.6362873475713431	550.0	550.0	550.0	0	0	1	-59.99999999999999	59.99999999999999								
	1530	1542	0.010591169018196405	0.08667001525314064	0.2830505393274801	578.0	578.0	578.0	0	0	1	-59.99999999999999	59.99999999999999								
	1530	1523	0.007275624434249477	0.0562984155930988	0.20639115483046486	559.0	559.0	559.0	0	0	1	-59.99999999999999	59.99999999999999								
	1530	1584	0.003395388568626721	0.025261623492386205	0.08792542442753908	546.0	546.0	546.0	0	0	1	-59.99999999999999	59.99999999999999								
	1530	1613	0.0005785878804111851	0.0067625809980952235	0.0523776280571474	718.0	718.0	718.0	0	0	1	-59.99999999999999	59.99999999999999								
	1530	1613	0.0005857823675740508	0.00728136011136463	0.05094575601842949	745.0	745.0	745.0	0	0	1	-59.99999999999999	59.99999999999999								
	1531	1542	0.008412398407929582	0.07004129780271091	0.44864254429873107	584.0	584.0	584.0	0	0	1	-59.99999999999999	59.99999999999999								
	1531	1542	0.005030892751740292	0.06009061511217243	0.46765691917510094	727.0	727.0	727.0	0	0	1	-59.99999999999999	59.99999999999999								
	1531	1542	0.005144230454657228	0.05818616291665659	0.46150620400186687	704.0	704.0	704.0	0	0	1	-59.99999999999999	59.99999999999999								
	1531	1564	0.005755107014586681	0.0424342317591165	0.704819405031744	543.0	543.0	543.0	0	0	1	-59.99999999999999	59.99999999999999								
	1531	1564	0.005487725590491202	0.05918603015040703	0.48879625455822096	684.0	684.0	684.0	0	0	1	-59.99999999999999	59.99999999999999								
	1531	1564	0.005298392174885613	0.06318545731677955	0.5022876392817499	727.0	727.0	727.0	0	0	1	-59.99999999999999	59.99999999999999								
	1533	1541	0.0035773018230632896	0.04256716676493451	0.3215000065528718	726.0	726.0	726.0	0	0	1	-59.99999999999999	59.99999999999999								
	1533	1541	0.003454124129868109	0.040962737101858916	0.334208772871543	724.0	724.0	724.0	0	0	1	-59.99999999999999	59.99999999999999								
	1533	1406	0.0010356989175631314	0.05189605833983599	0.004663576378002562	609.0	609.0	609.0	1.0281818181818183	0.0	1	-59.99999999999999	59.99999999999999								
	1533	1566	0.0008588416810361675	0.009377333195928953	0.0685635143097378	689.0	689.0	689.0	0	0	1	-59.99999999999999	59.99999999999999								
	1533	1578	0.0010538881376572	0.011404681738525605	0.0880060409906804	685.0	685.0	685.0	0	0	1	-59.99999999999999	59.99999999999999								
	1534	1557	0.015915382223425	0.13047407709372	0.5378753694272049	579.0	579.0	579.0	0	0	1	-59.99999999999999	59.99999999999999								
	1534	1557	0.016005319232103903	0.12537802721919103	0.527778272505663	563.0	563.0	563.0	0	0	1	-59.99999999999999	59.99999999999999								
	1534	1564	0.00649520275168028	0.04873850813580301	0.7226279725415627	548.0	548.0	548.0	0	0	1	-59.99999999999999	59.99999999999999								
	1534	1564	0.009409121203932908	0.07032192079104391	0.5306527339603869	547.0	547.0	547.0	0	0	1	-59.99999999999999	59.99999999999999								
	1534	1564	0.009597091417784339	0.07146187262766988	0.4950628239971969	546.0	546.0	546.0	0	0	1	-59.99999999999999	59.99999999999999								
	1536	1625	0.00214995381711423	0.02489084858386961	0.42334543710154293	856.0	856.0	856.0	0	0	1	-59.99999999999999	59.99999999999999								
	1625	1464	0.0022796151352961207	0.030526346630070044	0.415563588835431	1032.0	1032.0	1032.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1538	1542	0.007388500141942872	0.056687628757266816	0.22207346404246198	556.0	556.0	556.0	0	0	1	-59.99999999999999	59.99999999999999								
	1538	1542	0.007021490722300492	0.05850578084152193	0.232583130434054	584.0	584.0	584.0	0	0	1	-59.99999999999999	59.99999999999999								
	1566	1470	0.0019713448092741506	0.060476394304673185	0.06970871755113334	523.0	523.0	523.0	1.0108764330839086	0.0	1	-59.99999999999999	59.99999999999999								
	1541	1402	0.0007841235758356362	0.04111969833487748	0.0028170042162113705	769.0	769.0	769.0	1.0259740259740262	0.0	1	-59.99999999999999	59.99999999999999								
	1541	1400	0.0006681737319678516	0.03965230178451594	0.0022262047881813998	797.0	797.0	797.0	1.0259740259740262	0.0	1	-59.99999999999999	59.99999999999999								
	1541	1403	0.0007862083263705325	0.04082525269288728	0.004067512589040836	774.0	774.0	774.0	1.0389610389610395	0.0	1	-59.99999999999999	59.99999999999999								
	1541	1566	0.0043044521587640005	0.051037824690300014	0.39031746916268995	724.0	724.0	724.0	0	0	1	-59.99999999999999	59.99999999999999								
	1541	1566	0.00441295162497461	0.047304086238227815	0.41058777243348	681.0	681.0	681.0	0	0	1	-59.99999999999999	59.99999999999999								
	1541	1597	0.0006827221525227651	0.008013839076519015	0.05809544187019583	720.0	720.0	720.0	0	0	1	-59.99999999999999	59.99999999999999								
	1541	1597	0.000629010064191185	0.007734278240268581	0.05880975831310261	740.0	740.0	740.0	0	0	1	-59.99999999999999	59.99999999999999								
	1541	1597	0.000655997117956169	0.007830780257488132	0.0631804940295639	727.0	727.0	727.0	0	0	1	-59.99999999999999	59.99999999999999								
	1541	1597	0.0006410628560073671	0.0073859927352862426	0.06106131952369957	712.0	712.0	712.0	0	0	1	-59.99999999999999	59.99999999999999								
	1542	1613	0.004337443555757402	0.054643756967157134	0.34934432550026123	751.0	751.0	751.0	0	0	1	-59.99999999999999	59.99999999999999								
	1542	1613	0.00413846518833097	0.05001254138872772	0.3836376216546108	733.0	733.0	733.0	0	0	1	-59.99999999999999	59.99999999999999								
	1545	1562	0.0013774937657392607	0.009898579844866886	0.0751584397824085	534.0	534.0	534.0	0	0	1	-59.99999999999999	59.99999999999999								
	1546	1571	0.005791946597306059	0.05115052606575381	0.213113984348676	606.0	606.0	606.0	0	0	1	-59.99999999999999	59.99999999999999								
	1546	1597	0.011066150107537403	0.12460659916822305	1.0070339053335198	702.0	702.0	702.0	0	0	1	-59.99999999999999	59.99999999999999								
	1546	1597	0.011332084748596902	0.13385997279594405	1.0025110537590805	722.0	722.0	722.0	0	0	1	-59.99999999999999	59.99999999999999								
	1546	1613	0.00516765316656791	0.04138502137656321	0.29873082255625394	571.0	571.0	571.0	0	0	1	-59.99999999999999	59.99999999999999								
	1546	1613	0.00523897948206402	0.040310416065864316	0.280715497377087	557.0	557.0	557.0	0	0	1	-59.99999999999999	59.99999999999999								
	1546	1613	0.006713907804982738	0.0539098356817793	0.2182448473006689	571.0	571.0	571.0	0	0	1	-59.99999999999999	59.99999999999999								
	1555	1562	0.0029801195276957003	0.023138535999809404	0.16327691201811703	560.0	560.0	560.0	0	0	1	-59.99999999999999	59.99999999999999								
	1556	1562	0.0028807515907441294	0.022971390842871708	0.16558357695360998	569.0	569.0	569.0	0	0	1	-59.99999999999999	59.99999999999999								
	1557	1569	0.007790450492966916	0.056681080016836784	0.4956919170089898	538.0	538.0	538.0	0	0	1	-59.99999999999999	59.99999999999999								
	1557	1570	0.007986843624293801	0.05762007878297172	0.4970466582816472	536.0	536.0	536.0	0	0	1	-59.99999999999999	59.99999999999999								
	1562	1574	0.00040468066741712415	0.0036279995114547217	0.08055897613825928	611.0	611.0	611.0	0	0	1	-59.99999999999999	59.99999999999999								
	1562	1574	0.0006195601953472942	0.007078612170643173	0.056966365981291525	708.0	708.0	708.0	0	0	1	-59.99999999999999	59.99999999999999								
	1562	1574	0.0006145123267360028	0.00665973685724661	0.05377483549644468	686.0	686.0	686.0	0	0	1	-59.99999999999999	59.99999999999999								
	1566	1568	0.0009604213233124462	0.0069235108310175125	0.05092783584632211	535.0	535.0	535.0	0	0	1	-59.99999999999999	59.99999999999999								
	1566	1574	0.0006450516632967632	0.0071833291839384535	0.056225123585697305	697.0	697.0	697.0	0	0	1	-59.99999999999999	59.99999999999999								
	1571	1523	0.0011601174419056599	0.007998892167228272	0.05250295351699456	521.0	521.0	521.0	0	0	1	-59.99999999999999	59.99999999999999								
	1577	1523	0.00114164621260436	0.007440211321888493	0.028190765600837792	503.0	503.0	503.0	0	0	1	-59.99999999999999	59.99999999999999								
	1577	1584	0.0020196478581749806	0.014483044671827906	0.05216641636994199	534.0	534.0	534.0	0	0	1	-59.99999999999999	59.99999999999999								
	1578	1574	0.00043396304427273586	0.005199932314683678	0.04005014569557967	729.0	729.0	729.0	0	0	1	-59.99999999999999	59.99999999999999								
	1580	1582	0.0009320879566049201	0.011136619983189702	0.0888195165994782	728.0	728.0	728.0	0	0	1	-59.99999999999999	59.99999999999999								
	1580	1582	0.0009146896310197189	0.0113789694657405	0.09115326353518148	746.0	746.0	746.0	0	0	1	-59.99999999999999	59.99999999999999								
	1580	1588	0.00371133396582445	0.030144155011811818	0.20579886507224993	575.0	575.0	575.0	0	0	1	-59.99999999999999	59.99999999999999								
	1580	1589	0.0007276701772003431	0.008377253226843205	0.06947559294691961	711.0	711.0	711.0	0	0	1	-59.99999999999999	59.99999999999999								
	1580	1597	0.0038829743994916806	0.04781622504094152	0.3502925779370819	741.0	741.0	741.0	0	0	1	-59.99999999999999	59.99999999999999								
	1580	1597	0.004170554047232029	0.0441173792441189	0.3581599766820439	676.0	676.0	676.0	0	0	1	-59.99999999999999	59.99999999999999								
	1587	1588	0.00364649512991309	0.029105985866180212	0.19769732518529903	569.0	569.0	569.0	0	0	1	-59.99999999999999	59.99999999999999								
	1587	1588	0.0038356159958057097	0.029163122789017403	0.19611637820792194	553.0	553.0	553.0	0	0	1	-59.99999999999999	59.99999999999999								
	1587	1590	0.0020479835256580303	0.015493167079149306	0.10228623208322998	551.0	551.0	551.0	0	0	1	-59.99999999999999	59.99999999999999								
	1587	1590	0.00196378870267142	0.014919382537792006	0.10840011005464797	553.0	553.0	553.0	0	0	1	-59.99999999999999	59.99999999999999								
	1588	1589	0.0013455893692215903	0.016504507990004507	0.13129419526192504	739.0	739.0	739.0	0	0	1	-59.99999999999999	59.99999999999999								
	1590	1512	0.0028591999116083034	0.06683885857756726	0.11401607875894339	473.00000000000006	473.00000000000006	473.00000000000006	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1621	1623	0.00216503489238024	0.024733209068601006	0.373712831989134	849.0	849.0	849.0	0	0	1	-59.99999999999999	59.99999999999999								
	1621	1623	0.0021806979104722806	0.023981058781058502	0.3760561548362159	830.0000000000001	830.0000000000001	830.0000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1623	1625	0.0009738779507735741	0.011852874697800704	0.19629830644758992	883.0	883.0	883.0	0	0	1	-59.99999999999999	59.99999999999999								
	1623	1625	0.000991495599064976	0.011386429470072004	0.196256269498051	852.0	852.0	852.0	0	0	1	-59.99999999999999	59.99999999999999								
	1625	1629	0.00034579279226178963	0.02152400483083532	0.00840220099325483	1468.0	1468.0	1468.0	1.0565764023210826	0.0	1	-59.99999999999999	59.99999999999999								
	1635	1726	0.00121635981663102	0.008079623521008343	0.0356472378939688	509.0	509.0	509.0	0	0	1	-59.99999999999999	59.99999999999999								
	1635	1760	0.0010558987892532303	0.007962892097437013	0.0320607515322417	550.0	550.0	550.0	0	0	1	-59.99999999999999	59.99999999999999								
	1635	1770	0.0010767531336243303	0.008114202816397324	0.0315267035310343	550.0	550.0	550.0	0	0	1	-59.99999999999999	59.99999999999999								
	1664	1982	0.12577164157204804	0.2601498143021829	0.00023662400785088493	31.0	31.0	31.0	0	0	1	-59.99999999999999	59.99999999999999								
	1664	1982	0.101714305058168	0.20412710145665292	0.00017817033497011296	30.0	30.0	30.0	0	0	1	-59.99999999999999	59.99999999999999								
	1698	1936	0.0157921637373203	0.047292497068477275	0.0010330626706592698	76.0	76.0	76.0	0	0	1	-59.99999999999999	59.99999999999999								
	1698	1937	0.0283884083325136	0.08234669005610508	0.001579888965338469	74.0	74.0	74.0	0	0	1	-59.99999999999999	59.99999999999999								
	1663	1919	0.00404388331923634	0.023120737642906588	0.00038280806556343993	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1663	1932	0.0037570568781299506	0.022538935475214395	0.00039215188045054703	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1717	1768	0.0009882484366185963	0.0248588270822074	0.00020308380002155904	138.0	138.0	138.0	0	0	1	-59.99999999999999	59.99999999999999								
	1722	1769	0.0010200318328104903	0.02575328950537369	0.00020114301006309704	138.0	138.0	138.0	0	0	1	-59.99999999999999	59.99999999999999								
	1723	1724	0.0028787597681824103	0.020755068172023203	0.0846743289567996	535.0	535.0	535.0	0	0	1	-59.99999999999999	59.99999999999999								
	1723	1734	0.00569926819080021	0.040610588513786905	0.16970718013670993	532.0	532.0	532.0	0	0	1	-59.99999999999999	59.99999999999999								
	1724	1725	0.0075642930104155084	0.052401663179700686	0.22587887806545387	522.0	522.0	522.0	0	0	1	-59.99999999999999	59.99999999999999								
	1725	1726	0.009911532846807968	0.06768463418456351	0.28992914642906986	518.0	518.0	518.0	0	0	1	-59.99999999999999	59.99999999999999								
	1725	1728	0.00482450667030178	0.0342638862831891	0.125588125938419	530.0	530.0	530.0	0	0	1	-59.99999999999999	59.99999999999999								
	1725	1728	0.00438941575843841	0.036926092521846324	0.12410093419463396	588.0	588.0	588.0	0	0	1	-59.99999999999999	59.99999999999999								
	1725	1730	0.016129534811005004	0.11754966032754302	0.5937059324660198	539.0	539.0	539.0	0	0	1	-59.99999999999999	59.99999999999999								
	1725	1732	0.007044682728485201	0.04690742485017702	0.16098770010784097	509.99999999999994	509.99999999999994	509.99999999999994	0	0	1	-59.99999999999999	59.99999999999999								
	1725	1733	0.012086696841828502	0.08116277604341511	0.302281295160344	513.0	513.0	513.0	0	0	1	-59.99999999999999	59.99999999999999								
	1727	1731	0.0021515339179057594	0.015096677057286302	0.060315699451113994	527.0	527.0	527.0	0	0	1	-59.99999999999999	59.99999999999999								
	1727	1732	0.0068185841011572604	0.043763672148131316	0.16778123449635698	499.0	499.0	499.0	0	0	1	-59.99999999999999	59.99999999999999								
	1727	1759	0.008486581838986368	0.0591167622186216	0.21110872427025795	524.0	524.0	524.0	0	0	1	-59.99999999999999	59.99999999999999								
	1733	1766	0.008198957411544404	0.059799845231875835	0.223533405889291	539.0	539.0	539.0	0	0	1	-59.99999999999999	59.99999999999999								
	1734	1715	0.011342957698926293	0.0829178522879723	0.30918504982031997	540.0	540.0	540.0	0	0	1	-59.99999999999999	59.99999999999999								
	1734	1747	0.008120823799772189	0.058030028108758784	0.23618622344575085	532.0	532.0	532.0	0	0	1	-59.99999999999999	59.99999999999999								
	1734	1770	0.00416778351608664	0.029063220222876912	0.11408775132283598	525.0	525.0	525.0	0	0	1	-59.99999999999999	59.99999999999999								
	1715	1747	0.0014987872173311202	0.015682613099087007	0.11368355099406298	671.0	671.0	671.0	0	0	1	-59.99999999999999	59.99999999999999								
	1715	1751	0.00169214800585993	0.013043018706562002	0.04911470328886529	557.0	557.0	557.0	0	0	1	-59.99999999999999	59.99999999999999								
	1715	1766	0.0024126414224738294	0.017409272619009007	0.06843723498629678	536.0	536.0	536.0	0	0	1	-59.99999999999999	59.99999999999999								
	1743	1811	0.027983018004521697	0.08568530382659285	0.0206004698127508	153.0	153.0	153.0	0	0	1	-59.99999999999999	59.99999999999999								
	1747	1761	0.00108930966525106	0.011134191204030102	0.08211270142505037	662.0	662.0	662.0	0	0	1	-59.99999999999999	59.99999999999999								
	1747	1765	0.0046951742046140105	0.03592640249154071	0.13426919288645697	555.0	555.0	555.0	0	0	1	-59.99999999999999	59.99999999999999								
	1748	1850	0.05159910641696771	0.08820023919096218	0.0014179646809771695	54.0	54.0	54.0	0	0	1	-59.99999999999999	59.99999999999999								
	1748	1954	0.050358361751236924	0.08837769864981529	0.0013986184096988301	55.00000000000001	55.00000000000001	55.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1753	1758	0.000811953813731671	0.004959672432672231	0.02637627259396018	484.0	484.0	484.0	0	0	1	-59.99999999999999	59.99999999999999								
	1754	1720	0.0127404887224417	0.0922430098585878	0.341993802185906	537.0	537.0	537.0	0	0	1	-59.99999999999999	59.99999999999999								
	1755	1720	0.012086122339812096	0.09069230146761048	0.3420542508968149	548.0	548.0	548.0	0	0	1	-59.99999999999999	59.99999999999999								
	1754	1765	0.0101728375011943	0.07358775857014584	0.301238209775439	536.0	536.0	536.0	0	0	1	-59.99999999999999	59.99999999999999								
	1758	1753	0.0007872228344902403	0.005966363672818994	0.025280655939169207	552.0	552.0	552.0	0	0	1	-59.99999999999999	59.99999999999999								
	1761	1753	0.0010824778260011198	0.011383884498858798	0.08425973751122967	673.0	673.0	673.0	0	0	1	-59.99999999999999	59.99999999999999								
	1753	1765	0.006963829658925529	0.0568899062760361	0.3049658093831548	578.0	578.0	578.0	0	0	1	-59.99999999999999	59.99999999999999								
	1771	1780	0.01696046467429031	0.0564665572941536	0.013105686320662505	161.0	161.0	161.0	0	0	1	-59.99999999999999	59.99999999999999								
	1773	1775	0.05704442955739799	0.21591204389091592	0.0402931422403548	174.0	174.0	174.0	0	0	1	-59.99999999999999	59.99999999999999								
	1773	1780	0.04545506627255489	0.14116993353359597	0.025720602819195495	154.0	154.0	154.0	0	0	1	-59.99999999999999	59.99999999999999								
	1775	1958	0.040759437473982855	0.2652376685884598	0.01541888820326813	118.0	118.0	118.0	1.0175	0.0	1	-59.99999999999999	59.99999999999999								
	1775	1781	0.08689898167401548	0.34720090332264086	0.06612555766403669	180.0	180.0	180.0	0	0	1	-59.99999999999999	59.99999999999999								
	1777	1781	0.039826014236401905	0.08214770786591107	0.016983569635964004	120.0	120.0	120.0	0	0	1	-59.99999999999999	59.99999999999999								
	1713	1785	0.16925694638672292	0.3361417228742498	0.06477366427690713	118.0	118.0	118.0	0	0	1	-59.99999999999999	59.99999999999999								
	1713	1818	0.0032557567488662913	0.02599207385358589	0.009723597232113591	274.0	274.0	274.0	0	0	1	-59.99999999999999	59.99999999999999								
	1780	1772	0.003951626576185231	0.019989167923483993	0.004401288372548299	206.99999999999997	206.99999999999997	206.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	1780	1838	0.0038621894127689304	0.020514517010596988	0.004278653873985629	214.0	214.0	214.0	0	0	1	-59.99999999999999	59.99999999999999								
	1782	1783	0.01524316672569141	0.02889797150370662	0.005950132749415933	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1782	1785	0.04480357168452811	0.09222894781278908	0.018078281441163288	120.0	120.0	120.0	0	0	1	-59.99999999999999	59.99999999999999								
	1782	1797	0.0769454231047071	0.2171647465718629	0.044431661344785205	146.0	146.0	146.0	0	0	1	-59.99999999999999	59.99999999999999								
	1786	1787	0.021958453317265994	0.06666939479294227	0.014257564868331	152.0	152.0	152.0	0	0	1	-59.99999999999999	59.99999999999999								
	1786	1977	0.014830133824142572	0.2932817599448004	0.003420878614342401	108.0	108.0	108.0	0.9475	0.0	1	-59.99999999999999	59.99999999999999								
	1786	1798	0.024537118123308808	0.08649173785603417	0.020177007507470892	167.0	167.0	167.0	0	0	1	-59.99999999999999	59.99999999999999								
	1786	1810	0.04661342287408609	0.1426997226847709	0.025947368583506894	153.0	153.0	153.0	0	0	1	-59.99999999999999	59.99999999999999								
	1789	1798	0.012267185435423203	0.040431030419412976	0.009415765742864459	160.0	160.0	160.0	0	0	1	-59.99999999999999	59.99999999999999								
	1789	1815	0.0223065131035992	0.07231457625435429	0.016961357498219705	158.0	158.0	158.0	0	0	1	-59.99999999999999	59.99999999999999								
	1815	1805	0.020135918054998914	0.06953466496511289	0.014567659957351008	165.0	165.0	165.0	0	0	1	-59.99999999999999	59.99999999999999								
	1791	1799	0.004422898853253569	0.014835605277544793	0.003278268316574388	162.0	162.0	162.0	0	0	1	-59.99999999999999	59.99999999999999								
	1791	1805	0.011566739838155697	0.03871216348633358	0.007651264750588685	162.0	162.0	162.0	0	0	1	-59.99999999999999	59.99999999999999								
	1792	1793	0.014918926825001809	0.0531807873239042	0.011303189755585002	168.0	168.0	168.0	0	0	1	-59.99999999999999	59.99999999999999								
	1792	1799	0.00485352673521265	0.016722657739310493	0.0035968554669991108	164.0	164.0	164.0	0	0	1	-59.99999999999999	59.99999999999999								
	1793	1794	0.0179332064768951	0.05785763096215668	0.011996593546969797	158.0	158.0	158.0	0	0	1	-59.99999999999999	59.99999999999999								
	1794	1795	0.003474531492860991	0.011517652309536896	0.002319351489767429	161.0	161.0	161.0	0	0	1	-59.99999999999999	59.99999999999999								
	1795	1799	0.05851995475306181	0.14348861267685897	0.029190969554781905	134.0	134.0	134.0	0	0	1	-59.99999999999999	59.99999999999999								
	1795	1800	0.039110158940236985	0.19382369824033197	0.03532328083072789	204.99999999999997	204.99999999999997	204.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	1795	1800	0.09898993121275682	0.18776614488605892	0.04225371733708309	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1798	1803	0.009943732052803043	0.0333333779147598	0.0076887984114941185	162.0	162.0	162.0	0	0	1	-59.99999999999999	59.99999999999999								
	1800	10099	0.011083243141907052	0.14101353753018947	0.002944729132997216	224.00000000000003	224.00000000000003	224.00000000000003	1.0175	0.0	1	-59.99999999999999	59.99999999999999								
	1804	1808	0.013285283282711205	0.046065253692548686	0.018967511533498797	165.0	165.0	165.0	0	0	1	-59.99999999999999	59.99999999999999								
	1805	1808	0.03640549471192532	0.12274276098469307	0.029151673582736397	162.0	162.0	162.0	0	0	1	-59.99999999999999	59.99999999999999								
	1805	1811	0.09085458520963793	0.2033329293160049	0.03952559263631699	127.0	127.0	127.0	0	0	1	-59.99999999999999	59.99999999999999								
	1807	1808	0.0067930620894497305	0.020634344717340995	0.004545259506547358	152.0	152.0	152.0	0	0	1	-59.99999999999999	59.99999999999999								
	1807	1809	0.016496500077042706	0.054521201772452295	0.01108706704624	160.0	160.0	160.0	0	0	1	-59.99999999999999	59.99999999999999								
	1809	1819	0.007844044910408562	0.04116509947366499	0.009036214529335498	212.0	212.0	212.0	0	0	1	-59.99999999999999	59.99999999999999								
	1810	1811	0.034267142212949714	0.106646995450065	0.020598703856911503	155.0	155.0	155.0	0	0	1	-59.99999999999999	59.99999999999999								
	1811	1812	0.0441534425707534	0.10422737331350801	0.021346413987316196	131.0	131.0	131.0	0	0	1	-59.99999999999999	59.99999999999999								
	1812	1813	0.0740122877125814	0.15013299436677197	0.0294551712381653	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	1816	1817	0.00907692660290282	0.045861641036239485	0.00983149650335312	206.99999999999997	206.99999999999997	206.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	1817	1827	0.008248982617910953	0.0430277959540486	0.008740466211140148	211.0	211.0	211.0	0	0	1	-59.99999999999999	59.99999999999999								
	1819	1821	0.011820628670416802	0.03517812017938119	0.006732222788315272	150.0	150.0	150.0	0	0	1	-59.99999999999999	59.99999999999999								
	1821	1822	0.016878685435429194	0.049248587203212076	0.008115758832022549	149.0	149.0	149.0	0	0	1	-59.99999999999999	59.99999999999999								
	1822	1824	0.0107677948723082	0.033231868633646494	0.005209967390131198	154.0	154.0	154.0	0	0	1	-59.99999999999999	59.99999999999999								
	1824	1825	0.010401466834466001	0.03768915648579599	0.008304148459602149	169.0	169.0	169.0	0	0	1	-59.99999999999999	59.99999999999999								
	1825	1826	0.0024612860071286605	0.0124739549580496	0.002677331425026062	208.0	208.0	208.0	0	0	1	-59.99999999999999	59.99999999999999								
	1825	1828	0.022111748169316	0.07690442935887719	0.015061100977063207	165.0	165.0	165.0	0	0	1	-59.99999999999999	59.99999999999999								
	1826	1827	0.009122197201475498	0.044960339212901865	0.009799769098358226	204.0	204.0	204.0	0	0	1	-59.99999999999999	59.99999999999999								
	1828	1830	0.053214058006499004	0.28081148073201095	0.05857529328584668	213.0	213.0	213.0	0	0	1	-59.99999999999999	59.99999999999999								
	1830	1832	0.045637446269765514	0.2357974373093811	0.055425774615258015	210.0	210.0	210.0	0	0	1	-59.99999999999999	59.99999999999999								
	1831	1833	0.006941831848025321	0.035083815124891685	0.00827778966028243	206.99999999999997	206.99999999999997	206.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	1831	1835	0.012122804105482502	0.08455798356806386	0.026076412697941993	252.0	252.0	252.0	0	0	1	-59.99999999999999	59.99999999999999								
	1831	1839	0.016553907729629405	0.08718727949283078	0.019062274245685015	213.0	213.0	213.0	0	0	1	-59.99999999999999	59.99999999999999								
	1832	1839	0.026500438151657604	0.14056576330112794	0.030426527456520108	214.0	214.0	214.0	0	0	1	-59.99999999999999	59.99999999999999								
	1833	1834	0.017755869111511904	0.040034507184708495	0.007788723428547379	127.0	127.0	127.0	0	0	1	-59.99999999999999	59.99999999999999								
	1834	1835	0.04499098445288839	0.09869179960233616	0.020875666691637606	125.0	125.0	125.0	0	0	1	-59.99999999999999	59.99999999999999								
	1835	1836	0.0027260106697231503	0.021514943194787993	0.0054489833277901615	272.0	272.0	272.0	0	0	1	-59.99999999999999	59.99999999999999								
	1844	1845	0.005077569911587979	0.030502627649799913	0.0005794558033542709	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1846	1847	0.0052062084479816305	0.03238952698141902	0.0005285301813706761	118.0	118.0	118.0	0	0	1	-59.99999999999999	59.99999999999999								
	1846	1890	0.00448208322741091	0.06089291542628778	0.0009865619730670002	189.0	189.0	189.0	0	0	1	-59.99999999999999	59.99999999999999								
	1847	1889	0.00579553107363172	0.034081292097140094	0.0006132574355229733	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1849	1850	0.006284856719761162	0.03881352663338179	0.0006025065828301011	117.0	117.0	117.0	0	0	1	-59.99999999999999	59.99999999999999								
	1850	1948	0.02023821762383919	0.04079699764861731	0.000617403492350131	60.0	60.0	60.0	0	0	1	-59.99999999999999	59.99999999999999								
	1850	1993	0.015521217692010097	0.04291135224832219	0.000803669084832072	72.0	72.0	72.0	0	0	1	-59.99999999999999	59.99999999999999								
	1851	1670	0.0021768131842184795	0.014381807963093693	0.0009954252243041986	122.0	122.0	122.0	0	0	1	-59.99999999999999	59.99999999999999								
	1851	1948	0.010876878534145696	0.035261883162707106	0.0005819795131869611	79.0	79.0	79.0	0	0	1	-59.99999999999999	59.99999999999999								
	1670	1855	0.00344685455928091	0.019954202831773994	0.0010193188851233595	112.99999999999999	112.99999999999999	112.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1853	1856	0.004707046251534481	0.02881341284160319	0.0005513154470734301	117.0	117.0	117.0	0	0	1	-59.99999999999999	59.99999999999999								
	1853	1855	0.010247998668449002	0.03384062687972559	0.0005974919525440781	80.0	80.0	80.0	0	0	1	-59.99999999999999	59.99999999999999								
	1856	1863	0.003362112792167351	0.0213948972185981	0.0003893723726458851	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	1858	1861	0.00929460792168975	0.03154135899234558	0.0018787191797420394	82.0	82.0	82.0	0	0	1	-59.99999999999999	59.99999999999999								
	1858	1864	0.00487805978916585	0.017447216490861006	0.00103910950869322	84.0	84.0	84.0	0	0	1	-59.99999999999999	59.99999999999999								
	1858	1867	0.00738868617018778	0.0331324154646462	0.0010009577464778	97.0	97.0	97.0	0	0	1	-59.99999999999999	59.99999999999999								
	1858	1946	0.002389419779763561	0.016077427107542792	0.000302921552611515	124.0	124.0	124.0	0	0	1	-59.99999999999999	59.99999999999999								
	1858	1946	0.00255921796278562	0.016311580365579597	0.00029412263201549605	120.0	120.0	120.0	0	0	1	-59.99999999999999	59.99999999999999								
	1840	1860	0.011320955048333902	0.023049040959067586	0.00041561243215575795	60.0	60.0	60.0	0	0	1	-59.99999999999999	59.99999999999999								
	1840	1860	0.011068395767826596	0.022344791481792886	0.00040157693568617086	60.0	60.0	60.0	0	0	1	-59.99999999999999	59.99999999999999								
	1840	1858	0.024259698681146802	0.055256378160733685	0.004600930962692949	64.0	64.0	64.0	0	0	1	-59.99999999999999	59.99999999999999								
	1861	1943	0.004830689109331	0.015573493704143902	0.0010337936299387401	79.0	79.0	79.0	0	0	1	-59.99999999999999	59.99999999999999								
	1858	1946	0.0025684859206667196	0.01610694293254989	0.00030992684463970396	118.0	118.0	118.0	0	0	1	-59.99999999999999	59.99999999999999								
	1863	1948	0.00818593295722827	0.04564489076295218	0.0009352426844662989	110.00000000000001	110.00000000000001	110.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1864	1866	0.004889731844607738	0.01584452768261539	0.0010052672717254599	79.0	79.0	79.0	0	0	1	-59.99999999999999	59.99999999999999								
	1866	1869	0.0032554600163921706	0.010521342551773397	0.000577288544392213	79.0	79.0	79.0	0	0	1	-59.99999999999999	59.99999999999999								
	1868	1867	0.017709514504429008	0.0238755691211671	0.000206711522275582	47.0	47.0	47.0	0	0	1	-59.99999999999999	59.99999999999999								
	1869	1870	0.0037051519564166705	0.02350979670616799	0.00039406569080427297	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	1870	1905	0.009311865533045492	0.04780231110742321	0.0012661632441030803	105.0	105.0	105.0	0	0	1	-59.99999999999999	59.99999999999999								
	1870	1873	0.003547150855790819	0.014529007987924891	0.0008180498147383325	92.0	92.0	92.0	0	0	1	-59.99999999999999	59.99999999999999								
	1872	1873	0.0037397329357778696	0.009664518150757069	0.000609926628274843	69.0	69.0	69.0	0	0	1	-59.99999999999999	59.99999999999999								
	1872	1840	0.005582943472862238	0.013629270129930196	0.00502448254287243	67.0	67.0	67.0	0	0	1	-59.99999999999999	59.99999999999999								
	1872	1943	0.00333793721795082	0.011051643026759797	0.000629459478640929	80.0	80.0	80.0	0	0	1	-59.99999999999999	59.99999999999999								
	1875	1880	0.0020021186946379004	0.015489340388919196	0.048172832059292084	134.0	134.0	134.0	0	0	1	-59.99999999999999	59.99999999999999								
	1875	1840	0.012516709082410702	0.0351025647491217	0.0049284018559847004	73.0	73.0	73.0	0	0	1	-59.99999999999999	59.99999999999999								
	1877	1938	0.0014676798528283797	0.011673571696874191	0.00013130904796114195	137.0	137.0	137.0	0	0	1	-59.99999999999999	59.99999999999999								
	1873	1880	0.00188736265872605	0.011162886865436995	0.016134134046509895	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1873	1883	0.004564712669178841	0.028711554875811594	0.00041976919541135394	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	1881	1885	0.015883596032559906	0.02781086087473671	0.0003842253116890789	55.00000000000001	55.00000000000001	55.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1881	1886	0.026005909130731603	0.04558110242080868	0.0006210600965470068	55.00000000000001	55.00000000000001	55.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1881	1887	0.00324295619090088	0.02078884732143949	0.00100233803396113	120.0	120.0	120.0	0	0	1	-59.99999999999999	59.99999999999999								
	1881	1888	0.00440548447824083	0.02743694073088469	0.004111377515522758	118.0	118.0	118.0	0	0	1	-59.99999999999999	59.99999999999999								
	1881	1888	0.004380628097425212	0.0258804479595367	0.004093810324268409	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1881	1890	0.0048436292251572	0.031712044760389184	0.0005840636199060829	122.0	122.0	122.0	0	0	1	-59.99999999999999	59.99999999999999								
	1881	1905	0.00706707496727351	0.034973080301843616	0.0005797206505201761	103.0	103.0	103.0	0	0	1	-59.99999999999999	59.99999999999999								
	1882	1883	0.0022028617523890005	0.012531198300714601	0.00019755969859659695	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1882	2054	0.04464737566068685	1.015171725437736	0.0030498194307449983	32.0	32.0	32.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1882	1905	0.00271832921661437	0.01758507619638	0.00019500734764151296	121.0	121.0	121.0	0	0	1	-59.99999999999999	59.99999999999999								
	1887	1890	0.005255408394509	0.030237897031828817	0.000952912202524021	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1888	1889	0.0110148606971791	0.06547539564848877	0.0012329601722583195	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1891	2065	0.03535634136669337	1.0285751374906578	0.00020334650882441118	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1891	1904	0.0075163195598451395	0.041116621688939564	0.00030451958572491996	109.00000000000001	109.00000000000001	109.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1893	1907	0.0032662006410677	0.018732868531048292	0.002362316742539411	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1893	1908	0.0062984982018358966	0.020781599110476688	0.005871951667480169	80.0	80.0	80.0	0	0	1	-59.99999999999999	59.99999999999999								
	1894	1895	0.018752688796436403	0.026254987948825588	0.000796670004315674	48.0	48.0	48.0	0	0	1	-59.99999999999999	59.99999999999999								
	1894	1903	0.0031404838320845704	0.016110076626855895	0.0358867481446359	105.0	105.0	105.0	0	0	1	-59.99999999999999	59.99999999999999								
	1894	1908	0.005842919631209219	0.023729809475094094	0.000392338880486786	91.0	91.0	91.0	0	0	1	-59.99999999999999	59.99999999999999								
	1895	1908	0.0023501394270826104	0.011807412318745599	0.0355886677007191	104.0	104.0	104.0	0	0	1	-59.99999999999999	59.99999999999999								
	1901	1902	0.022391279178773996	0.034281761699994084	0.0006134896522387861	51.0	51.0	51.0	0	0	1	-59.99999999999999	59.99999999999999								
	1901	1923	0.0117795941259712	0.06927952191140498	0.0012218191923759904	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1908	1907	0.0063756630751490625	0.022970670026885295	0.002395199972279371	85.0	85.0	85.0	0	0	1	-59.99999999999999	59.99999999999999								
	1910	1876	0.004933838600367307	0.012784277520440493	0.005723374705296007	69.0	69.0	69.0	0	0	1	-59.99999999999999	59.99999999999999								
	1912	1923	0.00704181060640141	0.04616905755944549	0.057724013239424686	122.0	122.0	122.0	0	0	1	-59.99999999999999	59.99999999999999								
	1912	1923	0.007606822031717751	0.044624381730519184	0.021342916054842096	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1912	1950	0.009561990186404443	0.04085473546698219	0.0176325347201899	94.0	94.0	94.0	0	0	1	-59.99999999999999	59.99999999999999								
	1912	1950	0.00862213088493794	0.051081996133886295	0.00100168328578584	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1913	1914	0.00447328368121758	0.02512682397147639	0.00958508263379335	111.00000000000001	111.00000000000001	111.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1913	1950	0.0038498121986165596	0.023487155915750187	0.003632344291303308	115.99999999999999	115.99999999999999	115.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1914	1915	0.005757992173945531	0.019594961094148492	0.0006216493448708209	82.0	82.0	82.0	0	0	1	-59.99999999999999	59.99999999999999								
	1914	1953	0.00262759569686372	0.0171523056369647	0.00020340031254105303	121.0	121.0	121.0	0	0	1	-59.99999999999999	59.99999999999999								
	1915	1876	0.003709512242283669	0.013181560342577291	0.00019048715069889995	84.0	84.0	84.0	0	0	1	-59.99999999999999	59.99999999999999								
	1915	1917	0.0148554907017387	0.030277830654475802	0.00454541735615581	60.0	60.0	60.0	0	0	1	-59.99999999999999	59.99999999999999								
	1915	1918	0.014812944196863105	0.031101194530809322	0.004268603289648889	61.0	61.0	61.0	0	0	1	-59.99999999999999	59.99999999999999								
	1919	1950	0.00821658861508593	0.04975827934505418	0.0010216769204940603	115.99999999999999	115.99999999999999	115.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1912	1931	0.015980853815069404	0.06354288076779342	0.0011434599422849702	90.0	90.0	90.0	0	0	1	-59.99999999999999	59.99999999999999								
	1921	1923	0.006888202936509621	0.018006180463717294	0.00020324260360561294	70.0	70.0	70.0	0	0	1	-59.99999999999999	59.99999999999999								
	1923	1924	0.00261238919163588	0.015188554421737794	0.00020059061267413208	112.99999999999999	112.99999999999999	112.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1923	1929	0.027964866762533805	0.041756843122467385	0.0005791907741781319	50.0	50.0	50.0	0	0	1	-59.99999999999999	59.99999999999999								
	1923	1930	0.007652484259754419	0.024492810752596687	0.0004018163247406478	79.0	79.0	79.0	0	0	1	-59.99999999999999	59.99999999999999								
	1923	1953	0.00624818475013599	0.037464017027020485	0.0006149966830573977	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1924	1925	0.0039710081470850905	0.022304306104034197	0.00041816111069172603	111.00000000000001	111.00000000000001	111.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1925	1926	0.0033847888454329195	0.02178793015175959	0.00041424961585551497	120.0	120.0	120.0	0	0	1	-59.99999999999999	59.99999999999999								
	1926	1876	0.004297708284347319	0.022242160329567287	0.00039338292649015793	105.0	105.0	105.0	0	0	1	-59.99999999999999	59.99999999999999								
	1876	1763	0.0012307238993708664	0.07546785382996916	0.01182869407628513	419.00000000000006	419.00000000000006	419.00000000000006	1.012658227848101	0.0	1	-59.99999999999999	59.99999999999999								
	1930	1950	0.006001674975492062	0.037744578697253	0.0006125493864901359	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	1931	1932	0.00837761005997658	0.047882527258917694	0.0009906059839297093	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1931	1932	0.008384463862376292	0.04746801371739249	0.0010045327982399603	111.00000000000001	111.00000000000001	111.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1931	1933	0.0188558840945154	0.10897111855239097	0.0020934091992150096	112.99999999999999	112.99999999999999	112.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1931	1934	0.047312879635160815	0.07694531696867198	0.0010089448022190498	52.0	52.0	52.0	0	0	1	-59.99999999999999	59.99999999999999								
	1931	1936	0.029735069506777904	0.09392082755994559	0.0019874527296982695	78.0	78.0	78.0	0	0	1	-59.99999999999999	59.99999999999999								
	1932	1935	0.010302485277503699	0.030781057937862292	0.000599789825398475	76.0	76.0	76.0	0	0	1	-59.99999999999999	59.99999999999999								
	1933	1935	0.011140717928130203	0.0311039559273981	0.0005913554882258181	73.0	73.0	73.0	0	0	1	-59.99999999999999	59.99999999999999								
	1933	1949	0.0108647293751477	0.03242830454792359	0.0009649137524664396	76.0	76.0	76.0	0	0	1	-59.99999999999999	59.99999999999999								
	1937	1949	0.022980849933924595	0.06666278823528997	0.0009203368922173974	74.0	74.0	74.0	0	0	1	-59.99999999999999	59.99999999999999								
	1954	1955	0.0515208179588616	0.09739085018894629	0.00152670968562365	56.99999999999999	56.99999999999999	56.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1955	1993	0.015994273357121294	0.04431003973379728	0.0008118966334685676	72.0	72.0	72.0	0	0	1	-59.99999999999999	59.99999999999999								
	1975	1977	0.09496326820023823	0.19070194225969694	9.770200178958478e-5	30.0	30.0	30.0	0	0	1	-59.99999999999999	59.99999999999999								
	1976	1977	0.037917906544273704	0.051489263789532676	0.00019358983721584099	24.0	24.0	24.0	0	0	1	-59.99999999999999	59.99999999999999								
	2152	2156	0.008344505284960379	0.037105775682181076	0.0038886672524227786	160.0	160.0	160.0	0	0	1	-59.99999999999999	59.99999999999999								
	2153	2156	0.006612602031002754	0.017109146623965392	0.0016563345429301303	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	2153	2156	0.005506519284810398	0.01496983999272579	0.0017271481722616598	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	2155	2153	0.013939727080035998	0.10292674293550903	0.012307472631685403	218.00000000000003	218.00000000000003	218.00000000000003	0	0	1	-59.99999999999999	59.99999999999999								
	2156	2157	0.0254533465899588	0.07215540384607336	0.006800530361052142	122.0	122.0	122.0	0	0	1	-59.99999999999999	59.99999999999999								
	2157	2172	0.02999910991285181	0.08544870272021178	0.008448748178319075	122.0	122.0	122.0	0	0	1	-59.99999999999999	59.99999999999999								
	2158	2153	0.04463171725285978	0.07024435167216506	0.005571387344682591	85.0	85.0	85.0	0	0	1	-59.99999999999999	59.99999999999999								
	2160	2166	0.002217818070936019	0.015054231287409592	0.0016355893109589795	206.99999999999997	206.99999999999997	206.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	2161	2166	0.009794861790234215	0.02494720302135499	0.002968596249282359	113.99999999999999	113.99999999999999	113.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	2161	2167	0.022569879982047694	0.05988417779164287	0.006609730931470169	117.0	117.0	117.0	0	0	1	-59.99999999999999	59.99999999999999								
	2162	2163	0.0368750920058191	0.07127163929548117	0.0162320841231802	97.0	97.0	97.0	0	0	1	-59.99999999999999	59.99999999999999								
	2162	2164	0.13317272760672502	0.242714886019933	0.0159793607747415	93.0	93.0	93.0	0	0	1	-59.99999999999999	59.99999999999999								
	2162	2229	0.012501498767733602	0.09062168087871282	0.03402989954268561	215.0	215.0	215.0	0	0	1	-59.99999999999999	59.99999999999999								
	2163	2164	0.10060914863677697	0.1762482383539389	0.0157835522057069	91.0	91.0	91.0	0	0	1	-59.99999999999999	59.99999999999999								
	2164	2165	0.00386886836306751	0.010376907300827996	0.0011530489629087996	118.0	118.0	118.0	0	0	1	-59.99999999999999	59.99999999999999								
	2164	2166	0.0548456849238351	0.14605102686716293	0.015865389144659	117.0	117.0	117.0	0	0	1	-59.99999999999999	59.99999999999999								
	2164	2226	0.03220120076421179	0.08498370296025178	0.009049204976200126	117.0	117.0	117.0	0	0	1	-59.99999999999999	59.99999999999999								
	2165	2167	0.03265710417714621	0.08410553118825326	0.009557468426549814	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	2166	2168	0.0094845087677706	0.05040768457602759	0.006227096123760101	178.0	178.0	178.0	0	0	1	-59.99999999999999	59.99999999999999								
	2166	2169	0.021352137328784	0.08316763165316725	0.009389051099738569	148.0	148.0	148.0	0	0	1	-59.99999999999999	59.99999999999999								
	2166	2170	0.006484337441509589	0.03443856679479398	0.00404136947009386	178.0	178.0	178.0	0	0	1	-59.99999999999999	59.99999999999999								
	2166	2170	0.00693898262637388	0.032642249958517985	0.004250792714192071	166.0	166.0	166.0	0	0	1	-59.99999999999999	59.99999999999999								
	2168	2169	0.012330789449186997	0.03281061694200618	0.0034713036957755698	117.0	117.0	117.0	0	0	1	-59.99999999999999	59.99999999999999								
	2171	2172	0.030115664385611692	0.07960466187231983	0.008493227195844522	117.0	117.0	117.0	0	0	1	-59.99999999999999	59.99999999999999								
	2172	2227	0.043853785448283	0.11777375572089094	0.010752625594792904	118.0	118.0	118.0	0	0	1	-59.99999999999999	59.99999999999999								
	2173	2175	0.0036354707360034782	0.009799229272231452	0.0013204602313251195	118.0	118.0	118.0	0	0	1	-59.99999999999999	59.99999999999999								
	2173	2228	0.00817779703512788	0.016697325252618588	0.0016922451391965193	100.0	100.0	100.0	0	0	1	-59.99999999999999	59.99999999999999								
	2174	2175	0.00345243411819823	0.009417775688662653	0.0010653063090518096	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	2176	2177	0.005443984630722551	0.018950843333029193	0.0013044606222384608	138.0	138.0	138.0	0	0	1	-59.99999999999999	59.99999999999999								
	2176	2178	0.016235662227007595	0.07280548926056826	0.00196806784169748	161.0	161.0	161.0	0	0	1	-59.99999999999999	59.99999999999999								
	2176	2224	0.039440877304365886	0.1379526327592129	0.0041444190107286	138.0	138.0	138.0	0	0	1	-59.99999999999999	59.99999999999999								
	2177	2224	0.047367225759266905	0.1599663523930119	0.003950881932675842	135.0	135.0	135.0	0	0	1	-59.99999999999999	59.99999999999999								
	2178	2238	0.03418951243213098	0.13430156701253695	0.018231527371257498	148.0	148.0	148.0	0	0	1	-59.99999999999999	59.99999999999999								
	2180	2126	0.050705952685127474	0.6867452991275059	0.0013541401145704007	46.0	46.0	46.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2180	2189	0.0392573585555311	0.058002956481976384	0.004940463718026882	82.0	82.0	82.0	0	0	1	-59.99999999999999	59.99999999999999								
	2180	2323	0.03007769100522989	0.05185581050061807	0.00394640633368772	90.0	90.0	90.0	0	0	1	-59.99999999999999	59.99999999999999								
	2183	2217	0.022092430227871503	0.06483366400483899	0.006061390816604723	124.0	124.0	124.0	0	0	1	-59.99999999999999	59.99999999999999								
	2183	2323	0.0189442508493876	0.057645648069029685	0.005098807709572841	127.0	127.0	127.0	0	0	1	-59.99999999999999	59.99999999999999								
	2217	2323	0.04188953500150953	0.11629788020967574	0.01091064523580617	120.0	120.0	120.0	0	0	1	-59.99999999999999	59.99999999999999								
	2186	2190	0.021955375649680378	0.07907001240310814	0.009699590603645893	141.0	141.0	141.0	0	0	1	-59.99999999999999	59.99999999999999								
	2186	2323	0.09326695346117021	0.18336831321998492	0.015992638318470705	98.0	98.0	98.0	0	0	1	-59.99999999999999	59.99999999999999								
	2186	2190	0.0219083921358204	0.08569771567657117	0.009593339979723566	148.0	148.0	148.0	0	0	1	-59.99999999999999	59.99999999999999								
	2186	2323	0.09514051628585721	0.17641832405948105	0.0165238766949186	94.0	94.0	94.0	0	0	1	-59.99999999999999	59.99999999999999								
	2192	2198	0.011307095644697498	0.050853422247963	0.0066380290927514395	161.0	161.0	161.0	0	0	1	-59.99999999999999	59.99999999999999								
	2192	2217	0.0809689857371156	0.1597802651584059	0.056354651273721794	98.0	98.0	98.0	0	0	1	-59.99999999999999	59.99999999999999								
	2193	2194	0.0032044757057726383	0.013751261481909093	0.0017782006577542107	157.0	157.0	157.0	0	0	1	-59.99999999999999	59.99999999999999								
	2193	2194	0.0032290101088583486	0.013860228257736697	0.0016375393909076202	157.0	157.0	157.0	0	0	1	-59.99999999999999	59.99999999999999								
	2193	2194	0.0016134275212101603	0.011403984225341099	0.001203772326814941	212.0	212.0	212.0	0	0	1	-59.99999999999999	59.99999999999999								
	2193	2195	0.004667560147074981	0.022093079821914392	0.002608203896095512	166.0	166.0	166.0	0	0	1	-59.99999999999999	59.99999999999999								
	2193	2205	0.016025860995871506	0.04450729081711919	0.004873642972311002	120.0	120.0	120.0	0	0	1	-59.99999999999999	59.99999999999999								
	2193	2206	0.018822100750030907	0.05135977957566779	0.009270280247638	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	2193	2190	0.020571035576420794	0.057842618269473275	0.0056833629987463295	121.0	121.0	121.0	0	0	1	-59.99999999999999	59.99999999999999								
	2194	2195	0.0035544225968974596	0.011513761437893797	0.001307409372017721	132.0	132.0	132.0	0	0	1	-59.99999999999999	59.99999999999999								
	2194	10112	0.0028167553151113517	0.5265638401811447	0.07146267139932008	60.0	60.0	60.0	0.9877	0.0	1	-59.99999999999999	59.99999999999999								
	2194	2190	0.02196498516699759	0.06413143185821828	0.0006049942965712399	124.0	124.0	124.0	0	0	1	-59.99999999999999	59.99999999999999								
	2195	2198	0.0023173713241238093	0.010041276186469895	0.0010677093091681603	157.0	157.0	157.0	0	0	1	-59.99999999999999	59.99999999999999								
	2198	2203	0.0160672604063814	0.043755847347271594	0.004683966385252774	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	2198	2212	0.028596394840087695	0.07321992307483166	0.00825107615814172	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	2198	2232	0.004106622394144528	0.019969698820574186	0.0023196850752197212	169.0	169.0	169.0	0	0	1	-59.99999999999999	59.99999999999999								
	2198	2233	0.0039049297694112206	0.01879100063518159	0.0024277343462128197	168.0	168.0	168.0	0	0	1	-59.99999999999999	59.99999999999999								
	2200	2232	0.0033161570859551394	0.01508967043159159	0.001914417166847269	162.0	162.0	162.0	0	0	1	-59.99999999999999	59.99999999999999								
	2201	2233	0.00310765717618354	0.016267309971123894	0.0019262018873984898	177.0	177.0	177.0	0	0	1	-59.99999999999999	59.99999999999999								
	2202	2203	0.21097341708658304	0.18420501825211993	0.014928586995494606	60.0	60.0	60.0	0	0	1	-59.99999999999999	59.99999999999999								
	2203	2313	0.040314665182303616	0.6623830614989182	0.0033816566824145435	48.0	48.0	48.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	2204	2205	0.005585450999891389	0.015678477831796694	0.0015940749001358597	121.0	121.0	121.0	0	0	1	-59.99999999999999	59.99999999999999								
	2204	2206	0.006025723639337348	0.014902195548059391	0.0016651932186130404	112.00000000000001	112.00000000000001	112.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	2205	2209	0.022830568767450796	0.06376820462110547	0.006229202903599942	121.0	121.0	121.0	0	0	1	-59.99999999999999	59.99999999999999								
	2206	2207	0.046753323149823986	0.044651792523229976	0.0037617549813538805	63.0	63.0	63.0	0	0	1	-59.99999999999999	59.99999999999999								
	2207	2209	0.0719883445636779	0.06116331989835708	0.004695094143772032	59.0	59.0	59.0	0	0	1	-59.99999999999999	59.99999999999999								
	2209	2237	0.0348107242368609	0.050860457719922994	0.005245086064070464	82.0	82.0	82.0	0	0	1	-59.99999999999999	59.99999999999999								
	2210	2237	0.0032696363180764005	0.014534249260523395	0.00145874859141419	160.0	160.0	160.0	0	0	1	-59.99999999999999	59.99999999999999								
	2190	2323	0.13769185404576798	0.27944169713767186	0.023672072419078996	99.0	99.0	99.0	0	0	1	-59.99999999999999	59.99999999999999								
	2214	2220	0.005464037500342819	0.017164896468018897	0.00589143396744318	130.0	130.0	130.0	0	0	1	-59.99999999999999	59.99999999999999								
	2214	2220	0.0036475865059918695	0.028606747968819908	0.0004142632371746001	225.99999999999997	225.99999999999997	225.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	2215	2219	0.004673632000540381	0.018428991958795094	0.002451526928767562	149.0	149.0	149.0	0	0	1	-59.99999999999999	59.99999999999999								
	2219	2141	0.008430360916196072	0.1951966380094121	0.002371865527098911	162.0	162.0	162.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	2217	2219	0.038399645852949485	0.15647706117222088	0.0190922336806916	152.0	152.0	152.0	0	0	1	-59.99999999999999	59.99999999999999								
	2219	2137	1.2009799194082356	2	0.009275864248733745	1000	8.0	8.0	1.0314699999999999	0.0	1	-59.99999999999999	59.99999999999999								
	2219	2220	0.044756923604968905	0.12890038560204198	0.012667304816233908	123.0	123.0	123.0	0	0	1	-59.99999999999999	59.99999999999999								
	2219	2220	0.042474895608302185	0.11866241323918093	0.012016867148067802	121.0	121.0	121.0	0	0	1	-59.99999999999999	59.99999999999999								
	2219	2222	0.149471301929355	0.24283808096768486	0.019603325069821903	87.0	87.0	87.0	0	0	1	-59.99999999999999	59.99999999999999								
	2220	2224	0.0051782136404886795	0.025746951259076587	0.00295509923136234	171.0	171.0	171.0	0	0	1	-59.99999999999999	59.99999999999999								
	2220	2224	0.0051302910358533285	0.026152703162386985	0.003191748296881089	174.0	174.0	174.0	0	0	1	-59.99999999999999	59.99999999999999								
	2222	2231	0.10731612292516596	0.1634551194820719	0.014614566812057498	84.0	84.0	84.0	0	0	1	-59.99999999999999	59.99999999999999								
	2223	2225	0.0009853019952513276	0.008801583923071616	0.0366018740284299	244.0	244.0	244.0	0	0	1	-59.99999999999999	59.99999999999999								
	2223	2214	0.0015910540425330395	0.014708088120607692	0.04392845341656361	249.00000000000003	249.00000000000003	249.00000000000003	0	0	1	-59.99999999999999	59.99999999999999								
	2239	2243	0.00360884330952633	0.027201353864564088	0.052577014935982914	440.00000000000006	440.00000000000006	440.00000000000006	0	0	1	-59.99999999999999	59.99999999999999								
	2240	2243	0.00368515181837697	0.027291844710027293	0.05425249994394511	434.99999999999994	434.99999999999994	434.99999999999994	0	0	1	-59.99999999999999	59.99999999999999								
	2241	2243	0.00172089511687309	0.013583358020678197	0.025361995731093902	453.0	453.0	453.0	0	0	1	-59.99999999999999	59.99999999999999								
	2242	2243	0.005162631960686299	0.04012785024074558	0.07237259845727778	448.00000000000006	448.00000000000006	448.00000000000006	0	0	1	-59.99999999999999	59.99999999999999								
	2243	2249	0.008711778118244369	0.06757408855681027	0.12138338313257402	448.00000000000006	448.00000000000006	448.00000000000006	0	0	1	-59.99999999999999	59.99999999999999								
	2243	2249	0.00802602507800888	0.06747312326906667	0.117713203228534	470.0	470.0	470.0	0	0	1	-59.99999999999999	59.99999999999999								
	2244	2249	0.00683352590427361	0.03877333288070088	0.0597080006736307	370.0	370.0	370.0	0	0	1	-59.99999999999999	59.99999999999999								
	2249	2329	0.013345510709732382	0.20068051442716756	0.04958931019778054	158.0	158.0	158.0	1.0681000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	2247	2249	0.0038375613989867306	0.0192588914578073	0.034801096088429906	344.0	344.0	344.0	0	0	1	-59.99999999999999	59.99999999999999								
	2249	2164	0.011606877635737787	0.14077961302898126	0.0633475515842874	224.00000000000003	224.00000000000003	224.00000000000003	1.0113099999999997	0.0	1	-59.99999999999999	59.99999999999999								
	2249	2250	0.00791666807699157	0.05727606139280268	0.08987527121134571	429.0	429.0	429.0	0	0	1	-59.99999999999999	59.99999999999999								
	2249	2250	0.00826038602419943	0.056684808072708474	0.09133500153360895	416.0	416.0	416.0	0	0	1	-59.99999999999999	59.99999999999999								
	2249	2269	0.0149387624799768	0.07040945665055597	0.10612777813635399	331.0	331.0	331.0	0	0	1	-59.99999999999999	59.99999999999999								
	2250	2270	0.009362156983057503	0.04063722666761742	0.07106541321416573	315.0	315.0	315.0	0	0	1	-59.99999999999999	59.99999999999999								
	2250	2270	0.009530805970702322	0.043717642190850774	0.0702173933262304	326.0	326.0	326.0	0	0	1	-59.99999999999999	59.99999999999999								
	2255	2259	0.004241384766482749	0.020566626998593095	0.030180928545248197	337.0	337.0	337.0	0	0	1	-59.99999999999999	59.99999999999999								
	2255	2262	0.016451510198609902	0.06823589374251939	0.11328297936569907	306.0	306.0	306.0	0	0	1	-59.99999999999999	59.99999999999999								
	2255	2268	0.006554625481029969	0.0304432815257479	0.04265818446549031	328.0	328.0	328.0	0	0	1	-59.99999999999999	59.99999999999999								
	2255	2268	0.0034343574328785796	0.025992298511858088	0.0477408341363221	441.0	441.0	441.0	0	0	1	-59.99999999999999	59.99999999999999								
	2259	2262	0.011067516472307002	0.05200116913262708	0.08565493517649549	330.0	330.0	330.0	0	0	1	-59.99999999999999	59.99999999999999								
	2261	2262	0.0132215266532078	0.08934000322618614	0.157666756026846	412.0	412.0	412.0	0	0	1	-59.99999999999999	59.99999999999999								
	2261	2262	0.0145171332655661	0.09384263004780985	0.16864495484053596	401.0	401.0	401.0	0	0	1	-59.99999999999999	59.99999999999999								
	2263	2268	0.0131560796875316	0.08245822682780489	0.142504390295667	393.0	393.0	393.0	0	0	1	-59.99999999999999	59.99999999999999								
	2263	2268	0.0129197396136872	0.07960153239614139	0.14335068766018808	389.0	389.0	389.0	0	0	1	-59.99999999999999	59.99999999999999								
	2269	2142	0.005349792141510688	0.18297758712940976	0.00877871706562047	173.0	173.0	173.0	1.0681000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	2269	2144	0.005529170436296137	0.18471523476496238	0.008603787979386346	171.0	171.0	171.0	1.0681000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	2269	2145	0.006169406944787759	0.1754504235860824	0.008932604579924874	180.0	180.0	180.0	1.0681000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	2268	2269	0.00471877332513453	0.037673513068374194	0.07144203405168699	455.99999999999994	455.99999999999994	455.99999999999994	0	0	1	-59.99999999999999	59.99999999999999								
	2268	2269	0.00464160583745129	0.037767269676327694	0.065808905726355	461.00000000000006	461.00000000000006	461.00000000000006	0	0	1	-59.99999999999999	59.99999999999999								
	2269	2270	0.005965317068033853	0.02707416449344809	0.04834607142248052	323.0	323.0	323.0	0	0	1	-59.99999999999999	59.99999999999999								
	2269	2270	0.006190359822582452	0.02790267091651909	0.04900640736034512	322.0	322.0	322.0	0	0	1	-59.99999999999999	59.99999999999999								
	2315	2320	0.03784430952750661	0.05655182605726039	0.00156248425743124	17.0	17.0	17.0	0	0	1	-59.99999999999999	59.99999999999999								
	2315	2320	0.039047904520053404	0.057086060786619285	0.0016678225677805004	17.0	17.0	17.0	0	0	1	-59.99999999999999	59.99999999999999								
	487	188	0.002008692702794914	0.07197412379815199	0.0	681.0	681.0	681.0	0	0	1	-59.99999999999999	59.99999999999999								
	227	632	5.778934160128803e-5	0.6701101689838111	3.8341804080941686e-5	48.0	48.0	48.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	262	32	0.004227497141420586	0.2111177432268184	-4.999999998780915e-7	150.0	150.0	150.0	0.9900000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	280	487	0.00281889042970119	0.015882325277021193	0.0	221.0	221.0	221.0	0	0	1	-59.99999999999999	59.99999999999999								
	349	585	0.018051913549495903	0.042773781500473694	0.0	66.0	66.0	66.0	0	0	1	-59.99999999999999	59.99999999999999								
	349	636	0.022961551952860308	0.053418154205318986	0.0	65.0	65.0	65.0	0	0	1	-59.99999999999999	59.99999999999999								
	377	595	0.002077550852084653	0.06839249930691109	9.725448482839822e-6	462.0	462.0	462.0	1.0875	0.0	1	-59.99999999999999	59.99999999999999								
	401	102	0.0006698522088540944	0.09674209418752407	-4.999999999999996e-7	327.0	327.0	327.0	0.9905660377358491	0.0	1	-59.99999999999999	59.99999999999999								
	408	175	0.006881144681764333	0.030935970587637314	0.0022976687839784977	193.0	193.0	193.0	0	0	1	-59.99999999999999	59.99999999999999								
	489	587	0.011264405265823002	0.0283366808093153	0.0	68.0	68.0	68.0	0	0	1	-59.99999999999999	59.99999999999999								
	489	636	0.04899708044654692	0.131200769338244	0.0	71.0	71.0	71.0	0	0	1	-59.99999999999999	59.99999999999999								
	533	590	0.011799231773270299	0.052905735717811604	0.0	49.0	49.0	49.0	0	0	1	-59.99999999999999	59.99999999999999								
	585	588	0.020245905330708705	0.04758259148578211	0.0	65.0	65.0	65.0	0	0	1	-59.99999999999999	59.99999999999999								
	585	636	0.018691705160043197	0.042062855394906375	0.0	64.0	64.0	64.0	0	0	1	-59.99999999999999	59.99999999999999								
	587	636	0.043294958264357405	0.10654884205134597	0.0	67.0	67.0	67.0	0	0	1	-59.99999999999999	59.99999999999999								
	588	636	0.08568855755979517	0.1254740961053499	0.0	49.0	49.0	49.0	0	0	1	-59.99999999999999	59.99999999999999								
	661	765	0.004883281723067159	0.26588381343241785	0.0	1463.0	1463.0	1463.0	0	0	1	-59.99999999999999	59.99999999999999								
	683	781	0.005089311827999539	0.2968359199324622	0.0	1525.0	1525.0	1525.0	0	0	1	-59.99999999999999	59.99999999999999								
	742	749	0.00657579770874956	0.03235503536332868	0.009573139353609803	340.0	340.0	340.0	0	0	1	-59.99999999999999	59.99999999999999								
	749	742	0.006176475449348803	0.028966297453734993	0.0	330.0	330.0	330.0	0	0	1	-59.99999999999999	59.99999999999999								
	749	868	0.0018584926793508863	0.09788807074686916	-4.999999999156968e-7	323.0	323.0	323.0	0.9805	0.0	1	-59.99999999999999	59.99999999999999								
	846	742	0.001993755565892737	0.1256233984243702	-4.999999999999992e-7	252.0	252.0	252.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	911	922	0.018392521937750293	0.07804809380481016	0.0	94.0	94.0	94.0	0	0	1	-59.99999999999999	59.99999999999999								
	911	922	0.018340761289531392	0.08118278235654347	0.0	96.0	96.0	96.0	0	0	1	-59.99999999999999	59.99999999999999								
	937	938	0.0017218477687332796	0.16565245610708396	0.0	206.99999999999997	206.99999999999997	206.99999999999997	0	0	1	-59.99999999999999	59.99999999999999								
	1202	1019	0.0037687275825217365	0.12754133825872108	-4.999999998874906e-7	248.0	248.0	248.0	0.9565217391304348	0.0	1	-59.99999999999999	59.99999999999999								
	1202	1019	0.0030139922370965135	0.12533397559098114	-4.999999998954853e-7	252.0	252.0	252.0	0.9565217391304348	0.0	1	-59.99999999999999	59.99999999999999								
	1102	1424	0.0006470810803960764	0.17776914771684232	-4.999999999522982e-7	178.0	178.0	178.0	0.9625000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1243	1588	0.0005076983203215749	0.05030669242812824	-4.999999999999994e-7	628.0	628.0	628.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1297	1298	0.006241527140946906	0.17928108366555806	0.00010163118178090346	177.0	177.0	177.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1297	1298	0.006069268500766476	0.16328413745145492	9.478280337285767e-5	194.0	194.0	194.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1322	1325	0.008148168984908158	0.3811694044326865	2.007633108859305e-5	83.0	83.0	83.0	1.0113	0.0	1	-59.99999999999999	59.99999999999999								
	1343	1606	0.004362300372226005	0.15655088496814334	-4.999999999999994e-7	202.0	202.0	202.0	0.9638554216867469	0.0	1	-59.99999999999999	59.99999999999999								
	1345	10084	0.025349152725217643	1.1223202736665272	0.0	28.999999999999996	28.999999999999996	28.999999999999996	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1384	1154	0.009025312901263415	0.2842027202697339	-4.999999999999996e-7	112.00000000000001	112.00000000000001	112.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1474	1404	0.03919497983420272	0.5608406076132073	-4.999999999922837e-7	56.99999999999999	56.99999999999999	56.99999999999999	0.9999999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1740	1853	0.019478223231621107	0.06158674937370229	0.0	78.0	78.0	78.0	0	0	1	-59.99999999999999	59.99999999999999								
	1805	1961	0.0032780764148326673	0.11724226626329412	-4.99999999995136e-7	270.0	270.0	270.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	1974	1652	0.039720475497385596	0.29717700131755453	-4.999999966741841e-7	106.0	106.0	106.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1975	1976	0.06670651233773679	0.1873092269806189	0.0	37.0	37.0	37.0	0	0	1	-59.99999999999999	59.99999999999999								
	1729	1763	0.0005260134214801934	0.005409491170909093	0.04652925354465123	664.0	664.0	664.0	0	0	1	-59.99999999999999	59.99999999999999								
	1729	1764	0.00016265877536318177	0.0017074387091702487	0.14741354104657609	673.0	673.0	673.0	0	0	1	-59.99999999999999	59.99999999999999								
	1751	1752	0.00020874054100443088	0.0018545889916165299	0.1357171790496775	608.0	608.0	608.0	0	0	1	-59.99999999999999	59.99999999999999								
	1751	1753	0.0010157054211832836	0.011428291927537193	0.022024252428509923	701.0	701.0	701.0	0	0	1	-59.99999999999999	59.99999999999999								
	1740	1905	0.004868751275509499	0.03613124545454544	0.006966258236390701	131.0	131.0	131.0	0	0	1	-59.99999999999999	59.99999999999999								
	1841	1858	0.003629606117789336	0.02487253533057851	0.010119579001234334	125.0	125.0	125.0	0	0	1	-59.99999999999999	59.99999999999999								
	1841	1858	0.003733579173569051	0.024033265002295683	0.010472966790602058	120.0	120.0	120.0	0	0	1	-59.99999999999999	59.99999999999999								
	1841	1905	0.014436362375182947	0.08137647447199264	0.003093026428976213	111.00000000000001	111.00000000000001	111.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1841	1938	0.006307705213295981	0.047373019111570235	0.005313142184288336	132.0	132.0	132.0	0	0	1	-59.99999999999999	59.99999999999999								
	1841	1867	0.005053745736416663	0.03213516548438935	0.007832528087059403	119.0	119.0	119.0	0	0	1	-59.99999999999999	59.99999999999999								
	1729	1715	0.0008102121591399774	0.008866081226578516	0.028389045826045733	690.0	690.0	690.0	0	0	1	-59.99999999999999	59.99999999999999								
	1848	1849	0.003454386737852146	0.02371275876951331	0.01061452143486497	125.0	125.0	125.0	0	0	1	-59.99999999999999	59.99999999999999								
	1848	1851	0.0078060592830908205	0.04987567054637281	0.00504654039698091	120.0	120.0	120.0	0	0	1	-59.99999999999999	59.99999999999999								
	1890	1904	0.006263266606258149	0.03750894887511478	0.006710387621812854	114.99999999999999	114.99999999999999	114.99999999999999	0	0	1	-59.99999999999999	59.99999999999999								
	1891	1894	0.006103584238630432	0.034584409102387505	0.007277833936489186	111.00000000000001	111.00000000000001	111.00000000000001	0	0	1	-59.99999999999999	59.99999999999999								
	1891	1895	0.00897859962522523	0.05804102052341597	0.004336580989943759	121.0	121.0	121.0	0	0	1	-59.99999999999999	59.99999999999999								
	1892	1900	0.0025495264595881634	0.018424636053719006	0.013661034362085862	129.0	129.0	129.0	0	0	1	-59.99999999999999	59.99999999999999								
	1900	1901	0.006838349811800421	0.04724148109504133	0.005327935966537698	126.0	126.0	126.0	0	0	1	-59.99999999999999	59.99999999999999								
	1908	1945	0.0003250376856711629	0.0035714182897153344	0.07047608703903552	166.0	166.0	166.0	0	0	1	-59.99999999999999	59.99999999999999								
	1729	1749	0.0008073700399119964	0.005841328509223143	0.04308944204068668	536.0	536.0	536.0	0	0	1	-59.99999999999999	59.99999999999999								
	1729	1749	0.0009189314951460607	0.00711211446743802	0.035390260855777615	559.0	559.0	559.0	0	0	1	-59.99999999999999	59.99999999999999								
	1729	1751	0.002602383485534825	0.02251616704462811	0.011178616046856504	598.0	598.0	598.0	0	0	1	-59.99999999999999	59.99999999999999								
	1715	1742	0.0004890002486766705	0.004973607758320663	0.05060704391448987	660.0	660.0	660.0	0	0	1	-59.99999999999999	59.99999999999999								
	1715	1759	0.0010603074854928195	0.0063034386815206634	0.03993052030103359	476.0	476.0	476.0	0	0	1	-59.99999999999999	59.99999999999999								
	1742	1745	0.0005350636468944854	0.005387302370380168	0.04672089460258375	656.0	656.0	656.0	0	0	1	-59.99999999999999	59.99999999999999								
	1745	1764	5.804349631481176e-5	0.0005835615175537192	0.4313162857172318	655.0	655.0	655.0	0	0	1	-59.99999999999999	59.99999999999999								
	1729	1753	0.0026589780007418872	0.027647327579504142	0.009103939088325281	669.0	669.0	669.0	0	0	1	-59.99999999999999	59.99999999999999								
	1755	1765	0.010993962203673024	0.07852144412401191	0.3052686689383558	532.0	532.0	532.0	0	0	1	-59.99999999999999	59.99999999999999								
	3	7	1.0000000038417056e-9	0.11357095076864812	-4.999999999999996e-7	279.0	279.0	279.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	4	7	1.0000000038417056e-9	0.11497412229305314	-4.999999999999996e-7	275.0	275.0	275.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	10	8	0.00806046743294393	0.5063142907696707	-4.999999999999994e-7	63.0	63.0	63.0	1.0000000000000004	0.0	1	-59.99999999999999	59.99999999999999								
	11	8	0.008297564671320668	0.5549082148551406	-4.999999999999997e-7	56.99999999999999	56.99999999999999	56.99999999999999	1.0000000000000004	0.0	1	-59.99999999999999	59.99999999999999								
	13	375	0.009369065695919993	0.1184510319967115	-4.999999999999497e-7	266.0	266.0	266.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	14	375	0.009462735083853164	0.10863787594545198	-4.999999999999498e-7	290.0	290.0	290.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	15	375	0.008191248676960824	0.08775879706195192	-4.999999999999498e-7	359.0	359.0	359.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	24	553	0.008238174082116382	0.06260001982851865	-4.999999999999498e-7	501.0	501.0	501.0	1.0499999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	25	553	0.009642850663551817	0.07197604392635651	-4.999999999999497e-7	434.99999999999994	434.99999999999994	434.99999999999994	1.0499999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	26	554	0.006540899107905133	0.06177201284509548	-4.999999999999498e-7	509.0	509.0	509.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	59	78	0.011770198531469213	0.19307900942889222	-4.999999999999996e-7	164.0	164.0	164.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	59	78	0.0049217237727640605	0.18533946660558412	-4.999999999999994e-7	171.0	171.0	171.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	85	5	0.0006507708212808467	0.04248424171170184	-4.999999999999997e-7	744.0	744.0	744.0	1.0335	0.0	1	-59.99999999999999	59.99999999999999								
	85	5	0.0006668953353530924	0.04374030975120385	-4.999999999999996e-7	723.0	723.0	723.0	1.0335	0.0	1	-59.99999999999999	59.99999999999999								
	85	6	0.0006179694976648062	0.04325342753714743	-4.999999999999996e-7	731.0	731.0	731.0	1.0335	0.0	1	-59.99999999999999	59.99999999999999								
	85	6	0.0005990598214073362	0.042747928444017036	-4.999999999999994e-7	739.0	739.0	739.0	1.0335	0.0	1	-59.99999999999999	59.99999999999999								
	86	3	0.0006782290230941253	0.03689445965311433	-4.999999999999996e-7	857.0	857.0	857.0	0.9943393939393941	0.0	1	-59.99999999999999	59.99999999999999								
	86	3	0.0004714617408763843	0.03751951561175364	-4.999999999999994e-7	842.0	842.0	842.0	0.9943393939393941	0.0	1	-59.99999999999999	59.99999999999999								
	86	4	0.0004845234607000129	0.03750214799166594	-4.999999999999996e-7	843.0	843.0	843.0	0.9943393939393941	0.0	1	-59.99999999999999	59.99999999999999								
	86	4	0.000999397875292063	0.03718551304554746	-4.999999999999993e-7	850.0	850.0	850.0	0.9943393939393941	0.0	1	-59.99999999999999	59.99999999999999								
	12	152	0.0004037359347956444	0.04657695787988315	-4.999999999999994e-7	679.0	679.0	679.0	1.0714285714285716	0.0	1	-59.99999999999999	59.99999999999999								
	12	152	0.0003905033643746974	0.04362118943602024	-4.999999999999994e-7	725.0	725.0	725.0	1.0714285714285716	0.0	1	-59.99999999999999	59.99999999999999								
	94	20	0.0007288395824533219	0.03954888323754244	-4.999999999999996e-7	799.0	799.0	799.0	1.04675	0.0	1	-59.99999999999999	59.99999999999999								
	94	20	0.0007265380938135315	0.04111974750458434	-4.999999999999996e-7	769.0	769.0	769.0	1.04675	0.0	1	-59.99999999999999	59.99999999999999								
	94	21	0.000725284072809689	0.04148854040991683	-4.999999999999996e-7	762.0	762.0	762.0	1.04675	0.0	1	-59.99999999999999	59.99999999999999								
	94	21	0.0007011451725818443	0.042342492193581445	-4.999999999999997e-7	746.0	746.0	746.0	1.04675	0.0	1	-59.99999999999999	59.99999999999999								
	95	18	0.0006085289124882074	0.03788115448764696	-4.999999999999996e-7	834.0	834.0	834.0	1.027472727272727	0.0	1	-59.99999999999999	59.99999999999999								
	95	18	0.00046995923017088717	0.03947525579823824	-4.999999999999996e-7	801.0	801.0	801.0	1.027472727272727	0.0	1	-59.99999999999999	59.99999999999999								
	95	19	0.0005920777349577511	0.03704137876674705	-4.999999999999994e-7	852.9999999999999	852.9999999999999	852.9999999999999	1.027472727272727	0.0	1	-59.99999999999999	59.99999999999999								
	95	19	0.0005580682546932476	0.03605328244410634	-4.999999999999994e-7	877.0	877.0	877.0	1.027472727272727	0.0	1	-59.99999999999999	59.99999999999999								
	97	553	0.0014593916615627967	0.06176371057493786	-4.999999999999994e-7	512.0	512.0	512.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	97	553	0.00144666339884682	0.06605847418172467	-4.999999999999996e-7	479.0	479.0	479.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	97	554	0.0016957361268799868	0.0871286782751623	-4.999999999999996e-7	363.0	363.0	363.0	0.9730000000000004	0.0	1	-59.99999999999999	59.99999999999999								
	98	248	0.000856200873588048	0.044617258652147745	-4.999999999999996e-7	708.0	708.0	708.0	0.9809523809523809	0.0	1	-59.99999999999999	59.99999999999999								
	98	248	1.0000000002037268e-9	0.04413571570770055	-4.999999999999994e-7	716.0	716.0	716.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	99	157	0.0005440601962076726	0.04598551543498585	-4.999999999999993e-7	687.0	687.0	687.0	1.0190476190476192	0.0	1	-59.99999999999999	59.99999999999999								
	100	159	0.0007772753606194891	0.04764636045342486	-4.999999999999993e-7	663.0	663.0	663.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	100	159	0.00046285005402455133	0.04472027126936414	-4.999999999999994e-7	707.0	707.0	707.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	100	159	0.0008160981209034326	0.04500786848979245	-4.999999999999996e-7	702.0	702.0	702.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	100	159	0.0011055702177983039	0.04764247702327685	-4.999999999999993e-7	663.0	663.0	663.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	101	161	1.0000000002037268e-9	0.043204782172352435	-4.999999999999994e-7	732.0	732.0	732.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	101	161	9.99999996565748e-10	0.04488567478890705	-4.999999999999994e-7	704.0	704.0	704.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	102	401	1.0000000002037268e-9	0.04248732806350274	-4.999999999999993e-7	744.0	744.0	744.0	1.0190476190476192	0.0	1	-59.99999999999999	59.99999999999999								
	102	401	0.0002278526497373584	0.0952202269685845	-4.999999999999994e-7	332.0	332.0	332.0	1.0190476190476192	0.0	1	-59.99999999999999	59.99999999999999								
	105	162	1.0000000002037268e-9	0.04450528407721956	-4.999999999999993e-7	710.0	710.0	710.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	105	162	1.0000000002037268e-9	0.04432809871221604	-4.999999999999994e-7	713.0	713.0	713.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	105	162	1.0000000002037268e-9	0.045186503812285936	-4.999999999999993e-7	700.0	700.0	700.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	106	227	0.0011249723514447265	0.04917077594301729	0.002719602707916616	643.0	643.0	643.0	1.047619047619048	0.0	1	-59.99999999999999	59.99999999999999								
	106	227	0.00040024219840934894	0.04081805956291205	-4.999999999999994e-7	774.0	774.0	774.0	1.047619047619048	0.0	1	-59.99999999999999	59.99999999999999								
	107	527	0.001353450784731489	0.07351593299418868	-4.999999999999994e-7	430.0	430.0	430.0	1.047619047619048	0.0	1	-59.99999999999999	59.99999999999999								
	107	527	0.001531106661168691	0.07127055546386347	-4.999999999999996e-7	444.00000000000006	444.00000000000006	444.00000000000006	1.047619047619048	0.0	1	-59.99999999999999	59.99999999999999								
	108	165	0.00020818331164477422	0.04596449382811955	-4.999999999999993e-7	688.0	688.0	688.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	108	165	1.0000000002037268e-9	0.04693481774087796	-4.999999999999994e-7	674.0	674.0	674.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	109	29	0.0038107706169707963	0.10825408413702813	-4.999999999999994e-7	292.0	292.0	292.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	109	30	0.0038099322086682878	0.11065742066869713	-4.999999999999994e-7	286.0	286.0	286.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	110	34	0.0005080441396556107	0.027794037226002537	-4.999999999999994e-7	1137.0	1137.0	1137.0	1.0606060606060606	0.0	1	-59.99999999999999	59.99999999999999								
	110	35	0.0005044368716653662	0.03022995428329504	-4.999999999999994e-7	1045.0	1045.0	1045.0	1.0606060606060606	0.0	1	-59.99999999999999	59.99999999999999								
	110	36	0.00046038846509468385	0.03071514442071494	-4.999999999999993e-7	1029.0	1029.0	1029.0	1.0606060606060606	0.0	1	-59.99999999999999	59.99999999999999								
	110	533	0.0058057553057948245	0.17677179178999916	-4.999999999999994e-7	179.0	179.0	179.0	0.9194166666666668	0.0	1	-59.99999999999999	59.99999999999999								
	110	535	0.005825698297118608	0.17752198094440816	-4.999999999999994e-7	178.0	178.0	178.0	0.9707017543859651	0.0	1	-59.99999999999999	59.99999999999999								
	111	166	0.0013027320550208204	0.04587574846173814	-4.999999999999993e-7	689.0	689.0	689.0	1.047619047619048	0.0	1	-59.99999999999999	59.99999999999999								
	111	166	0.0012862698333094085	0.045006089356501446	-4.999999999999996e-7	702.0	702.0	702.0	1.047619047619048	0.0	1	-59.99999999999999	59.99999999999999								
	112	245	8.843793966996156e-5	0.045950953333079206	0.0015137253181723269	688.0	688.0	688.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	112	245	9.99999996565748e-10	0.042742033162040546	-4.999999999999994e-7	740.0	740.0	740.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	112	245	0.0006253374475611936	0.04393865594101121	0.001366318604441261	719.0	719.0	719.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	114	170	0.001683140931196347	0.06455604947237477	-4.999999999999994e-7	490.00000000000006	490.00000000000006	490.00000000000006	0.9899999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	115	171	0.0004171905631216432	0.04370037914197135	-4.999999999999994e-7	723.0	723.0	723.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	115	537	0.0019610299677046204	0.07509613574868249	-4.999999999999996e-7	421.0	421.0	421.0	1.0190476190476192	0.0	1	-59.99999999999999	59.99999999999999								
	117	43	0.0003046198787072917	0.019873436174953223	-4.999999999999994e-7	1590.0	1590.0	1590.0	1.010906060606061	0.0	1	-59.99999999999999	59.99999999999999								
	117	44	0.000326132488617508	0.01781696276229282	-4.999999999999994e-7	1773.0	1773.0	1773.0	1.010906060606061	0.0	1	-59.99999999999999	59.99999999999999								
	117	172	1.0000000002037268e-9	0.04273082635353214	-4.999999999999994e-7	740.0	740.0	740.0	0.9523809523809523	0.0	1	-59.99999999999999	59.99999999999999								
	118	45	0.0008729885065386297	0.03732841739582074	-4.999999999999994e-7	846.0000000000001	846.0000000000001	846.0000000000001	1.0352050909090913	0.0	1	-59.99999999999999	59.99999999999999								
	118	47	0.0015034672780817636	0.061164730592204175	-4.999999999999994e-7	517.0	517.0	517.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	118	48	0.0015457047083804645	0.06326829463107687	-4.999999999999996e-7	500.0	500.0	500.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	118	49	0.001513858593061399	0.06407773810489277	-4.999999999999994e-7	493.0	493.0	493.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	118	50	0.0014830492887802612	0.06310773610038858	-4.999999999999994e-7	501.0	501.0	501.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	118	454	0.0008085567499309075	0.04712638808818617	-4.999999999999993e-7	671.0	671.0	671.0	0.9809523809523809	0.0	1	-59.99999999999999	59.99999999999999								
	118	540	0.0068844832871964605	0.19449738831104926	-4.999999999999993e-7	163.0	163.0	163.0	0.9705882352941174	0.0	1	-59.99999999999999	59.99999999999999								
	118	541	0.0067591515247959755	0.2005554060106562	-4.999999999999994e-7	158.0	158.0	158.0	0.9705882352941174	0.0	1	-59.99999999999999	59.99999999999999								
	119	174	0.003310379913372744	0.15133752913592616	-4.999999999999996e-7	209.0	209.0	209.0	1.0270000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	119	174	0.0014986937969381179	0.06473809832198725	-4.999999999999996e-7	488.0	488.0	488.0	1.0270000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	120	175	0.0007606631239706875	0.042931365859030644	-4.999999999999996e-7	736.0	736.0	736.0	0.961904761904762	0.0	1	-59.99999999999999	59.99999999999999								
	120	175	0.000787646148150623	0.04471439304758503	-4.999999999999994e-7	707.0	707.0	707.0	0.961904761904762	0.0	1	-59.99999999999999	59.99999999999999								
	126	176	0.0054514929642126226	0.04435006072627555	-4.999999999999997e-7	707.0	707.0	707.0	0.9428571428571426	0.0	1	-59.99999999999999	59.99999999999999								
	126	176	0.0004136881588774922	0.042215536701951044	-4.999999999999996e-7	749.0	749.0	749.0	0.9428571428571426	0.0	1	-59.99999999999999	59.99999999999999								
	126	176	0.00039417061252689016	0.042315656140206256	-4.999999999999994e-7	747.0	747.0	747.0	0.9428571428571426	0.0	1	-59.99999999999999	59.99999999999999								
	127	177	0.00048466464985797206	0.045605929312875354	-4.999999999999994e-7	693.0	693.0	693.0	1.0095238095238095	0.0	1	-59.99999999999999	59.99999999999999								
	127	177	0.000776528064740658	0.04404689716428694	-4.999999999999994e-7	718.0	718.0	718.0	1.0095238095238095	0.0	1	-59.99999999999999	59.99999999999999								
	128	178	0.00039218271117827315	0.03386113723277284	-4.999999999999993e-7	933.0	933.0	933.0	1.028571428571429	0.0	1	-59.99999999999999	59.99999999999999								
	128	178	0.00039361106956547516	0.03390405282354155	-4.999999999999993e-7	932.0	932.0	932.0	1.028571428571429	0.0	1	-59.99999999999999	59.99999999999999								
	128	178	0.0005006331915425362	0.03514878331752664	-4.999999999999993e-7	899.0	899.0	899.0	1.028571428571429	0.0	1	-59.99999999999999	59.99999999999999								
	128	178	0.0004214634460078814	0.04690848777790175	-4.999999999999994e-7	674.0	674.0	674.0	1.028571428571429	0.0	1	-59.99999999999999	59.99999999999999								
	129	57	0.016049822794177396	0.28565351729294547	-4.999999999999996e-7	111.00000000000001	111.00000000000001	111.00000000000001	1.0099999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	129	58	0.01663501109153201	0.2921279778140992	-4.999999999999996e-7	108.0	108.0	108.0	1.0399999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	131	179	0.0008178794156218173	0.04757308887483725	-4.999999999999996e-7	664.0	664.0	664.0	1.0190476190476192	0.0	1	-59.99999999999999	59.99999999999999								
	131	179	0.0008072024687582853	0.042728956932683346	-4.999999999999993e-7	740.0	740.0	740.0	1.047619047619048	0.0	1	-59.99999999999999	59.99999999999999								
	131	179	0.0008085017334873082	0.04458374620943035	-4.999999999999996e-7	709.0	709.0	709.0	1.0190476190476192	0.0	1	-59.99999999999999	59.99999999999999								
	131	179	0.0008351001908833386	0.04444258628032815	-4.999999999999994e-7	711.0	711.0	711.0	1.0190476190476192	0.0	1	-59.99999999999999	59.99999999999999								
	131	179	0.0005438925221169593	0.045312244790403036	-4.999999999999993e-7	698.0	698.0	698.0	1.0190476190476192	0.0	1	-59.99999999999999	59.99999999999999								
	133	182	0.0004185431342961492	0.041138140690879746	-4.999999999999994e-7	768.0	768.0	768.0	1.0380952380952382	0.0	1	-59.99999999999999	59.99999999999999								
	133	182	0.0005406637411348711	0.04413797192140474	-4.999999999999994e-7	716.0	716.0	716.0	0.8571428571428574	0.0	1	-59.99999999999999	59.99999999999999								
	133	182	0.0004789026350684653	0.04460626736952165	-4.999999999999994e-7	709.0	709.0	709.0	1.0380952380952382	0.0	1	-59.99999999999999	59.99999999999999								
	133	182	0.0005435692086725721	0.04351813461033564	-4.999999999999994e-7	726.0	726.0	726.0	1.0380952380952382	0.0	1	-59.99999999999999	59.99999999999999								
	133	182	0.0005439966761160868	0.043543209235137256	-4.999999999999994e-7	726.0	726.0	726.0	1.0380952380952382	0.0	1	-59.99999999999999	59.99999999999999								
	135	629	0.002276460882501524	0.13156312346226717	-4.999999999999993e-7	241.0	241.0	241.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	135	629	0.0024080346867133193	0.13825071465252117	-4.999999999999994e-7	229.0	229.0	229.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	61	183	0.0003875330598285618	0.04314514056196614	-4.999999999999993e-7	733.0	733.0	733.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	61	183	0.0003899999124243113	0.042821610170886246	-4.999999999999996e-7	738.0	738.0	738.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	61	183	0.0006882558682717608	0.04403469149250386	-4.999999999999994e-7	718.0	718.0	718.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	61	184	0.0003994786054383221	0.04241450904464894	-4.999999999999996e-7	745.0	745.0	745.0	0.9714285714285719	0.0	1	-59.99999999999999	59.99999999999999								
	61	184	0.00047173099943792837	0.041712563931831946	-4.999999999999993e-7	758.0	758.0	758.0	0.9714285714285719	0.0	1	-59.99999999999999	59.99999999999999								
	138	185	0.0025965146789018252	0.08354807571958928	-4.999999999999994e-7	378.0	378.0	378.0	1.0238095238095242	0.0	1	-59.99999999999999	59.99999999999999								
	138	185	0.002400712849215437	0.08413189590875236	-4.999999999999994e-7	376.0	376.0	376.0	1.0238095238095242	0.0	1	-59.99999999999999	59.99999999999999								
	138	185	0.0008976736571703223	0.08183911969336861	-4.999999999999996e-7	386.0	386.0	386.0	1.0200000000000005	0.0	1	-59.99999999999999	59.99999999999999								
	139	186	0.0004530122880878116	0.041829566151031145	-4.999999999999996e-7	756.0	756.0	756.0	0.9333333333333335	0.0	1	-59.99999999999999	59.99999999999999								
	139	186	0.0006083097114016491	0.04899497954668656	-4.999999999999994e-7	645.0	645.0	645.0	0.9333333333333335	0.0	1	-59.99999999999999	59.99999999999999								
	139	186	0.000580460267392751	0.04868203821422705	-4.999999999999996e-7	649.0	649.0	649.0	0.9333333333333335	0.0	1	-59.99999999999999	59.99999999999999								
	140	188	0.0006995583685225101	0.041971109443886045	-4.999999999999994e-7	753.0	753.0	753.0	0.961904761904762	0.0	1	-59.99999999999999	59.99999999999999								
	140	188	0.0004575381798127891	0.04232425449464645	-4.999999999999994e-7	747.0	747.0	747.0	0.961904761904762	0.0	1	-59.99999999999999	59.99999999999999								
	142	76	0.0006045848707741315	0.04131271916633185	-4.999999999999994e-7	765.0	765.0	765.0	1.0108742424242425	0.0	1	-59.99999999999999	59.99999999999999								
	142	76	0.0006274052118154468	0.04134793120090094	-4.999999999999993e-7	764.0	764.0	764.0	1.0108742424242425	0.0	1	-59.99999999999999	59.99999999999999								
	142	77	0.000293969198459592	0.044309806748825946	-4.999999999999996e-7	713.0	713.0	713.0	1.0108742424242425	0.0	1	-59.99999999999999	59.99999999999999								
	142	77	0.0004956085143534692	0.04065335842316213	-4.999999999999994e-7	777.0	777.0	777.0	1.0108742424242425	0.0	1	-59.99999999999999	59.99999999999999								
	142	189	0.0008909741420269202	0.07607063785214155	-4.999999999999996e-7	416.0	416.0	416.0	0.961904761904762	0.0	1	-59.99999999999999	59.99999999999999								
	143	191	1.0000000002037268e-9	0.04401505614576564	-4.999999999999994e-7	718.0	718.0	718.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	143	191	0.0005331391160607527	0.04315057191790165	-4.999999999999994e-7	732.0	732.0	732.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	143	191	0.0005145728415630946	0.04509693773631554	-4.999999999999996e-7	701.0	701.0	701.0	0.9904761904761907	0.0	1	-59.99999999999999	59.99999999999999								
	144	192	0.0004835809688240515	0.03553577497973284	-4.999999999999994e-7	889.0	889.0	889.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	144	192	0.000482038549226545	0.04520173924375036	-4.999999999999994e-7	699.0	699.0	699.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	145	193	0.0004603426983131285	0.04390095780147416	-4.999999999999994e-7	720.0	720.0	720.0	0.9523809523809523	0.0	1	-59.99999999999999	59.99999999999999								
	145	193	0.00044932506244147586	0.04417908707018655	-4.999999999999994e-7	715.0	715.0	715.0	0.9523809523809523	0.0	1	-59.99999999999999	59.99999999999999								
	146	194	0.0005479303566271628	0.04631203210583134	-4.999999999999996e-7	683.0	683.0	683.0	0.9523809523809523	0.0	1	-59.99999999999999	59.99999999999999								
	146	194	0.0006519277342286186	0.04329862658966974	-4.999999999999994e-7	730.0	730.0	730.0	0.9523809523809523	0.0	1	-59.99999999999999	59.99999999999999								
	147	197	0.0004488538218725662	0.045427183531610155	-4.999999999999996e-7	696.0	696.0	696.0	0.9714285714285719	0.0	1	-59.99999999999999	59.99999999999999								
	147	197	0.00047519567862416075	0.046978502088503356	-4.999999999999994e-7	673.0	673.0	673.0	0.9714285714285719	0.0	1	-59.99999999999999	59.99999999999999								
	148	198	0.0003935725351626279	0.043785709262268546	-4.999999999999994e-7	722.0	722.0	722.0	0.9809523809523809	0.0	1	-59.99999999999999	59.99999999999999								
	148	198	0.0005308873692171837	0.04322583488226116	-4.999999999999996e-7	731.0	731.0	731.0	0.9809523809523809	0.0	1	-59.99999999999999	59.99999999999999								
	149	150	8.643191299617684e-5	0.011120253418019813	-4.999999999999996e-7	2841.0	2841.0	2841.0	1.0043478260869565	0.0	1	-59.99999999999999	59.99999999999999								
	151	199	0.0004790636131463761	0.08556477503757169	-4.999999999999996e-7	370.0	370.0	370.0	0.961904761904762	0.0	1	-59.99999999999999	59.99999999999999								
	151	199	0.0012054754487442114	0.08037798619131269	-4.999999999999993e-7	393.0	393.0	393.0	0.961904761904762	0.0	1	-59.99999999999999	59.99999999999999								
	152	516	0.004557682967811663	0.2081059087553682	-4.999999999999996e-7	152.0	152.0	152.0	0.9799999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	152	516	0.004803626095807951	0.20657899377719718	-4.999999999999994e-7	153.0	153.0	153.0	0.9799999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	157	524	0.0023249163239382397	0.1053209080556801	-4.999999999999996e-7	300.0	300.0	300.0	1.02	0.0	1	-59.99999999999999	59.99999999999999								
	157	524	0.002269897435736675	0.10193580668414212	-4.999999999999996e-7	310.0	310.0	310.0	1.02	0.0	1	-59.99999999999999	59.99999999999999								
	248	98	1.0000000002037268e-9	0.03666082861796843	-4.999999999999996e-7	861.9999999999999	861.9999999999999	861.9999999999999	1.0184999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	248	98	1.0000000002037268e-9	0.03593660078207204	-4.999999999999996e-7	878.9999999999999	878.9999999999999	878.9999999999999	1.0079999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	172	538	9.99999996565748e-10	0.11311257499260115	-4.999999999999996e-7	280.0	280.0	280.0	1.02	0.0	1	-59.99999999999999	59.99999999999999								
	172	539	9.99999996565748e-10	0.10963148321578413	-4.999999999999996e-7	289.0	289.0	289.0	1.02	0.0	1	-59.99999999999999	59.99999999999999								
	174	51	0.06787403266471057	0.4843129387022395	-4.999999999999994e-7	65.0	65.0	65.0	0.9599999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	182	133	0.0004960342672111692	0.04270134824795826	-4.999999999999996e-7	740.0	740.0	740.0	0.9555000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	193	504	9.999999892897904e-10	0.2923992457716182	-4.999999999999997e-7	109.00000000000001	109.00000000000001	109.00000000000001	1.0047497259773477	0.0	1	-59.99999999999999	59.99999999999999								
	193	505	9.999999892897904e-10	0.28412677028155126	-4.999999999999994e-7	112.00000000000001	112.00000000000001	112.00000000000001	1.0047497259773477	0.0	1	-59.99999999999999	59.99999999999999								
	193	549	0.003707206670204017	0.19679358109709025	-4.999999999999994e-7	161.0	161.0	161.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	193	549	0.00352144865743893	0.20672959944938926	-4.999999999999994e-7	153.0	153.0	153.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	199	506	0.01753957456289031	0.3284279550896423	-4.999999999999996e-7	97.0	97.0	97.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	201	202	0.005851185259533886	0.20195535907418222	-4.999999999999996e-7	157.0	157.0	157.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	201	202	0.005760267231173667	0.1911799613792192	-4.999999999999996e-7	166.0	166.0	166.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	204	550	9.999999892897904e-10	0.4161321274002475	-4.999999999999993e-7	76.0	76.0	76.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	205	490	0.018488237799826834	0.6809441807321857	-4.999999999999997e-7	47.0	47.0	47.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	205	490	0.017352461309816512	0.6826369234343777	-4.999999999999997e-7	47.0	47.0	47.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	210	8	1.0000000038417056e-9	0.16287250618727628	-4.999999999999992e-7	194.0	194.0	194.0	1.0199999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	210	8	1.0000000038417056e-9	0.15886744152645318	-4.999999999999993e-7	199.0	199.0	199.0	1.0199999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	211	636	0.006939118366887649	0.1619667380554802	-4.999999999999994e-7	195.0	195.0	195.0	1.0215	0.0	1	-59.99999999999999	59.99999999999999								
	211	636	0.006643109724241165	0.16412511372617816	-4.999999999999994e-7	193.0	193.0	193.0	1.0215	0.0	1	-59.99999999999999	59.99999999999999								
	211	636	0.00647576596931118	0.1702519463852402	-4.999999999999996e-7	186.0	186.0	186.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	218	22	0.0021317341639882177	0.05849543303341545	-4.999999999999994e-7	540.0	540.0	540.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	218	22	0.0021749266827775426	0.06010517439824006	-4.999999999999993e-7	526.0	526.0	526.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	255	555	0.0039009716478475166	0.17031305894814117	-4.999999999999994e-7	186.0	186.0	186.0	0.9900000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	255	555	0.003908212310277696	0.17928663234058917	-4.999999999999994e-7	177.0	177.0	177.0	0.9900000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	256	556	9.99999996565748e-10	0.10786634214654707	-4.999999999999997e-7	293.0	293.0	293.0	0.9900000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	256	556	9.99999996565748e-10	0.10846171688739405	-4.999999999999996e-7	292.0	292.0	292.0	0.9900000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	260	31	1.0000000038417056e-9	0.14891643954090913	-4.999999999999994e-7	213.0	213.0	213.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	262	32	0.0037147050396323465	0.1790951707519752	-4.999999999999996e-7	177.0	177.0	177.0	0.9900000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	262	32	0.0035566969562199225	0.1692866359258232	-4.999999999999994e-7	187.0	187.0	187.0	0.9900000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	262	32	0.0030811007419594824	0.17275587113587418	-4.999999999999996e-7	183.0	183.0	183.0	0.9900000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	267	33	0.01125076863946559	0.31559084291527234	-4.999999999999996e-7	101.0	101.0	101.0	1.160208	0.0	1	-59.99999999999999	59.99999999999999								
	274	564	0.006932098777863953	0.25625078845237625	-4.999999999999996e-7	124.0	124.0	124.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	274	564	0.0068525643007288015	0.26465538269797517	-4.999999999999996e-7	120.0	120.0	120.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	275	565	0.007221691372191373	0.25625344988307225	-4.999999999999994e-7	124.0	124.0	124.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	275	565	0.007850836121348504	0.2571386906655903	-4.999999999999994e-7	123.0	123.0	123.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	278	566	0.005949546643199239	0.11360874499244808	-4.999999999999997e-7	278.0	278.0	278.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	280	536	0.012819409378545183	0.7046907813525968	-4.999999999999996e-7	45.0	45.0	45.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	280	536	0.012774946145938534	0.6936707847575307	-4.999999999999996e-7	46.0	46.0	46.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	286	493	0.00462414520480654	0.20858795607191719	-4.999999999999994e-7	152.0	152.0	152.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	286	493	0.004524065341556285	0.20906718578356515	-4.999999999999996e-7	152.0	152.0	152.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	290	497	1.0000000038417056e-9	0.18630854850040918	-4.999999999999994e-7	170.0	170.0	170.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	290	497	1.0000000038417056e-9	0.19158814524445927	-4.999999999999996e-7	165.0	165.0	165.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	232	569	9.999999892897904e-10	0.2657453775373213	-4.999999999999994e-7	119.0	119.0	119.0	0.9374999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	297	569	9.999999892897904e-10	0.2628777094925683	-4.999999999999994e-7	121.0	121.0	121.0	0.95	0.0	1	-59.99999999999999	59.99999999999999								
	301	571	0.004601162562791112	0.19063233387278616	-4.999999999999993e-7	166.0	166.0	166.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	301	571	0.0045532123943482	0.1881929959136452	-4.999999999999993e-7	168.0	168.0	168.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	303	498	0.00838306498801506	0.17892394554134614	-4.999999999999994e-7	177.0	177.0	177.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	303	498	0.008282683098075765	0.18368174916407326	-4.999999999999996e-7	172.0	172.0	172.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	304	54	0.012634989374169904	0.3583524442461714	-4.999999999999997e-7	89.0	89.0	89.0	0.9833300000000003	0.0	1	-59.99999999999999	59.99999999999999								
	304	54	0.0052129070707520875	0.21393200922640226	-4.999999999999994e-7	148.0	148.0	148.0	0.9833300000000003	0.0	1	-59.99999999999999	59.99999999999999								
	305	572	0.004598680927209396	0.20864666735822526	-4.999999999999993e-7	152.0	152.0	152.0	1.0255	0.0	1	-59.99999999999999	59.99999999999999								
	305	572	0.0043517745580727496	0.2102159736908432	-4.999999999999996e-7	151.0	151.0	151.0	1.0255	0.0	1	-59.99999999999999	59.99999999999999								
	306	499	0.0023964057012850607	0.10027867041904606	-4.999999999999996e-7	315.0	315.0	315.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	306	499	0.002479327897766445	0.10819369538475014	-4.999999999999996e-7	292.0	292.0	292.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	306	499	0.002557964679428209	0.10575801914964007	-4.999999999999996e-7	299.0	299.0	299.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	306	573	0.007053985421151709	0.25409130431638327	-4.999999999999996e-7	125.0	125.0	125.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	156	544	0.012111651783335836	0.7524783913038092	-4.999999999999994e-7	42.0	42.0	42.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	156	544	0.01849562056077819	0.7598405894806536	-4.999999999999994e-7	42.0	42.0	42.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	156	544	0.011810107140449631	0.7051143942961776	-4.999999999999996e-7	45.0	45.0	45.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	310	311	0.005340769263222653	0.20415399386055919	-4.999999999999994e-7	155.0	155.0	155.0	1.044	0.0	1	-59.99999999999999	59.99999999999999								
	310	311	0.005017372476506818	0.20379177197949222	-4.999999999999996e-7	155.0	155.0	155.0	1.044	0.0	1	-59.99999999999999	59.99999999999999								
	310	311	0.005015373014023368	0.21047843815676623	-4.999999999999996e-7	151.0	151.0	151.0	1.044	0.0	1	-59.99999999999999	59.99999999999999								
	311	55	0.027685951674628798	0.2971115795600153	-4.999999999999996e-7	106.0	106.0	106.0	0.9500000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	315	500	1.0000000038417056e-9	0.1965863138453872	-4.999999999999993e-7	161.0	161.0	161.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	315	500	1.0000000038417056e-9	0.19793773219439822	-4.999999999999993e-7	160.0	160.0	160.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	317	46	9.999999892897904e-10	0.3396094465383725	-4.999999999999996e-7	94.0	94.0	94.0	1.045	0.0	1	-59.99999999999999	59.99999999999999								
	317	60	0.04956618170122325	0.22765117974853316	-4.999999999999996e-7	136.0	136.0	136.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	319	545	0.012736913033744145	0.7020849579209627	-4.999999999999996e-7	45.0	45.0	45.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	319	545	0.013084335677448485	0.7107253533819385	-4.999999999999994e-7	45.0	45.0	45.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	324	502	9.99999996565748e-10	0.10379575210906708	-4.999999999999994e-7	305.0	305.0	305.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	324	502	9.99999996565748e-10	0.09885338962136025	-4.999999999999996e-7	320.0	320.0	320.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	325	503	0.012956381033584315	0.2023409502482662	-4.999999999999996e-7	156.0	156.0	156.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	326	503	9.999999892897904e-10	0.32586086922852525	-4.999999999999996e-7	97.0	97.0	97.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	327	577	0.005321556283069628	0.19229868961129523	-4.999999999999993e-7	165.0	165.0	165.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	327	577	0.0051587752832489495	0.19156677853962617	-4.999999999999996e-7	165.0	165.0	165.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	328	579	0.0044192791032463576	0.19694699390208523	-4.999999999999994e-7	161.0	161.0	161.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	328	579	0.004825562264684908	0.19192277115466222	-4.999999999999994e-7	165.0	165.0	165.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	328	579	1.0000000038417056e-9	0.20042998201758822	-4.999999999999994e-7	158.0	158.0	158.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	329	580	0.009501704610504385	0.2790632566590722	-4.999999999999997e-7	113.99999999999999	113.99999999999999	113.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	329	580	0.008839926391391665	0.2688979781845042	-4.999999999999994e-7	118.0	118.0	118.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	329	580	0.008961491008370591	0.26709903272569324	-4.999999999999996e-7	119.0	119.0	119.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	329	546	0.01542485928208736	0.7356070724378367	-4.999999999999994e-7	43.0	43.0	43.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	329	546	0.014073904394024808	0.7012053878835428	-4.999999999999996e-7	46.0	46.0	46.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	340	582	0.007545133235041837	0.18845629377005813	-4.999999999999994e-7	168.0	168.0	168.0	0.95	0.0	1	-59.99999999999999	59.99999999999999								
	340	582	0.00785008209849878	0.20213013926521117	-4.999999999999996e-7	157.0	157.0	157.0	0.95	0.0	1	-59.99999999999999	59.99999999999999								
	340	582	0.007552240794167693	0.19872044980709114	-4.999999999999996e-7	159.0	159.0	159.0	0.95	0.0	1	-59.99999999999999	59.99999999999999								
	344	548	0.006934568017145458	0.2327165884810892	-4.999999999999996e-7	136.0	136.0	136.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	227	361	0.0031759973035956064	0.17605699762497318	-4.999999999999994e-7	180.0	180.0	180.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	227	361	0.00331487648055733	0.17199990627594913	-4.999999999999996e-7	184.0	184.0	184.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	227	361	0.003302294359819803	0.1765342607120162	-4.999999999999996e-7	179.0	179.0	179.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	366	507	0.011979731659369369	0.7031092904705808	-4.999999999999996e-7	45.0	45.0	45.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	366	507	0.014490022681413042	0.7160989419741015	-4.999999999999996e-7	45.0	45.0	45.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	366	507	0.012720236944362346	0.7208883915417157	-4.999999999999996e-7	44.0	44.0	44.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	367	508	0.025439031398847553	0.5345821066858646	-4.999999999999994e-7	60.0	60.0	60.0	0.9599999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	367	508	0.026042378467965754	0.5156278995152025	-4.999999999999996e-7	62.0	62.0	62.0	0.9599999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	384	599	0.023603114318695734	0.6180702845685577	-4.999999999999996e-7	52.0	52.0	52.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	384	600	0.023895279076608652	0.6151895839353027	-4.999999999999996e-7	52.0	52.0	52.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	385	523	0.017080087086429645	0.705147648005432	-4.999999999999997e-7	45.0	45.0	45.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	385	523	0.017338733436653275	0.7653403115448799	-4.999999999999996e-7	42.0	42.0	42.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	385	523	0.013698759063614415	0.6278932776951996	-4.999999999999996e-7	51.0	51.0	51.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	394	601	1.0000000038417056e-9	0.20416617288528224	-4.999999999999994e-7	155.0	155.0	155.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	394	601	1.0000000038417056e-9	0.2166886890153322	-4.999999999999996e-7	146.0	146.0	146.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	130	602	0.004821156178826306	0.20934606701204722	-4.999999999999996e-7	151.0	151.0	151.0	1.0375000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	130	603	0.0049667513214441275	0.2045239229985902	-4.999999999999996e-7	155.0	155.0	155.0	1.0375000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	406	608	1.0000000038417056e-9	0.2101302554217092	-4.999999999999996e-7	151.0	151.0	151.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	406	608	1.0000000038417056e-9	0.2120823011059242	-4.999999999999996e-7	149.0	149.0	149.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	411	610	1.0000000038417056e-9	0.2042191928026662	-4.999999999999994e-7	155.0	155.0	155.0	1.0375000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	411	610	0.0055549368087144824	0.20368420055221917	-4.999999999999994e-7	156.0	156.0	156.0	1.0375000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	415	611	0.008781831025281761	0.2067743292423462	-4.999999999999996e-7	153.0	153.0	153.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	415	611	0.009057309133794943	0.21190654614741025	-4.999999999999994e-7	149.0	149.0	149.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	420	491	0.007581553852559838	0.1765621504122872	-4.999999999999994e-7	179.0	179.0	179.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	424	613	9.99999996565748e-10	0.10468661209801805	-4.999999999999996e-7	302.0	302.0	302.0	1.01	0.0	1	-59.99999999999999	59.99999999999999								
	424	613	9.99999996565748e-10	0.10284757580127715	-4.999999999999994e-7	308.0	308.0	308.0	1.01	0.0	1	-59.99999999999999	59.99999999999999								
	425	614	0.005260181572271351	0.2003965345592632	-4.999999999999996e-7	158.0	158.0	158.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	425	614	0.008882096430220482	0.20015265523967518	-4.999999999999993e-7	158.0	158.0	158.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	426	559	0.016009183037711122	0.15869607493939517	-4.999999999999994e-7	199.0	199.0	199.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	429	428	0.008337134605349813	0.09672335272302102	-4.999999999999994e-7	326.0	326.0	326.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	182	563	0.00437112873189323	0.15748279080114017	-4.999999999999993e-7	200.99999999999997	200.99999999999997	200.99999999999997	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	182	563	0.004075317632166523	0.16259832791767312	-4.999999999999996e-7	195.0	195.0	195.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	182	563	0.004498285568935651	0.16078223594384414	-4.999999999999994e-7	197.0	197.0	197.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	436	617	0.005830071321261886	0.19623374158646223	-4.999999999999996e-7	161.0	161.0	161.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	436	617	0.006070590970611039	0.2110679454101132	-4.999999999999994e-7	150.0	150.0	150.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	436	617	0.00622302077341995	0.1959633624724082	-4.999999999999996e-7	162.0	162.0	162.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	439	619	0.024358369307487096	0.5915839585788948	-4.999999999999996e-7	54.0	54.0	54.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	439	620	0.0244050241733453	0.6380031300602877	-4.999999999999996e-7	50.0	50.0	50.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	440	621	0.00198753764273024	0.09510207189390622	-4.999999999999994e-7	333.0	333.0	333.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	440	621	0.0019557865455875362	0.09786362965008417	-4.999999999999994e-7	323.0	323.0	323.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	449	624	0.01510869500928727	0.7321954928039829	-4.999999999999997e-7	44.0	44.0	44.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	449	624	0.014848891179204743	0.7833017947935389	-4.999999999999996e-7	41.0	41.0	41.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	451	542	0.02202605663906486	0.6954773694207356	-4.999999999999997e-7	46.0	46.0	46.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	451	542	0.015041872949438984	0.7657093771059841	-4.999999999999994e-7	42.0	42.0	42.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	452	542	0.018708464089559215	0.831225912856071	-4.999999999999994e-7	38.0	38.0	38.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	452	542	0.02036840026629326	0.781206829987646	-4.999999999999996e-7	41.0	41.0	41.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	463	56	0.0005152621341560261	0.03496193964364183	-4.999999999999993e-7	903.9999999999999	903.9999999999999	903.9999999999999	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	464	626	1.0000000038417056e-9	0.19346243625396123	-4.999999999999994e-7	164.0	164.0	164.0	0.95	0.0	1	-59.99999999999999	59.99999999999999								
	464	626	1.0000000038417056e-9	0.2044163573491402	-4.999999999999996e-7	155.0	155.0	155.0	0.95	0.0	1	-59.99999999999999	59.99999999999999								
	464	627	0.014067318768065334	0.3311707760581203	-4.999999999999996e-7	96.0	96.0	96.0	0.9374999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	464	627	0.01686864994603381	0.3137146764310002	-4.999999999999997e-7	101.0	101.0	101.0	0.9374999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	469	628	0.013143495828417886	0.6961544498818295	-4.999999999999997e-7	46.0	46.0	46.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	469	628	0.0131404610937385	0.6972911686330268	-4.999999999999997e-7	46.0	46.0	46.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	470	630	0.005734375237582106	0.1905019536090472	-4.999999999999994e-7	166.0	166.0	166.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	471	64	9.99999996565748e-10	0.08903754671934709	-4.999999999999997e-7	355.0	355.0	355.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	471	65	9.99999996565748e-10	0.0936278486031265	-4.999999999999996e-7	338.0	338.0	338.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	471	66	9.99999996565748e-10	0.08847217433181769	-4.999999999999996e-7	358.0	358.0	358.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	471	67	9.99999996565748e-10	0.0938176990366	-4.999999999999996e-7	337.0	337.0	337.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	472	473	0.0017997799510763215	0.10029537655830106	-4.999999999999996e-7	315.0	315.0	315.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	472	473	0.0018404230326389151	0.0974649865867029	-4.999999999999997e-7	325.0	325.0	325.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	474	578	1.0000000038417056e-9	0.1657673928467022	-4.999999999999994e-7	191.0	191.0	191.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	474	578	1.0000000038417056e-9	0.15537319502350116	-4.999999999999994e-7	204.0	204.0	204.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	306	547	0.012541168116160552	0.7502931072763848	-4.999999999999996e-7	43.0	43.0	43.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	306	547	0.012541984244987252	0.746130837151569	-4.999999999999994e-7	43.0	43.0	43.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	184	632	9.999999892897904e-10	0.6474666296414497	-4.999999999999994e-7	49.0	49.0	49.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	184	637	0.0030942905556600015	0.16270844520883818	-4.999999999999993e-7	195.0	195.0	195.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	184	638	0.0030640734306288356	0.15828917236113216	-4.999999999999993e-7	200.0	200.0	200.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	184	638	0.003028039663070187	0.15332672348943718	-4.999999999999994e-7	206.0	206.0	206.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	487	634	0.01762334368540143	0.6891573985448647	-4.999999999999994e-7	46.0	46.0	46.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	487	634	0.01824123628998344	0.7053571617444448	-4.999999999999994e-7	45.0	45.0	45.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	488	635	0.004312894245853487	0.23330917761813122	-4.999999999999996e-7	136.0	136.0	136.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	488	635	0.004292479305809204	0.23689989282841525	-4.999999999999996e-7	134.0	134.0	134.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	510	1	0.024362617835105124	0.24951033851643128	-4.999999999999997e-7	126.0	126.0	126.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	517	598	1.0000000038417056e-9	0.1719456890947112	-4.999999999999994e-7	184.0	184.0	184.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	518	598	0.002398309483730074	0.16474260776248917	-4.999999999999994e-7	192.0	192.0	192.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	519	598	0.009290831608317618	0.28247832310140825	-4.999999999999994e-7	112.00000000000001	112.00000000000001	112.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	543	570	0.006354182378637445	0.19937381196356527	-4.999999999999994e-7	159.0	159.0	159.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	557	214	0.00044602709025966394	0.043820849370781255	-4.999999999999994e-7	721.0	721.0	721.0	0.9714285714285719	0.0	1	-59.99999999999999	59.99999999999999								
	557	156	0.000983613674009055	0.044704536672650744	-4.999999999999994e-7	707.0	707.0	707.0	1.047619047619048	0.0	1	-59.99999999999999	59.99999999999999								
	590	83	9.999999892897904e-10	0.3393239316529055	-4.999999999999994e-7	111.00000000000001	111.00000000000001	111.00000000000001	1.018011363636364	0.0	1	-59.99999999999999	59.99999999999999								
	590	84	9.999999892897904e-10	0.3400956225335994	-4.999999999999994e-7	111.00000000000001	111.00000000000001	111.00000000000001	1.018011363636364	0.0	1	-59.99999999999999	59.99999999999999								
	615	562	0.0031511590555513536	0.1479422882820872	-4.999999999999994e-7	214.0	214.0	214.0	0.95	0.0	1	-59.99999999999999	59.99999999999999								
	615	562	1.0000000038417056e-9	0.1717409273726791	-4.999999999999994e-7	184.0	184.0	184.0	0.95	0.0	1	-59.99999999999999	59.99999999999999								
	615	562	0.003779308430665958	0.1632233230478991	-4.999999999999996e-7	194.0	194.0	194.0	0.95	0.0	1	-59.99999999999999	59.99999999999999								
	639	80	0.00905298912179083	0.3259495339547674	-4.999999999999996e-7	97.0	97.0	97.0	0.9565217391304348	0.0	1	-59.99999999999999	59.99999999999999								
	640	79	0.00939294694703567	0.3091600060461484	-4.999999999999996e-7	103.0	103.0	103.0	0.9565217391304348	0.0	1	-59.99999999999999	59.99999999999999								
	641	82	0.005641100045679923	0.24990875453813227	-4.999999999999994e-7	127.0	127.0	127.0	0.9565217391304348	0.0	1	-59.99999999999999	59.99999999999999								
	81	361	0.018593376215589746	0.3407362148749081	0.05946155994421125	93.0	93.0	93.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	645	932	0.03132739801420559	0.2063850919489899	-4.999999999999498e-7	152.0	152.0	152.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	646	931	0.036189145448435656	0.230712519476789	-4.999999999999496e-7	136.0	136.0	136.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	707	708	0.010312444328536965	0.2674140529013633	-4.999999999999996e-7	119.0	119.0	119.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	707	709	0.010869410716278335	0.2493370761441463	-4.999999999999994e-7	127.0	127.0	127.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	715	644	0.01005627831262476	0.07785389709107833	-4.999999999999498e-7	403.0	403.0	403.0	1.0499999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	716	905	0.0037123001708712616	0.11137543525624709	-4.999999999999994e-7	284.0	284.0	284.0	1.075	0.0	1	-59.99999999999999	59.99999999999999								
	716	905	0.0035297270556183718	0.11953420053850111	-4.999999999999994e-7	265.0	265.0	265.0	1.075	0.0	1	-59.99999999999999	59.99999999999999								
	716	948	9.999999892897904e-10	0.29504098686719543	-4.999999999999993e-7	108.0	108.0	108.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	716	948	1.0000000183936208e-9	0.2948414068454334	-4.999999999999993e-7	108.0	108.0	108.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	716	979	1.0000000002037268e-9	0.05426756011877385	-4.999999999999992e-7	583.0	583.0	583.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	716	979	1.0000000002037268e-9	0.052927905496630755	-4.999999999999993e-7	597.0	597.0	597.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	716	979	1.0000000002037268e-9	0.05091084135958167	-4.999999999999993e-7	621.0	621.0	621.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	721	798	1.0000000002037268e-9	0.03838110636486005	-4.999999999999993e-7	823.0	823.0	823.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	725	757	1.0137557193957023e-5	0.11615935095846618	-4.999999999972084e-7	272.0	272.0	272.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	724	800	9.67878799063327e-6	0.11766326630293827	-4.999999999972803e-7	269.0	269.0	269.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	738	649	0.0024727424133492893	0.07880936402457006	-4.999999999999996e-7	401.0	401.0	401.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	738	650	0.002604580693742093	0.07391846833249725	-4.999999999999996e-7	428.0	428.0	428.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	739	862	0.0023449885866356343	0.09615487612249138	-4.999999999999994e-7	329.0	329.0	329.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	739	863	0.0024305054193556495	0.0917537872293405	-4.999999999999994e-7	345.0	345.0	345.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	742	684	0.00206283594898304	0.11603402985176714	-4.999999999999993e-7	273.0	273.0	273.0	1.014425057537399	0.0	1	-59.99999999999999	59.99999999999999								
	742	685	0.002037631086676214	0.11840527403530117	-4.999999999999994e-7	267.0	267.0	267.0	1.014425057537399	0.0	1	-59.99999999999999	59.99999999999999								
	742	735	0.0022113120813032875	0.09377239596761758	-4.999999999999994e-7	337.0	337.0	337.0	0.9414999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	742	846	0.0022525108411459442	0.09636809309673118	-4.999999999999993e-7	328.0	328.0	328.0	0.9414999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	743	850	0.0023596357515969575	0.10943767488503311	-4.999999999999994e-7	289.0	289.0	289.0	1.005151111111111	0.0	1	-59.99999999999999	59.99999999999999								
	743	850	0.002858258212683562	0.11081630378092809	-4.999999999999993e-7	285.0	285.0	285.0	1.005151111111111	0.0	1	-59.99999999999999	59.99999999999999								
	744	739	0.005532827939625935	0.0712874563188196	0.017225628885542493	442.0	442.0	442.0	1.0323863636363637	0.0	1	-59.99999999999999	59.99999999999999								
	745	647	0.006164855084474038	0.2126823969647102	-4.999999999999992e-7	149.0	149.0	149.0	1.0937499999999996	0.0	1	-59.99999999999999	59.99999999999999								
	745	648	0.006140082361023334	0.22479040188786725	-4.999999999999993e-7	141.0	141.0	141.0	1.0937499999999996	0.0	1	-59.99999999999999	59.99999999999999								
	746	856	0.0029758363111427313	0.12631968876616811	-4.999999999999993e-7	250.0	250.0	250.0	1.0392933333333334	0.0	1	-59.99999999999999	59.99999999999999								
	746	856	0.0017210321164907508	0.10359203804894808	-4.999999999999994e-7	305.0	305.0	305.0	1.0392933333333334	0.0	1	-59.99999999999999	59.99999999999999								
	746	933	0.004578667651192518	0.21967601570721934	-4.999999999999993e-7	144.0	144.0	144.0	1.022222222222222	0.0	1	-59.99999999999999	59.99999999999999								
	746	934	0.004518458297354475	0.21401596590126637	-4.999999999999992e-7	148.0	148.0	148.0	1.022222222222222	0.0	1	-59.99999999999999	59.99999999999999								
	747	737	0.0025993720421957113	0.07984722415006427	-4.999999999999993e-7	396.0	396.0	396.0	1.0323863636363637	0.0	1	-59.99999999999999	59.99999999999999								
	747	737	0.0025219402314124962	0.08219240834227941	-4.999999999999993e-7	385.0	385.0	385.0	1.0323863636363637	0.0	1	-59.99999999999999	59.99999999999999								
	742	857	0.0021542042910399103	0.10539637593692115	-4.999999999999993e-7	300.0	300.0	300.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	742	857	0.0022249193520246188	0.1003293508917141	-4.999999999999993e-7	315.0	315.0	315.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	742	858	0.00220199289836159	0.10591991182612714	-4.999999999999992e-7	299.0	299.0	299.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	742	935	0.007035742145571246	0.37252511766479546	-4.999999999999993e-7	85.0	85.0	85.0	0.9374999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	742	935	0.006525594183323759	0.3656442010348125	-4.999999999999993e-7	87.0	87.0	87.0	0.9374999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	754	859	0.002171703315347724	0.1015424079034031	-4.999999999999993e-7	312.0	312.0	312.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	754	859	0.0021413625244052744	0.10207306552601512	-4.999999999999994e-7	310.0	310.0	310.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	754	859	0.0023252899813468683	0.09700579559502741	-4.999999999999993e-7	326.0	326.0	326.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	756	826	0.00031127864618806417	0.02771005464552224	-4.999999999999992e-7	1140.0	1140.0	1140.0	1.0363636363636364	0.0	1	-59.99999999999999	59.99999999999999								
	756	826	0.00047319699146302805	0.029974596155026855	-4.999999999999993e-7	1054.0	1054.0	1054.0	1.0363636363636364	0.0	1	-59.99999999999999	59.99999999999999								
	756	826	0.002183880131309226	0.03215918909448935	-4.999999999999991e-7	980.0000000000001	980.0000000000001	980.0000000000001	1.0363636363636364	0.0	1	-59.99999999999999	59.99999999999999								
	757	866	0.0028011642566340305	0.09331956989769069	-4.999999999999993e-7	339.0	339.0	339.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	757	866	0.0020693093301254995	0.10844022076459314	-4.999999999999994e-7	292.0	292.0	292.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	757	867	0.002879881745807659	0.09920977041551181	-4.999999999999992e-7	319.0	319.0	319.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	757	867	0.0026745791333558154	0.09740277156169569	-4.999999999999993e-7	325.0	325.0	325.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	758	659	0.005714599114229742	0.1486536815736412	-4.999999999999992e-7	213.0	213.0	213.0	1.0227272727272725	0.0	1	-59.99999999999999	59.99999999999999								
	758	660	0.006200636830019604	0.14209276891922717	-4.999999999999993e-7	223.0	223.0	223.0	1.0227272727272725	0.0	1	-59.99999999999999	59.99999999999999								
	749	868	0.002921496029302303	0.10330322018465914	-4.999999999999993e-7	306.0	306.0	306.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	749	868	0.002773962312196687	0.09723306381730543	-4.999999999999993e-7	325.0	325.0	325.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	761	968	0.008610862759759488	0.19739944594832326	-4.999999999999994e-7	160.0	160.0	160.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	762	869	0.002783464082145896	0.12647641252618114	-4.999999999999993e-7	250.0	250.0	250.0	0.9711008888888889	0.0	1	-59.99999999999999	59.99999999999999								
	763	869	0.0017037184348472581	0.1070489533982691	-4.999999999999994e-7	296.0	296.0	296.0	0.988141333333333	0.0	1	-59.99999999999999	59.99999999999999								
	764	871	0.0019142843605734596	0.10680484023333715	-4.999999999999993e-7	296.0	296.0	296.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	764	871	0.002090871624111496	0.09946133622058667	-4.999999999999993e-7	318.0	318.0	318.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	764	872	0.0035476077150998825	0.11146060609039114	-4.999999999999994e-7	284.0	284.0	284.0	0.9820000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	764	872	0.002980790775336165	0.10924132222002514	-4.999999999999992e-7	290.0	290.0	290.0	0.9820000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	765	874	0.0031578244822722335	0.15517288523031617	-4.999999999999993e-7	204.0	204.0	204.0	1.044444444444444	0.0	1	-59.99999999999999	59.99999999999999								
	765	874	0.0032825255977090855	0.16153450833923808	-4.999999999999992e-7	196.0	196.0	196.0	1.044444444444444	0.0	1	-59.99999999999999	59.99999999999999								
	800	876	0.0034407745026720877	0.10064021308489714	-4.999999999999993e-7	314.0	314.0	314.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	800	876	0.0034328335936198197	0.10296187496672413	-4.999999999999993e-7	307.0	307.0	307.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	800	876	0.003172415548894387	0.10069376220236514	-4.999999999999993e-7	314.0	314.0	314.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	779	706	0.008641535463595631	0.2558859515882723	-4.999999999999993e-7	124.0	124.0	124.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	779	706	0.008313455601098786	0.26278396755009625	-4.999999999999992e-7	121.0	121.0	121.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	775	726	0.012472832727983434	0.2534635793659763	-4.999999999999993e-7	125.0	125.0	125.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	775	727	0.013606251834371898	0.2659004052325544	-4.999999999999994e-7	119.0	119.0	119.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	776	969	0.007013729006775509	0.1531006915289932	-4.999999999999991e-7	206.99999999999997	206.99999999999997	206.99999999999997	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	776	969	0.006752176943236831	0.15889782952312118	-4.999999999999993e-7	199.0	199.0	199.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	776	969	0.006707034878825623	0.15616098859896116	-4.999999999999992e-7	202.99999999999997	202.99999999999997	202.99999999999997	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	779	676	0.0051437313538993034	0.15172634524663117	-4.999999999999994e-7	209.0	209.0	209.0	1.1181136363636361	0.0	1	-59.99999999999999	59.99999999999999								
	779	677	0.0048662291597499135	0.15793765675354923	-4.999999999999992e-7	200.0	200.0	200.0	1.1181136363636361	0.0	1	-59.99999999999999	59.99999999999999								
	779	678	0.004724045878273275	0.15505032913851718	-4.999999999999993e-7	204.0	204.0	204.0	1.1181136363636361	0.0	1	-59.99999999999999	59.99999999999999								
	779	679	0.004878680756261412	0.1504405234556102	-4.999999999999993e-7	210.0	210.0	210.0	1.1181136363636361	0.0	1	-59.99999999999999	59.99999999999999								
	779	680	0.0034754325328039265	0.12378694421874112	-4.999999999999993e-7	256.0	256.0	256.0	1.0726363636363634	0.0	1	-59.99999999999999	59.99999999999999								
	779	681	0.0035279477525519466	0.12478908770018413	-4.999999999999993e-7	254.0	254.0	254.0	1.0726363636363634	0.0	1	-59.99999999999999	59.99999999999999								
	779	682	0.0036826583237287848	0.12453436962876618	-4.999999999999993e-7	254.0	254.0	254.0	1.0726363636363634	0.0	1	-59.99999999999999	59.99999999999999								
	782	883	0.001927099430301525	0.1041811751820071	-4.999999999999993e-7	304.0	304.0	304.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	782	883	0.0019026695158591682	0.1014112643091181	-4.999999999999992e-7	312.0	312.0	312.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	782	884	0.003032886923050333	0.10419136610620412	-4.999999999999994e-7	304.0	304.0	304.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	782	884	0.0028260930051448086	0.10653191224362416	-4.999999999999992e-7	297.0	297.0	297.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	782	885	0.0022133153346291	0.09720158984864964	-4.999999999999993e-7	325.0	325.0	325.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	745	886	0.009445729798195737	0.2500081503188632	-4.999999999999993e-7	127.0	127.0	127.0	1.0563031111111107	0.0	1	-59.99999999999999	59.99999999999999								
	786	692	0.0043801978764048035	0.11615201408166619	-4.999999999999994e-7	272.0	272.0	272.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	787	974	0.0008741517116565482	0.05661587854107553	-4.999999999999996e-7	558.0	558.0	558.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	745	699	0.009685009192718499	0.2050069308193093	-4.999999999999992e-7	154.0	154.0	154.0	1.0929752066115697	0.0	1	-59.99999999999999	59.99999999999999								
	745	700	0.010094518985468719	0.19511681144730425	-4.999999999999993e-7	162.0	162.0	162.0	1.0929752066115697	0.0	1	-59.99999999999999	59.99999999999999								
	745	701	1.0000000183936208e-9	0.18357803103964923	-4.999999999999993e-7	173.0	173.0	173.0	1.0931818181818176	0.0	1	-59.99999999999999	59.99999999999999								
	779	895	0.002373881978734236	0.11020474085702407	-4.999999999999993e-7	287.0	287.0	287.0	1.0017545454545456	0.0	1	-59.99999999999999	59.99999999999999								
	897	779	0.0017455249904512174	0.10766166968737646	0.0038065630021154573	294.0	294.0	294.0	0.9982485275834218	0.0	1	-59.99999999999999	59.99999999999999								
	779	895	0.002013286162754819	0.10872141776905206	-4.999999999999993e-7	291.0	291.0	291.0	1.0017545454545456	0.0	1	-59.99999999999999	59.99999999999999								
	794	899	0.001379066700769421	0.07724261573558477	-4.999999999999993e-7	409.0	409.0	409.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	794	899	0.0014054284932267182	0.08321324858024522	-4.999999999999993e-7	380.0	380.0	380.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	749	712	0.0004143190271424355	0.03834961395377933	-4.999999999999994e-7	824.0	824.0	824.0	1.0614999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	798	906	0.010831038807124714	0.1570211222264281	-4.999999999999992e-7	200.99999999999997	200.99999999999997	200.99999999999997	0.9732204545454544	0.0	1	-59.99999999999999	59.99999999999999								
	798	906	0.01107336641378401	0.1605595510920432	-4.999999999999994e-7	197.0	197.0	197.0	0.9732204545454544	0.0	1	-59.99999999999999	59.99999999999999								
	798	949	0.02567398322234867	0.7468865499940628	-4.999999999999992e-7	43.0	43.0	43.0	1.0681818181818175	0.0	1	-59.99999999999999	59.99999999999999								
	798	949	0.0258926237968186	0.7212069044353607	-4.999999999999994e-7	44.0	44.0	44.0	1.0681818181818175	0.0	1	-59.99999999999999	59.99999999999999								
	803	741	0.006882560261031467	0.36668410087184944	-4.999999999999993e-7	87.0	87.0	87.0	0.9749999999999995	0.0	1	-59.99999999999999	59.99999999999999								
	803	833	0.002829457863190968	0.1023239885581941	-4.999999999999993e-7	309.0	309.0	309.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	803	833	0.0013571462913312279	0.09666753353070881	-4.999999999999993e-7	327.0	327.0	327.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	803	833	0.0033869906329678486	0.10280911530906009	-4.999999999999993e-7	308.0	308.0	308.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	803	907	0.0034023694600158485	0.10399926760468814	-4.999999999999994e-7	304.0	304.0	304.0	0.9024999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	803	907	0.0033153011965097972	0.09824607010784277	-4.999999999999994e-7	322.0	322.0	322.0	0.9024999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	803	907	0.002175426764327865	0.10312894611638111	-4.999999999999992e-7	307.0	307.0	307.0	0.9024999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	803	741	0.0030844392132082284	0.1401712188749782	-4.999999999999993e-7	225.99999999999997	225.99999999999997	225.99999999999997	0.9772727272727267	0.0	1	-59.99999999999999	59.99999999999999								
	804	908	0.0019042905077848846	0.09323421041905357	-4.999999999999994e-7	339.0	339.0	339.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	804	908	0.003418480997178536	0.09704803301403292	-4.999999999999993e-7	326.0	326.0	326.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	804	909	0.0022282847942056466	0.0957902890074793	-4.999999999999993e-7	330.0	330.0	330.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	804	909	0.002919217899704199	0.09394606080529463	-4.999999999999992e-7	337.0	337.0	337.0	0.9609999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	804	951	0.006801554082540621	0.3972517960470406	-4.999999999999993e-7	187.11478237951468	80.0	80.0	0.9250000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	804	952	0.006516272654606291	0.39137283732897954	-4.999999999999994e-7	81.0	81.0	81.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	805	910	0.0029449314836685805	0.10947396642806607	-4.999999999999994e-7	289.0	289.0	289.0	0.9880800000000006	0.0	1	-59.99999999999999	59.99999999999999								
	805	910	0.0028668934858989232	0.10941024590336311	-4.999999999999994e-7	289.0	289.0	289.0	0.9880800000000006	0.0	1	-59.99999999999999	59.99999999999999								
	805	910	0.002078572136085313	0.1011626891603081	-4.999999999999994e-7	313.0	313.0	313.0	0.9880800000000006	0.0	1	-59.99999999999999	59.99999999999999								
	806	911	0.0012232234025726283	0.08773292513538658	-4.999999999999994e-7	361.0	361.0	361.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	807	911	0.0013043833060393372	0.08429104425251481	-4.999999999999993e-7	375.0	375.0	375.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	800	912	0.003410025709133435	0.10628116463390011	-4.999999999999993e-7	298.0	298.0	298.0	0.9414999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	800	912	0.003270979796023872	0.1003121356977081	-4.999999999999994e-7	315.0	315.0	315.0	0.9414999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	800	913	0.003363589240381319	0.10241077084954814	-4.999999999999994e-7	309.0	309.0	309.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	800	913	0.002149169332740668	0.1096238133983221	-4.999999999999993e-7	289.0	289.0	289.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	776	914	0.0021518235084287077	0.09702867836082489	-4.999999999999993e-7	326.0	326.0	326.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	776	914	0.0022437920956321247	0.09910907927476562	-4.999999999999992e-7	319.0	319.0	319.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	776	914	0.002179068950284105	0.1060827353989501	-4.999999999999994e-7	298.0	298.0	298.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	812	915	0.0021482257049906255	0.1042955573667041	-4.999999999999994e-7	303.0	303.0	303.0	0.9710088888888891	0.0	1	-59.99999999999999	59.99999999999999								
	812	915	0.003223858035432007	0.12752059506817517	-4.999999999999994e-7	248.0	248.0	248.0	0.9710088888888891	0.0	1	-59.99999999999999	59.99999999999999								
	813	916	0.0021334508909609355	0.1022037430996061	-4.999999999999993e-7	309.0	309.0	309.0	1.022222222222222	0.0	1	-59.99999999999999	59.99999999999999								
	813	916	0.002242904035180647	0.10808962087454314	-4.999999999999993e-7	293.0	293.0	293.0	1.022222222222222	0.0	1	-59.99999999999999	59.99999999999999								
	814	919	0.003218702696468048	0.10273232206815315	-4.999999999999994e-7	308.0	308.0	308.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	814	919	0.003177352669132706	0.0993939703576471	-4.999999999999993e-7	318.0	318.0	318.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	814	920	0.0027336966437015798	0.09779432337128187	-4.999999999999994e-7	323.0	323.0	323.0	0.9804999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	815	921	0.007268319153568271	0.2221241849203892	-4.999999999999993e-7	143.0	143.0	143.0	1.039262666666667	0.0	1	-59.99999999999999	59.99999999999999								
	807	924	0.0016847322475065593	0.10099308176309914	-4.999999999999993e-7	313.0	313.0	313.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	807	925	0.0034661133812207917	0.10416660216897211	-4.999999999999994e-7	304.0	304.0	304.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	817	925	0.002285422012702715	0.10011277378485509	-4.999999999999994e-7	316.0	316.0	316.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	806	924	0.002106921840326882	0.10595968205579911	-4.999999999999993e-7	299.0	299.0	299.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	806	925	0.0024647945380041635	0.09567351254517394	-4.999999999999993e-7	331.0	331.0	331.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	745	729	0.009713714689947039	0.19806825634533728	-4.999999999999993e-7	160.0	160.0	160.0	1.0929752066115697	0.0	1	-59.99999999999999	59.99999999999999								
	749	926	0.0033137054117636944	0.10260588505703408	-4.999999999999993e-7	308.0	308.0	308.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	749	926	0.0032367210588369706	0.10553716210430007	-4.999999999999993e-7	300.0	300.0	300.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	749	926	0.0020414414160156813	0.10188338741166715	-4.999999999999994e-7	310.0	310.0	310.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	749	927	0.003316752220838636	0.09745523804360526	-4.999999999999992e-7	324.0	324.0	324.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	749	957	0.0032498444767867477	0.14397862777686316	-4.999999999999993e-7	220.00000000000003	220.00000000000003	220.00000000000003	0.9772727272727267	0.0	1	-59.99999999999999	59.99999999999999								
	749	959	0.003190146216286201	0.14409470885044118	-4.999999999999992e-7	220.00000000000003	220.00000000000003	220.00000000000003	0.9614409090909091	0.0	1	-59.99999999999999	59.99999999999999								
	822	731	0.0006527834965356851	0.033523601469925446	-4.999999999999992e-7	943.0	943.0	943.0	1.0061454545454551	0.0	1	-59.99999999999999	59.99999999999999								
	822	732	0.0006021061918170435	0.032296122904649824	-4.999999999999992e-7	977.9999999999999	977.9999999999999	977.9999999999999	1.0061454545454551	0.0	1	-59.99999999999999	59.99999999999999								
	822	733	0.0006107403727097662	0.03159728748681664	-4.999999999999991e-7	1000.0	1000.0	1000.0	1.0061454545454551	0.0	1	-59.99999999999999	59.99999999999999								
	822	966	0.01713428645323435	0.43026831860555553	-4.999999999999992e-7	74.0	74.0	74.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	822	967	0.017548831586039915	0.42783142991228257	-4.999999999999993e-7	74.0	74.0	74.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	822	983	0.009302464537920285	0.21850134607112728	-4.999999999999993e-7	145.0	145.0	145.0	1.045454545454545	0.0	1	-59.99999999999999	59.99999999999999								
	823	730	0.0005773699045666271	0.03295690924487394	-4.999999999999992e-7	959.0	959.0	959.0	0.9963181818181828	0.0	1	-59.99999999999999	59.99999999999999								
	827	740	0.01283279526757152	0.23880982848405122	-4.999999999999996e-7	133.0	133.0	133.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	827	740	0.012587947472580534	0.24425868114101923	-4.999999999999994e-7	130.0	130.0	130.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	828	806	0.0009241864002289494	0.023388995754347938	-4.999999999999994e-7	1350.0	1350.0	1350.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	828	807	0.000954290165282624	0.024268092511027926	-4.999999999999994e-7	1301.0	1301.0	1301.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	834	754	0.00019743159364389798	0.018101848586154917	-4.999999999999996e-7	1745.0	1745.0	1745.0	1.0375000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	835	779	0.00042985297991831255	0.02832909945269663	-4.999999999999996e-7	1115.0	1115.0	1115.0	0.985217391304348	0.0	1	-59.99999999999999	59.99999999999999								
	835	779	0.00042935632131046086	0.028972448535700634	-4.999999999999996e-7	1091.0	1091.0	1091.0	0.985217391304348	0.0	1	-59.99999999999999	59.99999999999999								
	835	779	0.0006517829807963384	0.029175510485123905	0.006627461571643289	1083.0	1083.0	1083.0	0.985217391304348	0.0	1	-59.99999999999999	59.99999999999999								
	836	832	0.00028795426225254784	0.02042271853691883	-4.999999999999996e-7	1547.0	1547.0	1547.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	837	782	0.00033652628183534767	0.02875295753242064	-4.999999999999996e-7	1099.0	1099.0	1099.0	0.9999999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	837	782	0.00033689008141804885	0.028885297644212243	-4.999999999999994e-7	1094.0	1094.0	1094.0	0.9999999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	837	783	0.0003587606388207751	0.028783048522720935	-4.999999999999997e-7	1098.0	1098.0	1098.0	0.9899999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	838	686	0.00040411700861698414	0.02510126205253582	-4.999999999999997e-7	1259.0	1259.0	1259.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	838	687	0.0003929551701637211	0.025394107393232928	-4.999999999999996e-7	1244.0	1244.0	1244.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	838	688	0.0004164441592822078	0.024875891337890026	-4.999999999999996e-7	1270.0	1270.0	1270.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	838	689	0.0003920900537090602	0.025032491551397223	-4.999999999999997e-7	1262.0	1262.0	1262.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	838	690	0.0003602261999117437	0.027693820371392033	-4.999999999999997e-7	1141.0	1141.0	1141.0	1.0375000000000014	0.0	1	-59.99999999999999	59.99999999999999								
	838	691	0.00034923746391742137	0.02759799555648062	-4.999999999999996e-7	1145.0	1145.0	1145.0	1.0375000000000014	0.0	1	-59.99999999999999	59.99999999999999								
	839	764	0.00016791793212837003	0.018086644645055622	-4.999999999999994e-7	1747.0	1747.0	1747.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	839	764	0.00015090786922250483	0.01723724317309012	-4.999999999999994e-7	1832.9999999999998	1832.9999999999998	1832.9999999999998	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	840	702	0.000652728394863967	0.04774035945582844	-4.999999999999994e-7	662.0	662.0	662.0	1.058250000000001	0.0	1	-59.99999999999999	59.99999999999999								
	840	703	0.000668881062086508	0.046231604140803136	-4.999999999999996e-7	684.0	684.0	684.0	1.058250000000001	0.0	1	-59.99999999999999	59.99999999999999								
	842	757	0.00018911864173703363	0.017976519968418217	-4.999999999999996e-7	1757.9999999999998	1757.9999999999998	1757.9999999999998	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	843	828	0.00016343151030486844	0.012423680907969217	-4.999999999999996e-7	2543.0	2543.0	2543.0	0.9875	0.0	1	-59.99999999999999	59.99999999999999								
	845	811	0.0003094744793603423	0.026501742616204426	-4.999999999999996e-7	1192.0	1192.0	1192.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	849	931	0.014250304748859114	0.33110598601627333	-4.999999999999996e-7	96.0	96.0	96.0	1.0176399999999999	0.0	1	-59.99999999999999	59.99999999999999								
	849	932	0.014212017359848922	0.32285654756865645	-4.999999999999994e-7	98.0	98.0	98.0	0.9941200000000002	0.0	1	-59.99999999999999	59.99999999999999								
	861	653	0.027858788027853656	0.3241279480415417	0.003007447060270294	98.0	98.0	98.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	862	654	0.011655521302584522	0.09159409178368817	-4.999999999999996e-7	343.0	343.0	343.0	0.9500000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	863	655	0.005618472058727718	0.04067341091982446	-4.999999999999996e-7	770.0	770.0	770.0	0.9500000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	864	656	0.04605481474112895	0.6038437076801457	-4.999999999999994e-7	53.0	53.0	53.0	1.08	0.0	1	-59.99999999999999	59.99999999999999								
	864	657	0.049829741882264446	0.5885649532302498	-4.999999999999997e-7	54.0	54.0	54.0	1.08	0.0	1	-59.99999999999999	59.99999999999999								
	879	882	0.006863042392089338	0.17791601699426918	-4.999999999999994e-7	178.0	178.0	178.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	880	881	0.0064139189028421546	0.1744905129971372	-4.999999999999996e-7	181.0	181.0	181.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	895	975	0.04962817868282263	0.7815365834711049	-4.999999999999997e-7	41.0	41.0	41.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	899	946	0.006103468354618935	0.2613989697499504	-4.999999999999994e-7	121.0	121.0	121.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	899	946	0.006693531835211282	0.23902597657595037	-4.999999999999996e-7	133.0	133.0	133.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	900	947	0.010547659769726802	0.41624487775782354	-4.999999999999994e-7	76.0	76.0	76.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	901	902	0.022572497085574697	0.4393491865291874	-4.999999999999994e-7	72.0	72.0	72.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	901	903	0.02375023043567382	0.4417784342907775	-4.999999999999996e-7	72.0	72.0	72.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	902	714	0.04080421171499594	0.4304254352219794	-4.999999999999993e-7	74.0	74.0	74.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	903	713	0.04820610499357973	0.5782694873155483	-4.999999999999996e-7	55.00000000000001	55.00000000000001	55.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	904	644	0.006293764092425642	0.1667565198532002	-4.999999999999996e-7	190.0	190.0	190.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	905	717	0.00788219659194056	0.00892066708737224	-4.999999999999994e-7	2654.0	2654.0	2654.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	905	718	0.009241040786767206	0.20080380595376932	-4.999999999999996e-7	158.0	158.0	158.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	905	719	0.015059038710288502	0.33228621431565136	-4.999999999999996e-7	95.0	95.0	95.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	905	720	0.01588180621597148	0.33925835980078445	-4.999999999999996e-7	94.0	94.0	94.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	916	728	0.0032243152483549717	0.060654438483167254	-4.999999999999993e-7	521.0	521.0	521.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	922	953	0.010611864957233718	0.4058909175672966	-4.999999999999994e-7	78.0	78.0	78.0	0.9903409090909091	0.0	1	-59.99999999999999	59.99999999999999								
	922	954	0.010363504530695967	0.4046665351779596	-4.999999999999996e-7	79.0	79.0	79.0	0.9903409090909091	0.0	1	-59.99999999999999	59.99999999999999								
	922	955	0.010010972367396375	0.4159225147345495	-4.999999999999996e-7	76.0	76.0	76.0	0.9903409090909091	0.0	1	-59.99999999999999	59.99999999999999								
	922	956	0.010456847689991703	0.38570933596579543	-4.999999999999997e-7	82.0	82.0	82.0	0.9903409090909091	0.0	1	-59.99999999999999	59.99999999999999								
	930	825	0.0017243461345800464	0.13625764947695823	-4.999999999999993e-7	231.99999999999997	231.99999999999997	231.99999999999997	1.0227272727272725	0.0	1	-59.99999999999999	59.99999999999999								
	930	825	0.0018109773184781155	0.12714721376257215	-4.999999999999994e-7	249.00000000000003	249.00000000000003	249.00000000000003	1.0227272727272725	0.0	1	-59.99999999999999	59.99999999999999								
	940	970	0.04937739340471277	0.9906519674451489	-4.999999999999993e-7	32.0	32.0	32.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	940	971	0.050854228840900455	0.963421595910325	-4.999999999999993e-7	33.0	33.0	33.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	940	972	0.04977412401115695	0.9827083584142319	-4.999999999999994e-7	33.0	33.0	33.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	941	704	0.01791291077501309	0.3945501918117445	-4.999999999999993e-7	80.0	80.0	80.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	705	945	0.038253581856821865	0.45428859375328995	0.001085406663220843	70.0	70.0	70.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	944	975	0.03213243133264302	0.4213200760477616	-4.999999999999993e-7	75.0	75.0	75.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	947	711	0.02630363147023542	0.27562232662129843	-4.999999999999993e-7	114.99999999999999	114.99999999999999	114.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	949	981	0.04780342196928528	1.0441072130331213	-4.999999999999991e-7	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	963	964	0.04805671310633612	1.0079745585785613	-4.999999999999992e-7	32.0	32.0	32.0	1.0227272727272725	0.0	1	-59.99999999999999	59.99999999999999								
	963	965	0.05140426124096096	0.9809011392982139	-4.999999999999992e-7	33.0	33.0	33.0	1.0227272727272725	0.0	1	-59.99999999999999	59.99999999999999								
	973	693	0.005598129267694265	0.06745446880090317	-4.999999999999996e-7	467.0	467.0	467.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	973	694	0.009368365033410328	0.10718106344334316	-4.999999999999996e-7	294.0	294.0	294.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	973	695	0.019581456114504035	0.23109287375681636	-4.999999999999996e-7	137.0	137.0	137.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	974	696	0.005946586341429345	0.0660876152022005	-4.999999999999997e-7	476.99999999999994	476.99999999999994	476.99999999999994	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	974	697	0.011198618635914127	0.12745908329292918	-4.999999999999994e-7	247.00000000000003	247.00000000000003	247.00000000000003	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	974	698	0.014241465851107436	0.15765487626423325	-4.999999999999993e-7	200.0	200.0	200.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	986	1800	1.0000000002037268e-9	0.03630166925816224	-4.999999999999992e-7	871.0000000000001	871.0000000000001	871.0000000000001	0.9654599999999999	0.0	1	-59.99999999999999	59.99999999999999								
	996	998	0.0077696113439107714	0.16069263744885112	-4.999999999999996e-7	197.0	197.0	197.0	1.0375000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	996	1000	0.02513961984949361	0.6564086026923477	-4.999999999999994e-7	49.0	49.0	49.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	997	998	0.007650059919135485	0.17211647536384017	-4.999999999999993e-7	184.0	184.0	184.0	1.0375000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	997	999	0.02354446099206514	0.6185945912396189	-4.999999999999996e-7	52.0	52.0	52.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1001	1003	0.053108782458813696	0.6439026632196097	-4.999999999999996e-7	49.0	49.0	49.0	0.92773	0.0	1	-59.99999999999999	59.99999999999999								
	1006	1007	0.013417761188235006	0.2587496554661932	-4.999999999999998e-7	122.0	122.0	122.0	0.9659090909090908	0.0	1	-59.99999999999999	59.99999999999999								
	1006	1007	0.0060699381524434584	0.17216931227656318	-4.999999999999994e-7	184.0	184.0	184.0	0.9624999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1006	1007	0.005941574350112875	0.17197387118013718	-4.999999999999996e-7	184.0	184.0	184.0	0.9624999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1008	1009	0.04323271583718376	0.7754675642182378	-4.999999999999994e-7	41.0	41.0	41.0	0.8874999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1008	1009	0.045022587105874784	0.7640013851675679	-4.999999999999994e-7	42.0	42.0	42.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	1011	1013	0.007789146458306204	0.24020744970600028	-4.999999999999993e-7	132.0	132.0	132.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1012	1011	0.006534568033778866	0.1726049051017142	-4.999999999999996e-7	183.0	183.0	183.0	0.9375	0.0	1	-59.99999999999999	59.99999999999999								
	1013	1012	0.037101171235464775	0.4946569761736095	-4.999999999999994e-7	64.0	64.0	64.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1013	1012	0.03648954335861542	0.5084731983561684	-4.999999999999996e-7	62.0	62.0	62.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1016	1058	0.00884385978252464	0.17165083436867748	0.0008358334294676284	184.0	184.0	184.0	0.9756097560975608	0.0	1	-59.99999999999999	59.99999999999999								
	1015	1016	0.007584504116067517	0.15825579516669916	-4.999999999999993e-7	200.0	200.0	200.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1021	1022	0.018776280486543517	0.21220084384705123	-4.999999999999996e-7	149.0	149.0	149.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1021	1022	0.016538867020739124	0.22556714349437726	-4.999999999999994e-7	140.0	140.0	140.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1021	1022	0.004465071697516221	0.1915944391250862	-4.999999999999994e-7	165.0	165.0	165.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1025	1202	0.013484260527077801	0.42187948015940524	0.0004971950739126648	75.0	75.0	75.0	1.0126582278481013	0.0	1	-59.99999999999999	59.99999999999999								
	1202	1025	0.012817733214908977	0.3937093649024724	-4.999999999999997e-7	81.0	81.0	81.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1026	1027	0.013882240469843906	0.3365269704311542	-4.999999999999993e-7	94.0	94.0	94.0	1.017241379310345	0.0	1	-59.99999999999999	59.99999999999999								
	1026	1028	0.013571648228510137	0.37959874454599013	-4.999999999999994e-7	84.0	84.0	84.0	1.017241379310345	0.0	1	-59.99999999999999	59.99999999999999								
	1026	1029	0.013196543164981412	0.3501686098379472	-4.999999999999994e-7	91.0	91.0	91.0	1.017241379310345	0.0	1	-59.99999999999999	59.99999999999999								
	1026	1030	0.012657294481985095	0.3536580663903771	-4.999999999999996e-7	90.0	90.0	90.0	1.017241379310345	0.0	1	-59.99999999999999	59.99999999999999								
	1031	1033	0.0032679858769977727	0.1260599219605441	-4.999999999999996e-7	250.99999999999997	250.99999999999997	250.99999999999997	0.9326086956521739	0.0	1	-59.99999999999999	59.99999999999999								
	1033	1456	0.031076057238449303	0.17352831752133183	0.010250061271861271	180.0	180.0	180.0	1.0722610722610724	0.0	1	-59.99999999999999	59.99999999999999								
	1034	1035	0.004822037968681486	0.17447147974120517	-4.999999999999996e-7	181.0	181.0	181.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1034	1035	0.004910034214620333	0.1592176984456622	-4.999999999999992e-7	199.0	199.0	199.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1037	1039	0.0029755768550157953	0.12862212763803213	-4.999999999999993e-7	246.0	246.0	246.0	0.9923913043478264	0.0	1	-59.99999999999999	59.99999999999999								
	1037	1039	0.0025134140446333476	0.1303170154960312	-4.999999999999994e-7	243.00000000000003	243.00000000000003	243.00000000000003	0.9923913043478264	0.0	1	-59.99999999999999	59.99999999999999								
	1040	1041	0.003845471178872358	0.1325352745120381	-4.999999999999994e-7	239.0	239.0	239.0	0.9708695652173912	0.0	1	-59.99999999999999	59.99999999999999								
	1040	1041	0.003923807932196025	0.12375393248822214	-4.999999999999996e-7	256.0	256.0	256.0	0.9708695652173912	0.0	1	-59.99999999999999	59.99999999999999								
	1042	1043	0.007925878083465447	0.17149120650467617	-4.999999999999996e-7	184.0	184.0	184.0	0.975	0.0	1	-59.99999999999999	59.99999999999999								
	1042	1043	0.03883034628629976	0.4973550741174845	-4.999999999999994e-7	64.0	64.0	64.0	1.13632	0.0	1	-59.99999999999999	59.99999999999999								
	1044	1045	0.008898678581530085	0.15648282161446517	-4.999999999999993e-7	202.0	202.0	202.0	1.0456	0.0	1	-59.99999999999999	59.99999999999999								
	1044	1045	0.008184405623517773	0.16615185889935316	-4.999999999999997e-7	190.0	190.0	190.0	1.0456	0.0	1	-59.99999999999999	59.99999999999999								
	987	1048	0.004848637859473776	0.1705379944658482	-4.999999999999994e-7	186.0	186.0	186.0	0.9792869565217392	0.0	1	-59.99999999999999	59.99999999999999								
	987	1048	0.0049366525886317975	0.17223912515696319	-4.999999999999994e-7	184.0	184.0	184.0	0.9565217391304348	0.0	1	-59.99999999999999	59.99999999999999								
	987	1048	0.0013375889155937547	0.0815227193565685	-4.999999999999996e-7	388.0	388.0	388.0	0.9792869565217392	0.0	1	-59.99999999999999	59.99999999999999								
	989	1050	0.002900260264791388	0.12375745363425612	-4.999999999999994e-7	256.0	256.0	256.0	0.9852173913043479	0.0	1	-59.99999999999999	59.99999999999999								
	989	1050	0.0037667057267360576	0.11303848650900807	-4.999999999999996e-7	280.0	280.0	280.0	0.9852173913043479	0.0	1	-59.99999999999999	59.99999999999999								
	989	1050	0.003935604038221602	0.10787003913094907	-4.999999999999994e-7	293.0	293.0	293.0	0.9852173913043479	0.0	1	-59.99999999999999	59.99999999999999								
	988	1052	0.004001854055171672	0.11228654058213505	-4.999999999999996e-7	282.0	282.0	282.0	0.9695304347826088	0.0	1	-59.99999999999999	59.99999999999999								
	988	1052	0.004303258225723941	0.12417261726690615	-4.999999999999994e-7	254.99999999999997	254.99999999999997	254.99999999999997	0.9695304347826088	0.0	1	-59.99999999999999	59.99999999999999								
	1053	1428	0.0075240516375720615	0.28777652779006613	-4.999999999999994e-7	110.00000000000001	110.00000000000001	110.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1055	1056	0.00507667201211986	0.17937792531401017	-4.999999999999994e-7	177.0	177.0	177.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1055	1056	0.004222043400259529	0.1261196800905531	-4.999999999999994e-7	250.99999999999997	250.99999999999997	250.99999999999997	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1055	1056	0.004678975838227037	0.17564067201026015	-4.999999999999996e-7	180.0	180.0	180.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1060	1061	0.009081897752864143	0.18040866473661016	-4.999999999999994e-7	175.0	175.0	175.0	1.0025645849630163	0.0	1	-59.99999999999999	59.99999999999999								
	1060	1061	0.007788026398259056	0.1473248006470152	-4.999999999999994e-7	215.0	215.0	215.0	1.0025645849630163	0.0	1	-59.99999999999999	59.99999999999999								
	1063	1615	0.003653744762793023	0.10763728397459905	-4.999999999999994e-7	294.0	294.0	294.0	0.9852173913043479	0.0	1	-59.99999999999999	59.99999999999999								
	1064	1615	0.0036751224191503788	0.11355868601786107	-4.999999999999996e-7	279.0	279.0	279.0	0.9852173913043479	0.0	1	-59.99999999999999	59.99999999999999								
	1065	1066	0.02417294390849938	0.5894473261327918	-4.999999999999996e-7	54.0	54.0	54.0	0.925	0.0	1	-59.99999999999999	59.99999999999999								
	1065	1066	0.03989857273566711	0.9576050951739612	-4.999999999999994e-7	33.0	33.0	33.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1067	1433	0.5590950039635386	2.315891219191683	-4.999999999999994e-7	14.000000000000002	14.000000000000002	14.000000000000002	0.9999999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1068	1069	0.011538435528790403	0.29548273707630535	-4.999999999999996e-7	107.0	107.0	107.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1068	1069	0.01129084722550481	0.2900440361285023	-4.999999999999997e-7	109.00000000000001	109.00000000000001	109.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1307	1071	0.010301598643010336	0.3251920561239285	-4.999999999999996e-7	98.0	98.0	98.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1072	1074	0.011367871168648735	0.31570164486915747	-4.999999999999994e-7	100.0	100.0	100.0	0.9374999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1073	1075	0.011401828665434674	0.30239316228104934	-4.999999999999998e-7	105.0	105.0	105.0	0.9374999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1426	1073	0.02024406562327453	0.35814681857765407	0.002688574980667356	89.0	89.0	89.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1078	1079	0.0036412080810934565	0.12884373809656313	-4.999999999999994e-7	246.0	246.0	246.0	0.9326086956521739	0.0	1	-59.99999999999999	59.99999999999999								
	1078	1079	0.0038268935628718026	0.12182913319267509	-4.999999999999994e-7	260.0	260.0	260.0	0.9326086956521739	0.0	1	-59.99999999999999	59.99999999999999								
	1080	1062	0.003611281058475673	0.10312320282165109	-4.999999999999996e-7	307.0	307.0	307.0	0.9852173913043479	0.0	1	-59.99999999999999	59.99999999999999								
	1080	1062	0.0025643740078591	0.09880971517510889	-4.999999999999994e-7	320.0	320.0	320.0	0.9852173913043479	0.0	1	-59.99999999999999	59.99999999999999								
	1083	1084	0.008719993806479354	0.25052580451249723	-4.999999999999996e-7	127.0	127.0	127.0	0.9813818181818181	0.0	1	-59.99999999999999	59.99999999999999								
	1083	1084	0.008461128823412439	0.2593297113640143	-4.999999999999994e-7	122.0	122.0	122.0	0.97728	0.0	1	-59.99999999999999	59.99999999999999								
	1085	1087	0.0035368808583978823	0.1382389887628862	-4.999999999999996e-7	229.0	229.0	229.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1085	1087	0.0034309359138522556	0.12946940024587514	-4.999999999999994e-7	244.0	244.0	244.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1086	1087	0.004343735658332545	0.18455731965122213	-4.999999999999994e-7	172.0	172.0	172.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1088	1089	0.002450349212032117	0.1248804790160411	-4.999999999999997e-7	252.99999999999997	252.99999999999997	252.99999999999997	0.9923913043478264	0.0	1	-59.99999999999999	59.99999999999999								
	1090	1092	0.0043637327697703876	0.14020947228260514	-4.999999999999994e-7	225.99999999999997	225.99999999999997	225.99999999999997	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1090	1092	0.024270204060004907	0.5326194446160156	-4.999999999999996e-7	60.0	60.0	60.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1093	1094	0.03018629067059775	0.6002672626985637	-4.999999999999996e-7	53.0	53.0	53.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1093	1095	0.03010391771164426	0.5608082053348497	-4.999999999999996e-7	56.99999999999999	56.99999999999999	56.99999999999999	0.9565217391304348	0.0	1	-59.99999999999999	59.99999999999999								
	1096	1097	0.009400146753589477	0.18132487374677514	-4.999999999999994e-7	174.0	174.0	174.0	1.013913043478261	0.0	1	-59.99999999999999	59.99999999999999								
	1096	1097	0.0033614964740461073	0.12778340658258816	-4.999999999999994e-7	248.0	248.0	248.0	1.013913043478261	0.0	1	-59.99999999999999	59.99999999999999								
	1099	1100	0.009975338256044167	0.19235173154012922	-4.999999999999996e-7	164.0	164.0	164.0	0.9995652173913043	0.0	1	-59.99999999999999	59.99999999999999								
	1099	1100	0.009067523952845338	0.19092153960043717	-4.999999999999994e-7	166.0	166.0	166.0	0.9995652173913043	0.0	1	-59.99999999999999	59.99999999999999								
	1102	1103	0.03017144548261244	0.4590872313692164	-4.999999999999996e-7	69.0	69.0	69.0	1.0344927536231887	0.0	1	-59.99999999999999	59.99999999999999								
	1102	1103	0.0192885216056293	0.35502809336384933	-4.999999999999996e-7	89.0	89.0	89.0	1.0282608695652173	0.0	1	-59.99999999999999	59.99999999999999								
	1105	1106	0.011021932479615209	0.5246545097264628	-4.999999999999997e-7	61.0	61.0	61.0	0.9624999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1105	1107	0.01066274144092278	0.5512633925003855	-4.999999999999996e-7	57.99999999999999	57.99999999999999	57.99999999999999	0.975	0.0	1	-59.99999999999999	59.99999999999999								
	1111	1112	0.01881420156224797	0.3423631656722463	-4.999999999999997e-7	93.0	93.0	93.0	0.952	0.0	1	-59.99999999999999	59.99999999999999								
	1111	1112	0.018629699464053677	0.3308100543363154	-4.999999999999996e-7	96.0	96.0	96.0	0.952	0.0	1	-59.99999999999999	59.99999999999999								
	1113	1114	0.023314207453412766	0.6303616125685979	-4.999999999999996e-7	51.0	51.0	51.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1113	1115	0.024556059341022573	0.617528816130574	-4.999999999999997e-7	52.0	52.0	52.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1119	1120	0.039841077861070454	0.9368738891237631	-4.999999999999996e-7	34.0	34.0	34.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1119	1121	0.001453096740620036	0.7790845280530417	-4.999999999999994e-7	41.0	41.0	41.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1122	1124	0.0034057009156880157	0.11959053525230114	-4.999999999999996e-7	265.0	265.0	265.0	0.9804347826086958	0.0	1	-59.99999999999999	59.99999999999999								
	1123	1124	0.0032334360919630415	0.1240549831506291	-4.999999999999996e-7	254.99999999999997	254.99999999999997	254.99999999999997	0.9804347826086958	0.0	1	-59.99999999999999	59.99999999999999								
	1125	1127	0.011197061403525848	0.3238686407935504	-4.999999999999993e-7	98.0	98.0	98.0	1.1	0.0	1	-59.99999999999999	59.99999999999999								
	1126	1127	0.011667297519614803	0.30811430192547146	-4.999999999999994e-7	103.0	103.0	103.0	1.125	0.0	1	-59.99999999999999	59.99999999999999								
	1130	991	0.021438430983295488	0.5502026019000285	-4.999999999999996e-7	57.99999999999999	57.99999999999999	57.99999999999999	0.925	0.0	1	-59.99999999999999	59.99999999999999								
	1130	991	0.02083067105680873	0.5473868014462506	-4.999999999999993e-7	57.99999999999999	57.99999999999999	57.99999999999999	0.925	0.0	1	-59.99999999999999	59.99999999999999								
	1140	1415	0.0014516400625275636	0.07201603140315686	-4.999999999999994e-7	438.99999999999994	438.99999999999994	438.99999999999994	1.0863578181818183	0.0	1	-59.99999999999999	59.99999999999999								
	1140	1416	0.00152627152523987	0.0750722024752218	-4.999999999999994e-7	421.0	421.0	421.0	1.0863578181818183	0.0	1	-59.99999999999999	59.99999999999999								
	1140	1417	0.001465910727932889	0.07885657120883238	-4.999999999999994e-7	401.0	401.0	401.0	1.0863578181818183	0.0	1	-59.99999999999999	59.99999999999999								
	1140	1499	0.0013087976405753978	0.06455813948319887	-4.999999999999994e-7	490.00000000000006	490.00000000000006	490.00000000000006	1.062272727272727	0.0	1	-59.99999999999999	59.99999999999999								
	1140	1500	0.0013510818223579117	0.06195543547734028	-4.999999999999993e-7	509.99999999999994	509.99999999999994	509.99999999999994	1.062272727272727	0.0	1	-59.99999999999999	59.99999999999999								
	1140	1501	0.0013325489804482313	0.06335554502290479	-4.999999999999994e-7	499.0	499.0	499.0	1.062272727272727	0.0	1	-59.99999999999999	59.99999999999999								
	1140	1621	8.16506658809485e-5	0.005331667138600568	-4.999999999999994e-7	3000.0	5924.0	5924.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1145	1251	0.00783915285239165	0.20089561374601125	-4.999999999999996e-7	158.0	158.0	158.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1145	1251	0.00944228610964642	0.1746104944672142	-4.999999999999997e-7	181.0	181.0	181.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1145	1251	0.008035676060702494	0.19822128611802325	-4.999999999999996e-7	160.0	160.0	160.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1154	990	0.010638796254729677	0.27352047848724925	-4.999999999999994e-7	115.99999999999999	115.99999999999999	115.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1158	1456	0.012717381414605737	0.14634888103974528	0.00615797300831964	216.0	216.0	216.0	1.0199556541019954	0.0	1	-59.99999999999999	59.99999999999999								
	1162	1165	0.009464097808289166	0.29451274226320234	-4.999999999999994e-7	108.0	108.0	108.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1165	1162	0.010892205659550187	0.5409819714090787	-4.999999988698368e-7	59.0	59.0	59.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1166	1168	0.0033951233315671053	0.11724872847344313	-4.999999999999996e-7	270.0	270.0	270.0	0.9923913043478264	0.0	1	-59.99999999999999	59.99999999999999								
	1168	1245	0.006510621920725712	0.13562068012817047	0.0007966826460069056	233.0	233.0	233.0	1.0076670317634169	0.0	1	-59.99999999999999	59.99999999999999								
	1169	1170	0.00607161902737974	0.1966788187010142	-4.999999999999996e-7	161.0	161.0	161.0	1.0375000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	1169	1170	0.006596847328307878	0.2074527977588042	-4.999999999999996e-7	153.0	153.0	153.0	1.0375000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	1171	1173	0.02095642224023334	0.6126112064375319	-4.999999999999997e-7	52.0	52.0	52.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1171	1173	0.020066831983029724	0.6298321474627528	-4.999999999999994e-7	51.0	51.0	51.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1172	1436	0.002194122284948193	0.09910470509895437	-4.999999999999996e-7	319.0	319.0	319.0	1.0165	0.0	1	-59.99999999999999	59.99999999999999								
	1174	1175	0.006442251041119744	0.16776047520489423	-4.999999999999996e-7	189.0	189.0	189.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1174	1175	0.0069593655873279505	0.16518053234279315	-4.999999999999994e-7	192.0	192.0	192.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1174	1175	0.004891287202790221	0.16404058766681517	-4.999999999999996e-7	193.0	193.0	193.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1174	1578	0.0007046817903936173	0.04737262146662168	-4.999999999999996e-7	667.0	667.0	667.0	0.9883399999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1178	1179	0.060435431070925666	1.008350138232502	-4.999999999999993e-7	32.0	32.0	32.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1180	1182	0.002671134310312409	0.11128426484629109	-4.999999999999994e-7	284.0	284.0	284.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	1181	1182	0.0028621348989734613	0.11490081318604511	-4.999999999999994e-7	275.0	275.0	275.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	1183	1184	0.007811005825392756	0.18139142734524022	-4.999999999999994e-7	174.0	174.0	174.0	1.0282608695652173	0.0	1	-59.99999999999999	59.99999999999999								
	1183	1184	0.0032620254371146	0.12172941655244812	-4.999999999999996e-7	260.0	260.0	260.0	1.0282608695652173	0.0	1	-59.99999999999999	59.99999999999999								
	1185	1188	0.004889242869626586	0.15834171011603118	-4.999999999999996e-7	200.0	200.0	200.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1186	1188	0.004806746227528755	0.15908858504012416	-4.999999999999996e-7	199.0	199.0	199.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1187	1188	0.005212833851051343	0.16794618148670218	-4.999999999999997e-7	188.0	188.0	188.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1193	1437	0.0017697485698678719	0.07470627956232609	-4.999999999999997e-7	423.00000000000006	423.00000000000006	423.00000000000006	1.0083333333333333	0.0	1	-59.99999999999999	59.99999999999999								
	1440	1235	0.0021259683939891115	0.07624902874531084	0.0005745554704639427	415.00000000000006	415.00000000000006	415.00000000000006	0.9447128287707998	0.0	1	-59.99999999999999	59.99999999999999								
	1195	1439	0.0017396904964086719	0.07406209519552788	-4.999999999999997e-7	426.99999999999994	426.99999999999994	426.99999999999994	1.0323863636363637	0.0	1	-59.99999999999999	59.99999999999999								
	1202	1203	0.012109976283518393	0.4287223923735904	-4.999999999999996e-7	74.0	74.0	74.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1202	1203	0.012545312738383014	0.3966571518334025	-4.999999999999994e-7	80.0	80.0	80.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1205	1206	0.02074148486524989	0.5660329386921437	-4.999999999999994e-7	56.00000000000001	56.00000000000001	56.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1205	1206	0.02265111318455712	0.5445813070731635	-4.999999999999994e-7	57.99999999999999	57.99999999999999	57.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1211	1212	0.004152778993482076	0.15363705068871014	-4.999999999999997e-7	206.0	206.0	206.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1211	1212	0.004003809560802605	0.1543183004419441	-4.999999999999996e-7	204.99999999999997	204.99999999999997	204.99999999999997	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1060	1218	0.044338223502521236	0.696762439127772	-4.999999999999996e-7	46.0	46.0	46.0	0.975	0.0	1	-59.99999999999999	59.99999999999999								
	1060	1218	0.04337220513838519	0.6743405407616336	-4.999999999999996e-7	47.0	47.0	47.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1219	1221	0.0037198657208511875	0.12322808813950213	-4.999999999999996e-7	257.0	257.0	257.0	1.03408	0.0	1	-59.99999999999999	59.99999999999999								
	1220	1221	0.0038471580638008533	0.1282187134188151	-4.999999999999994e-7	247.00000000000003	247.00000000000003	247.00000000000003	1.03408	0.0	1	-59.99999999999999	59.99999999999999								
	1225	1632	0.005532873380530465	0.16587870572997412	-4.999999999999994e-7	191.0	191.0	191.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	1233	1202	0.02215982831636067	0.44943349417320366	0.0009986859343444501	71.0	71.0	71.0	0.9876543209876544	0.0	1	-59.99999999999999	59.99999999999999								
	1195	1239	0.008064338029261526	0.13818047885580215	-4.999999999999996e-7	229.0	229.0	229.0	1.02272	0.0	1	-59.99999999999999	59.99999999999999								
	1241	1242	0.0003555076538588109	0.09842724892367041	-4.999999999999997e-7	321.0	321.0	321.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1241	1242	0.00032400077801739824	0.09515643850906193	-4.999999999999994e-7	332.0	332.0	332.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1245	1246	0.0014670962877211349	0.06953305441059995	-4.999999999999996e-7	455.0	455.0	455.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1243	1138	0.007761325612499233	0.15652789391292915	-4.999999999999994e-7	202.0	202.0	202.0	1.0625	0.0	1	-59.99999999999999	59.99999999999999								
	1241	1273	0.008596030059626173	0.10188269026857012	-4.999999999999994e-7	309.0	309.0	309.0	1.0875	0.0	1	-59.99999999999999	59.99999999999999								
	1139	995	0.02076419213762684	0.3116356533022524	-4.999999999999993e-7	102.0	102.0	102.0	0.9999999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1139	1396	0.0012539128327777834	0.050353954973890766	-4.999999999999994e-7	628.0	628.0	628.0	0.9426136363636363	0.0	1	-59.99999999999999	59.99999999999999								
	1284	1286	0.01020532448685897	0.5650491220909106	-4.999999999999997e-7	56.00000000000001	56.00000000000001	56.00000000000001	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1285	1287	0.010241705468857488	0.5588354021004989	-4.999999999999996e-7	56.99999999999999	56.99999999999999	56.99999999999999	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1293	1294	0.00847975735368379	0.16124781842776317	-4.999999999999996e-7	196.0	196.0	196.0	0.9875000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1297	1298	0.0058386625381036	0.16674821346422816	-4.999999999999996e-7	190.0	190.0	190.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1301	1478	0.017035735763877954	0.15509252154665554	0.008151695601140327	202.99999999999997	202.99999999999997	202.99999999999997	1.0256410256410258	0.0	1	-59.99999999999999	59.99999999999999								
	1300	1301	0.00842301798694006	0.1703282924358192	-4.999999999999994e-7	186.0	186.0	186.0	0.975	0.0	1	-59.99999999999999	59.99999999999999								
	1302	1305	0.010657008010513936	0.5214118113236665	-4.999999999999994e-7	61.0	61.0	61.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1303	1306	0.010662945794236644	0.5286177514456146	-4.999999999999996e-7	60.0	60.0	60.0	1.0251	0.0	1	-59.99999999999999	59.99999999999999								
	1304	1302	0.00834438149326651	0.17155608259829913	-4.999999999999994e-7	184.0	184.0	184.0	0.9885999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1304	1303	0.008473642702602636	0.16392661571259814	-4.999999999999994e-7	193.0	193.0	193.0	0.9885999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1309	1307	0.007504056210689555	0.36412238648105866	0.0006061001054474132	87.0	87.0	87.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1317	1445	0.017205582276393235	0.21209034791484263	0.005099624253054654	149.0	149.0	149.0	0.9669309611293754	0.0	1	-59.99999999999999	59.99999999999999								
	1316	1317	0.0035459389853913677	0.1337348956182901	-4.999999999999994e-7	237.0	237.0	237.0	1.03408	0.0	1	-59.99999999999999	59.99999999999999								
	1318	1319	0.00746517552881672	0.20444383927969423	-4.999999999999997e-7	155.0	155.0	155.0	0.98864	0.0	1	-59.99999999999999	59.99999999999999								
	1318	1319	0.007595810559226041	0.19522830144687722	-4.999999999999996e-7	162.0	162.0	162.0	0.98864	0.0	1	-59.99999999999999	59.99999999999999								
	1320	1321	0.008122898745813264	0.19679368479034326	-4.999999999999994e-7	161.0	161.0	161.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1320	1321	0.008158877251355735	0.20244783652166326	-4.999999999999996e-7	156.0	156.0	156.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1322	1325	0.008273803950549833	0.3630842111446075	-4.999999999999996e-7	87.0	87.0	87.0	1.0113	0.0	1	-59.99999999999999	59.99999999999999								
	1322	1325	0.008063874612377783	0.3915004597268083	-4.999999999999996e-7	81.0	81.0	81.0	1.0113	0.0	1	-59.99999999999999	59.99999999999999								
	1329	1297	0.024075180325245377	0.2319362156202075	0.00580289134829816	136.0	136.0	136.0	0.9164222873900294	0.0	1	-59.99999999999999	59.99999999999999								
	1331	1362	0.0352248908275675	0.2725759175766678	0.006897655328734235	114.99999999999999	114.99999999999999	114.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1335	1333	0.008193149257195024	0.2011615012038482	-4.999999999999994e-7	157.0	157.0	157.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1335	1333	0.00816445030971554	0.20903557941118223	-4.999999999999997e-7	151.0	151.0	151.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1335	1334	0.008454925700967042	0.20837849591573523	-4.999999999999998e-7	152.0	152.0	152.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1348	1359	0.008207862731281178	0.17738079058492862	0.08335086848738309	178.0	178.0	178.0	0.9876543209876544	0.0	1	-59.99999999999999	59.99999999999999								
	1347	1348	0.005273364709153147	0.16724148417152915	-4.999999999999996e-7	189.0	189.0	189.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1355	1357	0.02522417334501341	0.5350541972816857	-4.999999999999996e-7	59.0	59.0	59.0	0.9125	0.0	1	-59.99999999999999	59.99999999999999								
	1355	1358	0.024465553409691757	0.5368031985002218	-4.999999999999994e-7	59.0	59.0	59.0	0.8999999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1359	1360	0.010022858037756583	0.1994811856196112	-4.999999999999997e-7	159.0	159.0	159.0	0.98864	0.0	1	-59.99999999999999	59.99999999999999								
	1359	1360	0.009604579809078802	0.16540317370814014	-4.999999999999994e-7	191.0	191.0	191.0	0.98864	0.0	1	-59.99999999999999	59.99999999999999								
	1359	1360	0.009370730248892522	0.20116131162990922	-4.999999999999994e-7	157.0	157.0	157.0	1.0113599999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1359	1360	0.00490820334527531	0.1656126973834212	-4.999999999999996e-7	191.0	191.0	191.0	0.9875000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1362	1423	0.019379370523376217	0.5695528451596786	-4.999999999999996e-7	56.00000000000001	56.00000000000001	56.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1363	1364	0.010616831434007561	0.5499905450876826	-4.999999999999996e-7	57.99999999999999	57.99999999999999	57.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1363	1365	0.010426045097198106	0.5442854497787565	-4.999999999999997e-7	59.0	59.0	59.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1363	1366	0.01077118392020633	0.5340097096215026	-4.999999999999994e-7	60.0	60.0	60.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1367	1369	0.009068192973644489	0.17987314025812418	-4.999999999999996e-7	176.0	176.0	176.0	0.975	0.0	1	-59.99999999999999	59.99999999999999								
	1289	1371	0.0050728894416157575	0.15832147714018313	-4.999999999999993e-7	200.0	200.0	200.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1289	1371	0.004730489726540474	0.1592873585065312	-4.999999999999994e-7	199.0	199.0	199.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1372	1373	0.008290740285200824	0.17635668196263019	-4.999999999999998e-7	179.0	179.0	179.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1372	1373	0.008306568619368439	0.1741028238247542	-4.999999999999994e-7	182.0	182.0	182.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1372	1373	0.015270939554406246	0.3053970820452015	-4.999999999999996e-7	104.0	104.0	104.0	1.03408	0.0	1	-59.99999999999999	59.99999999999999								
	1374	1375	0.013311474921136922	0.5593406645632925	-4.999999999999996e-7	56.99999999999999	56.99999999999999	56.99999999999999	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1374	1376	0.013421546113059684	0.5720196539481376	-4.999999999999997e-7	56.00000000000001	56.00000000000001	56.00000000000001	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1374	1377	0.010079997953150248	0.5709593194516029	-4.999999999999997e-7	56.00000000000001	56.00000000000001	56.00000000000001	0.9624999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1379	1380	0.003917812678629381	0.1287351584646681	-4.999999999999993e-7	246.0	246.0	246.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1379	1380	0.003980959629287791	0.1279757832163961	-4.999999999999996e-7	247.00000000000003	247.00000000000003	247.00000000000003	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1312	1386	0.010931602376645259	0.5510419918440449	-4.999999999999996e-7	57.99999999999999	57.99999999999999	57.99999999999999	0.9875000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1312	1387	0.010224874557779928	0.5350970192708236	-4.999999999999994e-7	60.0	60.0	60.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1409	1410	0.04474031700874853	0.7707346226944243	-4.999999999999997e-7	41.0	41.0	41.0	0.9999999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1444	1516	0.0014999238245457602	0.07236477605367723	-4.999999999999996e-7	437.0	437.0	437.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1444	1516	0.0007356738520686778	0.050648796561555874	-4.999999999999996e-7	624.0	624.0	624.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1445	1446	0.004973967596224364	0.16170307252239613	-4.999999999999994e-7	196.0	196.0	196.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1445	1446	0.004970714113073278	0.16383855529390715	-4.999999999999996e-7	193.0	193.0	193.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1445	1446	0.004092130418222224	0.14437856393063214	-4.999999999999996e-7	219.0	219.0	219.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1445	1518	0.0015763209759828826	0.07357588798070919	-4.999999999999996e-7	430.0	430.0	430.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1445	1518	0.0015184668084278895	0.07212495692178789	-4.999999999999997e-7	438.0	438.0	438.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1445	1518	0.0007001954001624327	0.048272736857971045	-4.999999999999994e-7	655.0	655.0	655.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1445	1518	0.0007332285506011214	0.04744228760292747	-4.999999999999996e-7	666.0	666.0	666.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1382	1448	0.004372904727279995	0.15623162393341017	-4.999999999999994e-7	202.99999999999997	202.99999999999997	202.99999999999997	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1382	1519	0.001304443173318003	0.07485163881894746	-4.999999999999996e-7	422.0	422.0	422.0	1.0027272727272727	0.0	1	-59.99999999999999	59.99999999999999								
	1382	1519	0.0011092271020066112	0.07421342817794474	-4.999999999999996e-7	426.0	426.0	426.0	1.0027272727272727	0.0	1	-59.99999999999999	59.99999999999999								
	1382	1519	0.0017178499582873776	0.07551545622732385	-4.999999999999998e-7	419.00000000000006	419.00000000000006	419.00000000000006	1.0027272727272727	0.0	1	-59.99999999999999	59.99999999999999								
	1449	1520	0.0009283111283698344	0.03853181452355523	-4.999999999999994e-7	819.9999999999999	819.9999999999999	819.9999999999999	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1449	1520	0.0008916343424374463	0.03713385956368583	-4.999999999999994e-7	851.0	851.0	851.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1450	1522	0.0010446566257968806	0.053685725136346556	-4.999999999999994e-7	589.0	589.0	589.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1450	1522	0.0011025415751820765	0.054126820714304566	-4.999999999999994e-7	584.0	584.0	584.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1451	1527	0.000526942048095003	0.02999075359323053	-4.999999999999996e-7	1054.0	1054.0	1054.0	1.0152300000000003	0.0	1	-59.99999999999999	59.99999999999999								
	1453	1529	0.000666006047786981	0.03662087233278324	-4.999999999999994e-7	863.0000000000001	863.0000000000001	863.0000000000001	0.9864899999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1453	1529	0.0006937584876751752	0.03653348395651384	-4.999999999999994e-7	865.0	865.0	865.0	0.9864899999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1453	1292	0.006695883116918603	0.09570813452691457	0.001893619185961197	330.0	330.0	330.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1456	1530	0.001883853149649243	0.06780093295234899	-4.999999999999994e-7	466.0	466.0	466.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1456	1530	0.0006075845229879232	0.04532556555214883	-4.999999999999997e-7	697.0	697.0	697.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1457	1531	0.0015247535872915103	0.06544289062302266	-4.999999999999994e-7	483.0	483.0	483.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	1464	1536	4.9387444112751837e-5	0.005281940467083668	-4.999999999999993e-7	3000.0	5980.0	5980.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1060	1464	0.001374549184296113	0.07266872714056018	-4.999999999999996e-7	434.99999999999994	434.99999999999994	434.99999999999994	0.9858999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1060	1464	0.0016149236930737463	0.07582784224104318	-4.999999999999996e-7	417.0	417.0	417.0	0.985901509090909	0.0	1	-59.99999999999999	59.99999999999999								
	1060	1464	0.0016785270479897228	0.07253643280384775	-4.999999999999996e-7	436.00000000000006	436.00000000000006	436.00000000000006	0.985901509090909	0.0	1	-59.99999999999999	59.99999999999999								
	1131	1467	0.00463607663465834	0.17957694571939517	-4.999999999999996e-7	176.0	176.0	176.0	0.9684782608695652	0.0	1	-59.99999999999999	59.99999999999999								
	1131	1467	0.0050281319798127075	0.17867073647735815	-4.999999999999996e-7	177.0	177.0	177.0	0.9684782608695652	0.0	1	-59.99999999999999	59.99999999999999								
	1131	1467	0.005098980918491099	0.18072451638065912	-4.999999999999996e-7	175.0	175.0	175.0	0.9684782608695652	0.0	1	-59.99999999999999	59.99999999999999								
	1470	1540	0.0008977531061836745	0.04871552289556747	-4.999999999999997e-7	649.0	649.0	649.0	0.989240590909091	0.0	1	-59.99999999999999	59.99999999999999								
	1471	1541	0.0033747545276692323	0.09923407045400881	-4.999999999999997e-7	319.0	319.0	319.0	0.95	0.0	1	-59.99999999999999	59.99999999999999								
	1472	1541	0.0035814378633050436	0.10283303121575713	-4.999999999999997e-7	307.0	307.0	307.0	0.95	0.0	1	-59.99999999999999	59.99999999999999								
	1322	1543	0.0007077207611657906	0.04962492932473947	-4.999999999999997e-7	637.0	637.0	637.0	0.98655	0.0	1	-59.99999999999999	59.99999999999999								
	1478	1479	0.00882308337235995	0.1651265850399822	-4.999999999999996e-7	192.0	192.0	192.0	1.04544	0.0	1	-59.99999999999999	59.99999999999999								
	1478	1479	0.008315149130031308	0.1708746699462482	-4.999999999999996e-7	185.0	185.0	185.0	1.04544	0.0	1	-59.99999999999999	59.99999999999999								
	1478	1479	0.008740098668161635	0.16648050125560016	-4.999999999999996e-7	190.0	190.0	190.0	1.04544	0.0	1	-59.99999999999999	59.99999999999999								
	1478	1545	0.0008859464118572216	0.05283389947146356	-4.999999999999996e-7	598.0	598.0	598.0	0.98655	0.0	1	-59.99999999999999	59.99999999999999								
	1478	1545	0.0008627860597505424	0.04853163700030407	-4.999999999999994e-7	651.0	651.0	651.0	0.98655	0.0	1	-59.99999999999999	59.99999999999999								
	1474	1404	0.03937247111460547	0.5498582446330629	-4.999999999999994e-7	57.99999999999999	57.99999999999999	57.99999999999999	0.9999999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1490	1557	0.0012198048651177159	0.0677578366436692	-4.999999999999994e-7	467.0	467.0	467.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	1492	1564	0.0006411178367294632	0.04716560671147575	-4.999999999999994e-7	670.0	670.0	670.0	0.9869399999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1493	1494	0.004225202508775344	0.15256185574433417	-4.999999999999996e-7	206.99999999999997	206.99999999999997	206.99999999999997	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1493	1494	0.004275044956985702	0.1441787355156481	-4.999999999999998e-7	219.0	219.0	219.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1493	1568	0.0006845768502092252	0.05063126790294227	-4.999999999999996e-7	624.0	624.0	624.0	1.01345	0.0	1	-59.99999999999999	59.99999999999999								
	1307	1569	0.0006354514231740723	0.05255139324171174	-4.999999999999996e-7	602.0	602.0	602.0	0.9731100000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1307	1570	0.0006110775893341051	0.04721849769646245	-4.999999999999997e-7	669.0	669.0	669.0	0.9731100000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1503	1577	0.00030442137522792835	0.05682619998763497	-4.999999999999994e-7	556.0	556.0	556.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1505	1579	0.0006651429479120524	0.05155729882977145	-4.999999999999996e-7	613.0	613.0	613.0	0.9883399999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1505	1579	0.0007193596149173791	0.04967673915865813	-4.999999999999996e-7	636.0	636.0	636.0	0.9883399999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1139	1523	0.0006447900721706246	0.04752756762782284	-4.999999999999996e-7	665.0	665.0	665.0	1.0094699999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1139	1523	0.0006182371890319772	0.04698580652409684	-4.999999999999994e-7	673.0	673.0	673.0	1.0094699999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1507	1574	0.0013784762401858536	0.06918507917148006	-4.999999999999997e-7	457.0	457.0	457.0	0.9873	0.0	1	-59.99999999999999	59.99999999999999								
	1507	1574	0.0013322523372823565	0.07202727403329116	-4.999999999999996e-7	438.99999999999994	438.99999999999994	438.99999999999994	0.9873	0.0	1	-59.99999999999999	59.99999999999999								
	1508	1585	0.000624536591012522	0.04855994932730769	-4.999999999999993e-7	651.0	651.0	651.0	0.9883399999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1508	1586	0.0005995247457081277	0.047771745728829244	-4.999999999999993e-7	662.0	662.0	662.0	0.9883399999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1509	1108	0.0008465137689880357	0.14472556248004512	-4.999999999999994e-7	219.0	219.0	219.0	1.05682	0.0	1	-59.99999999999999	59.99999999999999								
	1509	1109	0.00330064455858602	0.1255540096420751	-4.999999999999996e-7	252.0	252.0	252.0	0.9905300000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1523	1395	0.0011023575816287885	0.05047870398253847	-4.999999999999994e-7	626.0	626.0	626.0	1.0152892561983466	0.0	1	-59.99999999999999	59.99999999999999								
	1523	1394	0.0011340738686847725	0.04924908186617946	-4.999999999999993e-7	642.0	642.0	642.0	1.0283057851239665	0.0	1	-59.99999999999999	59.99999999999999								
	1541	1474	0.0038284606118113005	0.10751212338506412	-4.999999999999994e-7	294.0	294.0	294.0	1.0132608695652177	0.0	1	-59.99999999999999	59.99999999999999								
	1541	1474	0.004070646457934963	0.1047280977075811	-4.999999999999993e-7	302.0	302.0	302.0	1.0132608695652177	0.0	1	-59.99999999999999	59.99999999999999								
	1546	1026	0.001767030602481277	0.0735271900453268	0.0005690289489815576	430.0	430.0	430.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1401	1541	0.0007966610775681697	0.04132987017408923	0.002491598588127509	765.0	765.0	765.0	0.9746835443037972	0.0	1	-59.99999999999999	59.99999999999999								
	1533	1405	0.0010167943513410427	0.05508162039010967	-4.999999999999993e-7	574.0	574.0	574.0	1.0413636363636365	0.0	1	-59.99999999999999	59.99999999999999								
	1407	1546	0.0006978268675540449	0.04109648115479178	0.002486962192390731	769.0	769.0	769.0	0.9999999999999991	0.0	1	-59.99999999999999	59.99999999999999								
	1408	1546	0.0007803003561902278	0.04083403222054617	0.002102391697123981	774.0	774.0	774.0	0.9999999999999991	0.0	1	-59.99999999999999	59.99999999999999								
	1555	1606	0.0008825194765052983	0.05089497982243997	-4.999999999999993e-7	621.0	621.0	621.0	1.0136	0.0	1	-59.99999999999999	59.99999999999999								
	1556	1606	0.0009554588209761532	0.04866173022469126	-4.999999999999993e-7	649.0	649.0	649.0	1.0136	0.0	1	-59.99999999999999	59.99999999999999								
	1546	1420	0.00046550950338768415	0.027025273647894935	-4.999999999999993e-7	1169.0	1169.0	1169.0	1.0363636363636362	0.0	1	-59.99999999999999	59.99999999999999								
	1419	1546	0.0005087612527069313	0.028727913764533024	0.002274188527888591	1100.0	1100.0	1100.0	0.9649122807017546	0.0	1	-59.99999999999999	59.99999999999999								
	1574	1422	0.0003656166128585355	0.03217657449443794	-4.999999999999994e-7	982.0	982.0	982.0	1.0436363636363637	0.0	1	-59.99999999999999	59.99999999999999								
	1274	1580	0.0011598309575847664	0.029538683906763036	0.0904943383974435	1069.0	1069.0	1069.0	1.0269470916858359	0.0	1	-59.99999999999999	59.99999999999999								
	1541	1421	0.0004920389136297854	0.03162671407845135	-4.999999999999993e-7	999.0	999.0	999.0	1.0727272727272728	0.0	1	-59.99999999999999	59.99999999999999								
	1582	1411	0.001900833034926858	0.092329580263379	-4.999999999999993e-7	343.0	343.0	343.0	1.0388500000000003	0.0	1	-59.99999999999999	59.99999999999999								
	1582	1412	0.002066815544331279	0.1001282189143091	-4.999999999999994e-7	316.0	316.0	316.0	1.0388500000000003	0.0	1	-59.99999999999999	59.99999999999999								
	1582	1413	0.0020538518405908905	0.10048212540214212	-4.999999999999994e-7	315.0	315.0	315.0	1.0388500000000003	0.0	1	-59.99999999999999	59.99999999999999								
	1582	1414	0.0006484367184795665	0.045591199435980855	-4.999999999999994e-7	693.0	693.0	693.0	1.0387142857142857	0.0	1	-59.99999999999999	59.99999999999999								
	1582	1621	8.077906536108275e-5	0.0053252155318724275	-4.999999999999994e-7	3000.0	5931.0	5931.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1587	1509	0.0006357899345404694	0.05047734383537515	-4.999999999999994e-7	626.0	626.0	626.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1587	1509	0.000623041496626869	0.048236736089004056	-4.999999999999994e-7	655.0	655.0	655.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1588	1243	0.0004136775795259273	0.04901716230256196	-4.999999999999994e-7	645.0	645.0	645.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1590	1591	0.0006377197717603522	0.04961596970125366	-4.999999999999994e-7	637.0	637.0	637.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1590	1591	0.0006550718497734743	0.048022365691099154	-4.999999999999994e-7	658.0	658.0	658.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1512	1590	0.002668239288660765	0.06692457172723576	0.11517098395274014	472.0	472.0	472.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1589	1514	0.003560101279590119	0.12149837665217321	-4.999999999999994e-7	260.0	260.0	260.0	1.04735	0.0	1	-59.99999999999999	59.99999999999999								
	1589	1514	0.0032928906819893306	0.12347595874547117	-4.999999999999996e-7	256.0	256.0	256.0	1.04735	0.0	1	-59.99999999999999	59.99999999999999								
	1596	1620	0.008653681684272656	0.20238424785779222	-4.999999999999997e-7	156.0	156.0	156.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1596	1620	0.004101548348357742	0.15488691042120314	-4.999999999999997e-7	204.0	204.0	204.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1596	1620	0.003924730066237812	0.14862599826784317	-4.999999999999994e-7	213.0	213.0	213.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1598	994	0.00808775751104657	0.25298690248766526	-4.999999999999996e-7	125.0	125.0	125.0	1.015	0.0	1	-59.99999999999999	59.99999999999999								
	1598	994	0.008112854578757515	0.24940302313889728	-4.999999999999997e-7	127.0	127.0	127.0	1.015	0.0	1	-59.99999999999999	59.99999999999999								
	1599	1057	0.0035676541043374015	0.10777675335430212	-4.999999999999996e-7	293.0	293.0	293.0	0.835	0.0	1	-59.99999999999999	59.99999999999999								
	1599	1057	0.0025443527897510867	0.10275475231272806	-4.999999999999996e-7	308.0	308.0	308.0	1.09	0.0	1	-59.99999999999999	59.99999999999999								
	1602	1067	0.05785127872608695	1.0056149019971512	-4.999999999999994e-7	32.0	32.0	32.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1309	1307	0.010704204892154696	0.3603764405832598	0.001732304397555025	88.0	88.0	88.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1071	1307	0.012282156809705784	0.3151353077055792	0.0006210542047380468	101.0	101.0	101.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1307	1071	0.011288460610957729	0.31818743671639144	-4.999999999999994e-7	100.0	100.0	100.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1606	1343	0.004441769302955218	0.15581432803831818	-4.999999999999994e-7	202.99999999999997	202.99999999999997	202.99999999999997	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1606	1344	0.020718254966094918	0.6078511882354896	-4.999999999999994e-7	52.0	52.0	52.0	0.9638120694972756	0.0	1	-59.99999999999999	59.99999999999999								
	1606	1343	0.004182309720556093	0.15564455473570313	-4.999999999999996e-7	202.99999999999997	202.99999999999997	202.99999999999997	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1297	1516	0.0009391749703859243	0.05248521906171545	-4.999999999999996e-7	602.0	602.0	602.0	0.98655	0.0	1	-59.99999999999999	59.99999999999999								
	1297	1516	0.0006876780647247325	0.050881358852226166	-4.999999999999997e-7	621.0	621.0	621.0	0.98655	0.0	1	-59.99999999999999	59.99999999999999								
	1297	1516	0.000860311351550583	0.05236109152448535	-4.999999999999994e-7	604.0	604.0	604.0	0.98655	0.0	1	-59.99999999999999	59.99999999999999								
	1139	1020	0.020965386603718505	0.29296639019948634	-4.999999999999997e-7	108.0	108.0	108.0	0.9999999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1139	1397	0.00128432153937763	0.04867586302263836	-4.999999999999994e-7	649.0	649.0	649.0	0.9545454545454545	0.0	1	-59.99999999999999	59.99999999999999								
	1202	1025	0.012674178829455603	0.42836501676852057	-4.999999999999996e-7	74.0	74.0	74.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1202	1025	0.012743196865191509	0.4075755441509396	-4.999999999999996e-7	78.0	78.0	78.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1613	1558	0.0005793492907266373	0.039182761952532834	-4.999999999999994e-7	807.0	807.0	807.0	1.0259740259740262	0.0	1	-59.99999999999999	59.99999999999999								
	1613	1559	0.0006964373425206395	0.04275935895848224	-4.999999999999996e-7	739.0	739.0	739.0	1.0259740259740262	0.0	1	-59.99999999999999	59.99999999999999								
	1613	1560	0.0006083212631026508	0.04143294331716995	-4.999999999999994e-7	763.0	763.0	763.0	1.0259740259740262	0.0	1	-59.99999999999999	59.99999999999999								
	1613	1561	0.0006366437467162723	0.04098814756113525	-4.999999999999993e-7	771.0	771.0	771.0	1.0259740259740262	0.0	1	-59.99999999999999	59.99999999999999								
	1616	1197	0.04176669589540164	0.6207363097951676	-4.999999999999996e-7	51.0	51.0	51.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1616	1197	0.0414031781452772	0.6153539462186326	-4.999999999999994e-7	52.0	52.0	52.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1139	1104	0.0032582909078912995	0.11936560006050613	-4.999999999999997e-7	265.0	265.0	265.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1139	1104	0.003550288042064596	0.12281497516435011	-4.999999999999996e-7	258.0	258.0	258.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1624	1623	0.0034809126726368703	0.12445125784705315	-4.999999999999996e-7	254.0	254.0	254.0	0.9888999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1625	1628	0.00031742923541397064	0.020499471622861427	-4.999999999999994e-7	1541.0	1541.0	1541.0	1.0565764023210826	0.0	1	-59.99999999999999	59.99999999999999								
	1636	1959	0.019796270768522896	0.22694187216825848	-4.999999999999497e-7	139.0	139.0	139.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1637	1958	0.007642621633211232	0.061484133934457556	-4.9999999999995e-7	509.99999999999994	509.99999999999994	509.99999999999994	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1640	1961	0.004942653903742957	0.05669358882570604	-4.999999999999499e-7	556.0	556.0	556.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1641	1961	0.005098000538950521	0.05725997080170986	-4.999999999999499e-7	550.0	550.0	550.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1654	1978	0.008059631420305153	0.06269256599316816	-4.999999999999498e-7	500.0	500.0	500.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1655	1979	0.00880845324893119	0.060782997071505224	-4.999999999999497e-7	515.0	515.0	515.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1656	1980	0.00822712091327286	0.06199879217124051	-4.999999999999498e-7	505.99999999999994	505.99999999999994	505.99999999999994	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1658	1633	0.010555923465926376	0.09788205645863761	-4.999999999999498e-7	321.0	321.0	321.0	1.0499999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1670	1669	9.999999965657482e-10	0.09331317138058781	-4.999999999999994e-7	339.0	339.0	339.0	1.0499999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1679	1680	0.00806206706498992	0.06315037013239437	-4.999999999999497e-7	497.0	497.0	497.0	1.0499999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1681	1983	0.0072287156192830035	0.064712970418767	-4.999999999999498e-7	486.00000000000006	486.00000000000006	486.00000000000006	1.0499999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1682	1984	0.006135213045166095	0.047129226892203176	-4.999999999999497e-7	665.0	665.0	665.0	1.0499999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1683	1987	0.00902342109235971	0.0638984001570799	-4.999999999999498e-7	490.00000000000006	490.00000000000006	490.00000000000006	1.0144927536231885	0.0	1	-59.99999999999999	59.99999999999999								
	1705	1701	0.027605094964020808	0.3192357038189727	-4.999999999999496e-7	99.0	99.0	99.0	1.0144927536231885	0.0	1	-59.99999999999999	59.99999999999999								
	1706	1701	0.03953586528228774	0.4386489916129742	-4.999999999999495e-7	72.0	72.0	72.0	1.0144927536231885	0.0	1	-59.99999999999999	59.99999999999999								
	1707	1722	0.009875399793464341	0.09783229127179145	-4.999999999999497e-7	322.0	322.0	322.0	0.975	0.0	1	-59.99999999999999	59.99999999999999								
	1708	1722	0.009479386384452206	0.1330448066725712	-4.999999999999501e-7	237.0	237.0	237.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1709	1717	0.006084643765420689	0.08836805950467064	-4.9999999999995e-7	357.0	357.0	357.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1710	1717	0.014816907574383701	0.2071786483702727	-4.999999999999501e-7	153.0	153.0	153.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1711	1712	0.007115306496197262	0.05861231455008459	-4.999999999999498e-7	535.0	535.0	535.0	1.0499999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1663	2021	0.015584478804601185	0.9135932778464332	-4.999999999999996e-7	35.0	35.0	35.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1663	2022	0.015620918250216057	0.877232013866974	-4.999999999999996e-7	37.0	37.0	37.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1663	2023	0.01656693810908299	0.8844438396911913	-4.999999999999994e-7	36.0	36.0	36.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1663	2024	0.016156600368900112	0.867005286341037	-4.999999999999996e-7	37.0	37.0	37.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1663	2025	0.01561667236475443	0.9333286289401294	-4.999999999999993e-7	34.0	34.0	34.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1663	2026	0.01600836476845836	0.921701250313993	-4.999999999999996e-7	35.0	35.0	35.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1723	1680	0.0038656793413570337	0.11434504131793213	-4.999999999999996e-7	277.0	277.0	277.0	1.0405000000000004	0.0	1	-59.99999999999999	59.99999999999999								
	1726	1983	0.003793246835773643	0.11709640715423211	-4.999999999999996e-7	270.0	270.0	270.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1729	1690	0.0025729111761151145	0.12317386366217113	-4.999999999999994e-7	257.0	257.0	257.0	1.0599999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1729	1691	0.0026808960630761865	0.1304335436239442	-4.999999999999992e-7	243.00000000000003	243.00000000000003	243.00000000000003	1.0599999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1729	1692	0.0032385518739314937	0.11451606507483116	-4.999999999999996e-7	276.0	276.0	276.0	1.0599999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1730	1784	0.0021777383678237235	0.10978169938224012	-4.999999999999994e-7	288.0	288.0	288.0	1.0130000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1730	1784	0.0020909692098254598	0.10940065861517713	-4.999999999999994e-7	289.0	289.0	289.0	1.0130000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1730	1784	0.002164308989984747	0.10419134805345509	-4.999999999999996e-7	304.0	304.0	304.0	1.0130000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1731	1974	0.001782857669435274	0.08882667063329919	-4.999999999999996e-7	356.0	356.0	356.0	1.0170000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1731	1974	0.001803570497049317	0.09037929632218318	-4.999999999999994e-7	350.0	350.0	350.0	1.0170000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1724	1978	0.001524311994446274	0.0890997072780662	-4.999999999999996e-7	355.0	355.0	355.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1724	1979	0.0015353866296092236	0.09134734870457739	-4.999999999999996e-7	346.0	346.0	346.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1724	1980	0.001608214851228353	0.08504749752522157	-4.999999999999996e-7	372.0	372.0	372.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1657	1724	0.0016557544221687094	0.08968615504024446	-4.999999999947779e-7	353.0	353.0	353.0	1.0389610389610389	0.0	1	-59.99999999999999	59.99999999999999								
	1742	1853	0.0017032909538646417	0.09900111716132791	-4.999999999999996e-7	320.0	320.0	320.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1742	1853	0.0017431803586071691	0.1318475618969391	-4.999999999999993e-7	240.0	240.0	240.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1743	1744	0.007100557415922943	0.2400183387280352	-4.999999999999994e-7	132.0	132.0	132.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1743	1744	0.006811647945622768	0.2453833773781642	-4.999999999999996e-7	129.0	129.0	129.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1745	1684	0.001222274994815074	0.061869698240549185	-4.999999999999994e-7	511.00000000000006	511.00000000000006	511.00000000000006	1.0500000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	1745	1685	0.0012248686845133306	0.05717756380704687	-4.999999999999993e-7	553.0	553.0	553.0	1.0500000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	1745	1686	0.0014942561691667178	0.06508242129936848	-4.999999999999994e-7	486.00000000000006	486.00000000000006	486.00000000000006	1.0500000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	1729	1693	0.001632342064647768	0.08698290742983288	-4.999999999999994e-7	364.0	364.0	364.0	1.0450000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1729	1694	0.0011120027027249524	0.09221994781008168	-4.999999999999996e-7	343.0	343.0	343.0	1.0450000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1729	1695	0.0010511812660068463	0.08722870607386518	-4.999999999999994e-7	363.0	363.0	363.0	1.0450000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1749	1905	0.0016310908329317535	0.10246668952142508	-4.999999999999996e-7	309.0	309.0	309.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1749	1881	0.0017651848011294568	0.09971449945030908	-4.999999999999994e-7	317.0	317.0	317.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1749	1881	0.0016884262905985305	0.1048895413777441	-4.999999999999996e-7	302.0	302.0	302.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1749	1881	0.001628245574354958	0.10421239985500212	-4.999999999999996e-7	304.0	304.0	304.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1751	1891	0.0017074431753641183	0.10017058956864909	-4.999999999999994e-7	316.0	316.0	316.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1751	1891	0.0018692307408860142	0.10420676250668813	-4.999999999999994e-7	304.0	304.0	304.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1751	1892	0.0015214680377001204	0.09406473932190053	-4.999999999999994e-7	336.0	336.0	336.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1752	1908	0.0014560361422987843	0.1071444346101321	-4.999999999999996e-7	295.0	295.0	295.0	0.9875000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	1753	1912	0.0019419423266703597	0.13243151226963418	-4.999999999999993e-7	239.0	239.0	239.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1753	1912	0.0024955811206626966	0.12333572540663414	-4.999999999999994e-7	257.0	257.0	257.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1753	1912	0.0027483249675536864	0.13035645920637717	-4.999999999999993e-7	243.00000000000003	243.00000000000003	243.00000000000003	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1758	1931	0.0018399462611361594	0.10279478666455513	-4.999999999999996e-7	308.0	308.0	308.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1758	1931	0.0017488503981910833	0.10326204126119412	-4.999999999999996e-7	306.0	306.0	306.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1759	1993	0.001669748016756792	0.09694564380659719	-4.999999999999996e-7	326.0	326.0	326.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1760	1995	0.0020466973633443196	0.09189958543816988	-4.999999999999996e-7	344.0	344.0	344.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1761	1941	0.0016767131642082894	0.10305155517206209	-4.999999999999994e-7	307.0	307.0	307.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1763	1945	0.0010678362384371647	0.07227076296308957	-4.999999999999996e-7	438.0	438.0	438.0	0.9875000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	1764	1946	0.0027035468960737996	0.12684671838989414	-4.999999999999993e-7	249.00000000000003	249.00000000000003	249.00000000000003	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1764	1946	0.0019236780674418768	0.1327076154404202	-4.999999999999993e-7	238.0	238.0	238.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1766	1804	0.014498843453566045	0.12481565221246395	0.009602613653895985	252.0	252.0	252.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1770	1712	0.005266986333953071	0.1882601942916152	-4.999999999999993e-7	168.0	168.0	168.0	1.0500000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	1772	1956	0.011197616635488171	0.30859976249089616	-4.999999999999996e-7	103.0	103.0	103.0	0.9824999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1773	1957	0.02797034384417333	0.4931712673173685	-4.999999999999994e-7	64.0	64.0	64.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1777	1959	0.006661823928139012	0.20479448869591224	-4.999999999999996e-7	155.0	155.0	155.0	1.0175	0.0	1	-59.99999999999999	59.99999999999999								
	1713	1725	0.002107589069334157	0.07051264708863376	-4.999999999999996e-7	448.00000000000006	448.00000000000006	448.00000000000006	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1713	1725	0.0020446995853686894	0.0714675966679928	-4.999999999999996e-7	442.0	442.0	442.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1713	1960	0.008895401810409341	0.26607485617217524	-4.999999999999997e-7	119.0	119.0	119.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1713	1960	0.008288910519718964	0.25783955642650525	-4.999999999999996e-7	123.0	123.0	123.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1780	1728	0.0014242289279325123	0.07212940387122507	-4.999999999999997e-7	438.0	438.0	438.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1780	1728	0.0015868694172243775	0.07578957593927389	-4.999999999999997e-7	417.0	417.0	417.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1781	1638	0.007175662768224094	0.23416850630084127	-4.999999999999994e-7	135.0	135.0	135.0	1.011931818181818	0.0	1	-59.99999999999999	59.99999999999999								
	1781	1967	0.022434141646180128	0.5349805726179834	-4.999999999999996e-7	59.0	59.0	59.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1784	2013	0.015593041557669494	0.3339595904928503	-4.999999999999996e-7	95.0	95.0	95.0	0.9870000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1784	2014	0.01621250214120542	0.3565546170952194	-4.999999999999994e-7	89.0	89.0	89.0	0.9870000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1784	2015	0.01524198121774834	0.33275163624302845	-4.999999999999994e-7	95.0	95.0	95.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1785	1972	0.05287182598144176	0.1256704552094501	-4.999999999999994e-7	231.99999999999997	231.99999999999997	231.99999999999997	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1786	1732	0.0015933541251056085	0.07221041435446296	-4.999999999999996e-7	438.0	438.0	438.0	0.96843	0.0	1	-59.99999999999999	59.99999999999999								
	1786	1975	0.00964184486364649	0.28484062840400426	-4.999999999999996e-7	111.00000000000001	111.00000000000001	111.00000000000001	0.9824999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1786	1975	0.005568283751254726	0.2977888437433372	-4.999999999999996e-7	107.0	107.0	107.0	0.9824999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1789	1733	0.001475038649349306	0.0717861532425409	-4.999999999999996e-7	440.00000000000006	440.00000000000006	440.00000000000006	0.9822199999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1789	1842	0.07285334999150322	1.0422216360212513	-4.999999999999993e-7	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1789	1842	0.07495435996604333	1.0738320219553206	-4.999999999999996e-7	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1795	1843	0.028442584167343417	0.3399980404975003	-4.999999999999996e-7	93.0	93.0	93.0	0.9824999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1795	1843	0.028962394986946048	0.3200487099797113	-4.999999999999994e-7	99.0	99.0	99.0	0.9824999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1795	1843	0.026961494437718617	0.3007122442126212	-4.999999999999994e-7	105.0	105.0	105.0	0.9824999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1784	2016	0.015810487111662427	0.3329664011582562	-4.999999999999997e-7	95.0	95.0	95.0	0.974	0.0	1	-59.99999999999999	59.99999999999999								
	1784	2017	0.015350274290917267	0.34634348687624034	-4.999999999999997e-7	92.0	92.0	92.0	0.974	0.0	1	-59.99999999999999	59.99999999999999								
	1784	2018	0.015252264250737498	0.3358432945137754	-4.999999999999997e-7	94.0	94.0	94.0	0.974	0.0	1	-59.99999999999999	59.99999999999999								
	1784	2019	0.015717227870372007	0.36246155380988354	-4.999999999999994e-7	88.0	88.0	88.0	0.974	0.0	1	-59.99999999999999	59.99999999999999								
	1784	2104	0.015834926574504818	0.35259193549282325	-4.999999999999996e-7	90.0	90.0	90.0	0.9219999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1799	1734	0.0013387673580570335	0.07241017785786494	-4.999999999999997e-7	437.0	437.0	437.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1799	1734	0.0010880251890307553	0.08087072175730195	-4.999999999999994e-7	391.0	391.0	391.0	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1800	1844	0.00597194812306932	0.1526475433574451	-4.999999999999994e-7	206.99999999999997	206.99999999999997	206.99999999999997	1.0175	0.0	1	-59.99999999999999	59.99999999999999								
	1803	1633	5.811362188199916e-5	0.0019601511266402216	-4.999999999999994e-7	3000.0	10000.0	10000.0	1.075	0.0	1	-59.99999999999999	59.99999999999999								
	1804	1982	0.0068089532060398045	0.2570609837039233	-4.999999999999996e-7	123.0	123.0	123.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1804	1982	0.0063831023380587285	0.25590684750249026	-4.999999999999994e-7	124.0	124.0	124.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1804	1982	0.00668556304130642	0.24897670714556727	-4.999999999999994e-7	127.0	127.0	127.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1805	2111	0.0249829481744355	0.5335672826393463	-4.999999999999997e-7	60.0	60.0	60.0	0.9824999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1805	2111	0.027194730581475306	0.5379213418516855	-4.999999999999997e-7	59.0	59.0	59.0	0.9824999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1809	1715	0.0011253615727339129	0.07298894628565007	-4.999999999999997e-7	433.0	433.0	433.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1810	1984	0.004336263955027636	0.1806776942338881	-4.999999999999996e-7	175.0	175.0	175.0	1.035	0.0	1	-59.99999999999999	59.99999999999999								
	1811	1857	0.025362465766413923	0.5392370742068405	-4.999999999999996e-7	59.0	59.0	59.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1811	1857	0.028428497442362654	0.5600241008426584	-4.999999999999996e-7	56.99999999999999	56.99999999999999	56.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1812	1985	0.02101901299854173	0.48017722523587647	-4.999999999999994e-7	66.0	66.0	66.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1812	1985	0.021145493972081545	0.48541385277918153	-4.999999999999996e-7	66.0	66.0	66.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1813	1986	0.021713572325758025	0.4913904070577024	-4.999999999999996e-7	65.0	65.0	65.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1813	1986	0.021428493188340537	0.4878572300232013	-4.999999999999994e-7	65.0	65.0	65.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2034	1813	0.04401482584522099	0.08036994112617639	0.014031199816836735	345.0	345.0	345.0	1.0345112968633616	0.0	1	-59.99999999999999	59.99999999999999								
	1815	1994	0.011899597249746614	0.26475878721263124	-4.999999999999994e-7	120.0	120.0	120.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1815	1994	0.011910552451425116	0.24942887379589324	-4.999999999999996e-7	127.0	127.0	127.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1816	1753	0.0014669612317921782	0.06997595223803245	-4.999999999999996e-7	451.99999999999994	451.99999999999994	451.99999999999994	0.9749999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1817	1941	0.00595929744773716	0.22056186886424428	-4.999999999999994e-7	144.0	144.0	144.0	1.0175	0.0	1	-59.99999999999999	59.99999999999999								
	1817	1941	0.0063363955319596715	0.20216786173502221	-4.999999999999996e-7	157.0	157.0	157.0	1.0175	0.0	1	-59.99999999999999	59.99999999999999								
	1821	1947	0.02007009914068444	0.49413930424698255	-4.999999999999994e-7	64.0	64.0	64.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1821	1947	0.02941322511040035	0.5210922560708063	-4.999999999999994e-7	61.0	61.0	61.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1825	1996	0.006131602309282709	0.26234905503107425	-4.999999999999994e-7	121.0	121.0	121.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1825	1997	0.006019628052098516	0.25635370222036025	-4.999999999999994e-7	124.0	124.0	124.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1828	1765	0.0015159787873521636	0.07266779134301879	-4.999999999999996e-7	434.99999999999994	434.99999999999994	434.99999999999994	0.9799999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1828	1998	0.042172474602369475	0.4894258069793154	-4.999999999999994e-7	65.0	65.0	65.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1828	1999	0.03997277209967543	0.47649664577426637	-4.999999999999996e-7	67.0	67.0	67.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1830	2000	0.023028089810753095	0.4874282081317176	-4.999999999999996e-7	65.0	65.0	65.0	1.035	0.0	1	-59.99999999999999	59.99999999999999								
	1830	2001	0.02213720573455261	0.5238379257095436	-4.999999999999993e-7	61.0	61.0	61.0	0.96516	0.0	1	-59.99999999999999	59.99999999999999								
	1831	1720	0.0021589984090913347	0.07933694386501226	-4.999999999999996e-7	398.0	398.0	398.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1831	1720	0.0011173511851689036	0.07777611243549445	-4.999999999999997e-7	407.0	407.0	407.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1832	2002	0.029152778868829686	0.5520726581625036	-4.999999999999996e-7	57.99999999999999	57.99999999999999	57.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1832	2002	0.016781027263076304	0.49242711838036657	-4.999999999999996e-7	65.0	65.0	65.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1833	2003	0.027819318302182334	0.47690607855631245	-4.999999999999994e-7	67.0	67.0	67.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1834	2004	0.010187666582005914	0.3074037437416631	-4.999999999999996e-7	103.0	103.0	103.0	0.98258	0.0	1	-59.99999999999999	59.99999999999999								
	1834	2004	0.0070356766676891854	0.23944130060916224	-4.999999999999994e-7	132.0	132.0	132.0	0.98258	0.0	1	-59.99999999999999	59.99999999999999								
	1835	1701	0.015523051192096347	0.5078770537938803	-4.999999999999996e-7	63.0	63.0	63.0	1.01742	0.0	1	-59.99999999999999	59.99999999999999								
	1835	1702	0.013838293814260395	0.27946470903272025	-4.999999999999994e-7	112.99999999999999	112.99999999999999	112.99999999999999	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1835	1703	0.005813059835802152	0.24295165029160443	-4.999999999999996e-7	130.0	130.0	130.0	1.1107954545454546	0.0	1	-59.99999999999999	59.99999999999999								
	1835	1704	0.013529354871215066	0.2835802157914843	-4.999999999999994e-7	112.00000000000001	112.00000000000001	112.00000000000001	1.1249999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	1836	1717	0.0033985099429328256	0.13614805155437415	-4.999999999999994e-7	231.99999999999997	231.99999999999997	231.99999999999997	1.0175	0.0	1	-59.99999999999999	59.99999999999999								
	1836	1722	0.0033960229540842845	0.1250354017456901	-4.999999999999994e-7	252.99999999999997	252.99999999999997	252.99999999999997	1.0175	0.0	1	-59.99999999999999	59.99999999999999								
	1772	2009	0.003958921674650002	0.1726691575878642	-4.999999999999994e-7	183.0	183.0	183.0	1.02544	0.0	1	-59.99999999999999	59.99999999999999								
	1772	2009	0.0038035007330950756	0.1877398247530422	-4.999999999999996e-7	169.0	169.0	169.0	1.02544	0.0	1	-59.99999999999999	59.99999999999999								
	1839	1699	0.007222615757128063	0.19730845643211323	-4.999999999999994e-7	160.0	160.0	160.0	1.0378787878787878	0.0	1	-59.99999999999999	59.99999999999999								
	1839	1700	0.007077469766536582	0.18855601896866922	-4.999999999999994e-7	168.0	168.0	168.0	1.0378787878787878	0.0	1	-59.99999999999999	59.99999999999999								
	1839	1951	0.0168922123448083	0.49889792888772844	-4.999999999999996e-7	64.0	64.0	64.0	1.035	0.0	1	-59.99999999999999	59.99999999999999								
	1839	1951	0.015389399399027111	0.5213921875327955	-4.999999999999996e-7	61.0	61.0	61.0	1.035	0.0	1	-59.99999999999999	59.99999999999999								
	1841	1729	0.0032320090477604684	0.12666286986139816	-4.999999999999994e-7	250.0	250.0	250.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1841	1729	0.003434067883539793	0.13110359630868015	-4.999999999999993e-7	241.0	241.0	241.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1846	2060	0.026580345287082547	0.9627526551758062	-4.999999999999996e-7	33.0	33.0	33.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1847	2020	0.030058739476131163	0.8995019286149579	-4.999999999999993e-7	36.0	36.0	36.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1847	2020	0.030764036168569528	0.926822904122987	-4.999999999999996e-7	35.0	35.0	35.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1848	1715	0.003944588089195852	0.12923711193882115	-4.999999999999994e-7	245.00000000000003	245.00000000000003	245.00000000000003	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1848	1715	0.004161795824758556	0.13501919331669018	-4.999999999999993e-7	234.0	234.0	234.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1849	2027	0.05123998918509292	1.0596197751422811	-4.999999999999993e-7	30.0	30.0	30.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1849	2027	0.051063704572330997	1.0910381080636213	-4.999999999999994e-7	28.999999999999996	28.999999999999996	28.999999999999996	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1850	2028	0.02658191951627081	0.9292267821420012	-4.999999999999996e-7	34.0	34.0	34.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1850	2028	0.028404306577501648	0.9269476657502191	-4.999999999999997e-7	35.0	35.0	35.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1851	2029	0.06743522575264052	1.0241330783606915	-4.999999999999993e-7	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1851	2029	0.06670369483669464	0.9746656389140919	-4.999999999999996e-7	33.0	33.0	33.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1851	2029	0.06186278704692797	1.0139327545135715	-4.999999999999993e-7	32.0	32.0	32.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1851	2029	0.06506615762598057	0.9772148509218762	-4.999999999999996e-7	33.0	33.0	33.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1670	2030	0.02638549046231603	0.9410944574907082	-4.999999999999996e-7	34.0	34.0	34.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1670	2030	0.026628443066907877	0.9353570925712242	-4.999999999999996e-7	34.0	34.0	34.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1853	2032	0.05087419293852704	1.0093873901368517	-4.999999999999992e-7	32.0	32.0	32.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1853	2032	0.03643265973584902	1.008960326221881	-4.999999999999996e-7	32.0	32.0	32.0	0.8625000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1855	2033	0.03533557092253294	0.958575470806791	-4.999999999999997e-7	33.0	33.0	33.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1855	2033	0.03801069550466899	0.9866340922580503	-4.999999999999997e-7	32.0	32.0	32.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1855	2033	0.023651999460106547	0.8362307953072182	-4.999999999999996e-7	38.0	38.0	38.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1856	2031	0.06185600928893034	1.0261690397714713	-4.999999999999994e-7	31.0	31.0	31.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1856	2031	0.053566861505510176	0.9376635722900213	-4.999999999999994e-7	34.0	34.0	34.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1858	1696	0.002006290342325185	0.12354627520567016	-4.999999999999996e-7	256.0	256.0	256.0	1.0092958860759491	0.0	1	-59.99999999999999	59.99999999999999								
	1858	1697	0.005245816038448204	0.21035481065487732	-4.999999999999994e-7	151.0	151.0	151.0	1.0124999999999995	0.0	1	-59.99999999999999	59.99999999999999								
	1858	2093	0.050985833053702384	0.9796273432893153	-4.999999999999993e-7	33.0	33.0	33.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1840	2035	0.037459788303023094	0.9812407247743504	-4.999999999999994e-7	33.0	33.0	33.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1840	2035	0.02227247621221637	0.9204054935730832	-4.999999999999996e-7	35.0	35.0	35.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1860	2036	0.025959757565243057	0.8911828502996574	-4.999999999999996e-7	36.0	36.0	36.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1860	2036	0.03485485819870781	0.9641798444976498	-4.999999999999994e-7	33.0	33.0	33.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1861	2037	0.04486874258936558	0.9561050212697529	-4.999999999999994e-7	34.0	34.0	34.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1861	2037	0.05498692068899226	1.2686643166604812	-4.999999999999994e-7	25.0	25.0	25.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1858	2038	0.037898005933633024	1.076478889564091	-4.999999999999994e-7	30.0	30.0	30.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1858	2038	0.03848812258042582	1.0269691788686817	-4.999999999999993e-7	31.0	31.0	31.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1864	2039	0.042985035901071396	1.214154928902491	-4.999999999999996e-7	26.0	26.0	26.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	1864	2039	0.04143649348376494	1.1969071622466014	-4.999999999999996e-7	27.0	27.0	27.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	1867	2040	0.029923211018314414	0.952162158406566	-4.999999999999997e-7	34.0	34.0	34.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1867	2040	0.030370354113394282	0.9736211302785603	-4.999999999999994e-7	33.0	33.0	33.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1868	2041	0.05684805079311308	0.9037087960286471	-4.999999999999994e-7	35.0	35.0	35.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1868	2041	0.056902070257921655	1.080996480607221	-4.999999999999994e-7	30.0	30.0	30.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1869	1989	0.034910343096909935	1.0016559143085013	-4.999999999999996e-7	32.0	32.0	32.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1870	2044	0.05234780072918337	0.9643114657828051	-4.999999999999996e-7	33.0	33.0	33.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1870	2044	0.05034927960405302	0.9573132295382613	-4.999999999999994e-7	33.0	33.0	33.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1873	2046	0.027338265350779465	0.9925667870414105	-4.999999999999996e-7	32.0	32.0	32.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1873	2046	0.027897307591868394	0.9168654575576469	-4.999999999999993e-7	35.0	35.0	35.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1840	2047	0.05946589172439826	0.8804586046734763	-4.999999999999994e-7	36.0	36.0	36.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1840	2047	0.06595426688375128	1.2895956873262713	-4.999999999999994e-7	25.0	25.0	25.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1875	2048	0.03824177169691947	1.0167110524245913	-4.999999999999996e-7	32.0	32.0	32.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1875	2048	0.03463418617932295	0.9174099640550492	-4.999999999999996e-7	35.0	35.0	35.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1877	1687	0.006028486241206368	0.2548614847636763	-4.999999999999996e-7	124.0	124.0	124.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	1688	1938	0.007756033314181561	0.25472778695884585	0.00013404082472814568	124.0	124.0	124.0	0.9638554216867469	0.0	1	-59.99999999999999	59.99999999999999								
	1873	2051	0.03671146126207134	0.9288036354476981	-4.999999999999996e-7	34.0	34.0	34.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1873	2051	0.03685691375130963	0.9550981959055582	-4.999999999999997e-7	34.0	34.0	34.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1880	2052	0.03433534963553941	0.952915979014004	-4.999999999999997e-7	34.0	34.0	34.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1880	2052	0.03474089360529732	0.9765975691256511	-4.999999999999994e-7	33.0	33.0	33.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1883	2053	0.03844957309564751	0.9715037168057101	-4.999999999999996e-7	33.0	33.0	33.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1883	2053	0.039605151792747734	0.9382246036899681	-4.999999999999994e-7	34.0	34.0	34.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1885	2055	0.05741427711615515	0.8542848619439108	-4.999999999999996e-7	37.0	37.0	37.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1885	2055	0.04503432585912938	1.0212254361377515	-4.999999999999993e-7	31.0	31.0	31.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1886	2056	0.0592878186674713	0.9081645913922632	-4.999999999999994e-7	35.0	35.0	35.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1886	2056	0.05604559701983061	0.9382827478191282	-4.999999999999993e-7	34.0	34.0	34.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1887	2057	0.053999347056021746	1.0638318678967114	-4.999999999999994e-7	30.0	30.0	30.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1887	2057	0.05925209982054489	1.0995436684421713	-4.999999999999994e-7	28.999999999999996	28.999999999999996	28.999999999999996	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1888	2058	0.038811716722549704	0.9453550959379812	-4.999999999999996e-7	34.0	34.0	34.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1888	2058	0.018134990797975918	0.8809228187309511	-4.999999999999994e-7	36.0	36.0	36.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1889	2059	0.015228320127857735	0.9887323494152562	-4.999999999999994e-7	32.0	32.0	32.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1889	2059	0.01642136296047067	0.9521518900216962	-4.999999999999996e-7	34.0	34.0	34.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1889	2059	0.019848373669671654	0.9012664042973271	-4.999999999999996e-7	36.0	36.0	36.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1890	2061	0.038860547076670346	1.0295976708646313	-4.999999999999994e-7	31.0	31.0	31.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1890	2061	0.03715922389481392	0.955535958908073	-4.999999999999994e-7	34.0	34.0	34.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1894	2062	0.037634199555722885	0.9993218244628451	-4.999999999999996e-7	32.0	32.0	32.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1894	2062	0.03609275230070751	0.9747685867117191	-4.999999999999997e-7	33.0	33.0	33.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1894	2062	0.03576809611724865	0.9955787249819772	-4.999999999999994e-7	32.0	32.0	32.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1895	2063	0.028104916659315936	0.8762871040593299	-4.999999999999997e-7	37.0	37.0	37.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1895	2063	0.02812250012425875	0.9252787053063911	-4.999999999999996e-7	35.0	35.0	35.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2064	1891	0.0545066388863331	1.054463434833102	0.0005794361437745893	30.0	30.0	30.0	1.0126582278481013	0.0	1	-59.99999999999999	59.99999999999999								
	1891	2065	0.03626381625006145	0.9254697422804711	-4.999999999999994e-7	35.0	35.0	35.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1902	2066	0.016350452958919924	0.9745848401950142	-4.999999999999994e-7	33.0	33.0	33.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1902	2066	0.03610190173824493	0.9993988219217803	-4.999999999999994e-7	32.0	32.0	32.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1904	2067	0.02229107785615308	0.8401756649429378	-4.999999999999996e-7	38.0	38.0	38.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1904	2067	0.021876859032261945	0.9002603379518191	-4.999999999999993e-7	36.0	36.0	36.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1905	2049	0.03654007641602477	0.9184756864540681	-4.999999999999997e-7	35.0	35.0	35.0	0.9374999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1905	2049	0.037391225905010365	0.9730854216650532	-4.999999999999994e-7	33.0	33.0	33.0	0.9374999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1905	2049	0.020085106703938746	0.895416155679312	-4.999999999999996e-7	36.0	36.0	36.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1905	2049	0.03573570571072016	0.9893187574142732	-4.999999999999996e-7	32.0	32.0	32.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1905	2050	0.08675350039689059	1.5874341123492817	-4.999999999999994e-7	20.0	20.0	20.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1908	1991	0.020802283458236405	0.2615080108952353	-4.999999999999996e-7	121.0	121.0	121.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1908	1991	0.021526366670957597	0.26582857245289027	-4.999999999999997e-7	119.0	119.0	119.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1908	2068	0.041369356559349174	1.0462378013499514	-4.999999999999994e-7	31.0	31.0	31.0	0.8375000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1908	2068	0.04049595982743608	1.0184171250469414	-4.999999999999993e-7	31.0	31.0	31.0	0.8375000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1908	2068	0.03893285156203609	1.0280599261291712	-4.999999999999994e-7	31.0	31.0	31.0	0.8375000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1907	2069	0.05624400746639982	1.1290574332100711	-4.999999999999994e-7	28.000000000000004	28.000000000000004	28.000000000000004	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1907	2069	0.05602224425919535	1.1021108293195612	-4.999999999999992e-7	28.999999999999996	28.999999999999996	28.999999999999996	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1908	1992	0.021457732619896405	0.26223374143609024	-4.999999999999996e-7	121.0	121.0	121.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1908	2070	0.017699051271138598	0.9826846051228635	-4.999999999999996e-7	33.0	33.0	33.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1908	2070	0.04064157223677432	1.0649467191554116	-4.999999999999994e-7	30.0	30.0	30.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1908	2070	0.017123298056462607	1.0199109642782611	-4.999999999999994e-7	31.0	31.0	31.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1908	2071	0.03829841079538869	1.0622734625430212	-4.999999999999994e-7	30.0	30.0	30.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1908	2071	0.041306391520185226	1.0805421103050414	-4.999999999999994e-7	30.0	30.0	30.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1908	2071	0.017296517552101813	1.031500277272742	-4.999999999999994e-7	31.0	31.0	31.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1908	2072	0.02392861211769452	0.806849873158767	-4.999999999999997e-7	40.0	40.0	40.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1908	2072	0.025083668082116	0.7486857556621569	-4.999999999999996e-7	43.0	43.0	43.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1913	2074	0.019187178560459817	0.8535293459833999	-4.999999999999997e-7	37.0	37.0	37.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1913	2074	0.019589248082187843	0.887332389588973	-4.999999999999996e-7	36.0	36.0	36.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1915	2075	0.04806012706713932	1.029596473278661	-4.999999999999994e-7	31.0	31.0	31.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1915	2075	0.049881996478645024	0.9865563247511561	-4.999999999999997e-7	32.0	32.0	32.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1917	2076	0.043314467061303506	1.0851677909919515	-4.999999999999994e-7	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1917	2076	0.04715938059239818	1.0608122722116715	-4.999999999999994e-7	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1919	2077	0.036118300112357254	1.0065526496536512	-4.999999999999994e-7	32.0	32.0	32.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1919	2077	0.034313605689468625	0.9535247955221149	-4.999999999999994e-7	34.0	34.0	34.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1921	2078	0.056590122753322834	1.1052129958267214	-4.999999999999997e-7	28.999999999999996	28.999999999999996	28.999999999999996	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1921	2078	0.05860770220020973	1.0368278351679812	-4.999999999999996e-7	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2079	1876	0.0538848485630855	1.0203479893880583	0.010182287032744368	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1923	2080	0.06157391953660351	1.0099690581118113	-4.999999999999994e-7	32.0	32.0	32.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1923	2080	0.06329582378888207	1.0908281021562811	-4.999999999999994e-7	28.999999999999996	28.999999999999996	28.999999999999996	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1924	2081	0.05184654593311903	1.0110838999332312	-4.999999999999993e-7	32.0	32.0	32.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1924	2081	0.0504633370761358	1.0014709696324016	-4.999999999999993e-7	32.0	32.0	32.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1925	2082	0.053358020306883275	0.9145805234724119	-4.999999999999994e-7	35.0	35.0	35.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1925	2082	0.0608707656488772	1.0352774977327714	-4.999999999999993e-7	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1926	2083	0.054617341114158634	1.1049049732449914	-4.999999999999993e-7	28.999999999999996	28.999999999999996	28.999999999999996	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1926	2083	0.0522310503693687	1.0461381835354415	-4.999999999999996e-7	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1876	2084	0.03777143973297615	0.9581879358561184	-4.999999999999996e-7	33.0	33.0	33.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1876	2084	0.03854859007060697	0.9370678775088332	-4.999999999999996e-7	34.0	34.0	34.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1929	2085	0.01661708776815032	0.9112677244779119	-4.999999999999996e-7	35.0	35.0	35.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1929	2085	0.01534120735241275	0.9968742080075141	-4.999999999999994e-7	32.0	32.0	32.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1930	2086	0.049050573395417955	1.0271874210252414	-4.999999999999994e-7	31.0	31.0	31.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1930	2086	0.051660420550142305	0.981330082211823	-4.999999999999994e-7	33.0	33.0	33.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1930	2086	0.05268331346444961	0.982682370796933	-4.999999999999996e-7	33.0	33.0	33.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1932	1634	0.015281346311552278	0.910601517249959	-4.999999999999996e-7	35.0	35.0	35.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1932	1634	0.02734244441840641	0.9118941680838121	-4.999999999999994e-7	35.0	35.0	35.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1932	1634	0.01662571869282215	0.9366651534930922	-4.999999999999994e-7	34.0	34.0	34.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1933	2089	0.05193397916208197	0.9631307661371703	-4.999999999999996e-7	33.0	33.0	33.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1933	2089	0.046360861834242775	1.0693010966011713	-4.999999999999996e-7	30.0	30.0	30.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1935	2088	0.053394240248279594	1.0144269586029713	-4.999999999999994e-7	32.0	32.0	32.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1935	2088	0.04735871796406987	1.0290670836542213	-4.999999999999994e-7	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1936	2092	0.017121070294195614	0.3597450936160444	-4.999999999999996e-7	88.0	88.0	88.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	1936	2092	0.018027030972001933	0.36681001656115236	-4.999999999999994e-7	87.0	87.0	87.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	1937	2091	0.08297418149363425	1.396740715306152	-4.999999999999996e-7	23.0	23.0	23.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1937	2091	0.12768053075516808	1.3246842424815015	-4.999999999999994e-7	24.0	24.0	24.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1689	1841	0.012256913189636256	0.29519515708413513	0.0014716117127737567	107.0	107.0	107.0	0.9876543209876546	0.0	1	-59.99999999999999	59.99999999999999								
	1867	2042	0.051143678365034875	0.9795231052429809	-4.999999999999996e-7	33.0	33.0	33.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1943	2094	0.051105135289246054	1.0853624610060313	-4.999999999999996e-7	30.0	30.0	30.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1943	2094	0.052587432697873394	1.0523425306996714	-4.999999999999996e-7	30.0	30.0	30.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1946	2095	0.059665816092609264	1.0503046709316712	-4.999999999999996e-7	31.0	31.0	31.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1946	2095	0.058406128034761126	1.0996638094569515	-4.999999999999994e-7	28.999999999999996	28.999999999999996	28.999999999999996	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1948	2096	0.05068962164310926	1.0158842462714712	-4.999999999999994e-7	32.0	32.0	32.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1948	2096	0.050878727406348925	0.9858240008737361	-4.999999999999996e-7	32.0	32.0	32.0	0.9749999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	1949	2090	0.041001001229362566	1.2671374827823914	-4.999999999999993e-7	25.0	25.0	25.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1950	2097	0.025968360211161726	0.8380554793412822	-4.999999999999994e-7	38.0	38.0	38.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1950	2097	0.026944363122751766	0.8291913823586173	-4.999999999999994e-7	39.0	39.0	39.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1840	2098	0.0620303880670498	1.1766832350969711	-4.999999999999994e-7	27.0	27.0	27.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1840	2098	0.04897108755576588	1.1897006879660712	-4.999999999999994e-7	27.0	27.0	27.0	0.9874999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1953	2099	0.037820408345145995	1.0009194011505211	-4.999999999999994e-7	32.0	32.0	32.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1954	2100	0.07172062501794846	1.0019012776794811	-4.999999999999992e-7	32.0	32.0	32.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1954	2100	0.06940740863372753	0.9981078581738223	-4.999999999999993e-7	32.0	32.0	32.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1954	2100	0.08879698874371296	0.9827841682224655	-4.999999999999994e-7	33.0	33.0	33.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1955	2101	0.020037802360907082	0.8909661903978264	-4.999999999999994e-7	36.0	36.0	36.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1955	2101	0.0213048341626784	0.9447971401294811	-4.999999999999996e-7	34.0	34.0	34.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1961	1642	1.0000000002037268e-9	0.05662706507904627	-4.999999999999996e-7	558.0	558.0	558.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1967	1639	0.018223119709893914	0.38422587569220223	-4.999999999999997e-7	83.0	83.0	83.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	1968	1643	0.03218188039377662	0.2718298150473684	-4.999999999999996e-7	115.99999999999999	115.99999999999999	115.99999999999999	0.9857142857142857	0.0	1	-59.99999999999999	59.99999999999999								
	1968	1645	0.02022578836523174	0.15759076703366123	-4.999999999999994e-7	199.0	199.0	199.0	0.9857142857142857	0.0	1	-59.99999999999999	59.99999999999999								
	1968	1647	1.0000000002037268e-9	0.05441598501661035	-4.999999999999996e-7	581.0	581.0	581.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1968	1648	1.0000000002037268e-9	0.053388307067790866	-4.999999999999996e-7	592.0	592.0	592.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1969	1644	0.016896874781839433	0.1389329799192232	-4.999999999999993e-7	225.99999999999997	225.99999999999997	225.99999999999997	0.9857142857142857	0.0	1	-59.99999999999999	59.99999999999999								
	1969	1646	0.027534841471698962	0.21266671464904635	-4.999999999999993e-7	148.0	148.0	148.0	0.9857142857142857	0.0	1	-59.99999999999999	59.99999999999999								
	1969	1649	1.0000000002037268e-9	0.05416169009752746	-4.999999999999996e-7	584.0	584.0	584.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1969	1650	1.0000000002037268e-9	0.05518351377615878	-4.999999999999996e-7	573.0	573.0	573.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1974	1651	0.014144541431087811	0.09434588656764666	-4.999999999999997e-7	332.0	332.0	332.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1974	1653	0.005956683076243691	0.043902854948809265	-4.999999999999994e-7	713.0	713.0	713.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1987	2034	0.0009085687654244901	0.10704383400132812	-4.999999999999993e-7	296.0	296.0	296.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1987	2034	0.0009586335700036286	0.10936094935057408	-4.999999999999992e-7	289.0	289.0	289.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2010	1955	0.037224265360405524	0.39658178785716436	-4.999999999999996e-7	80.0	80.0	80.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2073	2072	0.02496362518426206	0.773487427328064	-4.999999999999994e-7	41.0	41.0	41.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	2140	2215	0.003255288496233363	0.1776055064709732	-4.999999999999996e-7	178.0	178.0	178.0	0.9565217391304348	0.0	1	-59.99999999999999	59.99999999999999								
	2146	2319	0.009532488905987244	0.09767915943357781	-4.999999999999498e-7	322.0	322.0	322.0	1.0144927536231885	0.0	1	-59.99999999999999	59.99999999999999								
	2147	2148	0.010628881346071711	0.11768072134886612	-4.999999999999992e-7	268.0	268.0	268.0	0.9595959595959596	0.0	1	-59.99999999999999	59.99999999999999								
	2112	2149	0.019511938913992402	0.38635859628440056	-4.999999999999994e-7	82.0	82.0	82.0	0.9750000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	2112	2150	0.01861327883756891	0.36919372057192235	-4.999999999999994e-7	86.0	86.0	86.0	0.9750000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	2153	2279	0.02274783909243701	0.5521898153837238	-4.999999999999996e-7	57.99999999999999	57.99999999999999	57.99999999999999	0.9875000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2153	2279	0.02228020432213962	0.5353901843780815	-4.999999999999994e-7	59.0	59.0	59.0	0.9875000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2155	2280	0.0195879369142855	0.5026231117898807	-4.999999999999996e-7	63.0	63.0	63.0	1.0115400000000003	0.0	1	-59.99999999999999	59.99999999999999								
	2155	2280	0.013518009676650023	0.4953167242241137	-4.999999999999996e-7	64.0	64.0	64.0	1.0116	0.0	1	-59.99999999999999	59.99999999999999								
	2155	2281	0.05773399913138885	0.9508691875113292	-4.999999999999996e-7	34.0	34.0	34.0	1.0454	0.0	1	-59.99999999999999	59.99999999999999								
	2155	2281	0.055209133620990274	0.933929222835966	-4.999999999999996e-7	34.0	34.0	34.0	1.0454	0.0	1	-59.99999999999999	59.99999999999999								
	2157	2282	0.03425957737001294	0.5755431006856939	-4.999999999999996e-7	55.00000000000001	55.00000000000001	55.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2158	2283	0.11002427483851313	1.3306812355271216	-4.999999999999997e-7	24.0	24.0	24.0	0.9759999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	2158	2284	0.08050912571398718	1.1480548445043417	-4.999999999999994e-7	28.000000000000004	28.000000000000004	28.000000000000004	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2161	2119	0.007323766870374632	0.2264509920761663	-4.999999999999996e-7	140.0	140.0	140.0	1.0773000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	2162	2285	0.01422239434063141	0.4869818151436167	-4.999999999999997e-7	65.0	65.0	65.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2162	2285	0.014127747894345639	0.4740068768338327	-4.999999999999996e-7	67.0	67.0	67.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2163	2286	0.025468413581530392	0.38445703964554956	-4.999999999999997e-7	82.0	82.0	82.0	0.9875000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2163	2286	0.026980228258652414	0.40538959715913253	-4.999999999999996e-7	78.0	78.0	78.0	0.975	0.0	1	-59.99999999999999	59.99999999999999								
	2164	2287	0.01314613615126521	0.3239651555628584	-4.999999999999994e-7	98.0	98.0	98.0	1.0136200000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2164	2287	0.012808330240679674	0.3111927895095544	-4.999999999999997e-7	102.0	102.0	102.0	1.0136200000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2165	2288	0.01914506928506942	0.5713596446456417	-4.999999999999996e-7	56.00000000000001	56.00000000000001	56.00000000000001	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	2165	2288	0.019863786249553612	0.6134921272210796	-4.999999999999996e-7	52.0	52.0	52.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	2167	2289	0.014299536620021626	0.4452631530612916	-4.999999999999996e-7	71.0	71.0	71.0	0.9863600000000001	0.0	1	-59.99999999999999	59.99999999999999								
	2167	2289	0.013823516249825947	0.5450964166200417	-4.999999999999997e-7	57.99999999999999	57.99999999999999	57.99999999999999	0.9863600000000001	0.0	1	-59.99999999999999	59.99999999999999								
	2168	2290	0.019610185348863513	0.5002903542486645	-4.999999999999997e-7	64.0	64.0	64.0	0.975	0.0	1	-59.99999999999999	59.99999999999999								
	2168	2290	0.018343519574745417	0.48752533080723365	-4.999999999999997e-7	65.0	65.0	65.0	0.975	0.0	1	-59.99999999999999	59.99999999999999								
	2168	2290	0.014370884027254624	0.5336041173519038	-4.999999999999996e-7	60.0	60.0	60.0	0.975	0.0	1	-59.99999999999999	59.99999999999999								
	2169	2272	0.02909351806707384	0.6253186648054627	-4.999999999999997e-7	51.0	51.0	51.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2169	2272	0.029513397992301564	0.5927168034815807	-4.999999999999997e-7	54.0	54.0	54.0	0.975	0.0	1	-59.99999999999999	59.99999999999999								
	2170	2291	0.013302535325125618	0.5086869174315637	-4.999999999999994e-7	63.0	63.0	63.0	0.9624999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	2170	2291	0.01346897226667902	0.5155810786140207	-4.999999999999996e-7	62.0	62.0	62.0	0.9624999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	2171	2273	0.026233101624880805	0.38608973305057054	-4.999999999999996e-7	82.0	82.0	82.0	0.9624999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	2171	2273	0.02761270856227904	0.41631139660051353	-4.999999999999996e-7	76.0	76.0	76.0	0.9624999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	2173	2292	0.029445670258711854	0.6075789816262227	-4.999999999999996e-7	52.0	52.0	52.0	1.02556	0.0	1	-59.99999999999999	59.99999999999999								
	2173	2292	0.007759799710257271	0.5121177249583325	-4.999999999999997e-7	62.0	62.0	62.0	1.02556	0.0	1	-59.99999999999999	59.99999999999999								
	2177	2293	0.011936535417979411	0.2681257286367023	-4.999999999999997e-7	118.0	118.0	118.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2177	2293	0.011578205955617015	0.24846266968263542	-4.999999999999996e-7	127.0	127.0	127.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2178	2294	0.05970782961704019	0.9098111633720739	-4.999999999999996e-7	35.0	35.0	35.0	1.0495	0.0	1	-59.99999999999999	59.99999999999999								
	2127	2323	0.005524880817018946	0.20424135935229762	0.0009991942162049182	155.0	155.0	155.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2128	2323	0.005611123869084982	0.21290766950026882	8.821841429920742e-5	149.0	149.0	149.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2186	2133	0.008437636167043662	0.20065913622631928	-4.999999999999996e-7	158.0	158.0	158.0	1.04545	0.0	1	-59.99999999999999	59.99999999999999								
	2186	2296	0.021306067871434558	0.5145790373619108	-4.999999999999994e-7	62.0	62.0	62.0	0.964	0.0	1	-59.99999999999999	59.99999999999999								
	2189	2297	0.12306736661339321	1.5253341114749523	-4.999999999999996e-7	21.0	21.0	21.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2190	2274	0.02902351477711171	0.636134454326772	-4.999999999999996e-7	50.0	50.0	50.0	0.9999999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	2190	2274	0.02148680494982924	0.645020761555939	-4.999999999999997e-7	49.0	49.0	49.0	0.9999999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	2192	2298	0.028161551175445207	0.6254614832127205	-4.999999999999996e-7	51.0	51.0	51.0	1.0122199999999997	0.0	1	-59.99999999999999	59.99999999999999								
	2192	2299	0.0201050772011017	0.6624090463696448	-4.999999999999998e-7	48.0	48.0	48.0	1.0122199999999997	0.0	1	-59.99999999999999	59.99999999999999								
	2194	2336	0.006751310105698009	0.3051150340680512	-4.999999999999997e-7	104.0	104.0	104.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	2194	2336	0.007065886065249158	0.29833680444895944	-4.999999999999996e-7	106.0	106.0	106.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	2194	2336	0.00719841202807316	0.29784943083101134	-4.999999999999997e-7	107.0	107.0	107.0	1.0125	0.0	1	-59.99999999999999	59.99999999999999								
	2195	2277	0.007004022795820435	0.4225635170864985	-4.999999999999994e-7	75.0	75.0	75.0	0.97724	0.0	1	-59.99999999999999	59.99999999999999								
	2195	2277	0.006833645576761862	0.3926293569854483	-4.999999999999994e-7	81.0	81.0	81.0	0.97724	0.0	1	-59.99999999999999	59.99999999999999								
	2195	2277	0.006954519499281219	0.3867583302247085	-4.999999999999996e-7	82.0	82.0	82.0	0.97724	0.0	1	-59.99999999999999	59.99999999999999								
	2195	2324	9.999999965657482e-10	0.1012205199689571	-4.999999999999996e-7	313.0	313.0	313.0	0.9757799999999999	0.0	1	-59.99999999999999	59.99999999999999								
	2195	2325	9.999999892897906e-10	0.09663653802929532	-4.999999999999997e-7	327.0	327.0	327.0	0.9757799999999999	0.0	1	-59.99999999999999	59.99999999999999								
	2195	2326	9.999999965657482e-10	0.10144247184568314	-4.999999999999997e-7	312.0	312.0	312.0	0.9757799999999999	0.0	1	-59.99999999999999	59.99999999999999								
	2198	2278	0.01558742841685357	0.40071454999181655	-4.999999999999997e-7	79.0	79.0	79.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2198	2278	0.015393558037147686	0.3880701541568405	-4.999999999999996e-7	82.0	82.0	82.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2200	2304	0.021592668604088774	0.691785922603442	-4.999999999999997e-7	46.0	46.0	46.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2201	2305	0.022506582037850113	0.6654336956367477	-4.999999999999996e-7	48.0	48.0	48.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2202	2306	0.019578934151438826	0.5458474759919036	-4.999999999999996e-7	57.99999999999999	57.99999999999999	57.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2202	2307	0.020011691177023432	0.5114155089045337	-4.999999999999998e-7	62.0	62.0	62.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2204	2199	0.01604703861590638	0.38242768621873335	-4.999999999999997e-7	83.0	83.0	83.0	0.9317200000000001	0.0	1	-59.99999999999999	59.99999999999999								
	2204	2199	0.01677843692636292	0.3816909193583043	-4.999999999999994e-7	83.0	83.0	83.0	0.9317200000000001	0.0	1	-59.99999999999999	59.99999999999999								
	2204	2308	0.021325895349923293	0.6891870951266797	-4.999999999999998e-7	46.0	46.0	46.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2204	2309	0.021849303398134075	0.6430706891268377	-4.999999999999994e-7	50.0	50.0	50.0	0.98778	0.0	1	-59.99999999999999	59.99999999999999								
	2207	2310	0.02146288611821071	0.4854768743724026	-4.999999999999997e-7	66.0	66.0	66.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2207	2310	0.021166845280264305	0.47465319543265955	-4.999999999999994e-7	67.0	67.0	67.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2208	2311	0.04044044266582642	0.7965946698725809	-4.999999999999996e-7	40.0	40.0	40.0	0.9624999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	2209	2311	0.038317016708508025	0.869999160802646	-4.999999999999996e-7	37.0	37.0	37.0	0.975	0.0	1	-59.99999999999999	59.99999999999999								
	2210	2312	0.0539738688496147	0.9961065034079766	-4.999999999999994e-7	32.0	32.0	32.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2210	2312	0.056657310183729985	1.0014866632896813	-4.999999999999994e-7	32.0	32.0	32.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2212	2313	0.02818737956806261	0.6461877692499358	-4.999999999999997e-7	49.0	49.0	49.0	0.975	0.0	1	-59.99999999999999	59.99999999999999								
	2190	2314	0.01695468611451035	0.624685969925339	-4.999999999999996e-7	51.0	51.0	51.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2190	2314	0.01614174751179462	0.6275296617367239	-4.999999999999996e-7	51.0	51.0	51.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2214	2138	9.999999892897906e-10	0.18985169189988024	-4.999999999999997e-7	167.0	167.0	167.0	0.98818	0.0	1	-59.99999999999999	59.99999999999999								
	2214	2139	1.0000000038417058e-9	0.17518627539299617	-4.999999999999994e-7	181.0	181.0	181.0	0.98818	0.0	1	-59.99999999999999	59.99999999999999								
	2214	2315	0.00883536152430979	0.5047997504165787	-4.999999999999996e-7	63.0	63.0	63.0	1.0127799999999998	0.0	1	-59.99999999999999	59.99999999999999								
	2214	2315	0.009224831533792284	0.49638138983670876	-4.999999999999996e-7	64.0	64.0	64.0	1.0127799999999998	0.0	1	-59.99999999999999	59.99999999999999								
	2214	2315	0.008897677536464123	0.5044125788777437	-4.999999999999996e-7	63.0	63.0	63.0	1.0127799999999998	0.0	1	-59.99999999999999	59.99999999999999								
	2219	2316	0.023124651935954435	0.5269262458314727	-4.999999999999996e-7	60.0	60.0	60.0	1.02306	0.0	1	-59.99999999999999	59.99999999999999								
	2219	2316	0.01968574822390624	0.5315293776615915	-4.999999999999994e-7	60.0	60.0	60.0	1.0140000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2220	2221	0.008331732810418909	0.49913859690994267	-4.999999999999996e-7	64.0	64.0	64.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2220	2221	0.008543396696463985	0.5053979616527846	-4.999999999999997e-7	63.0	63.0	63.0	0.8415200000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2222	2338	0.021036196326037697	0.46603220628818764	-4.999999999999996e-7	68.0	68.0	68.0	0.9885000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2223	2317	0.00650618015764453	0.4998316132056686	-4.999999999999997e-7	64.0	64.0	64.0	0.9661	0.0	1	-59.99999999999999	59.99999999999999								
	2223	2317	0.00672275358783253	0.5287786068274988	-4.999999999999994e-7	60.0	60.0	60.0	0.9661	0.0	1	-59.99999999999999	59.99999999999999								
	2224	2318	0.011701845278629918	0.45649309800996163	-4.999999999999997e-7	70.0	70.0	70.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2224	2318	0.017428724790310317	0.5681475425101938	-4.999999999999996e-7	56.00000000000001	56.00000000000001	56.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2229	2147	9.999999892897906e-10	0.16991307797161123	-4.999999999999996e-7	186.0	186.0	186.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2229	2319	0.006042709651957107	0.23166689925376527	-4.999999999999996e-7	137.0	137.0	137.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2214	2320	0.008780242603073684	0.5012241181710018	-4.999999999999996e-7	64.0	64.0	64.0	0.98722	0.0	1	-59.99999999999999	59.99999999999999								
	2214	2320	0.008940752106715782	0.49443287346549075	-4.999999999999997e-7	64.0	64.0	64.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2231	2321	0.054019961262761505	0.916424875130242	-4.999999999999996e-7	35.0	35.0	35.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2231	2321	0.05931027728934482	0.9001735899871061	-4.999999999999997e-7	36.0	36.0	36.0	0.9886999999999999	0.0	1	-59.99999999999999	59.99999999999999								
	2232	2235	0.008231153828652402	0.38096584899394537	-4.999999999999997e-7	83.0	83.0	83.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2233	2234	0.00837761643210595	0.3885621118999855	-4.999999999999996e-7	82.0	82.0	82.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2322	2237	0.03867337689966463	0.5676412610980782	0.004819072668619385	56.00000000000001	56.00000000000001	56.00000000000001	1.050420168067227	0.0	1	-59.99999999999999	59.99999999999999								
	2238	2112	0.005623412314859991	0.15653465301554415	-4.999999999999996e-7	202.0	202.0	202.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	2238	2112	0.005360588923740988	0.16254081986552715	-4.999999999999994e-7	195.0	195.0	195.0	1.0375	0.0	1	-59.99999999999999	59.99999999999999								
	2239	2114	0.0017580185835825396	0.10642718849221211	-4.999999999999993e-7	297.0	297.0	297.0	1.0908999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	2240	2115	0.0022136641458997616	0.10445398564549314	-4.999999999999994e-7	303.0	303.0	303.0	1.0908999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	2241	2116	0.005507376005804952	0.19040786944920426	-4.999999999999993e-7	166.0	166.0	166.0	1.0908999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	2243	2156	0.0015448946632368678	0.10570835848683212	-4.999999999999994e-7	299.0	299.0	299.0	1.0135999999999994	0.0	1	-59.99999999999999	59.99999999999999								
	2243	2156	0.0014264054245472144	0.1044821014746901	-4.999999999999994e-7	303.0	303.0	303.0	1.0135999999999994	0.0	1	-59.99999999999999	59.99999999999999								
	2244	2117	0.004306569243503575	0.20559986542421724	-4.999999999999993e-7	154.0	154.0	154.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2118	2249	0.0069520990572440895	0.10377776962850051	0.03215727981679762	304.0	304.0	304.0	0.9362419249133974	0.0	1	-59.99999999999999	59.99999999999999								
	2247	2330	0.01591046050304253	0.3330255129132445	-4.999999999999993e-7	95.0	95.0	95.0	1.0681000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	2249	2166	0.0020271599555637876	0.0821328341872449	-4.999999999999993e-7	385.0	385.0	385.0	1.0224999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	2249	2166	0.001921038177480761	0.08129033755200159	-4.999999999999994e-7	389.0	389.0	389.0	1.0224999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	2250	2124	0.0019953831036545596	0.07930259815002039	-4.999999999999993e-7	399.0	399.0	399.0	0.9884999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	2250	2125	0.004123879534692358	0.14679973454479317	-4.999999999999992e-7	216.0	216.0	216.0	0.9884999999999996	0.0	1	-59.99999999999999	59.99999999999999								
	2173	2120	0.011396804328529894	0.3606380918860733	-4.999999999999996e-7	88.0	88.0	88.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	2173	2123	0.00613840206529094	0.22006388172641628	-4.999999999999996e-7	144.0	144.0	144.0	1.020990909090909	0.0	1	-59.99999999999999	59.99999999999999								
	2173	2121	0.012007211256955549	0.3937230735505865	-4.999999999999996e-7	81.0	81.0	81.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	2173	2122	0.01184546421136879	0.39440357431763035	-4.999999999999996e-7	81.0	81.0	81.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	2250	2173	0.00112986682378158	0.08687325660117619	-4.999999999999993e-7	364.0	364.0	364.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2250	2173	0.0011185451075218806	0.0822550507437828	-4.999999999999992e-7	384.0	384.0	384.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2250	2174	0.0010876774757512103	0.07891001973981678	-4.999999999999994e-7	401.0	401.0	401.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2255	2331	0.020878117874164045	0.39007711561000147	-4.999999999999992e-7	81.0	81.0	81.0	1.0454499999999995	0.0	1	-59.99999999999999	59.99999999999999								
	2255	2332	0.019975064000442508	0.4036154045418296	-4.999999999999993e-7	79.0	79.0	79.0	1.0454499999999995	0.0	1	-59.99999999999999	59.99999999999999								
	2255	2333	0.01135566795197493	0.20773005004205933	-4.999999999999993e-7	152.0	152.0	152.0	1.0434499999999998	0.0	1	-59.99999999999999	59.99999999999999								
	2255	2334	0.019943320690618768	0.3651340747530034	-4.999999999999992e-7	87.0	87.0	87.0	1.0454499999999995	0.0	1	-59.99999999999999	59.99999999999999								
	2255	2335	0.019523666562432308	0.37978995806040133	-4.999999999999993e-7	84.0	84.0	84.0	1.0454499999999995	0.0	1	-59.99999999999999	59.99999999999999								
	2132	2259	0.012762934293124046	0.2908110860920296	0.0036239095540895627	109.00000000000001	109.00000000000001	109.00000000000001	0.9565258979386871	0.0	1	-59.99999999999999	59.99999999999999								
	2261	2134	0.0016725611568440945	0.0906622081920876	-4.999999999999993e-7	349.0	349.0	349.0	1.0908999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	2261	2135	0.0018145111398904846	0.0924484662053566	-4.999999999999993e-7	342.0	342.0	342.0	1.0908999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	2261	2136	0.0015935601758824923	0.08488182912259079	-4.999999999999994e-7	373.0	373.0	373.0	1.0908999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	2262	2193	0.001187153037378397	0.08207635813097647	-4.999999999999993e-7	385.0	385.0	385.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2262	2193	0.001107931181738917	0.08800529720120309	-4.999999999999994e-7	359.0	359.0	359.0	1.0111000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	2262	2193	0.0011796531206004583	0.08483583030695269	-4.999999999999993e-7	373.0	373.0	373.0	1.0111000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	2262	2193	0.0011124093640868741	0.08718374837938879	-4.999999999999993e-7	363.0	363.0	363.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2263	2198	0.0011004216317188184	0.08131558100674478	-4.999999999999993e-7	389.0	389.0	389.0	1.0339300000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2263	2198	0.001062310408998128	0.07902534070222819	-4.999999999999992e-7	400.0	400.0	400.0	1.0339300000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2143	2269	0.005552274828189138	0.1747219947285647	0.008491136250690262	181.0	181.0	181.0	0.9362419249133974	0.0	1	-59.99999999999999	59.99999999999999								
	2269	2219	0.001440220833515581	0.08455849004643218	-4.999999999999992e-7	374.0	374.0	374.0	1.0113300000000003	0.0	1	-59.99999999999999	59.99999999999999								
	2270	2220	0.001167694348785866	0.0880918321492569	-4.999999999999993e-7	359.0	359.0	359.0	1.0113199999999996	0.0	1	-59.99999999999999	59.99999999999999								
	2270	2220	0.0011961029704444372	0.0839130570605434	-4.999999999999992e-7	377.0	377.0	377.0	1.0113199999999996	0.0	1	-59.99999999999999	59.99999999999999								
	2323	2129	0.0217315496084996	0.33400477528838635	-4.999999999999996e-7	95.0	95.0	95.0	1.0454	0.0	1	-59.99999999999999	59.99999999999999								
	2323	2130	0.02111415902620825	0.3316535928281134	-4.999999999999994e-7	96.0	96.0	96.0	1.0454	0.0	1	-59.99999999999999	59.99999999999999								
	2323	2131	0.021597308758601403	0.3305862376535845	-4.999999999999997e-7	96.0	96.0	96.0	1.0454	0.0	1	-59.99999999999999	59.99999999999999								
	2323	2295	0.09314798983434397	1.098080016701242	-4.999999999999996e-7	28.999999999999996	28.999999999999996	28.999999999999996	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2117	2328	0.19988457300116738	1.1162303129840465	0.012639823328266821	28.000000000000004	28.000000000000004	28.000000000000004	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2337	2324	0.025242976418269628	0.5755488119984996	-4.999999999999996e-7	55.00000000000001	55.00000000000001	55.00000000000001	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	2337	2324	0.025221855705018975	0.6128588930584306	-4.999999999999997e-7	52.0	52.0	52.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	2337	2325	0.01576882979992015	0.5472942429198228	-4.999999999999997e-7	57.99999999999999	57.99999999999999	57.99999999999999	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	2337	2325	0.017654208051964528	0.6320164541789637	-4.999999999999996e-7	50.0	50.0	50.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	2337	2326	0.020243843906365164	0.6009579138397407	-4.999999999999996e-7	53.0	53.0	53.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	2337	2326	0.020088434351870618	0.5731603193671045	-4.999999999999996e-7	56.00000000000001	56.00000000000001	56.00000000000001	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	85	10001	1.5659619602993967e-5	0.008755371665905693	-5.000000000000001e-7	3000.0	3608.0	3608.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	86	10001	8.460988671580803e-5	0.0024805421883962006	0.0	3000.0	10000.0	10000.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	512	10001	0.0008695857298647381	0.04486436534917219	0.0	704.0	704.0	704.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	87	10002	2.988417663928803e-5	0.010862759944412399	-5.000000000000001e-7	2908.0	2908.0	2908.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	88	10002	7.097161146198103e-5	0.0008491365834627995	0.0	3000.0	10000.0	10000.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	514	10002	0.000898285235796676	0.04619788971752629	0.0	684.0	684.0	684.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	87	10003	4.3178274857037994e-5	0.0077083761366271005	-5.000000000000001e-7	3000.0	4098.0	4098.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	88	10003	5.8080286329769986e-5	0.003634214109778399	0.0	3000.0	8691.0	8691.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	515	10003	0.0008922683949282681	0.040044640304222716	0.0	789.0	789.0	789.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	92	10004	7.203154663788398e-6	0.0095081685924413	-5.000000000000001e-7	3000.0	3322.9999999999995	3322.9999999999995	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	93	10004	7.538128367508746e-5	0.0016989205613849006	0.0	3000.0	10000.0	10000.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	154	10004	0.0007486019160610157	0.04977126362264851	0.0	635.0	635.0	635.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	92	10005	2.4027743404265252e-5	0.008274644848494746	-5.000000000000001e-7	3000.0	3818.0	3818.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	93	10005	5.692216883832621e-5	0.003077995957867252	0.0	3000.0	10000.0	10000.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	155	10005	0.0007926631635492669	0.04836286593681665	0.0	654.0	654.0	654.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	94	10006	5.858636656333659e-5	0.009971587547133745	-5.000000000000001e-7	3000.0	3168.0	3168.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	95	10006	2.293824222381259e-5	0.00150102322200775	0.0	3000.0	10000.0	10000.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	521	10006	0.0007488180844408926	0.04966898312273904	0.0	636.0	636.0	636.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	94	10007	4.136513149132979e-5	0.007865901881810348	-5.000000000000001e-7	3000.0	4015.9999999999995	4015.9999999999995	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	95	10007	3.900042344862576e-5	0.0028184219385869536	0.0	3000.0	10000.0	10000.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	522	10007	0.0007719659715988673	0.04618766692640266	0.0	684.0	684.0	684.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	101	10008	8.02335494105508e-6	0.0	-5.0e-7	3000.0	10000.0	10000.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	160	10008	0.0034964653038354544	0.049438203631192404	0.0	638.0	638.0	638.0	0.9600000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	525	10008	0.018271033753297247	0.06544104013288359	0.0	465.00000000000006	465.00000000000006	465.00000000000006	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	101	10009	0.0009968085101945418	0.0	-5.0e-7	3000.0	10000.0	10000.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	160	10009	0.0027429588550501385	0.05241243639091033	0.0	602.0	602.0	602.0	0.9600000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	526	10009	0.018579503401206364	0.0664734764381127	0.0	458.0	458.0	458.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	113	10010	0.00013984197727591002	0.006030370221487246	-5.0e-7	3000.0	5237.0	5237.0	1.048484848484849	0.0	1	-59.99999999999999	59.99999999999999								
	37	10010	0.000710016716336829	0.03740492577622175	0.0	844.9999999999999	844.9999999999999	844.9999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	38	10010	0.000812361649430821	0.03482555944744966	0.0	907.0	907.0	907.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	113	10011	9.270750631787706e-5	0.007522300540856102	-5.0e-7	3000.0	4199.0	4199.0	1.048484848484849	0.0	1	-59.99999999999999	59.99999999999999								
	39	10011	0.0007621554438124891	0.034583268749394394	0.0	914.0	914.0	914.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	40	10011	0.0008235000742741411	0.034801895182917805	0.0	908.0	908.0	908.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	113	10012	0.00011229668126651001	0.007236667022134806	-5.0e-7	3000.0	4365.0	4365.0	1.048484848484849	0.0	1	-59.99999999999999	59.99999999999999								
	41	10012	0.000800344416350826	0.03632600703223831	0.0	869.9999999999999	869.9999999999999	869.9999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	42	10012	0.000754302968970734	0.0359441240740915	0.0	878.9999999999999	878.9999999999999	878.9999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	116	10013	0.0	0.01145100209835215	-5.000000000000001e-7	2759.0	2759.0	2759.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	117	10013	0.0	0.00024171490810115043	0.0	3000.0	10000.0	10000.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	622	10013	0.0	0.05175036570417466	0.0	611.0	611.0	611.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	116	10014	0.0	0.009547348370442549	-5.000000000000001e-7	3000.0	3309.0000000000005	3309.0000000000005	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	117	10014	0.0	0.0019515660573612504	0.0	3000.0	10000.0	10000.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	623	10014	0.0	0.04842758619966676	0.0	653.0	653.0	653.0	1.0454545454545454	0.0	1	-59.99999999999999	59.99999999999999								
	141	10015	0.0005312025436698452	0.0082619093516374	-5.0e-7	3000.0	3815.9999999999995	3815.9999999999995	1.048484848484849	0.0	1	-59.99999999999999	59.99999999999999								
	68	10015	0.0028174213050990355	0.0842740867233837	0.0	375.0	375.0	375.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	69	10015	0.0027062113934294353	0.0813576827390587	0.0	389.0	389.0	389.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	141	10016	0.0005600779625668649	0.004984628876312405	-5.0e-7	3000.0	6298.0	6298.0	1.048484848484849	0.0	1	-59.99999999999999	59.99999999999999								
	70	10016	0.002816421865123556	0.0907631327940386	0.0	348.0	348.0	348.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	71	10016	0.0027772093066235556	0.0912113413797368	0.0	347.0	347.0	347.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	141	10017	0.00014091636513592463	0.012831438375877526	-5.0e-7	2462.0	2462.0	2462.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	72	10017	0.004152361972252376	0.12250515727814253	0.0	258.0	258.0	258.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	73	10017	0.004440949467394035	0.1189823517622055	0.0	266.0	266.0	266.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	141	10018	2.2525152219694987e-5	0.011047824994901994	-5.0e-7	2860.0	2860.0	2860.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	74	10018	0.004342520057004646	0.122403856985756	0.0	258.0	258.0	258.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	75	10018	0.004584188290552936	0.12571979528170002	0.0	252.0	252.0	252.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	266	10019	0.005753160339354097	0.020760424398165	-5.0e-7	1467.0	1467.0	1467.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	560	10019	0.005661141234354602	0.187374755991344	0.0	169.0	169.0	169.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	561	10019	0.0115572848116257	0.36808578737052217	0.0	86.0	86.0	86.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	266	10020	0.005569148323277449	0.03654376790854196	-5.0e-7	855.0000000000001	855.0000000000001	855.0000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	560	10020	0.004992969608122952	0.15645835352134807	0.0	202.0	202.0	202.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	561	10020	0.012322215158946355	0.352667308446438	0.0	90.0	90.0	90.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	289	10021	0.00108820256983627	0.17732152896593356	-5.0e-7	179.0	179.0	179.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	494	10021	0.003501861765563969	0.018198294839495477	0.0	1705.0	1705.0	1705.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	495	10021	0.015468923914341732	0.24579462610608957	0.0	129.0	129.0	129.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	289	10022	0.0016336235209484659	0.161286366758049	-5.0e-7	196.0	196.0	196.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	494	10022	0.003092625660679766	0.032702861320935	0.0	961.9999999999999	961.9999999999999	961.9999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	496	10022	0.015237590587332338	0.23128384162517296	0.0	137.0	137.0	137.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	420	10023	0.002594974011546	0.16729872000352053	-5.0e-7	189.0	189.0	189.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	491	10023	0.00186247051410377	0.018783248796113483	0.0	1673.9999999999998	1673.9999999999998	1673.9999999999998	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	528	10023	0.0	0.25631487271470554	0.0	124.0	124.0	124.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	420	10024	0.0012386709656790184	0.1665253913089115	-5.0e-7	190.0	190.0	190.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	491	10024	0.004323147558443221	0.04280470025134753	0.0	735.0	735.0	735.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	529	10024	0.017777832767903783	0.26792361511375234	0.0	118.0	118.0	118.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	422	10025	0.0016989911183046705	0.11476723623188903	-5.0e-7	276.0	276.0	276.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	492	10025	0.0011650195118242399	0.007690478247677993	0.0	3000.0	4061.0	4061.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	531	10025	0.00440529580263351	0.12000488389214302	0.0	264.0	264.0	264.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	422	10026	0.0019160850950737953	0.11736345267037902	-5.0e-7	270.0	270.0	270.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	492	10026	0.0011036434024351146	0.010614943840710997	0.0	2960.0	2960.0	2960.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	532	10026	0.004552447213708654	0.11183991004568501	0.0	283.0	283.0	283.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	575	10027	0.0	0.19188951118006853	-5.0e-7	165.0	165.0	165.0	1.15	0.0	1	-59.99999999999999	59.99999999999999								
	321	10027	0.0	0.21037350496854149	0.0	151.0	151.0	151.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	62	10027	0.0	0.003993174414974501	0.0	3000.0	7911.0	7911.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	576	10028	0.0	0.1968627319567375	-5.0e-7	161.0	161.0	161.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	63	10028	0.0	0.005300261338492498	0.0	3000.0	5960.0	5960.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	604	10029	0.00632023591630535	0.09495876986895851	-5.0e-7	332.0	332.0	332.0	0.9900000000000003	0.0	1	-59.99999999999999	59.99999999999999								
	28	10029	0.00514351838275785	0.20966316671701044	0.0	151.0	151.0	151.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	606	10029	0.009777703271104056	0.13169192033277155	0.0	240.0	240.0	240.0	1.0363636363636362	0.0	1	-59.99999999999999	59.99999999999999								
	605	10030	0.0060572172987125505	0.08424747200755	-5.0e-7	374.0	374.0	374.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	28	10030	0.00499932904998025	0.22196546241016202	0.0	143.0	143.0	143.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	607	10030	0.01043936546496675	0.14347501091556297	0.0	220.00000000000003	220.00000000000003	220.00000000000003	1.0363636363636362	0.0	1	-59.99999999999999	59.99999999999999								
	716	10031	0.00023317818399029753	0.0030400113205355044	-4.999999999999999e-7	3000.0	10000.0	10000.0	1.0149999999999995	0.0	1	-59.99999999999999	59.99999999999999								
	841	10031	7.267021870962346e-5	0.027701330963775996	0.0	1141.0	1141.0	1141.0	0.9999999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	977	10031	0.0007027194174949545	0.041873850952989906	0.0	755.0	755.0	755.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	716	10032	0.00022655603796425312	0.0033526904319180015	-4.999999999999999e-7	3000.0	9401.0	9401.0	1.0149999999999995	0.0	1	-59.99999999999999	59.99999999999999								
	841	10032	7.993565361485798e-5	0.028556501916963593	0.0	1107.0	1107.0	1107.0	0.9999999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	978	10032	0.000702676143724378	0.0425791891443497	0.0	742.0	742.0	742.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	716	10033	0.0002626788988325281	0.002413794606975252	-4.999999999999999e-7	3000.0	10000.0	10000.0	1.0149999999999995	0.0	1	-59.99999999999999	59.99999999999999								
	841	10033	5.6615443932590916e-5	0.029561602284945542	0.0	1069.0	1069.0	1069.0	0.9999999999999998	0.0	1	-59.99999999999999	59.99999999999999								
	980	10033	0.0007291270759936889	0.04131917479644995	0.0	765.0	765.0	765.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	781	10034	0.008264327199884703	0.3827075381869616	-4.999999999999999e-7	83.0	83.0	83.0	1.0817477272727272	0.0	1	-59.99999999999999	59.99999999999999								
	878	10034	0.0044184482846064	0.011666799532612538	0.0	2532.0	2532.0	2532.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	940	10034	0.009172264634543102	0.30634811749185764	0.0	104.0	104.0	104.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	781	10035	0.008005825872078553	0.29715862514813507	-4.999999999999999e-7	107.0	107.0	107.0	1.0817477272727272	0.0	1	-59.99999999999999	59.99999999999999								
	878	10035	0.004298508060036249	0.02624903392745498	0.0	1188.0	1188.0	1188.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	940	10035	0.009252582247680058	0.2829688654187611	0.0	112.00000000000001	112.00000000000001	112.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	781	10036	0.013104522387902304	0.33077530368138164	-4.999999999999999e-7	96.0	96.0	96.0	1.0817477272727272	0.0	1	-59.99999999999999	59.99999999999999								
	878	10036	0.009365810263235998	0.03216060555862649	0.0	944.0	944.0	944.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	940	10036	0.013216206581497105	0.3840675277260006	0.0	83.0	83.0	83.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	798	10037	0.0013512440728630207	0.07119588785821114	-4.999999999999999e-7	444.00000000000006	444.00000000000006	444.00000000000006	0.9673454545454544	0.0	1	-59.99999999999999	59.99999999999999								
	906	10037	0.00073925844573986	0.005651477604103207	0.0	3000.0	5543.0	5543.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	949	10037	0.0016291745959424208	0.07487611576381613	0.0	422.0	422.0	422.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	827	10038	0.0003944506124495551	0.008905186740304244	-5.0e-7	3000.0	3544.0	3544.0	1.048484848484849	0.0	1	-59.99999999999999	59.99999999999999								
	662	10038	0.001257121956948655	0.06602388863712556	0.0	479.0	479.0	479.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	663	10038	0.001167470614182295	0.06820557762095247	0.0	463.99999999999994	463.99999999999994	463.99999999999994	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	827	10039	0.00038225168621447496	0.01344865241053996	-5.0e-7	2348.0	2348.0	2348.0	1.048484848484849	0.0	1	-59.99999999999999	59.99999999999999								
	664	10039	0.0012567169950376254	0.058555695533975854	0.0	540.0	540.0	540.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	665	10039	0.0011774573246887852	0.059418988537597354	0.0	532.0	532.0	532.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	827	10040	0.00021450703139230516	0.0035864952345064523	-5.0e-7	3000.0	8792.0	8792.0	1.048484848484849	0.0	1	-59.99999999999999	59.99999999999999								
	667	10040	0.002639900802362715	0.09001490722694175	0.0	351.0	351.0	351.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	668	10040	0.0024518373269774045	0.09056512908929326	0.0	349.0	349.0	349.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	827	10041	0.0002670057976082901	0.0028272144965269534	-5.0e-7	3000.0	10000.0	10000.0	1.048484848484849	0.0	1	-59.99999999999999	59.99999999999999								
	669	10041	0.0023543529770723498	0.09061478273364795	0.0	349.0	349.0	349.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	670	10041	0.00245079840367334	0.09733609140506905	0.0	325.0	325.0	325.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	827	10042	6.288175224140013e-5	0.007536145605093096	-5.0e-7	3000.0	4192.0	4192.0	1.048484848484849	0.0	1	-59.99999999999999	59.99999999999999								
	671	10042	0.00274019928508345	0.09078882984254112	0.0	348.0	348.0	348.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	672	10042	0.00277089210923296	0.09328930288874988	0.0	339.0	339.0	339.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	827	10043	0.00014995550334128	0.006143452531214055	-5.0e-7	3000.0	5141.0	5141.0	1.048484848484849	0.0	1	-59.99999999999999	59.99999999999999								
	673	10043	0.00256611025990126	0.09415584974780593	0.0	336.0	336.0	336.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	674	10043	0.0027222229963303505	0.08702599548831703	0.0	363.0	363.0	363.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	827	10044	7.353890579845985e-5	0.000893842153382091	-5.0e-7	3000.0	10000.0	10000.0	1.048484848484849	0.0	1	-59.99999999999999	59.99999999999999								
	675	10044	0.0026638400089992196	0.09497236344401341	0.0	333.0	333.0	333.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	666	10044	0.0027878969080755503	0.09268297037199322	0.0	341.0	341.0	341.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	831	10045	0.004006644132351972	0.22743275804592408	-5.0e-7	139.0	139.0	139.0	1.0140909090909087	0.0	1	-59.99999999999999	59.99999999999999								
	928	10045	0.0022163629853664897	0.014580208149677995	0.0	2142.0	2142.0	2142.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	963	10045	0.006515959021909632	0.19399765723746615	0.0	163.0	163.0	163.0	1.0227272727272725	0.0	1	-59.99999999999999	59.99999999999999								
	831	10046	0.003786496607310581	0.23977692762928102	-5.0e-7	132.0	132.0	132.0	1.0140909090909087	0.0	1	-59.99999999999999	59.99999999999999								
	928	10046	0.00224250035948355	0.0022520277836019916	0.0	3000.0	9940.0	9940.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	963	10046	0.006816938980701823	0.21312096648553003	0.0	149.0	149.0	149.0	1.0227272727272725	0.0	1	-59.99999999999999	59.99999999999999								
	836	10047	0.00011079330317094089	0.018454072297644692	-5.000000000000001e-7	1712.0	1712.0	1712.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	832	10047	0.0002149354760556011	0.0029153556731707016	0.0	3000.0	10000.0	10000.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	938	10047	0.0013092354925491395	0.03879302023470161	0.0	814.0	814.0	814.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	836	10048	0.00017247272064466936	0.019726340921920247	-5.000000000000001e-7	1602.0	1602.0	1602.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	832	10048	0.00015614834357122965	0.0015976076172585514	0.0	3000.0	10000.0	10000.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	937	10048	0.001264893574237591	0.04084301250462427	0.0	774.0	774.0	774.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1116	10049	0.0009236425130360503	0.247981276370745	-5.000000000000001e-7	128.0	128.0	128.0	0.9774599999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1117	10049	0.028008808880998447	1.089592246494565	0.0	28.999999999999996	28.999999999999996	28.999999999999996	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1118	10049	0.02667579599185076	1.0190269304278752	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1116	10050	0.002643061129738597	0.22471108919458985	-5.000000000000001e-7	141.0	141.0	141.0	0.9774599999999999	0.0	1	-59.99999999999999	59.99999999999999								
	1117	10050	0.024301137804134707	1.0487151042421403	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1118	10050	0.02417500802009551	1.08575301557315	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1159	10051	0.002245742752891952	0.22574541388494485	-5.000000000000001e-7	140.0	140.0	140.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1161	10051	0.022177699004001954	1.0500497217562952	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1160	10051	0.023141413876572647	1.0176462511771849	0.0	32.0	32.0	32.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1159	10052	0.0022527982910559995	0.16017827686016006	-5.000000000000001e-7	198.0	198.0	198.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1161	10052	0.0231624242382985	1.1277755445657502	0.0	28.999999999999996	28.999999999999996	28.999999999999996	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1160	10052	0.02170177954990641	1.0442014266508404	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1208	10053	0.0018857274046854486	0.28015200091619996	-5.000000000000001e-7	112.99999999999999	112.99999999999999	112.99999999999999	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1209	10053	0.02491974858052866	1.0473381256123402	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1210	10053	0.02416482846905876	1.0477515267475206	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1208	10054	0.0008275491940025016	0.2322000964685549	-5.000000000000001e-7	137.0	137.0	137.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1209	10054	0.026286669278487607	1.083585198846075	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1210	10054	0.026839346494600194	1.108096878191985	0.0	28.999999999999996	28.999999999999996	28.999999999999996	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1213	10055	0.0008724217699835998	0.200611286754965	-5.000000000000001e-7	158.0	158.0	158.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1617	10055	0.02749847749297651	1.0720380283281452	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1618	10055	0.026011921740370314	1.0953647891004552	0.0	28.999999999999996	28.999999999999996	28.999999999999996	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1213	10056	0.002854842824970598	0.26437738736829963	-5.000000000000001e-7	120.0	120.0	120.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1617	10056	0.024982746900177304	0.9879148615596803	0.0	32.0	32.0	32.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1618	10056	0.023935658739930313	1.0833411974889404	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1243	10057	0.0017471508472065508	0.01777051685959702	-5.0e-7	1769.0000000000002	1769.0000000000002	1769.0000000000002	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1136	10057	0.011193720384952848	0.31737208856938703	0.0	100.0	100.0	100.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1137	10057	0.012070348541780651	0.330733217537127	0.0	96.0	96.0	96.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1280	10058	0.0024564552997611497	0.18483278793740518	-5.000000000000001e-7	171.0	171.0	171.0	1.01255	0.0	1	-59.99999999999999	59.99999999999999								
	1282	10058	0.022232907481570755	1.050949774414845	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1281	10058	0.02254166727725415	1.064651512923945	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1280	10059	0.003419526323836696	0.22732873080315985	-5.000000000000001e-7	139.0	139.0	139.0	1.01255	0.0	1	-59.99999999999999	59.99999999999999								
	1282	10059	0.020333135407779014	0.9633928440148601	0.0	33.0	33.0	33.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1281	10059	0.02034078646329941	1.0326851855928703	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1280	10060	0.00347307155763495	0.24428836364873494	-5.000000000000001e-7	130.0	130.0	130.0	1.01255	0.0	1	-59.99999999999999	59.99999999999999								
	1282	10060	0.021216713417770854	0.9741520124331153	0.0	33.0	33.0	33.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1281	10060	0.020745592151845352	1.030535905269295	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1280	10061	0.0027124777382356515	0.12468113048935024	-5.000000000000001e-7	254.0	254.0	254.0	0.98745	0.0	1	-59.99999999999999	59.99999999999999								
	1313	10061	0.021987150873301956	1.08267742715677	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1314	10061	0.022671656878117848	1.1077088453329502	0.0	28.999999999999996	28.999999999999996	28.999999999999996	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1280	10062	0.003210641269888751	0.14878714693842474	-5.000000000000001e-7	213.0	213.0	213.0	0.98745	0.0	1	-59.99999999999999	59.99999999999999								
	1314	10062	0.022049077242561558	1.0557699616902052	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1313	10062	0.02104738894304725	1.0691536741056054	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1280	10063	0.0022374348078481494	0.18604159337156997	-5.000000000000001e-7	170.0	170.0	170.0	0.98745	0.0	1	-59.99999999999999	59.99999999999999								
	1314	10063	0.021949807331748353	1.0807081855926104	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1313	10063	0.02187904497232295	1.00790945794029	0.0	32.0	32.0	32.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1337	10064	0.000891175501984504	0.21791538195050994	-5.000000000000001e-7	145.0	145.0	145.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1338	10064	0.029853965281792995	1.1343805118749797	0.0	28.000000000000004	28.000000000000004	28.000000000000004	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1339	10064	0.032123371285339895	1.1534938616021002	0.0	28.000000000000004	28.000000000000004	28.000000000000004	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1337	10065	0.002843041154842348	0.23643244013826006	-5.000000000000001e-7	134.0	134.0	134.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1338	10065	0.026804721576611054	1.06984026960125	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1339	10065	0.02912923782313016	1.1818512940452	0.0	27.0	27.0	27.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1337	10066	5.7022181886703944e-5	0.17575448764827506	-5.000000000000001e-7	180.0	180.0	180.0	0.9875000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1338	10066	0.030111030256825006	1.2099818209016153	0.0	27.0	27.0	27.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1339	10066	0.0329459379941854	1.216937023752025	0.0	26.0	26.0	26.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1280	10067	0.0013804729450191502	0.14977163530279491	-5.000000000000001e-7	211.0	211.0	211.0	0.98745	0.0	1	-59.99999999999999	59.99999999999999								
	1342	10067	0.02292270671637025	1.052860854591955	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1341	10067	0.02338376061236715	1.1459579083301252	0.0	28.000000000000004	28.000000000000004	28.000000000000004	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1280	10068	0.0020759771129745014	0.2046604568472801	-5.000000000000001e-7	155.0	155.0	155.0	0.98745	0.0	1	-59.99999999999999	59.99999999999999								
	1342	10068	0.022150206655694598	1.08668338406168	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1341	10068	0.022260541154414004	1.02318732686119	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1337	10069	0.002808571619981	0.2650512071653202	-5.000000000000001e-7	120.0	120.0	120.0	1.01255	0.0	1	-59.99999999999999	59.99999999999999								
	1350	10069	0.025286292711336106	1.06897990689592	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1351	10069	0.023046072287897103	1.0299268411030502	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1337	10070	0.00016533519059745014	0.297555301331045	-5.000000000000001e-7	107.0	107.0	107.0	1.01255	0.0	1	-59.99999999999999	59.99999999999999								
	1350	10070	0.026690613640425253	1.069466117068335	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1351	10070	0.026659096130054967	1.051609003649875	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	10071	1478	0.011967975620907203	0.1751496432000119	0.0026629712666700026	180.0	180.0	180.0	1.0127095042786975	0.0	1	-59.99999999999999	59.99999999999999								
	1357	10071	0.021118199864327954	1.0897620686716054	0.0	28.999999999999996	28.999999999999996	28.999999999999996	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1358	10071	0.021134722173660952	1.0480679509524453	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1390	10072	0.002987499770868551	0.21461007158397005	-5.000000000000001e-7	148.0	148.0	148.0	0.9749	0.0	1	-59.99999999999999	59.99999999999999								
	1392	10072	0.02380730498278565	1.10940077917566	0.0	28.999999999999996	28.999999999999996	28.999999999999996	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1391	10072	0.024565356202132554	1.0236860919707504	0.0	31.0	31.0	31.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1390	10073	0.002006536513837049	0.24602623671232982	-5.000000000000001e-7	129.0	129.0	129.0	0.9749	0.0	1	-59.99999999999999	59.99999999999999								
	1392	10073	0.025440188616698153	1.0582030135020004	0.0	30.0	30.0	30.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1391	10073	0.023802674957069163	1.00165425908851	0.0	32.0	32.0	32.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1457	10074	0.0002907720361447405	0.004277368306929346	-5.0e-7	3000.0	7368.000000000001	7368.000000000001	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	1531	10074	0.0003324099886638604	0.04564231720069696	0.0	693.0	693.0	693.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1458	10074	0.0025794113248696097	0.1388480233892317	0.0	227.99999999999997	227.99999999999997	227.99999999999997	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1457	10075	0.00028140907784458304	0.005481810945652642	-5.0e-7	3000.0	5755.0	5755.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	1531	10075	0.0003641526145357629	0.04277066148071106	0.0	739.0	739.0	739.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1459	10075	0.0022553979621874175	0.1454139715252024	0.0	218.00000000000003	218.00000000000003	218.00000000000003	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1460	10076	0.0008837712510249053	0.0026633937875759632	-5.0e-7	3000.0	10000.0	10000.0	1.0323863636363637	0.0	1	-59.99999999999999	59.99999999999999								
	1534	10076	0.0008346048897185854	0.07570688545345093	0.0	418.0	418.0	418.0	1.0472727272727271	0.0	1	-59.99999999999999	59.99999999999999								
	1461	10076	0.0063618005904152565	0.299464959366056	0.0	106.0	106.0	106.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1460	10077	0.0011275710347546303	0.0663982561100849	-5.0e-7	476.0	476.0	476.0	1.0323863636363637	0.0	1	-59.99999999999999	59.99999999999999								
	1534	10077	0.00059214366796706	0.006203994809918374	0.0	3000.0	5069.0	5069.0	1.0472727272727271	0.0	1	-59.99999999999999	59.99999999999999								
	1462	10077	0.0064334248375019516	0.29598108470219553	0.0	107.0	107.0	107.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1460	10078	0.00053878717183019	0.06311896946876333	-5.0e-7	501.0	501.0	501.0	1.0323863636363637	0.0	1	-59.99999999999999	59.99999999999999								
	1534	10078	0.0009899347771157002	0.01107219973598589	0.0	2842.0	2842.0	2842.0	1.0472727272727271	0.0	1	-59.99999999999999	59.99999999999999								
	1463	10078	0.00444284748868668	0.2472829641690111	0.0	128.0	128.0	128.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1131	10079	0.0003466694316550394	0.007999767635751054	-5.0e-7	3000.0	3945.0000000000005	3945.0000000000005	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	1538	10079	0.0002419720020616196	0.038449337414306846	0.0	822.0000000000001	822.0000000000001	822.0000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1468	10079	0.0029176065456026005	0.14581359156467794	0.0	217.0	217.0	217.0	1.0052631578947366	0.0	1	-59.99999999999999	59.99999999999999								
	1131	10080	0.0003026228731433824	0.0037669303867665918	-5.0e-7	3000.0	8359.0	8359.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	1538	10080	0.00032576160586076264	0.04404799607350621	0.0	718.0	718.0	718.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1469	10080	0.0028940504539333263	0.1562136574279764	0.0	202.99999999999997	202.99999999999997	202.99999999999997	1.0052631578947366	0.0	1	-59.99999999999999	59.99999999999999								
	1490	10081	0.00090491325720316	0.0058145810603480175	-5.0e-7	3000.0	5368.0	5368.0	0.9625	0.0	1	-59.99999999999999	59.99999999999999								
	1557	10081	0.0007163119762596702	0.06437822126185996	0.0	491.0	491.0	491.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1491	10081	0.00551178505459884	0.25726428597639406	0.0	123.0	123.0	123.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1601	10082	0.002521681624232051	0.08706031632893653	-5.0e-7	363.0	363.0	363.0	1.0875	0.0	1	-59.99999999999999	59.99999999999999								
	1431	10082	0.010489536984233452	0.2624287985776854	0.0	121.0	121.0	121.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1429	10082	0.010852445055817948	0.26024244780089434	0.0	122.0	122.0	122.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1602	10083	0.0027439962660775	0.06468746040017599	-5.0e-7	488.0	488.0	488.0	1.0875	0.0	1	-59.99999999999999	59.99999999999999								
	1430	10083	0.011116407462326098	0.29269332387872304	0.0	108.0	108.0	108.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1432	10083	0.009936188589886503	0.2925464843254509	0.0	108.0	108.0	108.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1606	10084	0.0011275585876249494	0.24555983374656012	-5.000000000000001e-7	129.0	129.0	129.0	0.9749	0.0	1	-59.99999999999999	59.99999999999999								
	10084	1345	0.026992508335644084	1.1455814167545573	0.0	28.000000000000004	28.000000000000004	28.000000000000004	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1663	10085	0.0	0.03715786788286651	-5.0e-7	851.0	851.0	851.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	1660	10085	0.0	0.17582023418531753	0.0	180.0	180.0	180.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1659	10085	0.0	0.1782601617274335	0.0	178.0	178.0	178.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1663	10086	0.0	0.02885896079766101	-5.0e-7	1095.0	1095.0	1095.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	1662	10086	0.0	0.17585083008988303	0.0	180.0	180.0	180.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1661	10086	0.0	0.184960619543563	0.0	171.0	171.0	171.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1670	10087	0.0	0.032978340407019	-5.0e-7	958.0	958.0	958.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	1666	10087	0.0	0.17463391830807004	0.0	181.0	181.0	181.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1665	10087	0.0	0.1900327977492701	0.0	167.0	167.0	167.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1670	10088	0.0	0.02363695951353301	-5.0e-7	1337.0	1337.0	1337.0	1.05	0.0	1	-59.99999999999999	59.99999999999999								
	1667	10088	0.0	0.18920612393936603	0.0	167.0	167.0	167.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1668	10088	0.0	0.18433676412876202	0.0	172.0	172.0	172.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1723	10089	0.0024515810049278654	0.03565227919688902	-5.0e-7	884.0	884.0	884.0	1.0625000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1671	10089	0.0011053263262612756	0.274793916964322	0.0	114.99999999999999	114.99999999999999	114.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1672	10089	0.0009190155746648052	0.2680168539056321	0.0	118.0	118.0	118.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1723	10090	0.0022412993113184398	0.005834847772680507	-5.0e-7	3000.0	5054.0	5054.0	1.0625000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1673	10090	0.0010450713956682003	0.29138066600579765	0.0	109.00000000000001	109.00000000000001	109.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1674	10090	0.0009935239274101294	0.29836066506970654	0.0	106.0	106.0	106.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1723	10091	0.004521529711326581	0.038298372807330505	-5.0e-7	819.9999999999999	819.9999999999999	819.9999999999999	1.0625000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1675	10091	0.0008807835252210501	0.2774425771624085	0.0	113.99999999999999	113.99999999999999	113.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1676	10091	0.0011147609973140098	0.27350693492114053	0.0	115.99999999999999	115.99999999999999	115.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1723	10092	0.0023899099407903857	0.022063826988218512	-5.0e-7	1424.0	1424.0	1424.0	1.0625000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	1677	10092	0.0009216995565593251	0.2843732633747536	0.0	112.00000000000001	112.00000000000001	112.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1678	10092	0.0011245509980805251	0.2886995950322226	0.0	110.00000000000001	110.00000000000001	110.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1726	10093	1.0259649849964948e-5	0.009071460005489501	-5.0e-7	3000.0	3483.0	3483.0	1.0250000000000001	0.0	1	-59.99999999999999	59.99999999999999								
	1968	10093	0.004581109212675595	0.18407560001426448	0.0	172.0	172.0	172.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1969	10093	0.004445586231666145	0.1887981140403065	0.0	168.0	168.0	168.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1775	10094	0.015591051096951155	0.2537782556846674	-5.0e-7	125.0	125.0	125.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1718	10094	0.011355414879193048	0.06908306142061549	0.0	451.99999999999994	451.99999999999994	451.99999999999994	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2011	10094	0.025314884385602063	0.5381562236267013	0.0	59.0	59.0	59.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1775	10095	0.0171206025906545	0.24468172351357947	-5.0e-7	129.0	129.0	129.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1718	10095	0.010599731946007404	0.06034048330075553	0.0	516.0	516.0	516.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2012	10095	0.024491657316985504	0.5357694417762096	0.0	59.0	59.0	59.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1781	10096	0.01526296288084305	0.5091655718430196	-5.0e-7	63.0	63.0	63.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1967	10096	0.00788697723895195	0.04380385013212052	0.0	710.0	710.0	710.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2102	10096	0.015967159563719552	0.24848072511868252	0.0	127.0	127.0	127.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1781	10097	0.015327419901452049	0.49041484865976176	-5.0e-7	65.0	65.0	65.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1967	10097	0.008214393779925049	0.027888407137447505	0.0	1087.0	1087.0	1087.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2103	10097	0.017729565766274453	0.2694078298618354	0.0	117.0	117.0	117.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	10098	1800	0.005739306758725138	0.14283255025361788	0.0015685922058536455	221.0	221.0	221.0	0.9828009828009827	0.0	1	-59.99999999999999	59.99999999999999								
	1845	10098	0.0025066033209557507	0.00999138949268297	0.0	3000.0	3067.0	3067.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2105	10098	0.019604858044388253	0.284935666886523	0.0	111.00000000000001	111.00000000000001	111.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1845	10099	0.004161629478337704	0.020710409711981514	0.0	1496.0	1496.0	1496.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2106	10099	0.022035230029535037	0.27367784082150937	0.0	115.99999999999999	115.99999999999999	115.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1833	10100	0.007705962115796304	0.28103226843453993	-5.0e-7	112.99999999999999	112.99999999999999	112.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2003	10100	0.0024717881695647	0.02192310880087299	0.0	1432.0	1432.0	1432.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2107	10100	0.019059786464190105	0.15150508135747198	0.0	206.99999999999997	206.99999999999997	206.99999999999997	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1835	10101	0.014330789189217649	0.3282363193234478	-5.0e-7	97.0	97.0	97.0	1.01742	0.0	1	-59.99999999999999	59.99999999999999								
	1701	10101	0.009941400651922451	0.08829538475263396	0.0	356.0	356.0	356.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2109	10101	0.024959743215553453	0.17491282443217906	0.0	179.0	179.0	179.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1835	10102	0.03742235343890105	0.3151996362864429	-5.0e-7	100.0	100.0	100.0	1.01742	0.0	1	-59.99999999999999	59.99999999999999								
	1701	10102	0.010316811942999944	0.06124317104054698	0.0	509.0	509.0	509.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2110	10102	0.02504055109906776	0.19574715541815807	0.0	161.0	161.0	161.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1835	10103	0.01623122916747355	0.37264036941708945	-5.0e-7	85.0	85.0	85.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2005	10103	0.00910559422246645	0.0843318028452435	0.0	373.0	373.0	373.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2108	10103	0.025436588392495154	0.17490709970979054	0.0	179.0	179.0	179.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1869	10104	0.0058109129325905505	0.2032222146859326	-5.0e-7	156.0	156.0	156.0	1.025	0.0	1	-59.99999999999999	59.99999999999999								
	1988	10104	0.009833809761172149	0.05847620600086344	0.0	533.0	533.0	533.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2043	10104	0.04477978842975106	0.5646069315771834	0.0	56.00000000000001	56.00000000000001	56.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1872	10105	0.004799412547741095	0.218854985759254	-5.0e-7	145.0	145.0	145.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1990	10105	0.010650817857403305	0.04636586477432402	0.0	664.0	664.0	664.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2045	10105	0.048388845699708916	0.62661148271326	0.0	51.0	51.0	51.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1872	10106	0.0075547770365467495	0.2427737613550229	-5.0e-7	131.0	131.0	131.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1990	10106	0.008667278637797551	0.020419208621422043	0.0	1424.0	1424.0	1424.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2045	10106	0.04700584588641766	0.6658397686178308	0.0	48.0	48.0	48.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	1872	10107	0.005589208605838953	0.23643734767869995	-5.0e-7	134.0	134.0	134.0	1.0124999999999997	0.0	1	-59.99999999999999	59.99999999999999								
	1990	10107	0.009775136173604948	0.02993403953970902	0.0	1003.9999999999999	1003.9999999999999	1003.9999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2045	10107	0.05038689757454676	0.6222517106085363	0.0	51.0	51.0	51.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2190	10108	0.003467824692297699	0.06524701414312502	-5.000000000000001e-7	484.0	484.0	484.0	1.0105	0.0	1	-59.99999999999999	59.99999999999999								
	2275	10108	0.015535049285385807	0.29921272152354417	0.0	106.0	106.0	106.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2276	10108	0.014364693845892408	0.28911032012374216	0.0	110.00000000000001	110.00000000000001	110.00000000000001	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2190	10109	0.00300336193405255	0.054780119665564	-5.000000000000001e-7	576.0	576.0	576.0	1.0105	0.0	1	-59.99999999999999	59.99999999999999								
	2275	10109	0.01695572250091446	0.3073140502175731	0.0	103.0	103.0	103.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2339	10109	0.016649532039401362	0.3104407872369472	0.0	102.0	102.0	102.0	1.0000000000000002	0.0	1	-59.99999999999999	59.99999999999999								
	2193	10110	0.0004934328871348537	0.08035953529793459	-5.000000000000001e-7	394.0	394.0	394.0	0.98778	0.0	1	-59.99999999999999	59.99999999999999								
	2300	10110	0.017918247574534047	0.5889639848215306	0.0	54.0	54.0	54.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2301	10110	0.018924640855408452	0.5737023220032595	0.0	56.00000000000001	56.00000000000001	56.00000000000001	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2193	10111	0.0009391074901190511	0.09667738601216302	-5.000000000000001e-7	327.0	327.0	327.0	0.9755600000000001	0.0	1	-59.99999999999999	59.99999999999999								
	2300	10111	0.01691107526091625	0.551221465984914	0.0	57.99999999999999	57.99999999999999	57.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2301	10111	0.018180937307004354	0.552568133664856	0.0	57.99999999999999	57.99999999999999	57.99999999999999	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2302	10112	0.007349122031773658	0.4000738173516172	0.0	79.0	79.0	79.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2303	10112	0.00735771486409356	0.44509388195387495	0.0	71.0	71.0	71.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	10113	2194	0.00226681762035299	0.5198674109006728	0.07184571900645055	61.0	61.0	61.0	1.0124531740407006	0.0	1	-59.99999999999999	59.99999999999999								
	2302	10113	0.007985213570070931	0.402136619594909	0.0	79.0	79.0	79.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
	2303	10113	0.008259598487934573	0.41983601729225195	0.0	76.0	76.0	76.0	1.0	0.0	1	-59.99999999999999	59.99999999999999								
];

%%-----  OPF Data  -----%%
%% cost data
%    1    startup    shutdown    n    x1    y1    ...    xn    yn
%    2    startup    shutdown    n    c(n-1)    ...    c0
mpc.gencost = [
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	0.0	0.0	2	0.0	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	62.5	0.0	2	0.09031278538812786	0.0
	2	62.5	0.0	2	0.09031278538812786	0.0
	2	62.5	0.0	2	0.09031278538812786	0.0
	2	62.5	0.0	2	0.09031278538812786	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	350.0	0.0	2	0.07095890410958904	0.0
	2	0.0	0.0	2	0.0	0.0
	2	62.5	0.0	2	0.09031278538812786	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	350.0	0.0	2	0.15480593607305937	0.0
	2	350.0	0.0	2	0.15480593607305937	0.0
	2	350.0	0.0	2	0.15480593607305937	0.0
	2	350.0	0.0	2	0.15480593607305937	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	350.0	0.0	2	0.15480593607305937	0.0
	2	350.0	0.0	2	0.15480593607305937	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	62.5	0.0	2	0.10081278538812787	0.0
	2	0.0	0.0	2	0.0	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	0.0	0.0	2	0.0	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	62.5	0.0	2	0.10081278538812787	0.0
	2	62.5	0.0	2	0.10081278538812787	0.0
	2	0.0	0.0	2	0.0	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	62.5	0.0	2	0.10081278538812787	0.0
	2	62.5	0.0	2	0.10081278538812787	0.0
	2	62.5	0.0	2	0.10081278538812787	0.0
	2	62.5	0.0	2	0.10081278538812787	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	62.5	0.0	2	0.10081278538812787	0.0
	2	62.5	0.0	2	0.10081278538812787	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	350.0	0.0	2	0.0713013698630137	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	200.0	0.0	2	0.09426940639269407	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	200.0	0.0	2	0.09426940639269407	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	200.0	0.0	2	0.09426940639269407	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	100.0	0.0	2	0.12021004566210046	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0015	0.0
	2	0.0	0.0	2	0.0	0.0
	2	0.0	0.0	2	0.0	0.0
];

%% bus names
mpc.bus_name = {
	'bus_1000'
	'bus_1001'
	'bus_1002'
	'bus_1003'
	'bus_1004'
	'bus_1005'
	'bus_1006'
	'bus_1007'
	'bus_1009'
	'bus_1010'
	'bus_1011'
	'bus_1012'
	'bus_1013'
	'bus_1014'
	'bus_1015'
	'bus_1016'
	'bus_1017'
	'bus_1018'
	'bus_1019'
	'bus_1020'
	'bus_1021'
	'bus_1022'
	'bus_1023'
	'bus_1024'
	'bus_1025'
	'bus_1026'
	'bus_1027'
	'bus_1029'
	'bus_1030'
	'bus_1031'
	'bus_1032'
	'bus_1033'
	'bus_1034'
	'bus_1036'
	'bus_1037'
	'bus_1038'
	'bus_1039'
	'bus_1040'
	'bus_1041'
	'bus_1042'
	'bus_1043'
	'bus_1044'
	'bus_1045'
	'bus_1047'
	'bus_1048'
	'bus_1049'
	'bus_1050'
	'bus_1051'
	'bus_1052'
	'bus_1053'
	'bus_1054'
	'bus_1055'
	'bus_1056'
	'bus_1057'
	'bus_1058'
	'bus_1059'
	'bus_1060'
	'bus_1061'
	'bus_1062'
	'bus_1066'
	'bus_1067'
	'bus_1068'
	'bus_1069'
	'bus_1070'
	'bus_1071'
	'bus_1072'
	'bus_1073'
	'bus_1074'
	'bus_1075'
	'bus_1076'
	'bus_1077'
	'bus_1078'
	'bus_1079'
	'bus_1080'
	'bus_1081'
	'bus_1082'
	'bus_1083'
	'bus_1084'
	'bus_1085'
	'bus_1086'
	'bus_1087'
	'bus_1088'
	'bus_1089'
	'bus_1090'
	'bus_1091'
	'bus_1092'
	'bus_1093'
	'bus_1096'
	'bus_1097'
	'bus_1098'
	'bus_1099'
	'bus_1100'
	'bus_1102'
	'bus_1103'
	'bus_1104'
	'bus_1105'
	'bus_1106'
	'bus_1107'
	'bus_1108'
	'bus_1109'
	'bus_1110'
	'bus_1111'
	'bus_1112'
	'bus_1113'
	'bus_1114'
	'bus_1115'
	'bus_1116'
	'bus_1117'
	'bus_1118'
	'bus_1119'
	'bus_1120'
	'bus_1121'
	'bus_1123'
	'bus_1124'
	'bus_1125'
	'bus_1126'
	'bus_1127'
	'bus_1128'
	'bus_1129'
	'bus_1130'
	'bus_1132'
	'bus_1133'
	'bus_1134'
	'bus_1136'
	'bus_1137'
	'bus_1138'
	'bus_1139'
	'bus_1140'
	'bus_1142'
	'bus_1145'
	'bus_1146'
	'bus_1147'
	'bus_1148'
	'bus_1149'
	'bus_1150'
	'bus_1151'
	'bus_1152'
	'bus_1153'
	'bus_1154'
	'bus_1155'
	'bus_1156'
	'bus_1157'
	'bus_1158'
	'bus_1159'
	'bus_1161'
	'bus_1162'
	'bus_1163'
	'bus_1164'
	'bus_1166'
	'bus_1167'
	'bus_1168'
	'bus_1169'
	'bus_1172'
	'bus_1173'
	'bus_1177'
	'bus_1178'
	'bus_1179'
	'bus_1181'
	'bus_1182'
	'bus_1183'
	'bus_1184'
	'bus_1185'
	'bus_1186'
	'bus_1187'
	'bus_1188'
	'bus_1189'
	'bus_1190'
	'bus_1191'
	'bus_1192'
	'bus_1193'
	'bus_1195'
	'bus_1196'
	'bus_1198'
	'bus_1199'
	'bus_1200'
	'bus_1201'
	'bus_1202'
	'bus_1203'
	'bus_1204'
	'bus_1205'
	'bus_1206'
	'bus_1207'
	'bus_1208'
	'bus_1209'
	'bus_1211'
	'bus_1212'
	'bus_1215'
	'bus_1217'
	'bus_1218'
	'bus_1219'
	'bus_1221'
	'bus_1222'
	'bus_1223'
	'bus_1224'
	'bus_1225'
	'bus_1226'
	'bus_1228'
	'bus_1229'
	'bus_1230'
	'bus_1232'
	'bus_1234'
	'bus_1236'
	'bus_1237'
	'bus_1238'
	'bus_1239'
	'bus_1240'
	'bus_1241'
	'bus_1243'
	'bus_1244'
	'bus_1246'
	'bus_1247'
	'bus_1249'
	'bus_1252'
	'bus_1253'
	'bus_1254'
	'bus_1255'
	'bus_1256'
	'bus_1257'
	'bus_1258'
	'bus_1259'
	'bus_1260'
	'bus_1261'
	'bus_1262'
	'bus_1263'
	'bus_1264'
	'bus_1265'
	'bus_1267'
	'bus_1269'
	'bus_1273'
	'bus_1274'
	'bus_1281'
	'bus_1282'
	'bus_1283'
	'bus_1284'
	'bus_1285'
	'bus_1287'
	'bus_1288'
	'bus_1289'
	'bus_1292'
	'bus_1293'
	'bus_1294'
	'bus_1296'
	'bus_1297'
	'bus_1299'
	'bus_1300'
	'bus_1301'
	'bus_1302'
	'bus_1304'
	'bus_1305'
	'bus_1306'
	'bus_1307'
	'bus_1308'
	'bus_1309'
	'bus_1310'
	'bus_1311'
	'bus_1312'
	'bus_1313'
	'bus_1314'
	'bus_1315'
	'bus_1317'
	'bus_1318'
	'bus_1319'
	'bus_1320'
	'bus_1321'
	'bus_1322'
	'bus_1324'
	'bus_1326'
	'bus_1328'
	'bus_1330'
	'bus_1331'
	'bus_1332'
	'bus_1333'
	'bus_1334'
	'bus_1335'
	'bus_1336'
	'bus_1338'
	'bus_1341'
	'bus_1343'
	'bus_1344'
	'bus_1345'
	'bus_1346'
	'bus_1347'
	'bus_1349'
	'bus_1350'
	'bus_1351'
	'bus_1354'
	'bus_1356'
	'bus_1357'
	'bus_1358'
	'bus_1360'
	'bus_1361'
	'bus_1364'
	'bus_1365'
	'bus_1369'
	'bus_1371'
	'bus_1372'
	'bus_1373'
	'bus_1374'
	'bus_1375'
	'bus_1377'
	'bus_1378'
	'bus_1380'
	'bus_1382'
	'bus_1383'
	'bus_1385'
	'bus_1387'
	'bus_1388'
	'bus_1392'
	'bus_1393'
	'bus_1395'
	'bus_1396'
	'bus_1397'
	'bus_1400'
	'bus_1401'
	'bus_1402'
	'bus_1403'
	'bus_1404'
	'bus_1405'
	'bus_1406'
	'bus_1409'
	'bus_1414'
	'bus_1416'
	'bus_1418'
	'bus_1419'
	'bus_1423'
	'bus_1428'
	'bus_1430'
	'bus_1432'
	'bus_1433'
	'bus_1434'
	'bus_1435'
	'bus_1436'
	'bus_1437'
	'bus_1438'
	'bus_1444'
	'bus_1445'
	'bus_1446'
	'bus_1447'
	'bus_1449'
	'bus_1450'
	'bus_1451'
	'bus_1453'
	'bus_1454'
	'bus_1455'
	'bus_1456'
	'bus_1458'
	'bus_1459'
	'bus_1460'
	'bus_1461'
	'bus_1463'
	'bus_1464'
	'bus_1467'
	'bus_1468'
	'bus_1472'
	'bus_1473'
	'bus_1474'
	'bus_1475'
	'bus_1477'
	'bus_1478'
	'bus_1479'
	'bus_1480'
	'bus_1481'
	'bus_1482'
	'bus_1483'
	'bus_1486'
	'bus_1488'
	'bus_1496'
	'bus_1497'
	'bus_1498'
	'bus_1499'
	'bus_1501'
	'bus_1502'
	'bus_1503'
	'bus_1504'
	'bus_1505'
	'bus_1506'
	'bus_1507'
	'bus_1508'
	'bus_1509'
	'bus_1510'
	'bus_1512'
	'bus_1513'
	'bus_1515'
	'bus_1516'
	'bus_1517'
	'bus_1518'
	'bus_1519'
	'bus_1521'
	'bus_1522'
	'bus_1523'
	'bus_1524'
	'bus_1525'
	'bus_1526'
	'bus_1527'
	'bus_1528'
	'bus_1529'
	'bus_1530'
	'bus_1531'
	'bus_1532'
	'bus_1533'
	'bus_1534'
	'bus_1535'
	'bus_1536'
	'bus_1537'
	'bus_1538'
	'bus_1539'
	'bus_1540'
	'bus_1542'
	'bus_1543'
	'bus_1544'
	'bus_1546'
	'bus_1547'
	'bus_1548'
	'bus_1549'
	'bus_1550'
	'bus_1551'
	'bus_1552'
	'bus_1553'
	'bus_1554'
	'bus_1555'
	'bus_1556'
	'bus_1557'
	'bus_1558'
	'bus_1559'
	'bus_1560'
	'bus_1561'
	'bus_1563'
	'bus_1564'
	'bus_1565'
	'bus_1567'
	'bus_1568'
	'bus_1569'
	'bus_1570'
	'bus_1571'
	'bus_1572'
	'bus_1573'
	'bus_1574'
	'bus_1575'
	'bus_1576'
	'bus_1577'
	'bus_1578'
	'bus_1579'
	'bus_1580'
	'bus_1581'
	'bus_1582'
	'bus_1583'
	'bus_1584'
	'bus_1585'
	'bus_1587'
	'bus_1588'
	'bus_1589'
	'bus_1590'
	'bus_1591'
	'bus_1592'
	'bus_1593'
	'bus_1594'
	'bus_1595'
	'bus_1596'
	'bus_1597'
	'bus_1598'
	'bus_1599'
	'bus_1600'
	'bus_1601'
	'bus_1602'
	'bus_1604'
	'bus_1607'
	'bus_1610'
	'bus_1611'
	'bus_1612'
	'bus_1613'
	'bus_1614'
	'bus_1615'
	'bus_1616'
	'bus_1617'
	'bus_1618'
	'bus_1619'
	'bus_1620'
	'bus_1621'
	'bus_1622'
	'bus_1623'
	'bus_1624'
	'bus_1625'
	'bus_1626'
	'bus_1627'
	'bus_1629'
	'bus_1630'
	'bus_1631'
	'bus_1632'
	'bus_1633'
	'bus_1634'
	'bus_1635'
	'bus_1636'
	'bus_1638'
	'bus_1639'
	'bus_1640'
	'bus_1642'
	'bus_1645'
	'bus_1647'
	'bus_1648'
	'bus_1649'
	'bus_1650'
	'bus_1651'
	'bus_1652'
	'bus_1653'
	'bus_1654'
	'bus_1655'
	'bus_1656'
	'bus_1658'
	'bus_2000'
	'bus_2001'
	'bus_2002'
	'bus_2003'
	'bus_2004'
	'bus_2005'
	'bus_2006'
	'bus_2007'
	'bus_2008'
	'bus_2009'
	'bus_2010'
	'bus_2011'
	'bus_2012'
	'bus_2013'
	'bus_2014'
	'bus_2015'
	'bus_2016'
	'bus_2017'
	'bus_2018'
	'bus_2019'
	'bus_2020'
	'bus_2021'
	'bus_2022'
	'bus_2023'
	'bus_2024'
	'bus_2025'
	'bus_2026'
	'bus_2027'
	'bus_2028'
	'bus_2029'
	'bus_2030'
	'bus_2031'
	'bus_2032'
	'bus_2033'
	'bus_2034'
	'bus_2035'
	'bus_2036'
	'bus_2037'
	'bus_2038'
	'bus_2039'
	'bus_2040'
	'bus_2041'
	'bus_2042'
	'bus_2043'
	'bus_2044'
	'bus_2045'
	'bus_2046'
	'bus_2047'
	'bus_2048'
	'bus_2054'
	'bus_2055'
	'bus_2056'
	'bus_2057'
	'bus_2058'
	'bus_2059'
	'bus_2060'
	'bus_2061'
	'bus_2062'
	'bus_2063'
	'bus_2064'
	'bus_2065'
	'bus_2066'
	'bus_2067'
	'bus_2068'
	'bus_2069'
	'bus_2070'
	'bus_2072'
	'bus_2073'
	'bus_2074'
	'bus_2075'
	'bus_2076'
	'bus_2077'
	'bus_2078'
	'bus_2079'
	'bus_2080'
	'bus_2081'
	'bus_2082'
	'bus_2085'
	'bus_2086'
	'bus_2088'
	'bus_2089'
	'bus_2090'
	'bus_2091'
	'bus_2092'
	'bus_2093'
	'bus_2094'
	'bus_2095'
	'bus_2096'
	'bus_2097'
	'bus_2099'
	'bus_2100'
	'bus_2101'
	'bus_2102'
	'bus_2103'
	'bus_2104'
	'bus_2105'
	'bus_2106'
	'bus_2107'
	'bus_2108'
	'bus_2109'
	'bus_2111'
	'bus_2113'
	'bus_2114'
	'bus_2117'
	'bus_2118'
	'bus_2120'
	'bus_2121'
	'bus_2122'
	'bus_2125'
	'bus_2126'
	'bus_2127'
	'bus_2128'
	'bus_2129'
	'bus_2136'
	'bus_2139'
	'bus_2140'
	'bus_2143'
	'bus_2145'
	'bus_2146'
	'bus_2147'
	'bus_2150'
	'bus_2151'
	'bus_2158'
	'bus_2160'
	'bus_2161'
	'bus_2162'
	'bus_2164'
	'bus_2167'
	'bus_2168'
	'bus_2169'
	'bus_2170'
	'bus_2171'
	'bus_2175'
	'bus_2176'
	'bus_2177'
	'bus_2178'
	'bus_2179'
	'bus_2181'
	'bus_2186'
	'bus_2187'
	'bus_2188'
	'bus_2189'
	'bus_2190'
	'bus_2191'
	'bus_2192'
	'bus_2195'
	'bus_2196'
	'bus_2197'
	'bus_2198'
	'bus_2199'
	'bus_2200'
	'bus_2201'
	'bus_2202'
	'bus_2203'
	'bus_2204'
	'bus_2205'
	'bus_2206'
	'bus_2207'
	'bus_2208'
	'bus_2209'
	'bus_2210'
	'bus_2211'
	'bus_2213'
	'bus_2214'
	'bus_2215'
	'bus_2216'
	'bus_2218'
	'bus_2219'
	'bus_2220'
	'bus_2221'
	'bus_2222'
	'bus_2224'
	'bus_2225'
	'bus_2226'
	'bus_2227'
	'bus_2228'
	'bus_2229'
	'bus_2230'
	'bus_2231'
	'bus_2232'
	'bus_2233'
	'bus_2234'
	'bus_2235'
	'bus_2236'
	'bus_2237'
	'bus_2238'
	'bus_2239'
	'bus_2240'
	'bus_2241'
	'bus_2242'
	'bus_2243'
	'bus_2244'
	'bus_2245'
	'bus_2246'
	'bus_2247'
	'bus_2248'
	'bus_2249'
	'bus_2250'
	'bus_2251'
	'bus_2252'
	'bus_2254'
	'bus_2255'
	'bus_2256'
	'bus_2257'
	'bus_2260'
	'bus_2262'
	'bus_2264'
	'bus_2265'
	'bus_2266'
	'bus_2267'
	'bus_2268'
	'bus_2269'
	'bus_2270'
	'bus_2271'
	'bus_2272'
	'bus_2273'
	'bus_2274'
	'bus_2275'
	'bus_2276'
	'bus_2277'
	'bus_2278'
	'bus_2279'
	'bus_2280'
	'bus_2281'
	'bus_2282'
	'bus_2283'
	'bus_2284'
	'bus_2285'
	'bus_2286'
	'bus_2287'
	'bus_2289'
	'bus_2290'
	'bus_2291'
	'bus_2292'
	'bus_2293'
	'bus_2294'
	'bus_2295'
	'bus_2296'
	'bus_2297'
	'bus_2298'
	'bus_2299'
	'bus_2300'
	'bus_2303'
	'bus_2304'
	'bus_2306'
	'bus_2307'
	'bus_2309'
	'bus_2310'
	'bus_2311'
	'bus_2312'
	'bus_2313'
	'bus_2314'
	'bus_2315'
	'bus_2320'
	'bus_2321'
	'bus_2322'
	'bus_2323'
	'bus_2324'
	'bus_2325'
	'bus_2326'
	'bus_2328'
	'bus_2332'
	'bus_2333'
	'bus_2334'
	'bus_2335'
	'bus_2336'
	'bus_2337'
	'bus_2338'
	'bus_2339'
	'bus_2340'
	'bus_2341'
	'bus_2342'
	'bus_2343'
	'bus_2344'
	'bus_2346'
	'bus_2347'
	'bus_2348'
	'bus_2349'
	'bus_2350'
	'bus_2351'
	'bus_2352'
	'bus_2355'
	'bus_3000'
	'bus_3001'
	'bus_3002'
	'bus_3003'
	'bus_3004'
	'bus_3005'
	'bus_3006'
	'bus_3007'
	'bus_3008'
	'bus_3009'
	'bus_3010'
	'bus_3011'
	'bus_3012'
	'bus_3013'
	'bus_3014'
	'bus_3016'
	'bus_3017'
	'bus_3018'
	'bus_3019'
	'bus_3020'
	'bus_3021'
	'bus_3022'
	'bus_3023'
	'bus_3024'
	'bus_3025'
	'bus_3026'
	'bus_3028'
	'bus_3029'
	'bus_3032'
	'bus_3033'
	'bus_3034'
	'bus_3035'
	'bus_3038'
	'bus_3039'
	'bus_3040'
	'bus_3041'
	'bus_3042'
	'bus_3043'
	'bus_3044'
	'bus_3046'
	'bus_3048'
	'bus_3049'
	'bus_3050'
	'bus_3051'
	'bus_3053'
	'bus_3054'
	'bus_3055'
	'bus_3056'
	'bus_3057'
	'bus_3058'
	'bus_3059'
	'bus_3060'
	'bus_3062'
	'bus_3064'
	'bus_3066'
	'bus_3067'
	'bus_3068'
	'bus_3069'
	'bus_3070'
	'bus_3071'
	'bus_3072'
	'bus_3074'
	'bus_3075'
	'bus_3076'
	'bus_3077'
	'bus_3078'
	'bus_3080'
	'bus_3081'
	'bus_3082'
	'bus_3083'
	'bus_3085'
	'bus_3087'
	'bus_3088'
	'bus_3089'
	'bus_3090'
	'bus_3091'
	'bus_3094'
	'bus_3095'
	'bus_3096'
	'bus_3099'
	'bus_3100'
	'bus_3101'
	'bus_3102'
	'bus_3103'
	'bus_3106'
	'bus_3107'
	'bus_3108'
	'bus_3110'
	'bus_3111'
	'bus_3112'
	'bus_3113'
	'bus_3114'
	'bus_3115'
	'bus_3116'
	'bus_3117'
	'bus_3118'
	'bus_3120'
	'bus_3121'
	'bus_3122'
	'bus_3123'
	'bus_3124'
	'bus_3125'
	'bus_3126'
	'bus_3127'
	'bus_3128'
	'bus_3129'
	'bus_3130'
	'bus_3131'
	'bus_3132'
	'bus_3133'
	'bus_3134'
	'bus_3135'
	'bus_3136'
	'bus_3137'
	'bus_3138'
	'bus_3139'
	'bus_3140'
	'bus_3141'
	'bus_3142'
	'bus_3143'
	'bus_3144'
	'bus_3145'
	'bus_3147'
	'bus_3148'
	'bus_3149'
	'bus_3150'
	'bus_3151'
	'bus_3152'
	'bus_3153'
	'bus_3154'
	'bus_3155'
	'bus_3156'
	'bus_3157'
	'bus_3158'
	'bus_3159'
	'bus_3160'
	'bus_3161'
	'bus_3162'
	'bus_3163'
	'bus_3164'
	'bus_3165'
	'bus_3167'
	'bus_3168'
	'bus_3169'
	'bus_3170'
	'bus_3171'
	'bus_3172'
	'bus_3173'
	'bus_3174'
	'bus_3176'
	'bus_3177'
	'bus_3178'
	'bus_3179'
	'bus_3180'
	'bus_3183'
	'bus_3184'
	'bus_3186'
	'bus_3187'
	'bus_3188'
	'bus_3189'
	'bus_3190'
	'bus_3191'
	'bus_3192'
	'bus_3193'
	'bus_3194'
	'bus_3195'
	'bus_3196'
	'bus_3197'
	'bus_3198'
	'bus_3199'
	'bus_3200'
	'bus_3201'
	'bus_3202'
	'bus_3203'
	'bus_3204'
	'bus_3205'
	'bus_3206'
	'bus_3209'
	'bus_3211'
	'bus_3213'
	'bus_3214'
	'bus_3215'
	'bus_3217'
	'bus_3218'
	'bus_3220'
	'bus_3221'
	'bus_3222'
	'bus_3223'
	'bus_3224'
	'bus_3225'
	'bus_3226'
	'bus_3227'
	'bus_3228'
	'bus_3229'
	'bus_3230'
	'bus_3231'
	'bus_3232'
	'bus_3233'
	'bus_3236'
	'bus_3237'
	'bus_3238'
	'bus_3239'
	'bus_3240'
	'bus_3241'
	'bus_3242'
	'bus_3243'
	'bus_3245'
	'bus_3247'
	'bus_3248'
	'bus_3251'
	'bus_3253'
	'bus_3257'
	'bus_3258'
	'bus_3259'
	'bus_3260'
	'bus_3261'
	'bus_3262'
	'bus_3263'
	'bus_3264'
	'bus_3267'
	'bus_3270'
	'bus_3271'
	'bus_3272'
	'bus_3273'
	'bus_3274'
	'bus_3275'
	'bus_3276'
	'bus_3277'
	'bus_3278'
	'bus_3279'
	'bus_3280'
	'bus_3282'
	'bus_3283'
	'bus_3284'
	'bus_3285'
	'bus_3287'
	'bus_3288'
	'bus_3289'
	'bus_3292'
	'bus_3294'
	'bus_3295'
	'bus_3298'
	'bus_3299'
	'bus_3300'
	'bus_3302'
	'bus_3303'
	'bus_3304'
	'bus_3305'
	'bus_3306'
	'bus_3307'
	'bus_3308'
	'bus_3309'
	'bus_3310'
	'bus_3311'
	'bus_3312'
	'bus_3314'
	'bus_3315'
	'bus_3316'
	'bus_3319'
	'bus_3320'
	'bus_3322'
	'bus_3323'
	'bus_3324'
	'bus_3325'
	'bus_3326'
	'bus_3327'
	'bus_3328'
	'bus_3329'
	'bus_3331'
	'bus_3332'
	'bus_3334'
	'bus_3335'
	'bus_3336'
	'bus_3338'
	'bus_3339'
	'bus_3340'
	'bus_3341'
	'bus_3342'
	'bus_3343'
	'bus_3344'
	'bus_3347'
	'bus_3351'
	'bus_3353'
	'bus_3354'
	'bus_3355'
	'bus_3356'
	'bus_3357'
	'bus_3359'
	'bus_3360'
	'bus_3361'
	'bus_3363'
	'bus_3364'
	'bus_3365'
	'bus_3366'
	'bus_3367'
	'bus_3369'
	'bus_3370'
	'bus_3372'
	'bus_3373'
	'bus_3375'
	'bus_3376'
	'bus_3378'
	'bus_3380'
	'bus_3381'
	'bus_3382'
	'bus_3383'
	'bus_3385'
	'bus_3386'
	'bus_3387'
	'bus_3388'
	'bus_3389'
	'bus_3390'
	'bus_3392'
	'bus_3394'
	'bus_3395'
	'bus_3396'
	'bus_3397'
	'bus_3398'
	'bus_3399'
	'bus_3400'
	'bus_3401'
	'bus_3402'
	'bus_3403'
	'bus_3404'
	'bus_3405'
	'bus_3407'
	'bus_3409'
	'bus_3410'
	'bus_3411'
	'bus_3412'
	'bus_3413'
	'bus_3414'
	'bus_3415'
	'bus_3417'
	'bus_3418'
	'bus_3419'
	'bus_3420'
	'bus_3421'
	'bus_3422'
	'bus_3423'
	'bus_3424'
	'bus_3425'
	'bus_3426'
	'bus_3427'
	'bus_3428'
	'bus_3429'
	'bus_3430'
	'bus_3431'
	'bus_3432'
	'bus_3433'
	'bus_3434'
	'bus_3435'
	'bus_3436'
	'bus_3437'
	'bus_3438'
	'bus_3439'
	'bus_3440'
	'bus_3441'
	'bus_3442'
	'bus_3443'
	'bus_3444'
	'bus_3445'
	'bus_3446'
	'bus_3447'
	'bus_3448'
	'bus_3449'
	'bus_3452'
	'bus_3453'
	'bus_3454'
	'bus_3455'
	'bus_3456'
	'bus_3457'
	'bus_3459'
	'bus_3460'
	'bus_3461'
	'bus_3462'
	'bus_3463'
	'bus_3464'
	'bus_3465'
	'bus_3466'
	'bus_3467'
	'bus_3470'
	'bus_3471'
	'bus_3472'
	'bus_3474'
	'bus_3475'
	'bus_3476'
	'bus_3477'
	'bus_3478'
	'bus_3479'
	'bus_3482'
	'bus_3483'
	'bus_3484'
	'bus_3485'
	'bus_3486'
	'bus_3487'
	'bus_3488'
	'bus_3489'
	'bus_3490'
	'bus_3493'
	'bus_3494'
	'bus_3495'
	'bus_3496'
	'bus_3497'
	'bus_3498'
	'bus_3500'
	'bus_3504'
	'bus_3505'
	'bus_3506'
	'bus_3516'
	'bus_3517'
	'bus_3518'
	'bus_3519'
	'bus_3520'
	'bus_3525'
	'bus_3526'
	'bus_3527'
	'bus_3529'
	'bus_3530'
	'bus_3532'
	'bus_3534'
	'bus_3535'
	'bus_3536'
	'bus_3539'
	'bus_3540'
	'bus_3541'
	'bus_3542'
	'bus_3543'
	'bus_3545'
	'bus_3546'
	'bus_3547'
	'bus_3549'
	'bus_3550'
	'bus_3554'
	'bus_3556'
	'bus_3557'
	'bus_3558'
	'bus_3560'
	'bus_3561'
	'bus_3563'
	'bus_3565'
	'bus_3567'
	'bus_3568'
	'bus_3569'
	'bus_3570'
	'bus_3572'
	'bus_3573'
	'bus_3582'
	'bus_3583'
	'bus_3584'
	'bus_3585'
	'bus_3586'
	'bus_3587'
	'bus_3588'
	'bus_3589'
	'bus_3591'
	'bus_3593'
	'bus_3595'
	'bus_3596'
	'bus_3597'
	'bus_3598'
	'bus_3601'
	'bus_3604'
	'bus_3605'
	'bus_3606'
	'bus_3607'
	'bus_3609'
	'bus_3611'
	'bus_3612'
	'bus_3613'
	'bus_3614'
	'bus_3615'
	'bus_3616'
	'bus_3617'
	'bus_3618'
	'bus_3623'
	'bus_3624'
	'bus_3625'
	'bus_3626'
	'bus_3628'
	'bus_3629'
	'bus_3633'
	'bus_3634'
	'bus_3635'
	'bus_3640'
	'bus_3642'
	'bus_3643'
	'bus_3644'
	'bus_3645'
	'bus_3647'
	'bus_3648'
	'bus_3650'
	'bus_3651'
	'bus_3652'
	'bus_3655'
	'bus_3656'
	'bus_3659'
	'bus_4000'
	'bus_4001'
	'bus_4002'
	'bus_4003'
	'bus_4004'
	'bus_4005'
	'bus_4006'
	'bus_4007'
	'bus_4008'
	'bus_4009'
	'bus_4010'
	'bus_4011'
	'bus_4012'
	'bus_4013'
	'bus_4014'
	'bus_4015'
	'bus_4016'
	'bus_4017'
	'bus_4018'
	'bus_4019'
	'bus_4020'
	'bus_4022'
	'bus_4023'
	'bus_4024'
	'bus_4025'
	'bus_4026'
	'bus_4027'
	'bus_4028'
	'bus_4029'
	'bus_4030'
	'bus_4031'
	'bus_4032'
	'bus_4033'
	'bus_4034'
	'bus_4035'
	'bus_4036'
	'bus_4037'
	'bus_4038'
	'bus_4039'
	'bus_4040'
	'bus_4041'
	'bus_4042'
	'bus_4043'
	'bus_4044'
	'bus_4045'
	'bus_4046'
	'bus_4047'
	'bus_4048'
	'bus_4049'
	'bus_4050'
	'bus_4051'
	'bus_4052'
	'bus_4053'
	'bus_4054'
	'bus_4055'
	'bus_4056'
	'bus_4057'
	'bus_4058'
	'bus_4059'
	'bus_4061'
	'bus_4062'
	'bus_4064'
	'bus_4065'
	'bus_4066'
	'bus_4067'
	'bus_4071'
	'bus_4072'
	'bus_4073'
	'bus_4074'
	'bus_4075'
	'bus_4076'
	'bus_4077'
	'bus_4078'
	'bus_4079'
	'bus_4080'
	'bus_4081'
	'bus_4082'
	'bus_4083'
	'bus_4084'
	'bus_4085'
	'bus_4089'
	'bus_4094'
	'bus_4096'
	'bus_4097'
	'bus_4101'
	'bus_4103'
	'bus_4104'
	'bus_4106'
	'bus_4107'
	'bus_4109'
	'bus_4110'
	'bus_4111'
	'bus_4112'
	'bus_4113'
	'bus_4114'
	'bus_4115'
	'bus_4116'
	'bus_4117'
	'bus_4123'
	'bus_4125'
	'bus_4126'
	'bus_4127'
	'bus_4128'
	'bus_4131'
	'bus_4132'
	'bus_4133'
	'bus_4135'
	'bus_4136'
	'bus_4137'
	'bus_4138'
	'bus_4139'
	'bus_4142'
	'bus_4143'
	'bus_4144'
	'bus_4145'
	'bus_4147'
	'bus_4148'
	'bus_4149'
	'bus_4150'
	'bus_4152'
	'bus_4153'
	'bus_4154'
	'bus_4156'
	'bus_4157'
	'bus_4158'
	'bus_4160'
	'bus_4162'
	'bus_4165'
	'bus_4166'
	'bus_4167'
	'bus_4168'
	'bus_4169'
	'bus_4170'
	'bus_4171'
	'bus_4172'
	'bus_4174'
	'bus_4176'
	'bus_4177'
	'bus_4178'
	'bus_4179'
	'bus_4180'
	'bus_4182'
	'bus_4183'
	'bus_4184'
	'bus_4185'
	'bus_4188'
	'bus_4189'
	'bus_4190'
	'bus_4192'
	'bus_4193'
	'bus_4194'
	'bus_4195'
	'bus_4196'
	'bus_4197'
	'bus_4198'
	'bus_4200'
	'bus_4201'
	'bus_4202'
	'bus_4203'
	'bus_4204'
	'bus_4206'
	'bus_4207'
	'bus_4209'
	'bus_4210'
	'bus_4211'
	'bus_4212'
	'bus_4213'
	'bus_4215'
	'bus_4216'
	'bus_4217'
	'bus_4218'
	'bus_4219'
	'bus_4220'
	'bus_4221'
	'bus_4223'
	'bus_4224'
	'bus_4225'
	'bus_4226'
	'bus_4227'
	'bus_4228'
	'bus_4229'
	'bus_4230'
	'bus_4231'
	'bus_4232'
	'bus_4233'
	'bus_4234'
	'bus_4235'
	'bus_4236'
	'bus_4238'
	'bus_4240'
	'bus_4241'
	'bus_4242'
	'bus_4243'
	'bus_4245'
	'bus_4246'
	'bus_4248'
	'bus_4249'
	'bus_4251'
	'bus_4252'
	'bus_4253'
	'bus_4254'
	'bus_4255'
	'bus_4257'
	'bus_4258'
	'bus_4260'
	'bus_4261'
	'bus_4262'
	'bus_4265'
	'bus_4266'
	'bus_4267'
	'bus_4268'
	'bus_4270'
	'bus_4271'
	'bus_4272'
	'bus_4273'
	'bus_4274'
	'bus_4275'
	'bus_4276'
	'bus_4277'
	'bus_4278'
	'bus_4279'
	'bus_4280'
	'bus_4285'
	'bus_4286'
	'bus_4287'
	'bus_4288'
	'bus_4289'
	'bus_4292'
	'bus_4295'
	'bus_4296'
	'bus_4298'
	'bus_4300'
	'bus_4301'
	'bus_4302'
	'bus_4303'
	'bus_4305'
	'bus_4306'
	'bus_4307'
	'bus_4309'
	'bus_4311'
	'bus_4312'
	'bus_4313'
	'bus_4314'
	'bus_4317'
	'bus_4318'
	'bus_4319'
	'bus_4320'
	'bus_4321'
	'bus_4322'
	'bus_4323'
	'bus_4324'
	'bus_4325'
	'bus_4326'
	'bus_4329'
	'bus_4332'
	'bus_4334'
	'bus_4335'
	'bus_4336'
	'bus_4337'
	'bus_4338'
	'bus_4339'
	'bus_4340'
	'bus_4342'
	'bus_4343'
	'bus_4344'
	'bus_4345'
	'bus_4346'
	'bus_4347'
	'bus_4348'
	'bus_4349'
	'bus_4350'
	'bus_4356'
	'bus_4357'
	'bus_4358'
	'bus_4361'
	'bus_4363'
	'bus_4364'
	'bus_4365'
	'bus_4366'
	'bus_4367'
	'bus_4368'
	'bus_4369'
	'bus_4371'
	'bus_4372'
	'bus_4373'
	'bus_4374'
	'bus_4375'
	'bus_4376'
	'bus_4377'
	'bus_4378'
	'bus_4379'
	'bus_4380'
	'bus_4381'
	'bus_4382'
	'bus_4383'
	'bus_4384'
	'bus_4385'
	'bus_4386'
	'bus_4387'
	'bus_4388'
	'bus_4389'
	'bus_4390'
	'bus_4391'
	'bus_4392'
	'bus_4393'
	'bus_4394'
	'bus_4398'
	'bus_4399'
	'bus_4400'
	'bus_4401'
	'bus_4402'
	'bus_4403'
	'bus_4404'
	'bus_4405'
	'bus_4406'
	'bus_4407'
	'bus_4408'
	'bus_4409'
	'bus_4410'
	'bus_4411'
	'bus_4412'
	'bus_4413'
	'bus_4414'
	'bus_4415'
	'bus_4416'
	'bus_4417'
	'bus_4418'
	'bus_4419'
	'bus_4420'
	'bus_4421'
	'bus_4422'
	'bus_4423'
	'bus_4424'
	'bus_4425'
	'bus_4426'
	'bus_4427'
	'bus_4428'
	'bus_4429'
	'bus_4430'
	'bus_4431'
	'bus_4432'
	'bus_4433'
	'bus_4434'
	'bus_4435'
	'bus_4436'
	'bus_4437'
	'bus_4438'
	'bus_4439'
	'bus_4440'
	'bus_4441'
	'bus_4442'
	'bus_4443'
	'bus_4444'
	'bus_4445'
	'bus_4446'
	'bus_4447'
	'bus_4448'
	'bus_4449'
	'bus_4450'
	'bus_4451'
	'bus_4452'
	'bus_4453'
	'bus_4454'
	'bus_4455'
	'bus_4456'
	'bus_4457'
	'bus_4458'
	'bus_4459'
	'bus_4460'
	'bus_4461'
	'bus_4462'
	'bus_4463'
	'bus_4464'
	'bus_4465'
	'bus_4466'
	'bus_4467'
	'bus_4468'
	'bus_4469'
	'bus_4470'
	'bus_4471'
	'bus_4472'
	'bus_4473'
	'bus_4474'
	'bus_4475'
	'bus_4477'
	'bus_4478'
	'bus_4479'
	'bus_4480'
	'bus_4481'
	'bus_4482'
	'bus_4483'
	'bus_4484'
	'bus_4485'
	'bus_4486'
	'bus_4487'
	'bus_4488'
	'bus_4489'
	'bus_4490'
	'bus_4491'
	'bus_4492'
	'bus_4493'
	'bus_4494'
	'bus_4495'
	'bus_4496'
	'bus_4497'
	'bus_4498'
	'bus_4499'
	'bus_4500'
	'bus_5000'
	'bus_5001'
	'bus_5004'
	'bus_5005'
	'bus_5006'
	'bus_5008'
	'bus_5010'
	'bus_5012'
	'bus_5013'
	'bus_5014'
	'bus_5015'
	'bus_5016'
	'bus_5017'
	'bus_5018'
	'bus_5019'
	'bus_5020'
	'bus_5021'
	'bus_5022'
	'bus_5023'
	'bus_5026'
	'bus_5028'
	'bus_5030'
	'bus_5031'
	'bus_5032'
	'bus_5033'
	'bus_5034'
	'bus_5035'
	'bus_5036'
	'bus_5037'
	'bus_5038'
	'bus_5039'
	'bus_5040'
	'bus_5041'
	'bus_5042'
	'bus_5043'
	'bus_5044'
	'bus_5045'
	'bus_5046'
	'bus_5047'
	'bus_5049'
	'bus_5050'
	'bus_5052'
	'bus_5053'
	'bus_5054'
	'bus_5055'
	'bus_5057'
	'bus_5058'
	'bus_5059'
	'bus_5060'
	'bus_5061'
	'bus_5062'
	'bus_5063'
	'bus_5064'
	'bus_5065'
	'bus_5066'
	'bus_5067'
	'bus_5068'
	'bus_5069'
	'bus_5070'
	'bus_5071'
	'bus_5072'
	'bus_5073'
	'bus_5074'
	'bus_5075'
	'bus_5077'
	'bus_5080'
	'bus_5083'
	'bus_5086'
	'bus_5087'
	'bus_5089'
	'bus_5090'
	'bus_5091'
	'bus_5092'
	'bus_5095'
	'bus_5096'
	'bus_5097'
	'bus_5098'
	'bus_5099'
	'bus_5100'
	'bus_5101'
	'bus_5102'
	'bus_5103'
	'bus_5104'
	'bus_5105'
	'bus_5106'
	'bus_5109'
	'bus_5111'
	'bus_5113'
	'bus_5114'
	'bus_5116'
	'bus_5118'
	'bus_5119'
	'bus_5120'
	'bus_5121'
	'bus_5122'
	'bus_5123'
	'bus_5124'
	'bus_5125'
	'bus_5126'
	'bus_5127'
	'bus_5128'
	'bus_5130'
	'bus_5131'
	'bus_5132'
	'bus_5133'
	'bus_5134'
	'bus_5136'
	'bus_5137'
	'bus_5139'
	'bus_5140'
	'bus_5141'
	'bus_5142'
	'bus_5143'
	'bus_5144'
	'bus_5147'
	'bus_5149'
	'bus_5150'
	'bus_5155'
	'bus_5159'
	'bus_5161'
	'bus_5162'
	'bus_5163'
	'bus_5168'
	'bus_5169'
	'bus_5170'
	'bus_5172'
	'bus_5173'
	'bus_5174'
	'bus_5175'
	'bus_5176'
	'bus_5177'
	'bus_5178'
	'bus_5179'
	'bus_5180'
	'bus_5181'
	'bus_5182'
	'bus_5183'
	'bus_5184'
	'bus_5185'
	'bus_5186'
	'bus_5187'
	'bus_5188'
	'bus_5189'
	'bus_5190'
	'bus_5191'
	'bus_5192'
	'bus_5193'
	'bus_5194'
	'bus_5195'
	'bus_5196'
	'bus_5197'
	'bus_5198'
	'bus_5199'
	'bus_5200'
	'bus_5201'
	'bus_5202'
	'bus_5203'
	'bus_5204'
	'bus_5205'
	'bus_5206'
	'bus_5207'
	'bus_5208'
	'bus_5209'
	'bus_5210'
	'bus_5211'
	'bus_5212'
	'bus_5213'
	'bus_5214'
	'bus_5215'
	'bus_5216'
	'bus_5217'
	'bus_5218'
	'bus_5219'
	'bus_5220'
	'bus_5221'
	'bus_5222'
	'bus_5223'
	'bus_5224'
	'bus_5225'
	'bus_5226'
	'bus_5228'
	'bus_5229'
	'bus_5230'
	'bus_5231'
	'bus_5233'
	'bus_5234'
	'bus_5235'
	'bus_5236'
	'bus_5237'
	'bus_5238'
	'bus_5240'
	'bus_5241'
	'starbus_xf_1090_1091_1523_9'
	'starbus_xf_1092_1093_1525_1'
	'starbus_xf_1092_1093_1526_2'
	'starbus_xf_1097_1098_1161_2'
	'starbus_xf_1097_1098_1162_1'
	'starbus_xf_1099_1100_1532_10'
	'starbus_xf_1099_1100_1533_9'
	'starbus_xf_1106_1167_1536_3'
	'starbus_xf_1106_1167_1537_4'
	'starbus_xf_1118_1038_1039_1'
	'starbus_xf_1118_1040_1041_2'
	'starbus_xf_1118_1042_1043_3'
	'starbus_xf_1121_1123_1634_6'
	'starbus_xf_1121_1123_1635_7'
	'starbus_xf_1148_1073_1074_1'
	'starbus_xf_1148_1075_1076_2'
	'starbus_xf_1148_1077_1078_3'
	'starbus_xf_1148_1079_1080_4'
	'starbus_xf_1273_1572_1573_1'
	'starbus_xf_1273_1572_1573_2'
	'starbus_xf_1296_1504_1505_2'
	'starbus_xf_1296_1504_1506_1'
	'starbus_xf_1428_1501_1539_1'
	'starbus_xf_1428_1501_1540_2'
	'starbus_xf_1430_1502_1542_1'
	'starbus_xf_1430_1502_1543_2'
	'starbus_xf_1587_1328_1067_1'
	'starbus_xf_1588_1327_1068_2'
	'starbus_xf_1616_1027_1618_1'
	'starbus_xf_1617_1027_1619_2'
	'starbus_xf_2077_2205_2346_2'
	'starbus_xf_2077_2205_2347_1'
	'starbus_xf_2077_2205_2349_3'
	'starbus_xf_2145_2243_2306_1'
	'starbus_xf_2145_2243_2306_2'
	'starbus_xf_2145_2243_2306_3'
	'starbus_xf_2162_2271_2315_5'
	'starbus_xf_2191_2018_2019_6'
	'starbus_xf_2191_2020_2021_7'
	'starbus_xf_2191_2023_2024_1'
	'starbus_xf_2191_2025_2026_2'
	'starbus_xf_2191_2027_2028_3'
	'starbus_xf_2191_2029_2030_4'
	'starbus_xf_2191_2031_2022_5'
	'starbus_xf_2195_2293_2332_1'
	'starbus_xf_2195_2293_2332_2'
	'starbus_xf_2200_2196_2304_3'
	'starbus_xf_2200_2196_2305_2'
	'starbus_xf_3134_3135_3136_1'
	'starbus_xf_3134_3135_3136_2'
	'starbus_xf_3177_3179_3178_1'
	'starbus_xf_3177_3179_3178_2'
	'starbus_xf_3226_3227_3228_1'
	'starbus_xf_3226_3227_3228_2'
	'starbus_xf_3231_3644_3645_1'
	'starbus_xf_3231_3644_3645_2'
	'starbus_xf_3266_3154_3155_1'
	'starbus_xf_3302_3304_3303_1'
	'starbus_xf_3302_3304_3303_2'
	'starbus_xf_3302_3304_3303_3'
	'starbus_xf_3333_3335_3336_2'
	'starbus_xf_3333_3336_3335_1'
	'starbus_xf_3333_3336_3335_3'
	'starbus_xf_3358_3360_3361_1'
	'starbus_xf_3359_3360_3361_2'
	'starbus_xf_3359_3360_3361_3'
	'starbus_xf_3362_3364_3363_1'
	'starbus_xf_3362_3364_3363_2'
	'starbus_xf_3371_3372_3373_1'
	'starbus_xf_3371_3372_3373_2'
	'starbus_xf_3379_3380_3381_3'
	'starbus_xf_3413_3415_3414_1'
	'starbus_xf_3413_3415_3414_2'
	'starbus_xf_3483_3558_3484_3'
	'starbus_xf_3483_3558_3485_2'
	'starbus_xf_3486_3561_3487_1'
	'starbus_xf_3486_3561_3488_2'
	'starbus_xf_3486_3561_3489_3'
	'starbus_xf_3492_3565_3494_2'
	'starbus_xf_3492_3565_3495_1'
	'starbus_xf_3516_3584_3517_1'
	'starbus_xf_3628_3455_3453_1'
	'starbus_xf_3629_3454_3456_2'
	'starbus_xf_3633_3514_3513_4'
	'starbus_xf_4031_4028_4027_2'
	'starbus_xf_4031_4030_4029_1'
	'starbus_xf_4038_4034_4033_3'
	'starbus_xf_4038_4035_4036_2'
	'starbus_xf_4104_4039_4040_1'
	'starbus_xf_4104_4041_4042_2'
	'starbus_xf_4104_4043_4044_3'
	'starbus_xf_4104_4045_4046_4'
	'starbus_xf_4109_4357_4358_1'
	'starbus_xf_4160_4097_4400_2'
	'starbus_xf_4160_4097_4401_1'
	'starbus_xf_4166_4356_4491_3'
	'starbus_xf_4166_4356_4492_4'
	'starbus_xf_4186_4230_4494_1'
	'starbus_xf_4187_4230_4495_2'
	'starbus_xf_4218_4392_4496_1'
	'starbus_xf_4220_4074_4498_3'
	'starbus_xf_4220_4074_4499_5'
	'starbus_xf_4220_4394_4497_1'
	'starbus_xf_4254_4377_4432_1'
	'starbus_xf_4257_4379_4434_1'
	'starbus_xf_4257_4379_4434_2'
	'starbus_xf_4257_4379_4434_3'
	'starbus_xf_5087_5175_5176_3'
	'starbus_xf_5088_5175_5241_4'
	'starbus_xf_5090_5200_5201_5'
	'starbus_xf_5090_5200_5201_6'
	'starbus_xf_5093_5202_5203_1'
	'starbus_xf_5094_5202_5203_2'
};



%column_names% startup_warm_(dollar/MW) Ramp_Up_Rate(MW/h) Tpd0 d_axis_damper Rs X0 Maintenance(days/yr) Xq Kd_exc K_gen_exc saturation_type name Tpq0 Kd Kij H Xs noload_cost(dollar/MW/year) Fluxmq_Points variable_op_cost(dollar/MWh_sent_out) noload_recurring_cost(dollar/MW/year) Xppd mechanical_control Minimum_On_Time(Hours) Ramp_Down_Rate(MW/h) H_exc F D_exc D_gen_exc fixed_op_cost(dollar/MW/year) q_axis_damper startup_cold(dollar/MW) Tppd0 Xpd D Dij saturation_q_axis_curve_points Xpq Tppq0 tech startup_hot_(dollar/MW) Xppq Fluxm_Points fuel Minimum_Off_Time(Hours) exciter_type Imq_Points Xc exciter_control saturation_d_axis_curve_points Im_Points Xd type 
mpc.gen_data = {
	120.0	130	'8.64181632340699'	'1'	'0'	'0.56751502476334'	20.0	'2.15885508540102'	'0'	'0'	'0'	'gen_1002_1'	'0.375239718798548'	'0'	'[0 0 0 0]'	'3.16825912071811'	'0.190636673497502'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.254731010818402'	'2'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'2'	350.0	'0.046943271899363'	'0.320205435705767'	'0'	'[0 0 0 0]'	'2'	'0.253126455120051'	'0.136205370032741'	'Combustion'	40.0	'0.254731010818402'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.113990566016044 0.375405293004038 0 0 0 0 0 0 0]'	'2.27006009905336'	'Fossil'
	120.0	130	'8.42964508440159'	'1'	'0'	'0.5536047385564725'	20.0	'2.14820705504363'	'0'	'0'	'0'	'gen_1003_2'	'0.389128416377935'	'0'	'[0 0 0 0]'	'3.15421162367985'	'0.190670949609717'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.245573479835396'	'2'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'2'	350.0	'0.0462607079501264'	'0.331301903893286'	'0'	'[0 0 0 0]'	'2'	'0.258212115779878'	'0.135833965283772'	'Combustion'	40.0	'0.245573479835396'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.112666115340763 0.368391471655103 0 0 0 0 0 0 0]'	'2.21441895422589'	'Fossil'
	120.0	130	'8.397773353286089'	'1'	'0'	'0.5580462366286325'	20.0	'2.15366160325371'	'0'	'0'	'0'	'gen_1004_3'	'0.383822161483113'	'0'	'[0 0 0 0]'	'3.13463414354902'	'0.190881724390006'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.251368805532902'	'2'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'2'	350.0	'0.0476119478437584'	'0.332113386869733'	'0'	'[0 0 0 0]'	'2'	'0.254357078468506'	'0.135908252601512'	'Combustion'	40.0	'0.251368805532902'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.117853057886264 0.371673717224426 0 0 0 0 0 0 0]'	'2.23218494651453'	'Fossil'
	120.0	130	'8.394984227583739'	'1'	'0'	'0.5656604292314275'	20.0	'2.16079874452307'	'0'	'0'	'0'	'gen_1005_4'	'0.386250622768421'	'0'	'[0 0 0 0]'	'3.13492437275127'	'0.185403954635132'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.246066220155838'	'2'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'2'	350.0	'0.0469641184676904'	'0.32247932254998'	'0'	'[0 0 0 0]'	'2'	'0.250932273443153'	'0.135715317474026'	'Combustion'	40.0	'0.246066220155838'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.115268518456961 0.360750868524648 0 0 0 0 0 0 0]'	'2.26264171692571'	'Fossil'
	100.0	600	'9.297813491011039'	'1'	'0'	'0.29039684866072'	5.0	'0.5928788602156559'	'0'	'0'	'0'	'gen_1012_1'	'0.152946320953779'	'0'	'[0 0 0 0]'	'4.03096771309245'	'0.157411517668515'	600	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	500	'0.188905356998672'	'1'	1	595	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0539238605838269'	'0.280712300090119'	'0'	'[0 0 0 0]'	'2'	'0.188905356998672'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Distillate'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.13177192842029 0.592974049122538 0 0 0 0 0 0 0]'	'1.16158739464288'	'Fossil'
	3.0	900	'9.44040461014956'	'1'	'0'	'0.28746587569476'	3.0	'0.607215649646707'	'0'	'0'	'0'	'gen_1013_1'	'0.15697254223167'	'0'	'[0 0 0 0]'	'4.10389041107241'	'0.15289566900814'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.189256160524907'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0526899192777462'	'0.280331428875215'	'0'	'[0 0 0 0]'	'2'	'0.189256160524907'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.135691078041913 0.587066242041998 0 0 0 0 0 0 0]'	'1.14986350277904'	'Wind'
	3.0	900	'9.42527587695513'	'1'	'0'	'0.283157725875615'	3.0	'0.581197085483465'	'0'	'0'	'0'	'gen_1014_1'	'0.156126313571585'	'0'	'[0 0 0 0]'	'4.07182763364306'	'0.152158027030528'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.185665983258747'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0534463943126611'	'0.287706468353048'	'0'	'[0 0 0 0]'	'2'	'0.185665983258747'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.131101594094653 0.599824795256835 0 0 0 0 0 0 0]'	'1.13263090350246'	'Wind'
	120.0	130	'8.390679817018761'	'1'	'0'	'0.5467449585580625'	20.0	'1.60592827188673'	'0'	'0'	'0'	'gen_1017_1'	'2.05102453759257'	'0'	'[0 0 0 0]'	'3.29391465716064'	'0.189457268492132'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.203768784317002'	'2'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'2'	350.0	'0.0632392940051854'	'0.325645458190138'	'0'	'[0 0 0 0]'	'2'	'1.08153077109002'	'0.178434604043653'	'Combustion'	40.0	'0.203768784317002'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.09833795538311819 0.366664496996999 0 0 0 0 0 0 0]'	'2.18697983423225'	'Fossil'
	120.0	130	'8.246653611663101'	'1'	'0'	'0.543606385216815'	20.0	'1.64286390568612'	'0'	'0'	'0'	'gen_1018_2'	'1.97290236046906'	'0'	'[0 0 0 0]'	'3.21804560035467'	'0.193715469417721'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.19805634210119'	'2'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'2'	350.0	'0.0611450468741357'	'0.327735764552229'	'0'	'[0 0 0 0]'	'2'	'1.11781046042717'	'0.181748822734552'	'Combustion'	40.0	'0.19805634210119'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.09430904589057899 0.378953377043386 0 0 0 0 0 0 0]'	'2.17442554086726'	'Fossil'
	120.0	130	'8.521538339395191'	'1'	'0'	'0.55025156856171'	20.0	'1.66660411743992'	'0'	'0'	'0'	'gen_1019_3'	'1.99273348299945'	'0'	'[0 0 0 0]'	'3.35375534132123'	'0.193056594339386'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.203563261227636'	'2'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'2'	350.0	'0.0631405915910751'	'0.328312649695319'	'0'	'[0 0 0 0]'	'2'	'1.08521066677386'	'0.182128424060997'	'Combustion'	40.0	'0.203563261227636'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.09762546354182999 0.380439872584655 0 0 0 0 0 0 0]'	'2.20100627424684'	'Fossil'
	120.0	130	'8.33145218183744'	'1'	'0'	'0.54208183993693'	20.0	'1.64989939148594'	'0'	'0'	'0'	'gen_1020_4'	'2.00808816904044'	'0'	'[0 0 0 0]'	'3.27817697316408'	'0.195112073822413'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.207593269594805'	'2'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'2'	350.0	'0.0618033530248702'	'0.322611822450992'	'0'	'[0 0 0 0]'	'2'	'1.10005332359257'	'0.180988344361074'	'Combustion'	40.0	'0.207593269594805'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0959758984792512 0.37806775526139 0 0 0 0 0 0 0]'	'2.16832735974772'	'Fossil'
	3.0	590	'6.08867993660417'	'1'	'0'	'0.2772817670186625'	7.0	'0.6056825404295'	'0'	'0'	'0'	'gen_1022_1'	'0.239980493170395'	'0'	'[0 0 0 0]'	'4.06486977210152'	'0.148720965130371'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.188113821326336'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0768487544256006'	'0.24084191412814'	'0'	'[0 0 0 0]'	'2'	'0.188113821326336'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'1.10912706807465'	'Hydro'
	3.0	590	'9.01301313512127'	'1'	'0'	'0.253264289914165'	7.0	'0.702534276496153'	'0'	'0'	'0'	'gen_1030_4'	'0.230851957343053'	'0'	'[0 0 0 0]'	'4.4912705247649'	'0.152785054653371'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.205493323253468'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0730565607765689'	'0.22686294478314'	'0'	'[0 0 0 0]'	'2'	'0.205493323253468'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'1.01305715965666'	'Hydro'
	3.0	900	'6.74459750028513'	'1'	'0'	'0.35651549306442'	3.0	'0.725259874475119'	'0'	'0'	'0'	'gen_1031_1'	'0.103638262345921'	'0'	'[0 0 0 0]'	'3.96822433128487'	'0.200671900155139'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.215285751172295'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.06645807624247391'	'0.360715030336287'	'0'	'[0 0 0 0]'	'2'	'0.215285751172295'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0650091051340103 0.238240595932258 0 0 0 0 0 0 0]'	'1.42606197225768'	'Wind'
	120.0	130	'3.65829917187236'	'1'	'0'	'0.5740259373863225'	20.0	'2.2181340783881'	'0'	'0'	'0'	'gen_1034_1'	'0.376136706941249'	'0'	'[0 0 0 0]'	'2.78987184259761'	'0.182184809171688'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.212362598386127'	'1'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'1'	350.0	'0.0437073619368835'	'0.337903481459578'	'0'	'[0 0 0 0]'	'2'	'0.212362598386127'	'0.01'	'Combustion'	40.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'2.29610374954529'	'Fossil'
	120.0	130	'3.82475675741222'	'1'	'0'	'0.551748258512235'	20.0	'2.21355740551371'	'0'	'0'	'0'	'gen_1036_3'	'0.389375473775342'	'0'	'[0 0 0 0]'	'2.87278849575017'	'0.181209346052259'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.208229321039747'	'1'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'1'	350.0	'0.0437813889640686'	'0.332660602351355'	'0'	'[0 0 0 0]'	'2'	'0.208229321039747'	'0.01'	'Combustion'	40.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'2.20699303404894'	'Fossil'
	3.0	590	'3.76583915847132'	'1'	'0'	'0.5709313606948125'	7.0	'2.283065260523'	'0'	'0'	'0'	'gen_1037_4'	'0.378321451282338'	'0'	'[0 0 0 0]'	'2.81364450740721'	'0.178712068224186'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.207403352959082'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0438144045604672'	'0.332178768790921'	'0'	'[0 0 0 0]'	'2'	'0.207403352959082'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'2.28372544277925'	'Hydro'
	120.0	130	'14.6442208761923'	'1'	'0'	'0.41674134733216'	20.0	'0.776077050098032'	'0'	'0'	'0'	'gen_1038_1'	'0.0472368835955858'	'0'	'[0 0 0 0]'	'3.25332150796009'	'0.236584797610366'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.306640662051807'	'1'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'1'	350.0	'0.0295899051190121'	'0.420243821831234'	'0'	'[0 0 0 0]'	'2'	'0.306640662051807'	'0.01'	'Combustion'	40.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.253967852977803 0.856423022171878 0 0 0 0 0 0 0]'	'1.66696538932864'	'Fossil'
	120.0	130	'14.8640386024794'	'1'	'0'	'0.42754219776648'	20.0	'0.7724022796133529'	'0'	'0'	'0'	'gen_1039_2'	'0.0464558569884393'	'0'	'[0 0 0 0]'	'3.21982772525749'	'0.239894437453221'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.30078968214998'	'1'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'1'	350.0	'0.0302604074398451'	'0.409458185624925'	'0'	'[0 0 0 0]'	'2'	'0.30078968214998'	'0.01'	'Combustion'	40.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.253132513660239 0.873024938468519 0 0 0 0 0 0 0]'	'1.71016879106592'	'Fossil'
	120.0	130	'14.9148540720392'	'1'	'0'	'0.417865915450965'	20.0	'0.762259163425909'	'0'	'0'	'0'	'gen_1040_3'	'0.0457911968962289'	'0'	'[0 0 0 0]'	'3.29186792900087'	'0.240901087828889'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.296873828812817'	'1'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'1'	350.0	'0.0302604992726794'	'0.401581730715756'	'0'	'[0 0 0 0]'	'2'	'0.296873828812817'	'0.01'	'Combustion'	40.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.253118924319278 0.834528490301268 0 0 0 0 0 0 0]'	'1.67146366180386'	'Fossil'
	120.0	130	'14.8518670666396'	'1'	'0'	'0.4330380999159775'	20.0	'0.781009434596542'	'0'	'0'	'0'	'gen_1041_4'	'0.0459985336584505'	'0'	'[0 0 0 0]'	'3.48995867577754'	'0.239047732157609'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.3057972905459'	'1'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'1'	350.0	'0.0300360310875648'	'0.409013047951134'	'0'	'[0 0 0 0]'	'2'	'0.3057972905459'	'0.01'	'Combustion'	40.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.258577903325204 0.841955336298374 0 0 0 0 0 0 0]'	'1.73215239966391'	'Fossil'
	120.0	130	'14.8491940268893'	'1'	'0'	'0.4205071275938075'	20.0	'0.754270109408349'	'0'	'0'	'0'	'gen_1042_5'	'0.0466696398595814'	'0'	'[0 0 0 0]'	'3.48183408126282'	'0.238222133323294'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.305749526773102'	'1'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'1'	350.0	'0.029305506996375'	'0.410040563086595'	'0'	'[0 0 0 0]'	'2'	'0.305749526773102'	'0.01'	'Combustion'	40.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.260111580579542 0.8521947222002551 0 0 0 0 0 0 0]'	'1.68202851037523'	'Fossil'
	120.0	130	'14.7503153768795'	'1'	'0'	'0.419831816410855'	20.0	'0.763275312474882'	'0'	'0'	'0'	'gen_1043_6'	'0.0453982998013962'	'0'	'[0 0 0 0]'	'3.53615241267253'	'0.231587816122267'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.305164144053601'	'1'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'1'	350.0	'0.030080075807143'	'0.410694913491968'	'0'	'[0 0 0 0]'	'2'	'0.305164144053601'	'0.01'	'Combustion'	40.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.25100596891134 0.8437789681557329 0 0 0 0 0 0 0]'	'1.67932726564342'	'Fossil'
	120.0	130	'8.28933818250556'	'1'	'0'	'0.556526879117795'	20.0	'1.60399694923274'	'0'	'0'	'0'	'gen_1044_1'	'2.04649544797712'	'0'	'[0 0 0 0]'	'3.23862476497889'	'0.19137518667113'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.20690619433634'	'2'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'2'	350.0	'0.0611245826061815'	'0.318752726123305'	'0'	'[0 0 0 0]'	'2'	'1.1182657509669'	'0.184126026728563'	'Combustion'	40.0	'0.20690619433634'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.095430822324194 0.371389472297346 0 0 0 0 0 0 0]'	'2.22610751647118'	'Fossil'
	120.0	130	'5.92467431301158'	'1'	'0'	'0.5614527409493451'	20.0	'2.14879135707719'	'0'	'0'	'0'	'gen_1058_1'	'0.469903636420704'	'0'	'[0 0 0 0]'	'7.82370411843527'	'0.239809837361611'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.277527202355512'	'2'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'2'	350.0	'0.0217504555018153'	'0.35950926054162'	'0'	'[0 0 0 0]'	'2'	'0.72475032453197'	'0.041068053457886'	'Combustion'	40.0	'0.277527202355512'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0566004980416293 0.217275354504841 0 0 0 0 0 0 0]'	'2.24581096379738'	'Fossil'
	3.0	900	'6.01085570453201'	'1'	'0'	'0.4018746331973825'	3.0	'0.916542787935585'	'0'	'0'	'0'	'gen_1059_1'	'0.0514339772914536'	'0'	'[0 0 0 0]'	'3.35744332893006'	'0.189680992418667'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.237086805154802'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0705133091608994'	'0.394296536200214'	'0'	'[0 0 0 0]'	'2'	'0.237086805154802'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.134435962981544 0.360411761194351 0 0 0 0 0 0 0]'	'1.60749853278953'	'Wind'
	3.0	900	'5.95436197144212'	'1'	'0'	'0.40011123475508'	3.0	'0.88004660837166'	'0'	'0'	'0'	'gen_1060_2'	'0.0504694285034202'	'0'	'[0 0 0 0]'	'3.22030340120615'	'0.191603294584784'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.245533298791852'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0705786031519994'	'0.389005247015879'	'0'	'[0 0 0 0]'	'2'	'0.245533298791852'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.136476117643761 0.365882395888213 0 0 0 0 0 0 0]'	'1.60044493902032'	'Wind'
	3.0	590	'0.278572612223215'	'1'	'0'	'0.2858603513795525'	7.0	'0.735210589566743'	'0'	'0'	'0'	'gen_1067_1'	'0.0103215665838216'	'0'	'[0 0 0 0]'	'6.92948226211593'	'0.207373877484351'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.266868610015779'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0101880275546573'	'0.374614851844439'	'0'	'[0 0 0 0]'	'2'	'0.266868610015779'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'1.14344140551821'	'Hydro'
	3.0	590	'0.282933143766713'	'1'	'0'	'0.2826016265336425'	7.0	'0.728088686738377'	'0'	'0'	'0'	'gen_1068_2'	'0.0104268435533158'	'0'	'[0 0 0 0]'	'6.88583802017383'	'0.208864602590911'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.259144375379954'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0100554152012337'	'0.3727067901665'	'0'	'[0 0 0 0]'	'2'	'0.259144375379954'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'1.13040650613457'	'Hydro'
	57.5	420	'13.2996721277945'	'1'	'0'	'0.6296311295412025'	12.5	'2.44465301940264'	'0'	'0'	'0'	'gen_1069_1'	'1.95170033254032'	'0.0108735563005088'	'[0 0 0 0]'	'5.60216317037749'	'0.143658924385905'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.65	250	'0.200497999039292'	'2'	1	420	'0'	'[0 0 0 0]'	'0'	'0'	12100	'2'	62.5	'0.046465432904195'	'0.273239205386303'	'0'	'[0 0 0 0]'	'2'	'0.668168241571332'	'0.203306559700426'	'Combustion'	52.5	'0.200497999039292'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.189182514905347 0.776961018662457 0 0 0 0 0 0 0]'	'2.51852451816481'	'Fossil'
	57.5	420	'13.196043761936'	'1'	'0'	'0.6325718445101525'	12.5	'2.40724545206293'	'0'	'0'	'0'	'gen_1070_1'	'1.90006118166191'	'0.0106779984449619'	'[0 0 0 0]'	'5.74241753861564'	'0.144044353253208'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.65	250	'0.193713038411737'	'2'	1	420	'0'	'[0 0 0 0]'	'0'	'0'	12100	'2'	62.5	'0.0482392417188268'	'0.268120021589217'	'0'	'[0 0 0 0]'	'2'	'0.666805989973876'	'0.203061292059138'	'Combustion'	52.5	'0.193713038411737'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.193462500094855 0.779293112680293 0 0 0 0 0 0 0]'	'2.53028737804061'	'Fossil'
	57.5	420	'13.2585954592563'	'1'	'0'	'0.6456171243219875'	12.5	'2.35031908062124'	'0'	'0'	'0'	'gen_1071_1'	'1.9208578249251'	'0.0107622134504956'	'[0 0 0 0]'	'5.53843118465086'	'0.142698498049751'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.65	250	'0.195017864987254'	'2'	1	420	'0'	'[0 0 0 0]'	'0'	'0'	12100	'2'	62.5	'0.0467677966958843'	'0.272531327420427'	'0'	'[0 0 0 0]'	'2'	'0.683273629018245'	'0.201089784744219'	'Combustion'	52.5	'0.195017864987254'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.19297199129581 0.746550194930565 0 0 0 0 0 0 0]'	'2.58246849728795'	'Fossil'
	57.5	420	'13.1520820163889'	'1'	'0'	'0.6346908378613875'	12.5	'2.33866764679505'	'0'	'0'	'0'	'gen_1072_1'	'1.92749650900904'	'0.0110216279967455'	'[0 0 0 0]'	'5.50961575333495'	'0.145156730487943'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.65	250	'0.192910465116799'	'2'	1	420	'0'	'[0 0 0 0]'	'0'	'0'	12100	'2'	62.5	'0.046170137693407'	'0.274693726127897'	'0'	'[0 0 0 0]'	'2'	'0.660283152659773'	'0.201162778859516'	'Combustion'	52.5	'0.192910465116799'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.189188495927397 0.75222760741245 0 0 0 0 0 0 0]'	'2.53876335144555'	'Fossil'
	3.0	900	'7.30358025245764'	'1'	'0'	'0.2449191144704818'	3.0	'0.680828503818484'	'0'	'0'	'0'	'gen_1074_2'	'0.172023725859122'	'0'	'[0 0 0 0]'	'3.27968615151476'	'0.123382624990353'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.170055595806334'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0734919211221929'	'0.2621925007869'	'0'	'[0 0 0 0]'	'2'	'0.170055595806334'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'0.979676457881927'	'Wind'
	3.0	900	'7.26745661867469'	'1'	'0'	'0.25195615897514'	3.0	'0.700514080597553'	'0'	'0'	'0'	'gen_1075_3'	'0.171489330569981'	'0'	'[0 0 0 0]'	'3.37318986444594'	'0.122580307903374'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.170680748220067'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0723584957847325'	'0.267101460130338'	'0'	'[0 0 0 0]'	'2'	'0.170680748220067'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'1.00782463590056'	'Wind'
	3.0	900	'8.214832701827991'	'1'	'0'	'0.2316025956789962'	3.0	'0.54084188815055'	'0'	'0'	'0'	'gen_1078_6'	'0.153802419046406'	'0'	'[0 0 0 0]'	'3.1388534370102'	'0.127947661516862'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.182677759224316'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0535696149190469'	'0.250427186370427'	'0'	'[0 0 0 0]'	'2'	'0.182677759224316'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'0.926410382715985'	'Wind'
	3.0	900	'8.19016397855906'	'1'	'0'	'0.2308515359892045'	3.0	'0.539044667238742'	'0'	'0'	'0'	'gen_1079_7'	'0.155817796894116'	'0'	'[0 0 0 0]'	'3.17279280964658'	'0.130957778056758'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.181141554300557'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0514716198998038'	'0.25124353668428'	'0'	'[0 0 0 0]'	'2'	'0.181141554300557'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'0.923406143956818'	'Wind'
	3.0	900	'7.97789497352744'	'1'	'0'	'0.2361729249061318'	3.0	'0.563116229017335'	'0'	'0'	'0'	'gen_1080_8'	'0.152776010310045'	'0'	'[0 0 0 0]'	'3.15364401173219'	'0.130625074540055'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.175239341291599'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0526343136359775'	'0.252504222534201'	'0'	'[0 0 0 0]'	'2'	'0.175239341291599'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'0.944691699624527'	'Wind'
	120.0	130	'8.50451356032886'	'1'	'0'	'0.5533626668161875'	20.0	'1.65354417519325'	'0'	'0'	'0'	'gen_1081_5'	'1.99137753980123'	'0'	'[0 0 0 0]'	'3.32030633851886'	'0.193636014764477'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.20690878117187'	'2'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'2'	350.0	'0.0614381766491383'	'0.31367533963473'	'0'	'[0 0 0 0]'	'2'	'1.0908238255729'	'0.1797789244466'	'Combustion'	40.0	'0.20690878117187'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0961563939831685 0.368083550478704 0 0 0 0 0 0 0]'	'2.21345066726475'	'Fossil'
	120.0	130	'8.34280464674567'	'1'	'0'	'0.553613759516535'	20.0	'1.61763212694176'	'0'	'0'	'0'	'gen_1082_6'	'2.04065722653568'	'0'	'[0 0 0 0]'	'3.21484749294817'	'0.195409033201635'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.205219897416048'	'2'	8	180	'0'	'[0 0 0 0]'	'0'	'0'	53400	'2'	350.0	'0.0614552841114998'	'0.323817126925599'	'0'	'[0 0 0 0]'	'2'	'1.10297605503616'	'0.184893002607394'	'Combustion'	40.0	'0.205219897416048'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.09809677956542 0.365695381680317 0 0 0 0 0 0 0]'	'2.21445503806614'	'Fossil'
	3.0	900	'6.60510904180445'	'1'	'0'	'0.61129763161011'	3.0	'2.23062539809516'	'0'	'0'	'0'	'gen_1084_1'	'0.577876457579155'	'0'	'[0 0 0 0]'	'5.71009419059102'	'0.180948384403344'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.205625473761465'	'2'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0213932568600168'	'0.289740892106667'	'0'	'[0 0 0 0]'	'2'	'0.410227046634536'	'0.0441250885084039'	'Renewable'	2.0	'0.205625473761465'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.091946271550376 0.4899538991265 0 0 0 0 0 0 0]'	'2.44519052644044'	'Wind'
	57.5	420	'6.42466781241242'	'1'	'0'	'0.596786349874875'	12.5	'2.22495364837607'	'0'	'0'	'0'	'gen_1085_2'	'0.557730817954428'	'0'	'[0 0 0 0]'	'5.68853632065933'	'0.180439341512765'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.65	250	'0.212849698951375'	'2'	1	420	'0'	'[0 0 0 0]'	'0'	'0'	12100	'2'	62.5	'0.0210970202903962'	'0.287777392736636'	'0'	'[0 0 0 0]'	'2'	'0.399492474041297'	'0.0440704936427763'	'Combustion'	52.5	'0.212849698951375'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0905377852313686 0.491680710509419 0 0 0 0 0 0 0]'	'2.3871453994995'	'Fossil'
	3.0	2085	'13.1152812681953'	'1'	'0'	'0.3368692087645175'	7.0	'0.692169924931601'	'0'	'0'	'0'	'gen_2003_7'	'0.257573597604642'	'0'	'[0 0 0 0]'	'5.47055249727331'	'0.07037058142991739'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.140459885574644'	'1'	1	1945	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.08006743506900969'	'0.19645158962626'	'0'	'[0 0 0 0]'	'2'	'0.140459885574644'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0728272421874572 0.151229159968207 0 0 0 0 0 0 0]'	'1.34747683505807'	'Hydro'
	3.0	2085	'12.9697125383955'	'1'	'0'	'0.33792818401591'	7.0	'0.689755036254413'	'0'	'0'	'0'	'gen_2004_8'	'0.259286031714873'	'0'	'[0 0 0 0]'	'5.44570927568246'	'0.0703134508477524'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.140206874543801'	'1'	1	1945	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.08258637520298361'	'0.194228103008587'	'0'	'[0 0 0 0]'	'2'	'0.140206874543801'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.07119631454139019 0.156920705217635 0 0 0 0 0 0 0]'	'1.35171273606364'	'Hydro'
	3.0	550	'9.401682886714109'	'1'	'0'	'0.29580283292412'	3.0	'0.599022037639283'	'0'	'0'	'0'	'gen_2010_1'	'0.150723496227292'	'0'	'[0 0 0 0]'	'3.99037735044956'	'0.15170433190302'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.190709760872647'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0541547991681844'	'0.284851787428372'	'0'	'[0 0 0 0]'	'2'	'0.190709760872647'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.13186093249172 0.582683173609432 0 0 0 0 0 0 0]'	'1.18321133169648'	'Wind'
	100.0	570	'9.400862963497641'	'1'	'0'	'0.2913376410931825'	5.0	'0.599254368624184'	'0'	'0'	'0'	'gen_2011_2'	'0.152091597591061'	'0'	'[0 0 0 0]'	'4.08250164640555'	'0.154250349970534'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.193881744362647'	'1'	1	570	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0520561677645892'	'0.281819752996787'	'0'	'[0 0 0 0]'	'2'	'0.193881744362647'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.134941022572108 0.598012115219142 0 0 0 0 0 0 0]'	'1.16535056437273'	'Fossil'
	100.0	600	'9.70420996861067'	'1'	'0'	'0.2266249050199985'	5.0	'0.613079078556038'	'0'	'0'	'0'	'gen_2012_1'	'0.10216426093597'	'0'	'[0 0 0 0]'	'2.46005736810854'	'0.124883695847355'	550	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	350	'0.15064032941591'	'1'	1	595	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0582677543990125'	'0.174670651662163'	'0'	'[0 0 0 0]'	'2'	'0.15064032941591'	'0.01'	'Combustion'	100.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Distillate'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'0.906499620079994'	'Fossil'
	3.0	550	'9.141628227840179'	'1'	'0'	'0.3756812654261'	3.0	'0.8524309190064669'	'0'	'0'	'0'	'gen_2014_1'	'0.162205352655728'	'0'	'[0 0 0 0]'	'4.06409697877243'	'0.154798019940499'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.192903413359774'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0614735024808906'	'0.204563326168433'	'0'	'[0 0 0 0]'	'2'	'0.192903413359774'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'1.5027250617044'	'Wind'
	3.0	550	'5.75818576203892'	'1'	'0'	'0.29060807755409'	3.0	'0.657546600654721'	'0'	'0'	'0'	'gen_2015_1'	'0.125639858629312'	'0'	'[0 0 0 0]'	'4.7044058326981'	'0.157253336323192'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.180059996055462'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0584789610555745'	'0.303909980649501'	'0'	'[0 0 0 0]'	'2'	'0.180059996055462'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'1.16243231021636'	'Wind'
	3.0	550	'5.59510483304039'	'1'	'0'	'0.28831481979828'	3.0	'0.646937878787518'	'0'	'0'	'0'	'gen_2016_2'	'0.129609208103679'	'0'	'[0 0 0 0]'	'4.5725358363823'	'0.153311754179886'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.183554414698621'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0599073628931656'	'0.308310711539956'	'0'	'[0 0 0 0]'	'2'	'0.183554414698621'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'1.15325927919312'	'Wind'
	100.0	600	'9.649573004084081'	'1'	'0'	'0.339148916915'	5.0	'0.718284736941568'	'0'	'0'	'0'	'gen_2021_14'	'0.204975472120568'	'0'	'[0 0 0 0]'	'3.7471230134205'	'0.149407079946063'	550	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	350	'0.184559151216224'	'1'	1	595	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.063479751940188'	'0.272417223002063'	'0'	'[0 0 0 0]'	'2'	'0.184559151216224'	'0.01'	'Combustion'	100.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Distillate'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'1.35659566766'	'Fossil'
	3.0	550	'8.644294168148191'	'1'	'0'	'0.276688239189155'	3.0	'0.661138976527005'	'0'	'0'	'0'	'gen_2024_2'	'0.207557347007096'	'0'	'[0 0 0 0]'	'3.70091583372094'	'0.140207213005051'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.257079988287389'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0467904670265503'	'0.277829190868651'	'0'	'[0 0 0 0]'	'2'	'0.257079988287389'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0283119901584461 0.172946158540947 0 0 0 0 0 0 0]'	'1.10675295675662'	'Wind'
	3.0	550	'8.5900621545501'	'1'	'0'	'0.283993088279735'	3.0	'0.651046621859539'	'0'	'0'	'0'	'gen_2028_6'	'0.203371186354198'	'0'	'[0 0 0 0]'	'3.72723273860291'	'0.141533667792915'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.261211925436929'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0479352800024208'	'0.271353758693906'	'0'	'[0 0 0 0]'	'2'	'0.261211925436929'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0283815097064711 0.176099767547892 0 0 0 0 0 0 0]'	'1.13597235311894'	'Wind'
	3.0	550	'8.85834268579492'	'1'	'0'	'0.288221267361905'	3.0	'0.639310903342487'	'0'	'0'	'0'	'gen_2030_8'	'0.204495833693072'	'0'	'[0 0 0 0]'	'3.64607256987132'	'0.137732337652124'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.256180270528141'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0482526364274789'	'0.270161778015085'	'0'	'[0 0 0 0]'	'2'	'0.256180270528141'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0293098239625804 0.172572864756896 0 0 0 0 0 0 0]'	'1.15288506944762'	'Wind'
	3.0	550	'5.62580722622946'	'1'	'0'	'0.43566993067311'	3.0	'1.71331186818467'	'0'	'0'	'0'	'gen_2036_1'	'1.41292391285859'	'0'	'[0 0 0 0]'	'9.08808681561146'	'0.125024369685911'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.15050190007803'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0377539766477421'	'0.240637742372719'	'0'	'[0 0 0 0]'	'2'	'0.278220606380375'	'0.0522054060432129'	'Renewable'	2.0	'0.15050190007803'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'1.74267972269244'	'Wind'
	3.0	550	'5.63324014986213'	'1'	'0'	'0.4411855168432475'	3.0	'1.70471853161333'	'0'	'0'	'0'	'gen_2037_2'	'1.42386981241591'	'0'	'[0 0 0 0]'	'9.01305640603649'	'0.12429026450403'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.148858594405348'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0373273120949976'	'0.234873122577253'	'0'	'[0 0 0 0]'	'2'	'0.271363207275979'	'0.0513340991328005'	'Renewable'	2.0	'0.148858594405348'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'1.76474206737299'	'Wind'
	3.0	550	'5.56171743093361'	'1'	'0'	'0.43690150760049'	3.0	'1.67854669901873'	'0'	'0'	'0'	'gen_2038_3'	'1.66273468548339'	'0'	'[0 0 0 0]'	'9.0093198225135'	'0.121093014190905'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.157927029657736'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0322230394623708'	'0.241891812811024'	'0'	'[0 0 0 0]'	'2'	'0.281901037345408'	'0.287701905578258'	'Renewable'	2.0	'0.157927029657736'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'1.74760603040196'	'Wind'
	100.0	570	'12.1670928301318'	'1'	'0'	'0.56852672272101'	5.0	'2.13640583073918'	'0'	'0'	'0'	'gen_2040_1'	'1.92622005773117'	'0'	'[0 0 0 0]'	'6.14963329207208'	'0.147430063947011'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.179588804137288'	'2'	1	570	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0458926945318468'	'0.2405936365854'	'0'	'[0 0 0 0]'	'2'	'0.628676544888876'	'0.210096588095012'	'Combustion'	100.0	'0.179588804137288'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.213149927735503 0.876194069808419 0 0 0 0 0 0 0]'	'2.27410689088404'	'Fossil'
	100.0	570	'12.2804884779193'	'1'	'0'	'0.566038564199955'	5.0	'2.08898139820669'	'0'	'0'	'0'	'gen_2041_2'	'1.91468615333024'	'0'	'[0 0 0 0]'	'6.14581909604918'	'0.14895520463041'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.184987030366622'	'2'	1	570	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0445534495728929'	'0.24397955252789'	'0'	'[0 0 0 0]'	'2'	'0.60955103523354'	'0.20304874447389'	'Combustion'	100.0	'0.184987030366622'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.211620692036231 0.879657702257987 0 0 0 0 0 0 0]'	'2.26415425679982'	'Fossil'
	3.0	2085	'8.078392870917449'	'1'	'0'	'0.7660784252341825'	7.0	'1.97162422098429'	'0'	'0'	'0'	'gen_2043_2'	'1.6656421950832'	'0'	'[0 0 0 0]'	'4.74471527724992'	'0.238656334180152'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.282570772883482'	'2'	1	1945	'0'	'[0 0 0 0]'	'0'	'0'	56700	'2'	5.0	'0.0257566751906415'	'0.322901312890928'	'0'	'[0 0 0 0]'	'2'	'0.562876404516865'	'0.0609874658533372'	'Renewable'	2.0	'0.282570772883482'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0620794791110791 0.566092940667551 0 0 0 0 0 0 0]'	'3.06431370093673'	'Hydro'
	120.0	240	'9.63119054253213'	'1'	'0'	'0.7142032438178725'	20.0	'1.75351179362624'	'0'	'0'	'0'	'gen_2044_3'	'1.06803487882367'	'0'	'[0 0 0 0]'	'3.12175265106224'	'0.100007683518343'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.209143309472781'	'2'	16	220	'0'	'[0 0 0 0]'	'0'	'0'	126850	'2'	350.0	'0.0360135997417383'	'0.233962958633783'	'0'	'[0 0 0 0]'	'2'	'0.717366185103077'	'0.123079596955329'	'Combustion'	40.0	'0.209143309472781'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	16	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.128958338149451 0.411295651755529 0 0 0 0 0 0 0]'	'2.85681297527149'	'Fossil'
	120.0	240	'9.618236888374669'	'1'	'0'	'0.726353932854755'	20.0	'2.71512390831774'	'0'	'0'	'0'	'gen_2045_4'	'2.62273582036141'	'0'	'[0 0 0 0]'	'3.50812415473688'	'0.16241376766935'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.254124888244318'	'2'	16	220	'0'	'[0 0 0 0]'	'0'	'0'	126850	'2'	350.0	'0.0404989788755775'	'0.344685269669304'	'0'	'[0 0 0 0]'	'2'	'0.802516619203077'	'0.153707704602275'	'Combustion'	40.0	'0.254124888244318'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	16	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.143703583321068 0.583817961183004 0 0 0 0 0 0 0]'	'2.90541573141902'	'Fossil'
	120.0	240	'7.9957560302061'	'1'	'0'	'0.69228188475984'	20.0	'1.49396912607029'	'0'	'0'	'0'	'gen_2046_1'	'0.878809587816941'	'0'	'[0 0 0 0]'	'2.82492999458686'	'0.220370596198132'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.27078077274668'	'2'	16	220	'0'	'[0 0 0 0]'	'0'	'0'	126850	'2'	350.0	'0.0354125640279381'	'0.292980902360985'	'0'	'[0 0 0 0]'	'2'	'0.902106047159061'	'0.113304608154576'	'Combustion'	40.0	'0.27078077274668'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	16	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.110870278429007 0.5287843568409329 0 0 0 0 0 0 0]'	'2.76912753903936'	'Fossil'
	120.0	240	'7.98948127645068'	'1'	'0'	'0.6795054174677225'	20.0	'1.53402564272303'	'0'	'0'	'0'	'gen_2047_2'	'0.8879521721950731'	'0'	'[0 0 0 0]'	'2.89715258527547'	'0.21672931684088'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.272641338658379'	'2'	16	220	'0'	'[0 0 0 0]'	'0'	'0'	126850	'2'	350.0	'0.0358368078892818'	'0.291363623245386'	'0'	'[0 0 0 0]'	'2'	'0.92106840505451'	'0.113771175741684'	'Combustion'	40.0	'0.272641338658379'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	16	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.11333135988703 0.524200491215428 0 0 0 0 0 0 0]'	'2.71802166987089'	'Fossil'
	3.0	2085	'9.16600971654989'	'1'	'0'	'0.296177483896085'	7.0	'0.596343371211085'	'0'	'0'	'0'	'gen_2054_1'	'0.154421589545673'	'0'	'[0 0 0 0]'	'4.03117492500646'	'0.153062255956465'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.190769310319214'	'1'	1	1945	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0544922863943502'	'0.288383334587328'	'0'	'[0 0 0 0]'	'2'	'0.190769310319214'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.130411274833372 0.59412612610124 0 0 0 0 0 0 0]'	'1.18470993558434'	'Hydro'
	3.0	550	'9.07309239946771'	'1'	'0'	'0.295218588298245'	3.0	'0.603036889829207'	'0'	'0'	'0'	'gen_2055_2'	'0.15207743184641'	'0'	'[0 0 0 0]'	'4.06066666295053'	'0.150796227111714'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.18842873855005'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0544717363826931'	'0.284297608871013'	'0'	'[0 0 0 0]'	'2'	'0.18842873855005'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.133343112369068 0.594565711029805 0 0 0 0 0 0 0]'	'1.18087435319298'	'Wind'
	3.0	550	'9.02770271510817'	'1'	'0'	'0.28895081533835'	3.0	'0.59405834513763'	'0'	'0'	'0'	'gen_2056_3'	'0.151836432883283'	'0'	'[0 0 0 0]'	'4.08431555336993'	'0.157472956760321'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.185772904127254'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.053185727585014'	'0.287780083508231'	'0'	'[0 0 0 0]'	'2'	'0.185772904127254'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.136108512234408 0.581609428610653 0 0 0 0 0 0 0]'	'1.1558032613534'	'Wind'
	3.0	2085	'9.358395589026619'	'1'	'0'	'0.289167836851905'	7.0	'0.6073674085112289'	'0'	'0'	'0'	'gen_2057_4'	'0.155718487343984'	'0'	'[0 0 0 0]'	'4.02206549641024'	'0.155206665890291'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.187924511490506'	'1'	1	1945	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0534328781481832'	'0.292207703014836'	'0'	'[0 0 0 0]'	'2'	'0.187924511490506'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.134532691539265 0.607950304671656 0 0 0 0 0 0 0]'	'1.15667134740762'	'Hydro'
	100.0	570	'9.02192411413416'	'1'	'0'	'0.2938788464727125'	5.0	'0.595197321349289'	'0'	'0'	'0'	'gen_2058_5'	'0.151637689943891'	'0'	'[0 0 0 0]'	'3.99848786202748'	'0.156863717761589'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.186409482990741'	'1'	1	570	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0524561489649117'	'0.284556783134118'	'0'	'[0 0 0 0]'	'2'	'0.186409482990741'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.134033706157934 0.602461138121318 0 0 0 0 0 0 0]'	'1.17551538589085'	'Fossil'
	3.0	550	'9.35010723690502'	'1'	'0'	'0.2832616046133325'	3.0	'0.597387936248444'	'0'	'0'	'0'	'gen_2059_6'	'0.156428222410614'	'0'	'[0 0 0 0]'	'3.9632122449968'	'0.15744628916611'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.185813261497533'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0537023312235251'	'0.287029509564862'	'0'	'[0 0 0 0]'	'2'	'0.185813261497533'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.134673681959277 0.602642043429892 0 0 0 0 0 0 0]'	'1.13304641845333'	'Wind'
	3.0	2085	'7.68085595152594'	'1'	'0'	'0.3770897290089975'	7.0	'0.824091705071489'	'0'	'0'	'0'	'gen_2060_1'	'0.084247076077899'	'0'	'[0 0 0 0]'	'3.30043171584606'	'0.129965120342835'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.217732234889237'	'1'	1	1945	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0698387765660137'	'0.387085386070171'	'0'	'[0 0 0 0]'	'2'	'0.217732234889237'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.128144556057127 0.707332838140894 0 0 0 0 0 0 0]'	'1.50835891603599'	'Hydro'
	3.0	2085	'7.58959724868929'	'1'	'0'	'0.377666472370025'	7.0	'0.845341116429898'	'0'	'0'	'0'	'gen_2061_5'	'0.08189537336241449'	'0'	'[0 0 0 0]'	'3.34387728109956'	'0.12580229607692'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.222751605621412'	'1'	1	1945	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0729844010128453'	'0.403676320665549'	'0'	'[0 0 0 0]'	'2'	'0.222751605621412'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.129885810557031 0.7042550601650031 0 0 0 0 0 0 0]'	'1.5106658894801'	'Hydro'
	3.0	2085	'7.50128685525794'	'1'	'0'	'0.376256542097455'	7.0	'0.83213562498488'	'0'	'0'	'0'	'gen_2062_2'	'0.08204095216181601'	'0'	'[0 0 0 0]'	'3.21453293256462'	'0.128620932018664'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.220365055460222'	'1'	1	1945	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.070840064334143'	'0.392660750422804'	'0'	'[0 0 0 0]'	'2'	'0.220365055460222'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.127854901388474 0.703062873454392 0 0 0 0 0 0 0]'	'1.50502616838982'	'Hydro'
	120.0	240	'14.7992703462001'	'1'	'0'	'0.558759305460845'	20.0	'1.80545373802611'	'0'	'0'	'0'	'gen_2063_11'	'1.66678917597644'	'0'	'[0 0 0 0]'	'6.1948830040202'	'0.191272909612942'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.20616501327022'	'2'	16	220	'0'	'[0 0 0 0]'	'0'	'0'	126850	'2'	350.0	'0.0740629145089071'	'0.247864859093418'	'0'	'[0 0 0 0]'	'2'	'0.43446545309342'	'0.0785728729372844'	'Combustion'	40.0	'0.20616501327022'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	16	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.131922701058844 0.750702290336019 0 0 0 0 0 0 0]'	'2.23503722184338'	'Fossil'
	120.0	240	'14.7433220908174'	'1'	'0'	'0.571760032062045'	20.0	'1.81476633016775'	'0'	'0'	'0'	'gen_2064_12'	'1.7203412002414'	'0'	'[0 0 0 0]'	'6.25485634361487'	'0.198265866280301'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.206042246815632'	'2'	16	220	'0'	'[0 0 0 0]'	'0'	'0'	126850	'2'	350.0	'0.07488318341528059'	'0.250246868084436'	'0'	'[0 0 0 0]'	'2'	'0.417571711633354'	'0.0770717675060965'	'Combustion'	40.0	'0.206042246815632'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	16	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.127360670649963 0.677196917318972 0 0 0 0 0 0 0]'	'2.28704012824818'	'Fossil'
	100.0	570	'6.107127386868'	'1'	'0'	'0.428086248115695'	5.0	'1.67432753258985'	'0'	'0'	'0'	'gen_2069_1'	'0.449100501766196'	'0'	'[0 0 0 0]'	'2.09427953171544'	'0.132047091756854'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.196355714112404'	'2'	1	570	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0388881832155399'	'0.24952969160839'	'0'	'[0 0 0 0]'	'2'	'0.400432061496796'	'0.0592212326824199'	'Combustion'	100.0	'0.196355714112404'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.133330417062622 0.506281487579481 0 0 0 0 0 0 0]'	'1.71234499246278'	'Fossil'
	3.0	2085	'8.042133202410771'	'1'	'0'	'0.787430443246615'	7.0	'1.89472809397336'	'0'	'0'	'0'	'gen_2073_1'	'1.63130434907973'	'0'	'[0 0 0 0]'	'4.78634356811922'	'0.232123611525167'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.282732842341997'	'2'	1	1945	'0'	'[0 0 0 0]'	'0'	'0'	56700	'2'	5.0	'0.0252934310870478'	'0.312551544700051'	'0'	'[0 0 0 0]'	'2'	'0.571152368282201'	'0.0606394733847119'	'Renewable'	2.0	'0.282732842341997'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0646734404373448 0.5777143036279599 0 0 0 0 0 0 0]'	'3.14972177298646'	'Hydro'
	3.0	2085	'8.44111767042777'	'1'	'0'	'0.2485487533537845'	7.0	'0.6155278328632'	'0'	'0'	'0'	'gen_2091_1'	'0.0856915255014785'	'0'	'[0 0 0 0]'	'4.47370711159601'	'0.119260698258248'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.208017124790722'	'1'	1	1945	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0314025864723837'	'0.319939966568956'	'0'	'[0 0 0 0]'	'2'	'0.208017124790722'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'0.9941950134151381'	'Hydro'
	100.0	570	'7.3165585881006'	'1'	'0'	'0.511766669164295'	5.0	'1.97365733031929'	'0'	'0'	'0'	'gen_2092_1'	'0.272367673363467'	'0'	'[0 0 0 0]'	'3.33360681051202'	'0.176396053616796'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.225107598190312'	'1'	1	570	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0380721040721284'	'0.271743498196453'	'0'	'[0 0 0 0]'	'2'	'0.225107598190312'	'0.01'	'Combustion'	100.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'2.04706667665718'	'Fossil'
	3.0	550	'7.31055407261476'	'1'	'0'	'0.5006249842629775'	3.0	'1.99729462185502'	'0'	'0'	'0'	'gen_2093_2'	'0.270961899555149'	'0'	'[0 0 0 0]'	'3.28558189037256'	'0.17255781546915'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.21634164256847'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0370197912551463'	'0.271790645513311'	'0'	'[0 0 0 0]'	'2'	'0.21634164256847'	'0.01'	'Renewable'	2.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'2.00249993705191'	'Wind'
	100.0	570	'8.1800689175725'	'1'	'0'	'0.618070858482155'	5.0	'2.37412631153595'	'0'	'0'	'0'	'gen_2094_3'	'0.0703483978975564'	'0'	'[0 0 0 0]'	'2.84203912114631'	'0.21278581263274'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.269446662588138'	'1'	1	570	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0405651944782585'	'0.316171454609558'	'0'	'[0 0 0 0]'	'2'	'0.269446662588138'	'0.01'	'Combustion'	100.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'2.47228343392862'	'Fossil'
	100.0	570	'9.01403412369709'	'1'	'0'	'0.5659252276341425'	5.0	'2.06833851886913'	'0'	'0'	'0'	'gen_2095_4'	'0.304586769940252'	'0'	'[0 0 0 0]'	'3.07100263712928'	'0.165382165543782'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.20535805297941'	'1'	1	570	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0405587120503187'	'0.281499481397169'	'0'	'[0 0 0 0]'	'2'	'0.20535805297941'	'0.01'	'Combustion'	100.0	'10'	'[1 1.2 0 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'2'	'[0 0 0 0 0 0 0 0 0 0]'	'2.26370091053657'	'Fossil'
	100.0	570	'4.45158014260149'	'1'	'0'	'0.61594825312954'	5.0	'1.80323555976357'	'0'	'0'	'0'	'gen_2322_3'	'0.37324356560007'	'0'	'[0 0 0 0]'	'6.17647337724431'	'0.135614820701117'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.160890100223757'	'2'	1	570	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.021248307089248'	'0.255631518942537'	'0'	'[0 0 0 0]'	'2'	'0.410739804014389'	'0.06339402748252961'	'Combustion'	100.0	'0.160890100223757'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0773319850559346 0.323849116496742 0 0 0 0 0 0 0]'	'2.46379301251816'	'Fossil'
	3.0	550	'4.45641638381762'	'1'	'0'	'0.62873387726635'	3.0	'1.79202628061157'	'0'	'0'	'0'	'gen_2323_4'	'0.384897612011186'	'0'	'[0 0 0 0]'	'6.15002819432421'	'0.134278066840326'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.159617642189702'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0208416807888779'	'0.255641689372133'	'0'	'[0 0 0 0]'	'2'	'0.415280793136258'	'0.0643816046734122'	'Renewable'	2.0	'0.159617642189702'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0767526683356846 0.328133545421064 0 0 0 0 0 0 0]'	'2.5149355090654'	'Wind'
	3.0	550	'5.56300846283417'	'1'	'0'	'0.68280919779418'	3.0	'2.48358281386271'	'0'	'0'	'0'	'gen_2324_1'	'0.811437354814904'	'0'	'[0 0 0 0]'	'5.25764129845053'	'0.149059200884472'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.156744940988242'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.042133739922672'	'0.271188627389779'	'0'	'[0 0 0 0]'	'2'	'0.158051589153758'	'0.08705920038176231'	'Renewable'	2.0	'0.156744940988242'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0797420477679931 0.334629224643111 0 0 0 0 0 0 0]'	'2.73123679117672'	'Wind'
	3.0	550	'5.49128959307652'	'1'	'0'	'0.9024392279982675'	3.0	'2.67657415372133'	'0'	'0'	'0'	'gen_2325_2'	'0.598409325595759'	'0'	'[0 0 0 0]'	'4.26221469973587'	'0.198655885283835'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.227904606739432'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0388154977258481'	'0.369004891169176'	'0'	'[0 0 0 0]'	'2'	'0.236381660297401'	'0.108059357956569'	'Renewable'	2.0	'0.227904606739432'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0768497418945655 0.328209669783711 0 0 0 0 0 0 0]'	'3.60975691199307'	'Wind'
	3.0	550	'6.01524441617657'	'1'	'0'	'0.3718171642226625'	3.0	'0.653736277539516'	'0'	'0'	'0'	'gen_3154_3'	'0.136285069723614'	'0'	'[0 0 0 0]'	'6.02022996824328'	'0.100625005390029'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.165369049217552'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0409194248579442'	'0.236309943563933'	'0'	'[0 0 0 0]'	'2'	'0.165369049217552'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.15043238382088 0.424900714945514 0 0 0 0 0 0 0]'	'1.48726865689065'	'Wind'
	3.0	550	'5.23850024223793'	'1'	'0'	'0.5263130529960151'	3.0	'0.670176763130911'	'0'	'0'	'0'	'gen_3155_1'	'0.0372836178079247'	'0'	'[0 0 0 0]'	'3.60993799746037'	'0.0936156283468008'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.190548348950408'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0311510650548153'	'0.248329524861369'	'0'	'[0 0 0 0]'	'2'	'0.190548348950408'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.193288791911094 0.9991211643911661 0 0 0 0 0 0 0]'	'2.10525221198406'	'Wind'
	57.5	545	'5.90473576803925'	'1'	'0'	'0.3816853033265675'	12.5	'0.644433860891126'	'0'	'0'	'0'	'gen_3156_2'	'0.136108365259133'	'0'	'[0 0 0 0]'	'5.93844899515156'	'0.100444898027927'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	8.7	250	'0.163149734124541'	'1'	4	545	'0'	'[0 0 0 0]'	'0'	'0'	12100	'1'	62.5	'0.0414171042172238'	'0.23943890593769'	'0'	'[0 0 0 0]'	'2'	'0.163149734124541'	'0.01'	'Combustion'	52.5	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	4	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.137111357472371 0.404672492164746 0 0 0 0 0 0 0]'	'1.52674121330627'	'Fossil'
	3.0	550	'10.4247302248478'	'1'	'0'	'0.615674319156795'	3.0	'2.38781679937579'	'0'	'0'	'0'	'gen_3264_1'	'0.918850534861675'	'0'	'[0 0 0 0]'	'6.63361655944912'	'0.178184038713109'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.195174052917492'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.021265989656467'	'0.250429041439458'	'0'	'[0 0 0 0]'	'2'	'0.422410171864554'	'0.0325859198257327'	'Renewable'	2.0	'0.195174052917492'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.08939795621950181 0.473065880312119 0 0 0 0 0 0 0]'	'2.46269727662718'	'Wind'
	120.0	190	'6.49822890136416'	'1'	'0'	'0.7230897461436875'	20.0	'2.72520976324555'	'0'	'0'	'0'	'gen_3295_1'	'2.09722201965679'	'0'	'[0 0 0 0]'	'2.40391258200398'	'0.199349076014333'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.209308132514635'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.0349455311762402'	'0.327267125567719'	'0'	'[0 0 0 0]'	'2'	'1.09732162832391'	'0.24632794285465'	'Combustion'	40.0	'0.209308132514635'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.17525998005369 0.49884011385245 0 0 0 0 0 0 0]'	'2.89235898457475'	'Fossil'
	3.0	550	'11.7666526484396'	'1'	'0'	'0.5216690686102951'	3.0	'1.14978754612617'	'0'	'0'	'0'	'gen_3301_1'	'0.134077290374553'	'0'	'[0 0 0 0]'	'2.70277349474677'	'0.142658731834032'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.203913950338028'	'1'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0403545063221827'	'0.300747628742829'	'0'	'[0 0 0 0]'	'2'	'0.203913950338028'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.07104306664131579 0.258720623917179 0 0 0 0 0 0 0]'	'2.08667627444118'	'Wind'
	120.0	190	'8.841047646263609'	'1'	'0'	'0.5542875514127075'	20.0	'1.41951625270746'	'0'	'0'	'0'	'gen_3417_1'	'1.41977305095177'	'0'	'[0 0 0 0]'	'3.86626404018374'	'0.18968452615547'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.237618300461792'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.0355467345670331'	'0.316110383726307'	'0'	'[0 0 0 0]'	'2'	'0.787180420593359'	'0.134924549088813'	'Combustion'	40.0	'0.237618300461792'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0944042776855384 0.341244472153904 0 0 0 0 0 0 0]'	'2.21715020565083'	'Fossil'
	120.0	190	'8.945346971706019'	'1'	'0'	'0.5441811000095925'	20.0	'1.42679221200664'	'0'	'0'	'0'	'gen_3418_2'	'1.42720811647829'	'0'	'[0 0 0 0]'	'3.820521598591'	'0.187139095534687'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.240845218756702'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.0365770018170588'	'0.323964714750415'	'0'	'[0 0 0 0]'	'2'	'0.756816770962905'	'0.134260131702991'	'Combustion'	40.0	'0.240845218756702'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.09130882321532351 0.344133747342508 0 0 0 0 0 0 0]'	'2.17672440003837'	'Fossil'
	120.0	190	'9.011984201988669'	'1'	'0'	'0.5382673037995125'	20.0	'1.43418260413315'	'0'	'0'	'0'	'gen_3419_3'	'1.42844083372038'	'0'	'[0 0 0 0]'	'3.70773104398279'	'0.188146094688028'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.237310461413464'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.035481092891423'	'0.329564754615189'	'0'	'[0 0 0 0]'	'2'	'0.756886540021514'	'0.133668741711881'	'Combustion'	40.0	'0.237310461413464'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0920463975860691 0.354161911594402 0 0 0 0 0 0 0]'	'2.15306921519805'	'Fossil'
	120.0	190	'8.822544645974411'	'1'	'0'	'0.5501170843886199'	20.0	'1.45560889990954'	'0'	'0'	'0'	'gen_3420_4'	'1.46002057570033'	'0'	'[0 0 0 0]'	'3.7787187784072'	'0.189250415644329'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.243262402186636'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.0354735213819658'	'0.315368204015424'	'0'	'[0 0 0 0]'	'2'	'0.775654590973863'	'0.130525620050728'	'Combustion'	40.0	'0.243262402186636'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0921633735830476 0.350613086293964 0 0 0 0 0 0 0]'	'2.20046833755448'	'Fossil'
	3.0	300	'9.00120812370675'	'1'	'0'	'0.5584359856872475'	7.0	'1.44029444648721'	'0'	'0'	'0'	'gen_3421_5'	'1.42893853170797'	'0'	'[0 0 0 0]'	'3.74056686070515'	'0.189813048525085'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.244184825941338'	'2'	1	180	'0'	'[0 0 0 0]'	'0'	'0'	56700	'2'	5.0	'0.0353049714509398'	'0.329721502720378'	'0'	'[0 0 0 0]'	'2'	'0.756618822208838'	'0.136436433299445'	'Renewable'	2.0	'0.244184825941338'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0925870090375864 0.346753837848036 0 0 0 0 0 0 0]'	'2.23374394274899'	'Hydro'
	3.0	300	'9.070795653609091'	'1'	'0'	'0.5410429907657101'	7.0	'1.4382248303974'	'0'	'0'	'0'	'gen_3422_6'	'1.46636158179026'	'0'	'[0 0 0 0]'	'3.75828660446685'	'0.18743372169754'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.239014847423183'	'2'	1	180	'0'	'[0 0 0 0]'	'0'	'0'	56700	'2'	5.0	'0.0360380109102698'	'0.321553241912043'	'0'	'[0 0 0 0]'	'2'	'0.755177663953509'	'0.135713061690563'	'Renewable'	2.0	'0.239014847423183'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0946230090580741 0.33824450410502 0 0 0 0 0 0 0]'	'2.16417196306284'	'Hydro'
	3.0	550	'6.97784928334411'	'1'	'0'	'0.58663344774302'	3.0	'2.38811071860604'	'0'	'0'	'0'	'gen_3423_1'	'1.03591020514723'	'0'	'[0 0 0 0]'	'2.71856869414169'	'0.271956206222065'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.313211768131238'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0472164834095165'	'0.374671747592278'	'0'	'[0 0 0 0]'	'2'	'0.615954936782364'	'0.0680591719527729'	'Renewable'	2.0	'0.313211768131238'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.09498108428199779 0.29471710016448 0 0 0 0 0 0 0]'	'2.34653379097208'	'Wind'
	3.0	550	'6.99216537688626'	'1'	'0'	'0.6021013914016075'	3.0	'2.38183231748082'	'0'	'0'	'0'	'gen_3424_2'	'1.01008997280151'	'0'	'[0 0 0 0]'	'2.69100713427644'	'0.268802522245329'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.310896574940067'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0456134201057721'	'0.360658929898404'	'0'	'[0 0 0 0]'	'2'	'0.6238518974469039'	'0.0680016349351034'	'Renewable'	2.0	'0.310896574940067'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.09431959676947441 0.300689465802796 0 0 0 0 0 0 0]'	'2.40840556560643'	'Wind'
	3.0	550	'6.8380361740361'	'1'	'0'	'0.58602766990196'	3.0	'2.3776905409731'	'0'	'0'	'0'	'gen_3425_3'	'1.018040044792'	'0'	'[0 0 0 0]'	'2.70601596333087'	'0.262291630129796'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.314381588094635'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0466622058417415'	'0.36178484119568'	'0'	'[0 0 0 0]'	'2'	'0.624340658576926'	'0.068566897973977'	'Renewable'	2.0	'0.314381588094635'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.09837848503375431 0.301908637393909 0 0 0 0 0 0 0]'	'2.34411067960784'	'Wind'
	120.0	190	'6.89142244027462'	'1'	'0'	'0.6006789432642975'	20.0	'2.37170177614689'	'0'	'0'	'0'	'gen_3426_4'	'1.01466865255497'	'0'	'[0 0 0 0]'	'2.78368466207199'	'0.260394301671069'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.317155488227494'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.0470498466367135'	'0.364851457097568'	'0'	'[0 0 0 0]'	'2'	'0.6289099826193419'	'0.07094914040844889'	'Combustion'	40.0	'0.317155488227494'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.096046440549288 0.29969200202425 0 0 0 0 0 0 0]'	'2.40271577305719'	'Fossil'
	120.0	190	'5.13921708392445'	'1'	'0'	'0.577217709455405'	20.0	'1.6773203096858'	'0'	'0'	'0'	'gen_3430_1'	'2.03895327723585'	'0'	'[0 0 0 0]'	'2.74872787492443'	'0.278994397855829'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.300744122507051'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.0281393186561996'	'0.32652929502558'	'0'	'[0 0 0 0]'	'2'	'0.393120866359747'	'0.239056875193492'	'Combustion'	40.0	'0.300744122507051'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0982709180471487 0.301524968782146 0 0 0 0 0 0 0]'	'2.30887083782162'	'Fossil'
	3.0	550	'5.21611048839986'	'1'	'0'	'0.57261486406764'	3.0	'1.75171339861888'	'0'	'0'	'0'	'gen_3431_2'	'2.08348544691689'	'0'	'[0 0 0 0]'	'2.72372304161079'	'0.277044602485257'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.299484664914687'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.027697838442307'	'0.325070057422668'	'0'	'[0 0 0 0]'	'2'	'0.406744629743905'	'0.238239405105589'	'Renewable'	2.0	'0.299484664914687'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0971263587618247 0.290630471755229 0 0 0 0 0 0 0]'	'2.29045945627056'	'Wind'
	3.0	550	'9.62945421797982'	'1'	'0'	'0.4354186370585825'	3.0	'1.63401958680067'	'0'	'0'	'0'	'gen_3434_1'	'1.59715483102575'	'0'	'[0 0 0 0]'	'7.10239334703865'	'0.112458837043738'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.182454745493736'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0471132505866699'	'0.243421422506694'	'0'	'[0 0 0 0]'	'2'	'0.676707782286685'	'0.0756010422993917'	'Renewable'	2.0	'0.182454745493736'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.159174129848718 0.875452109647449 0 0 0 0 0 0 0]'	'1.74167454823433'	'Wind'
	3.0	550	'10.075610053159'	'1'	'0'	'0.4372074026148525'	3.0	'1.62910746678001'	'0'	'0'	'0'	'gen_3435_2'	'1.62233106968924'	'0'	'[0 0 0 0]'	'6.96282623333484'	'0.113130421920586'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.181810139138531'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0450799652872374'	'0.235475331413152'	'0'	'[0 0 0 0]'	'2'	'0.66835482379538'	'0.07645218429751691'	'Renewable'	2.0	'0.181810139138531'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.16086052753916 0.77851692851237 0 0 0 0 0 0 0]'	'1.74882961045941'	'Wind'
	100.0	600	'10.5812228892087'	'1'	'0'	'0.427048611814845'	5.0	'1.68207166656596'	'0'	'0'	'0'	'gen_3436_3'	'1.64749556288123'	'0'	'[0 0 0 0]'	'6.94982702993392'	'0.112414862059581'	550	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	350	'0.183731930937944'	'2'	1	595	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0460557944513857'	'0.232582163608365'	'0'	'[0 0 0 0]'	'2'	'0.667773232948966'	'0.0757992805988761'	'Combustion'	100.0	'0.183731930937944'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Distillate'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.139857704689354 0.694928226575279 0 0 0 0 0 0 0]'	'1.70819444725938'	'Fossil'
	120.0	190	'7.41282163191959'	'1'	'0'	'0.5656208392587025'	20.0	'2.24766059143685'	'0'	'0'	'0'	'gen_3437_4'	'0.554108337114216'	'0'	'[0 0 0 0]'	'3.14703987953276'	'0.197573733603896'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.260207124897318'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.0400270751188276'	'0.33568448709901'	'0'	'[0 0 0 0]'	'2'	'0.566703780147931'	'0.07693287145304489'	'Combustion'	40.0	'0.260207124897318'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0786652872574516 0.489276197398547 0 0 0 0 0 0 0]'	'2.26248335703481'	'Fossil'
	57.5	545	'13.7501555766666'	'1'	'0'	'0.6299167819390425'	12.5	'1.66677655987348'	'0'	'0'	'0'	'gen_3438_1'	'3.58677893648786'	'0'	'[0 0 0 0]'	'6.01690277789254'	'0.143520517237941'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	8.7	250	'0.169378895296929'	'2'	4	545	'0'	'[0 0 0 0]'	'0'	'0'	12100	'2'	62.5	'0.562812431588769'	'0.226013841770897'	'0'	'[0 0 0 0]'	'2'	'1.33642655266873'	'0.6233602077560501'	'Combustion'	52.5	'0.169378895296929'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	4	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.192392512983382 0.749744022292865 0 0 0 0 0 0 0]'	'2.51966712775617'	'Fossil'
	57.5	545	'13.5332678150258'	'1'	'0'	'0.5840767539287325'	12.5	'1.73738662648201'	'0'	'0'	'0'	'gen_3439_2'	'3.572616360866'	'0'	'[0 0 0 0]'	'6.05484230023809'	'0.143617800862212'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	8.7	250	'0.173830290560033'	'2'	4	545	'0'	'[0 0 0 0]'	'0'	'0'	12100	'2'	62.5	'0.0561062996534631'	'0.223073005936742'	'0'	'[0 0 0 0]'	'2'	'1.35569246493266'	'0.6290303697572091'	'Combustion'	52.5	'0.173830290560033'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	4	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.190450115207285 0.775795620411821 0 0 0 0 0 0 0]'	'2.33630701571493'	'Fossil'
	3.0	300	'6.49123385105608'	'1'	'0'	'0.4690290484931325'	7.0	'1.90396073045302'	'0'	'0'	'0'	'gen_3442_1'	'1.43420447916258'	'0'	'[0 0 0 0]'	'3.01790625403007'	'0.229095244088396'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.280788481080346'	'2'	1	180	'0'	'[0 0 0 0]'	'0'	'0'	56700	'2'	5.0	'0.03498675205498'	'0.33761339498919'	'0'	'[0 0 0 0]'	'2'	'0.539150571256271'	'0.0407677942737937'	'Renewable'	2.0	'0.280788481080346'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.127818385281716 0.44485959874437 0 0 0 0 0 0 0]'	'1.87611619397253'	'Hydro'
	120.0	190	'6.36829916049261'	'1'	'0'	'0.4808356375694275'	20.0	'1.94636825631536'	'0'	'0'	'0'	'gen_3443_2'	'1.46957646857947'	'0'	'[0 0 0 0]'	'3.0858770133506'	'0.229082102052402'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.272004663884919'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.0347444396400359'	'0.348516051633307'	'0'	'[0 0 0 0]'	'2'	'0.531549231579946'	'0.0406297421539202'	'Combustion'	40.0	'0.272004663884919'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.131087403011043 0.447417936634156 0 0 0 0 0 0 0]'	'1.92334255027771'	'Fossil'
	120.0	190	'6.53116008633329'	'1'	'0'	'0.462616370117815'	20.0	'1.89170319255325'	'0'	'0'	'0'	'gen_3444_1'	'1.41699244437274'	'0'	'[0 0 0 0]'	'2.85345358852949'	'0.223891816075658'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.244371353888186'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.0360051458599046'	'0.322514147432987'	'0'	'[0 0 0 0]'	'2'	'0.520653011214687'	'0.0471268866275903'	'Combustion'	40.0	'0.244371353888186'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.131461175711383 0.451748831035984 0 0 0 0 0 0 0]'	'1.85046548047126'	'Fossil'
	57.5	545	'8.16106135559008'	'1'	'0'	'0.356652551978605'	12.5	'0.8173371608082211'	'0'	'0'	'0'	'gen_3448_1'	'0.184429087537788'	'0'	'[0 0 0 0]'	'2.43705472178757'	'0.126975880239205'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	8.7	250	'0.20019613171611'	'1'	4	545	'0'	'[0 0 0 0]'	'0'	'0'	12100	'1'	62.5	'0.07114009471591561'	'0.324694296703194'	'0'	'[0 0 0 0]'	'2'	'0.20019613171611'	'0.01'	'Combustion'	52.5	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	4	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0906167020519232 0.263332975166002 0 0 0 0 0 0 0]'	'1.42661020791442'	'Fossil'
	57.5	545	'6.78570924373809'	'1'	'0'	'0.30697036185608'	12.5	'0.5403237317344169'	'0'	'0'	'0'	'gen_3449_2'	'0.160132405337552'	'0'	'[0 0 0 0]'	'3.22817093857541'	'0.166865420665592'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	8.7	250	'0.221875491310218'	'1'	4	545	'0'	'[0 0 0 0]'	'0'	'0'	12100	'1'	62.5	'0.0692698138938285'	'0.285440440901094'	'0'	'[0 0 0 0]'	'2'	'0.221875491310218'	'0.01'	'Combustion'	52.5	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	4	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.103165797910187 0.304445681607872 0 0 0 0 0 0 0]'	'1.22788144742432'	'Fossil'
	57.5	545	'6.12672656222945'	'1'	'0'	'0.2627915696300325'	12.5	'0.558998181402683'	'0'	'0'	'0'	'gen_3453_1'	'0.158503101532022'	'0'	'[0 0 0 0]'	'2.96793422286119'	'0.137558170996606'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	8.7	250	'0.180433868899941'	'1'	4	545	'0'	'[0 0 0 0]'	'0'	'0'	12100	'1'	62.5	'0.0562831844830886'	'0.257704870495945'	'0'	'[0 0 0 0]'	'2'	'0.180433868899941'	'0.01'	'Combustion'	52.5	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	4	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.107543722229227 0.339991694852011 0 0 0 0 0 0 0]'	'1.05116627852013'	'Fossil'
	57.5	545	'5.97985164252343'	'1'	'0'	'0.2758433507203775'	12.5	'0.553268195697572'	'0'	'0'	'0'	'gen_3454_2'	'0.152448674468719'	'0'	'[0 0 0 0]'	'3.04276347701065'	'0.139443754817708'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	8.7	250	'0.186795227232389'	'1'	4	545	'0'	'[0 0 0 0]'	'0'	'0'	12100	'1'	62.5	'0.0579157009681687'	'0.258397505886387'	'0'	'[0 0 0 0]'	'2'	'0.186795227232389'	'0.01'	'Combustion'	52.5	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	4	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.110582654210106 0.328403992902662 0 0 0 0 0 0 0]'	'1.10337340288151'	'Fossil'
	100.0	600	'5.91066214907914'	'1'	'0'	'0.2701580933232675'	5.0	'0.5450917308186179'	'0'	'0'	'0'	'gen_3455_3'	'0.152371044559637'	'0'	'[0 0 0 0]'	'3.05121519623231'	'0.135863187787472'	550	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	350	'0.184251038159709'	'1'	1	595	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0585304443674162'	'0.259573580621509'	'0'	'[0 0 0 0]'	'2'	'0.184251038159709'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Distillate'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.110161959833577 0.337843681309663 0 0 0 0 0 0 0]'	'1.08063237329307'	'Fossil'
	57.5	545	'5.96565050280886'	'1'	'0'	'0.2729835293692425'	12.5	'0.5663466325169429'	'0'	'0'	'0'	'gen_3456_4'	'0.153289203950041'	'0'	'[0 0 0 0]'	'3.06111575495359'	'0.139666955534485'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	8.7	250	'0.186317456903402'	'1'	4	545	'0'	'[0 0 0 0]'	'0'	'0'	12100	'1'	62.5	'0.0585229253903031'	'0.255758276960114'	'0'	'[0 0 0 0]'	'2'	'0.186317456903402'	'0.01'	'Combustion'	52.5	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	4	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.10631581778951 0.329448775223282 0 0 0 0 0 0 0]'	'1.09193411747697'	'Fossil'
	57.5	545	'5.90421553250868'	'1'	'0'	'0.268288888149715'	12.5	'0.549201534618158'	'0'	'0'	'0'	'gen_3457_5'	'0.158422106663394'	'0'	'[0 0 0 0]'	'3.01350850557629'	'0.135675959777785'	650	'[0.8 1.27 0 0 0 0 0 0 0 0]'	8.7	250	'0.188679827526212'	'1'	4	545	'0'	'[0 0 0 0]'	'0'	'0'	12100	'1'	62.5	'0.0570922884592786'	'0.25611996492371'	'0'	'[0 0 0 0]'	'2'	'0.188679827526212'	'0.01'	'Combustion'	52.5	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	4	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.109583096316978 0.342370632514881 0 0 0 0 0 0 0]'	'1.07315555259886'	'Waste'
	3.0	550	'9.988602927371399'	'1'	'0'	'0.659242306136585'	3.0	'2.60532179370057'	'0'	'0'	'0'	'gen_3462_1'	'2.56252056546509'	'0'	'[0 0 0 0]'	'6.02134603490704'	'0.20213662038655'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.240594708883669'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0459457762856036'	'0.356630612569861'	'0'	'[0 0 0 0]'	'2'	'0.65147003647997'	'0.153269049965311'	'Renewable'	2.0	'0.240594708883669'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.130303922620299 0.396977485469589 0 0 0 0 0 0 0]'	'2.63696922454634'	'Wind'
	3.0	550	'8.665996484808529'	'1'	'0'	'0.5600968019324924'	3.0	'2.07808341637021'	'0'	'0'	'0'	'gen_3463_1'	'2.57883605716052'	'0'	'[0 0 0 0]'	'4.51023245711694'	'0.135855539930798'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.175374579555728'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0503824694449548'	'0.273113670934318'	'0'	'[0 0 0 0]'	'2'	'0.472653432922438'	'0.150552357514389'	'Renewable'	2.0	'0.175374579555728'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.120702845322853 0.525762239581905 0 0 0 0 0 0 0]'	'2.24038720772997'	'Wind'
	3.0	550	'10.4732344514504'	'1'	'0'	'0.6467035999381625'	3.0	'2.1410347990822'	'0'	'0'	'0'	'gen_3464_1'	'3.45203370006289'	'0'	'[0 0 0 0]'	'6.28164900460839'	'0.234970570188016'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.241665739247855'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.045548999259132'	'0.292815330756642'	'0'	'[0 0 0 0]'	'2'	'1.5162614585096'	'0.422605552948779'	'Renewable'	2.0	'0.241665739247855'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.125669128373265 0.461689355796017 0 0 0 0 0 0 0]'	'2.58681439975265'	'Wind'
	3.0	550	'3.85515368472785'	'1'	'0'	'0.5354111614278525'	3.0	'1.07322426255606'	'0'	'0'	'0'	'gen_3466_1'	'0.800921465251595'	'0'	'[0 0 0 0]'	'0.889749546607677'	'0.100544154949021'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.174331337062223'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.486007277850062'	'0.264532680691266'	'0'	'[0 0 0 0]'	'2'	'1.0535195200108'	'0.0811903934385628'	'Renewable'	2.0	'0.174331337062223'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.254026163375238 0.748099787806929 0 0 0 0 0 0 0]'	'2.14164464571141'	'Wind'
	3.0	550	'10.5113917976534'	'1'	'0'	'0.6404796050221775'	3.0	'2.46432616055664'	'0'	'0'	'0'	'gen_3525_2'	'0.948073863982223'	'0'	'[0 0 0 0]'	'7.11769991533365'	'0.170384856407298'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.190478047210025'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0210824453208363'	'0.262067336944165'	'0'	'[0 0 0 0]'	'2'	'0.415023805266246'	'0.0322791219606996'	'Renewable'	2.0	'0.190478047210025'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.119813104767259 0.477150379756652 0 0 0 0 0 0 0]'	'2.56191842008871'	'Wind'
	3.0	550	'10.2293869178845'	'1'	'0'	'0.6591896275808675'	3.0	'2.39513134009298'	'0'	'0'	'0'	'gen_3526_3'	'0.965527558209607'	'0'	'[0 0 0 0]'	'7.18924208271783'	'0.170576797550311'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.196436051865341'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0218661442307755'	'0.260411747399485'	'0'	'[0 0 0 0]'	'2'	'0.414466611137614'	'0.0330936538539827'	'Renewable'	2.0	'0.196436051865341'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.121039913816038 0.482770825374545 0 0 0 0 0 0 0]'	'2.63675851032347'	'Wind'
	3.0	550	'10.5212591934707'	'1'	'0'	'0.6629519883183524'	3.0	'2.470071141202'	'0'	'0'	'0'	'gen_3527_1'	'0.9691151317872569'	'0'	'[0 0 0 0]'	'7.30375274606049'	'0.170470155445393'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.193139204173116'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0216991204970051'	'0.256666094687534'	'0'	'[0 0 0 0]'	'2'	'0.403817578935996'	'0.0326575705833733'	'Renewable'	2.0	'0.193139204173116'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.123148533204449 0.477072804204561 0 0 0 0 0 0 0]'	'2.65180795327341'	'Wind'
	3.0	550	'5.03132362128235'	'1'	'0'	'0.564136743018375'	3.0	'1.6770294983146'	'0'	'0'	'0'	'gen_3585_1'	'2.01377022638917'	'0'	'[0 0 0 0]'	'2.74490874500852'	'0.286182851218502'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.306198669456621'	'2'	1	535	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0281767686988693'	'0.321704444057308'	'0'	'[0 0 0 0]'	'2'	'0.402020928110299'	'0.23915942830476'	'Renewable'	2.0	'0.306198669456621'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.09769925569263289 0.296640700748144 0 0 0 0 0 0 0]'	'2.2565469720735'	'Wind'
	120.0	190	'5.03224208392203'	'1'	'0'	'0.568703848772885'	20.0	'1.74322218769863'	'0'	'0'	'0'	'gen_3586_2'	'2.04006330519915'	'0'	'[0 0 0 0]'	'2.73753789174743'	'0.279518983141054'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.296057862785854'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.027402938270336'	'0.31709007694535'	'0'	'[0 0 0 0]'	'2'	'0.403299651146959'	'0.238587287424132'	'Combustion'	40.0	'0.296057862785854'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0954707451985683 0.295126953427708 0 0 0 0 0 0 0]'	'2.27481539509154'	'Fossil'
	120.0	190	'5.168982744799'	'1'	'0'	'0.570048846006975'	20.0	'1.74486660734506'	'0'	'0'	'0'	'gen_3587_3'	'2.04926389493048'	'0'	'[0 0 0 0]'	'2.71798191038147'	'0.281319335393957'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.303982554954616'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.0273757392545929'	'0.320744155808352'	'0'	'[0 0 0 0]'	'2'	'0.404966220451379'	'0.239704781253589'	'Combustion'	40.0	'0.303982554954616'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0948291099937633 0.292491000939277 0 0 0 0 0 0 0]'	'2.2801953840279'	'Fossil'
	120.0	190	'5.13414660817944'	'1'	'0'	'0.5720967587517225'	20.0	'1.75201769268094'	'0'	'0'	'0'	'gen_3588_4'	'2.02966636954807'	'0'	'[0 0 0 0]'	'2.74790081625897'	'0.278137262566527'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.300327728850185'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.0273117118729278'	'0.319455117593519'	'0'	'[0 0 0 0]'	'2'	'0.409774367539654'	'0.234778617666801'	'Combustion'	40.0	'0.300327728850185'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.09550755948787561 0.297212320385221 0 0 0 0 0 0 0]'	'2.28838703500689'	'Fossil'
	120.0	190	'7.23080071737408'	'1'	'0'	'0.536179720030165'	20.0	'1.81843981607258'	'0'	'0'	'0'	'gen_3655_1'	'1.59401434882428'	'0'	'[0 0 0 0]'	'2.18888416496571'	'0.193236772105796'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.220684786459897'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.0209646982420236'	'0.306154155093245'	'0'	'[0 0 0 0]'	'2'	'1.05026188927819'	'0.251462698238902'	'Combustion'	40.0	'0.220684786459897'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.07986746050357819 0.244492200583038 0 0 0 0 0 0 0]'	'2.14471888012066'	'Fossil'
	120.0	190	'7.16370960273896'	'1'	'0'	'0.5421152264690025'	20.0	'1.80948558315402'	'0'	'0'	'0'	'gen_3656_2'	'1.55405060914112'	'0'	'[0 0 0 0]'	'2.2019494577134'	'0.196368822226766'	1500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	1.0	500	'0.227739578544162'	'2'	8	195	'0'	'[0 0 0 0]'	'0'	'0'	53700	'2'	350.0	'0.0209569999435917'	'0.304449887098744'	'0'	'[0 0 0 0]'	'2'	'1.08558250523871'	'0.25156340522808'	'Combustion'	40.0	'0.227739578544162'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Coal'	8	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0786993845665455 0.243997724476 0 0 0 0 0 0 0]'	'2.16846090587601'	'Fossil'
	100.0	410	'9.17843924118206'	'1'	'0'	'0.2934641098859725'	5.0	'0.5844911312768239'	'0'	'0'	'0'	'gen_4003_1'	'0.156655647353036'	'0'	'[0 0 0 0]'	'3.97934499998158'	'0.15678730553831'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.187902769177337'	'1'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.054201855822932'	'0.283242659330368'	'0'	'[0 0 0 0]'	'2'	'0.187902769177337'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.130051803027513 0.593210874324664 0 0 0 0 0 0 0]'	'1.17385643954389'	'Fossil'
	100.0	410	'9.36529112092685'	'1'	'0'	'0.289299014913675'	5.0	'0.591163104061037'	'0'	'0'	'0'	'gen_4007_1'	'0.154809081167914'	'0'	'[0 0 0 0]'	'4.09748774960963'	'0.155252380674938'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.187455511361128'	'1'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0526004907934926'	'0.289727672589943'	'0'	'[0 0 0 0]'	'2'	'0.187455511361128'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.135579899418633 0.587289435290266 0 0 0 0 0 0 0]'	'1.1571960596547'	'Fossil'
	100.0	410	'9.292492064600809'	'1'	'0'	'0.295109193776735'	5.0	'0.599822156392038'	'0'	'0'	'0'	'gen_4008_1'	'0.153276560122613'	'0'	'[0 0 0 0]'	'3.93874299145839'	'0.151160391656449'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.192075576484087'	'1'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0529066271455958'	'0.285328818768263'	'0'	'[0 0 0 0]'	'2'	'0.192075576484087'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.132764551453758 0.608734394371044 0 0 0 0 0 0 0]'	'1.18043677510694'	'Fossil'
	100.0	410	'6.92759781420697'	'1'	'0'	'0.8276675732114825'	5.0	'2.90521842113486'	'0'	'0'	'0'	'gen_4027_1'	'2.21503148312215'	'0'	'[0 0 0 0]'	'0.638568286315212'	'0.206326000192203'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.291972666970454'	'2'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0410523054329678'	'0.364900018619536'	'0'	'[0 0 0 0]'	'2'	'0.524982509855181'	'0.0402912167338654'	'Combustion'	100.0	'0.291972666970454'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.146712868638802 0.413700690531591 0 0 0 0 0 0 0]'	'3.31067029284593'	'Fossil'
	100.0	410	'6.74260334243998'	'1'	'0'	'0.7959422592825725'	5.0	'2.9652172489115'	'0'	'0'	'0'	'gen_4028_1'	'2.21459018998314'	'0'	'[0 0 0 0]'	'0.650970138574322'	'0.205050811241381'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.292826108609908'	'2'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.041636662135832'	'0.360967097370303'	'0'	'[0 0 0 0]'	'2'	'0.520752102683764'	'0.0414714867752045'	'Combustion'	100.0	'0.292826108609908'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.14277624659054 0.404808979857806 0 0 0 0 0 0 0]'	'3.18376903713029'	'Fossil'
	100.0	410	'6.8490337250568'	'1'	'0'	'0.795947279379935'	5.0	'2.94997158876411'	'0'	'0'	'0'	'gen_4029_1'	'2.22632003779057'	'0'	'[0 0 0 0]'	'0.635884067243268'	'0.208778605675325'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.287282751769409'	'2'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0408653176035732'	'0.367285415659053'	'0'	'[0 0 0 0]'	'2'	'0.52246138874907'	'0.0403539084820077'	'Combustion'	100.0	'0.287282751769409'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.145386544555426 0.40066567151933 0 0 0 0 0 0 0]'	'3.18378911751974'	'Fossil'
	100.0	410	'6.90915627587121'	'1'	'0'	'0.8114360498571775'	5.0	'2.89404749008431'	'0'	'0'	'0'	'gen_4030_1'	'2.21485167982522'	'0'	'[0 0 0 0]'	'0.630729210312665'	'0.207042969288304'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.297246730734827'	'2'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0410489713214338'	'0.37042945535311'	'0'	'[0 0 0 0]'	'2'	'0.518581234419253'	'0.0408038992714137'	'Combustion'	100.0	'0.297246730734827'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.145483384316321 0.411864801630704 0 0 0 0 0 0 0]'	'3.24574419942871'	'Fossil'
	100.0	410	'6.68756683983374'	'1'	'0'	'0.8084679086366675'	5.0	'2.93847436736571'	'0'	'0'	'0'	'gen_4033_1'	'2.22052502406761'	'0'	'[0 0 0 0]'	'0.639498501921888'	'0.207235419228673'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.295284240628593'	'2'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0410490254191682'	'0.355066767665744'	'0'	'[0 0 0 0]'	'2'	'0.514116341434419'	'0.0419163630865514'	'Combustion'	100.0	'0.295284240628593'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.144497200919781 0.399766729901964 0 0 0 0 0 0 0]'	'3.23387163454667'	'Fossil'
	100.0	410	'6.62671143864747'	'1'	'0'	'0.8162936026647225'	5.0	'3.03361017050082'	'0'	'0'	'0'	'gen_4034_1'	'2.24587251405232'	'0'	'[0 0 0 0]'	'0.627455456197425'	'0.203006632858887'	0	'[0.8 1.27 0 0 0 0 0 0 0 0]'	8.0	0	'0.293150664801244'	'2'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	12500	'2'	200.0	'0.0409542281460017'	'0.35693370004138'	'0'	'[0 0 0 0]'	'2'	'0.518068545253482'	'0.0406969609949738'	'Combustion'	100.0	'0.293150664801244'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Biomass'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.141204250569455 0.413058329032175 0 0 0 0 0 0 0]'	'3.26517441065889'	'Biomass'
	100.0	410	'6.7742420677375'	'1'	'0'	'0.8088157449744175'	5.0	'3.02947285106359'	'0'	'0'	'0'	'gen_4035_1'	'2.20991613238119'	'0'	'[0 0 0 0]'	'0.635680062490469'	'0.205308668892831'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.296604644083651'	'2'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0418790184557438'	'0.368124124032655'	'0'	'[0 0 0 0]'	'2'	'0.505550011212472'	'0.0416608289591968'	'Combustion'	100.0	'0.296604644083651'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.14528441200126 0.403249115825677 0 0 0 0 0 0 0]'	'3.23526297989767'	'Fossil'
	100.0	410	'6.72339465667494'	'1'	'0'	'0.829442892221735'	5.0	'2.99994834688795'	'0'	'0'	'0'	'gen_4036_1'	'2.28254319244996'	'0'	'[0 0 0 0]'	'0.631181208406319'	'0.203116274396889'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.289618320174166'	'2'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0407950328448787'	'0.362317013765639'	'0'	'[0 0 0 0]'	'2'	'0.504290030198172'	'0.0415979244560003'	'Combustion'	100.0	'0.289618320174166'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.144726410932373 0.403998799578985 0 0 0 0 0 0 0]'	'3.31777156888694'	'Fossil'
	3.0	300	'9.43565296875313'	'1'	'0'	'0.2951559283213575'	7.0	'0.589005427686963'	'0'	'0'	'0'	'gen_4051_1'	'0.150356083600782'	'0'	'[0 0 0 0]'	'4.07913892430207'	'0.151992672766792'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.19326474353706'	'1'	1	180	'0'	'[0 0 0 0]'	'0'	'0'	12500	'1'	5.0	'0.0530004094565287'	'0.288138393905014'	'0'	'[0 0 0 0]'	'2'	'0.19326474353706'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.130269146872917 0.596963295393623 0 0 0 0 0 0 0]'	'1.18062371328543'	'Hydro'
	3.0	700	'5.96803053396195'	'1'	'0'	'0.5965474841522524'	3.0	'2.16149507364677'	'0'	'0'	'0'	'gen_4052_11'	'1.01625046047312'	'0'	'[0 0 0 0]'	'9.209414504291489'	'0.150394752274733'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.177066295860335'	'2'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0229278964031488'	'0.223018523057457'	'0'	'[0 0 0 0]'	'2'	'0.351871006223373'	'0.0346846397274174'	'Renewable'	2.0	'0.177066295860335'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.122499680684879 0.47059609410353 0 0 0 0 0 0 0]'	'2.38618993660901'	'Wind'
	3.0	700	'6.06553120166436'	'1'	'0'	'0.6036265549005475'	3.0	'2.14257960294001'	'0'	'0'	'0'	'gen_4053_12'	'1.01559444761742'	'0'	'[0 0 0 0]'	'9.063417786185161'	'0.157130740061402'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.178184728439432'	'2'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0228931397322565'	'0.227537203013897'	'0'	'[0 0 0 0]'	'2'	'0.358970360463718'	'0.0340843847026583'	'Renewable'	2.0	'0.178184728439432'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.125413441236131 0.484584687893512 0 0 0 0 0 0 0]'	'2.41450621960219'	'Wind'
	100.0	410	'6.03764258647151'	'1'	'0'	'0.58947345005552'	5.0	'2.14296053675888'	'0'	'0'	'0'	'gen_4054_18'	'1.03706964065926'	'0'	'[0 0 0 0]'	'8.14038782794727'	'0.155965819212142'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.176058569985325'	'2'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0229919012343977'	'0.23191395131615'	'0'	'[0 0 0 0]'	'2'	'0.367635045382194'	'0.034806307345489'	'Combustion'	100.0	'0.176058569985325'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.13204855687893 0.430876162364613 0 0 0 0 0 0 0]'	'2.35789380022208'	'Fossil'
	100.0	410	'5.63698048211052'	'1'	'0'	'0.54238441960048'	5.0	'1.59470540627162'	'0'	'0'	'0'	'gen_4058_1'	'0.726625784244388'	'0'	'[0 0 0 0]'	'5.4514807471307'	'0.206327513656579'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.307269243356395'	'2'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0506218219106086'	'0.33853507436784'	'0'	'[0 0 0 0]'	'2'	'0.419636959563941'	'0.102953386534937'	'Combustion'	100.0	'0.307269243356395'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.171841255335836 0.517091084865388 0 0 0 0 0 0 0]'	'2.16953767840192'	'Fossil'
	3.0	700	'5.81185808123206'	'1'	'0'	'0.5221725440230225'	3.0	'1.62818475317373'	'0'	'0'	'0'	'gen_4059_2'	'0.724394014978316'	'0'	'[0 0 0 0]'	'5.32272242852952'	'0.205749020562507'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.301625064722481'	'2'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0516085953789297'	'0.335911991840135'	'0'	'[0 0 0 0]'	'2'	'0.416023704865947'	'0.104392981084529'	'Renewable'	2.0	'0.301625064722481'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.177794018537272 0.512371368694585 0 0 0 0 0 0 0]'	'2.08869017609209'	'Wind'
	100.0	410	'5.6157100670028'	'1'	'0'	'0.5310093617159874'	5.0	'1.66299619626347'	'0'	'0'	'0'	'gen_4061_4'	'0.719611669196747'	'0'	'[0 0 0 0]'	'5.38528578400845'	'0.201001975690015'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.300271373260999'	'2'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0519176516891457'	'0.336042857806105'	'0'	'[0 0 0 0]'	'2'	'0.400268676634878'	'0.100536718044896'	'Combustion'	100.0	'0.300271373260999'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.171242699662223 0.5128988242358899 0 0 0 0 0 0 0]'	'2.12403744686395'	'Fossil'
	3.0	700	'6.40017122149468'	'1'	'0'	'0.48675963286485'	3.0	'1.98192206219537'	'0'	'0'	'0'	'gen_4062_1'	'1.20413972176285'	'0'	'[0 0 0 0]'	'3.71073684319854'	'0.203523496957496'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.225983217998967'	'2'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0405958254551515'	'0.282545331689436'	'0'	'[0 0 0 0]'	'2'	'0.570550813626498'	'0.0331877614304423'	'Renewable'	2.0	'0.225983217998967'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.133453439018223 0.572741040422116 0 0 0 0 0 0 0]'	'1.9470385314594'	'Wind'
	3.0	700	'6.45610193923116'	'1'	'0'	'0.50477326384012'	3.0	'1.99154805296706'	'0'	'0'	'0'	'gen_4064_3'	'1.23758522977959'	'0'	'[0 0 0 0]'	'3.76831985305063'	'0.205531044285744'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.219337989206985'	'2'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0407054398311302'	'0.286583961114474'	'0'	'[0 0 0 0]'	'2'	'0.581868880489841'	'0.0325030825398862'	'Renewable'	2.0	'0.219337989206985'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.132293339465745 0.5578299672517461 0 0 0 0 0 0 0]'	'2.01909305536048'	'Wind'
	3.0	700	'6.6274527862668'	'1'	'0'	'0.50358357649867'	3.0	'1.98178839047998'	'0'	'0'	'0'	'gen_4065_4'	'1.22703910976136'	'0'	'[0 0 0 0]'	'3.66887286957353'	'0.208191523430869'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.223078246046975'	'2'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0418088025366887'	'0.281459558275994'	'0'	'[0 0 0 0]'	'2'	'0.560561018139124'	'0.0325258976228535'	'Renewable'	2.0	'0.223078246046975'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.132835075129289 0.567994472252904 0 0 0 0 0 0 0]'	'2.01433430599468'	'Wind'
	3.0	700	'13.1314481748268'	'1'	'0'	'0.60153904773295'	3.0	'1.7430849492806'	'0'	'0'	'0'	'gen_4066_1'	'3.29759017562494'	'0'	'[0 0 0 0]'	'6.96312351168133'	'0.155368680819869'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.181146601661108'	'2'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0204176598712802'	'0.224632904800586'	'0'	'[0 0 0 0]'	'2'	'0.885276040819683'	'0.0916507558718789'	'Renewable'	2.0	'0.181146601661108'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.172373836642802 0.457313768823195 0 0 0 0 0 0 0]'	'2.4061561909318'	'Wind'
	3.0	300	'11.023837137199'	'1'	'0'	'0.464406105964735'	7.0	'1.55376504692249'	'0'	'0'	'0'	'gen_4067_2'	'1.50445765501354'	'0'	'[0 0 0 0]'	'4.62459111272357'	'0.166284906353592'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.217818839299027'	'2'	1	180	'0'	'[0 0 0 0]'	'0'	'0'	56700	'2'	5.0	'0.0203490700470284'	'0.25109557152912'	'0'	'[0 0 0 0]'	'2'	'0.6944936321191491'	'0.124218902628869'	'Renewable'	2.0	'0.217818839299027'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.112281255816171 0.579237865740879 0 0 0 0 0 0 0]'	'1.85762442385894'	'Hydro'
	100.0	410	'5.24826739054872'	'1'	'0'	'0.4955897862495625'	5.0	'1.0053735620528'	'0'	'0'	'0'	'gen_4072_1'	'2.84290729199213'	'0'	'[0 0 0 0]'	'1.98785841308534'	'0.158843087055115'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.234599338155985'	'2'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0405561378989369'	'0.283952252129093'	'0'	'[0 0 0 0]'	'2'	'0.368525704099913'	'0.0327926296308637'	'Combustion'	100.0	'0.234599338155985'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.217126812126255 0.854401902809273 0 0 0 0 0 0 0]'	'1.98235914499825'	'Fossil'
	100.0	410	'9.29321550414898'	'1'	'0'	'0.2874148914692925'	5.0	'0.600045177151449'	'0'	'0'	'0'	'gen_4078_11'	'0.156875069002854'	'0'	'[0 0 0 0]'	'3.91619372858945'	'0.150826305462979'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.188476831981447'	'1'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0534858602050692'	'0.281397389925085'	'0'	'[0 0 0 0]'	'2'	'0.188476831981447'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.132571890313644 0.586623261474539 0 0 0 0 0 0 0]'	'1.14965956587717'	'Fossil'
	3.0	300	'9.000116564193741'	'1'	'0'	'0.2894250309343325'	7.0	'0.593313001164701'	'0'	'0'	'0'	'gen_4079_12'	'0.152052130030934'	'0'	'[0 0 0 0]'	'3.94851786133042'	'0.152027188693173'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.192326170376968'	'1'	1	180	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0530122577400878'	'0.282097413945943'	'0'	'[0 0 0 0]'	'2'	'0.192326170376968'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.132173920214409 0.584840002771933 0 0 0 0 0 0 0]'	'1.15770012373733'	'Hydro'
	100.0	410	'9.233899371488951'	'1'	'0'	'0.2834964207565075'	5.0	'0.600816943613812'	'0'	'0'	'0'	'gen_4081_2'	'0.155092288947199'	'0'	'[0 0 0 0]'	'3.9770387449814'	'0.156753281643614'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.192364343761466'	'1'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0524527228628285'	'0.286708662318997'	'0'	'[0 0 0 0]'	'2'	'0.192364343761466'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.133919472242007 0.592968022181187 0 0 0 0 0 0 0]'	'1.13398568302603'	'Fossil'
	3.0	700	'9.395676630106751'	'1'	'0'	'0.29221099415829'	3.0	'0.5979652850278649'	'0'	'0'	'0'	'gen_4082_3'	'0.152527046041796'	'0'	'[0 0 0 0]'	'3.94146927141561'	'0.153208841144806'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.191972146908753'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0532631505943835'	'0.28833330417797'	'0'	'[0 0 0 0]'	'2'	'0.191972146908753'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.130500552000711 0.590768476321362 0 0 0 0 0 0 0]'	'1.16884397663316'	'Wind'
	100.0	410	'9.072410927480091'	'1'	'0'	'0.292150312308165'	5.0	'0.597276761271991'	'0'	'0'	'0'	'gen_4083_4'	'0.154496698463336'	'0'	'[0 0 0 0]'	'4.03938563412428'	'0.153164466423914'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.18944713531679'	'1'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.054348768913094'	'0.281930342026055'	'0'	'[0 0 0 0]'	'2'	'0.18944713531679'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.13162055727141 0.580039693395607 0 0 0 0 0 0 0]'	'1.16860124923266'	'Fossil'
	3.0	910	'8.74702504477464'	'1'	'0'	'0.2488115041930125'	7.0	'0.821763478043268'	'0'	'0'	'0'	'gen_5004_1'	'0.132720764507353'	'0'	'[0 0 0 0]'	'3.66786438781908'	'0.18852995700622'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.261126842256635'	'1'	1	915	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0711697793488857'	'0.344339294709731'	'0'	'[0 0 0 0]'	'2'	'0.261126842256635'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.126354949656867 0.668281596952546 0 0 0 0 0 0 0]'	'0.99524601677205'	'Hydro'
	3.0	9740	'10.4756066911179'	'1'	'0'	'0.2942086525436025'	3.0	'0.716933679748327'	'0'	'0'	'0'	'gen_5005_2'	'0.0499426819268614'	'0'	'[0 0 0 0]'	'3.83138867123635'	'0.18503765401477'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.340287405041512'	'1'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.082799718471244'	'0.38534526446485'	'0'	'[0 0 0 0]'	'2'	'0.340287405041512'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.16493288499862 0.360802925336175 0 0 0 0 0 0 0]'	'1.17683461017441'	'Wind'
	3.0	910	'7.59521613064688'	'1'	'0'	'0.252783072046935'	7.0	'0.553383511886001'	'0'	'0'	'0'	'gen_5006_1'	'0.174535932511487'	'0'	'[0 0 0 0]'	'3.80142738206545'	'0.101724166010972'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.145292613220634'	'1'	1	915	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.07492338583823289'	'0.174827369039645'	'0'	'[0 0 0 0]'	'2'	'0.145292613220634'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.184031333498284 0.542391815814152 0 0 0 0 0 0 0]'	'1.01113228818774'	'Hydro'
	3.0	910	'8.23614376574289'	'1'	'0'	'0.31643721961882'	7.0	'0.839073885753751'	'0'	'0'	'0'	'gen_5008_1'	'0.563970345699927'	'0'	'[0 0 0 0]'	'3.20729808327276'	'0.142380864560977'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.260877983275335'	'1'	1	915	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.220169016325381'	'0.388478278086521'	'0'	'[0 0 0 0]'	'2'	'0.260877983275335'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.128608798471396 0.457621719811577 0 0 0 0 0 0 0]'	'1.26574887847528'	'Hydro'
	100.0	600	'9.55923343802802'	'1'	'0'	'0.3234723457974025'	5.0	'0.7116745720347391'	'0'	'0'	'0'	'gen_5010_1'	'0.221254664713051'	'0'	'[0 0 0 0]'	'3.17207759841112'	'0.153043946614489'	550	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	350	'0.248701347889379'	'1'	1	595	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.08602358342721129'	'0.315454478991916'	'0'	'[0 0 0 0]'	'2'	'0.248701347889379'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Distillate'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.155571648985008 0.502723538072314 0 0 0 0 0 0 0]'	'1.29388938318961'	'Fossil'
	100.0	410	'6.1387404654175'	'1'	'0'	'0.31332075052592'	5.0	'0.6501649588178841'	'0'	'0'	'0'	'gen_5012_1'	'0.185631442188285'	'0'	'[0 0 0 0]'	'3.01769822124741'	'0.154325268304674'	0	'[0.8 1.27 0 0 0 0 0 0 0 0]'	8.0	0	'0.209052208983339'	'1'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	12500	'1'	200.0	'0.0487754687140929'	'0.282818324382417'	'0'	'[0 0 0 0]'	'2'	'0.209052208983339'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Biomass'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.226847723557148 0.756103740836726 0 0 0 0 0 0 0]'	'1.25328300210368'	'Biomass'
	100.0	600	'9.081384618370789'	'1'	'0'	'0.6207415717325649'	5.0	'1.9367207089148'	'0'	'0'	'0'	'gen_5016_6'	'0.820173190496862'	'0'	'[0 0 0 0]'	'1.25006516969763'	'0.148048650905234'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.192224249258754'	'2'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	14200	'2'	100.0	'0.0501156165834982'	'0.202967797270976'	'0'	'[0 0 0 0]'	'2'	'0.261927351441234'	'0.0513946956919972'	'Combustion'	100.0	'0.192224249258754'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0781780890945811 0.389785741567006 0 0 0 0 0 0 0]'	'2.48296628693026'	'Fossil'
	3.0	9740	'8.84829626792343'	'1'	'0'	'0.5157990052463125'	3.0	'1.74826330939308'	'0'	'0'	'0'	'gen_5017_1'	'1.2809844690403'	'0'	'[0 0 0 0]'	'6.32548919849815'	'0.107299279139843'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.157140769721009'	'2'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0700780015490018'	'0.193334957496822'	'0'	'[0 0 0 0]'	'2'	'0.625304266330786'	'0.0902931747429538'	'Renewable'	2.0	'0.157140769721009'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.198745998335816 0.771605615922101 0 0 0 0 0 0 0]'	'2.06319602098525'	'Wind'
	3.0	9740	'5.73168120799819'	'1'	'0'	'0.5749339060363124'	3.0	'1.91000741438824'	'0'	'0'	'0'	'gen_5018_2'	'0.507553317747079'	'0'	'[0 0 0 0]'	'7.12228956878535'	'0.146977232673694'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.185621718681883'	'2'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'2'	5.0	'0.0205177206187509'	'0.255677304739668'	'0'	'[0 0 0 0]'	'2'	'0.627477423870005'	'0.0209077860121615'	'Renewable'	2.0	'0.185621718681883'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.12254166426044 0.553614712604321 0 0 0 0 0 0 0]'	'2.29973562414525'	'Wind'
	100.0	600	'5.08864011024823'	'1'	'0'	'0.329393194384175'	5.0	'0.86042637053947'	'0'	'0'	'0'	'gen_5019_1'	'0.0506473413563799'	'0'	'[0 0 0 0]'	'3.5755401427187'	'0.184275091849733'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.226428245000541'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0403257830180228'	'0.290093605467817'	'0'	'[0 0 0 0]'	'2'	'0.226428245000541'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.148136353833452 0.373060623571973 0 0 0 0 0 0 0]'	'1.3175727775367'	'Fossil'
	100.0	600	'8.1213656418398'	'1'	'0'	'0.3810283620997225'	5.0	'1.01153627024861'	'0'	'0'	'0'	'gen_5020_1'	'0.052081095239846'	'0'	'[0 0 0 0]'	'2.83653903900413'	'0.134963406756986'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.311260443435982'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0510424262552988'	'0.331986889290344'	'0'	'[0 0 0 0]'	'2'	'0.311260443435982'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0366475281999447 0.260852762719151 0 0 0 0 0 0 0]'	'1.52411344839889'	'Fossil'
	100.0	600	'7.74166894327733'	'1'	'0'	'0.3277596861496575'	5.0	'0.844808232254558'	'0'	'0'	'0'	'gen_5021_4'	'0.0520080470480025'	'0'	'[0 0 0 0]'	'2.793804211932'	'0.113523972480558'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.202375394717208'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0520592333364766'	'0.221801029459969'	'0'	'[0 0 0 0]'	'2'	'0.202375394717208'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0756900096446276 0.255148485631705 0 0 0 0 0 0 0]'	'1.31103874459863'	'Fossil'
	3.0	9740	'8.794950967328621'	'1'	'0'	'0.2781714209972425'	3.0	'0.689297532958444'	'0'	'0'	'0'	'gen_5022_1'	'0.296337645051768'	'0'	'[0 0 0 0]'	'3.10728719173116'	'0.198508361308137'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.236117589125643'	'1'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0571208542329259'	'0.323259469884913'	'0'	'[0 0 0 0]'	'2'	'0.236117589125643'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0483750213727355 0.220065048394725 0 0 0 0 0 0 0]'	'1.11268568398897'	'Wind'
	3.0	910	'8.505664929847701'	'1'	'0'	'0.2951254563045225'	7.0	'0.678727157317801'	'0'	'0'	'0'	'gen_5023_2'	'0.296561451896094'	'0'	'[0 0 0 0]'	'3.05276727499324'	'0.191337353344774'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.230609839008423'	'1'	1	915	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0552932796410751'	'0.292724154486554'	'0'	'[0 0 0 0]'	'2'	'0.230609839008423'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.061208732411731 0.234609147235518 0 0 0 0 0 0 0]'	'1.18050182521809'	'Hydro'
	3.0	9740	'8.890312088392671'	'1'	'0'	'0.2791817630784925'	3.0	'0.680790583598427'	'0'	'0'	'0'	'gen_5026_5'	'0.300883624962764'	'0'	'[0 0 0 0]'	'3.05742282888037'	'0.197707602338633'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.236424257267034'	'1'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0573895943954121'	'0.290301190034254'	'0'	'[0 0 0 0]'	'2'	'0.236424257267034'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0458928027772461 0.212981410968583 0 0 0 0 0 0 0]'	'1.11672705231397'	'Wind'
	100.0	410	'5.2067745354725'	'1'	'0'	'0.3817076594338275'	5.0	'0.931190368100046'	'0'	'0'	'0'	'gen_5028_1'	'0.0504008927976247'	'0'	'[0 0 0 0]'	'3.34441089279763'	'0.146029489391949'	0	'[0.8 1.27 0 0 0 0 0 0 0 0]'	8.0	0	'0.19172438368178'	'1'	1	300	'0'	'[0 0 0 0]'	'0'	'0'	12500	'1'	200.0	'0.0510837835329585'	'0.298232134659123'	'0'	'[0 0 0 0]'	'2'	'0.19172438368178'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Biomass'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.103439713951666 0.516975282889325 0 0 0 0 0 0 0]'	'1.52683063773531'	'Biomass'
	3.0	9740	'8.64943542546825'	'1'	'0'	'0.3485029874456825'	3.0	'0.736305897139013'	'0'	'0'	'0'	'gen_5030_1'	'0.180747697769199'	'0'	'[0 0 0 0]'	'3.7682907769829'	'0.140662283638492'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.235786713897018'	'1'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0854219186349074'	'0.343287756925263'	'0'	'[0 0 0 0]'	'2'	'0.235786713897018'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.170116121705621 0.562692960999906 0 0 0 0 0 0 0]'	'1.39401194978273'	'Wind'
	100.0	600	'9.041361163789411'	'1'	'0'	'0.284239473331895'	5.0	'0.59993613721244'	'0'	'0'	'0'	'gen_5031_1'	'0.154765920261852'	'0'	'[0 0 0 0]'	'3.99882500327495'	'0.150000232957536'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.189779104838148'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0537578068670817'	'0.293749337338842'	'0'	'[0 0 0 0]'	'2'	'0.189779104838148'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.131990863871295 0.587945094942581 0 0 0 0 0 0 0]'	'1.13695789332758'	'Fossil'
	3.0	9740	'9.287123952137771'	'1'	'0'	'0.2913045119952575'	3.0	'0.536486257723533'	'0'	'0'	'0'	'gen_5032_2'	'0.100951359749306'	'0'	'[0 0 0 0]'	'3.96614725872991'	'0.151001792532625'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.193999882639735'	'1'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0103272682637908'	'0.251639862527372'	'0'	'[0 0 0 0]'	'2'	'0.193999882639735'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.16173102060263 0.625932889161631 0 0 0 0 0 0 0]'	'1.16521804798103'	'Wind'
	100.0	600	'9.075324358544311'	'1'	'0'	'0.33033053490864'	5.0	'0.730186092278571'	'0'	'0'	'0'	'gen_5033_3'	'0.0503834899619687'	'0'	'[0 0 0 0]'	'3.97437572812242'	'0.153649799219565'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.197674625989841'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.06294329689163709'	'0.20045689177108'	'0'	'[0 0 0 0]'	'2'	'0.197674625989841'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.21758591457447 0.723073925689096 0 0 0 0 0 0 0]'	'1.32132213963456'	'Fossil'
	3.0	9740	'6.81108015392441'	'1'	'0'	'0.3324290807856025'	3.0	'0.779741670365911'	'0'	'0'	'0'	'gen_5035_3'	'0.250154000217095'	'0'	'[0 0 0 0]'	'4.3367640540353'	'0.152719729563687'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.270542959116865'	'1'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.09003412593388931'	'0.35684469100507'	'0'	'[0 0 0 0]'	'2'	'0.270542959116865'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.155825510529103 0.375505177639891 0 0 0 0 0 0 0]'	'1.32971632314241'	'Wind'
	100.0	600	'4.74182861999143'	'1'	'0'	'0.328477779476205'	5.0	'0.810418596626027'	'0'	'0'	'0'	'gen_5036_2'	'0.0521088133030571'	'0'	'[0 0 0 0]'	'3.6387557173972'	'0.12207409822382'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.202567852386343'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0503703514533118'	'0.276278702782234'	'0'	'[0 0 0 0]'	'2'	'0.202567852386343'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.130004509726446 0.3844666306603 0 0 0 0 0 0 0]'	'1.31391111790482'	'Fossil'
	3.0	9740	'9.36225530854426'	'1'	'0'	'0.3417731959463575'	3.0	'0.773800725478213'	'0'	'0'	'0'	'gen_5037_1'	'0.124031776573509'	'0'	'[0 0 0 0]'	'4.44698162184097'	'0.120166825281456'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.154590323728044'	'1'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.120159769652411'	'0.268367017591372'	'0'	'[0 0 0 0]'	'2'	'0.154590323728044'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.10233863189118 0.315026509076357 0 0 0 0 0 0 0]'	'1.36709278378543'	'Wind'
	3.0	9740	'9.23990161442198'	'1'	'0'	'0.345817406959365'	3.0	'0.759295067272615'	'0'	'0'	'0'	'gen_5039_3'	'0.124749082532711'	'0'	'[0 0 0 0]'	'4.76331831911812'	'0.12255032122694'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.151491135660326'	'1'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.121516685611568'	'0.26482190166926'	'0'	'[0 0 0 0]'	'2'	'0.151491135660326'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.104359039773699 0.325621367128682 0 0 0 0 0 0 0]'	'1.38326962783746'	'Wind'
	3.0	9740	'9.168173366552219'	'1'	'0'	'0.33797765557235'	3.0	'0.771706657495815'	'0'	'0'	'0'	'gen_5040_4'	'0.124714353952557'	'0'	'[0 0 0 0]'	'4.7692725137691'	'0.121783336702734'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.15076357232756'	'1'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.120458483378403'	'0.262631974991411'	'0'	'[0 0 0 0]'	'2'	'0.15076357232756'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.104809342531953 0.330422795515973 0 0 0 0 0 0 0]'	'1.3519106222894'	'Wind'
	3.0	9740	'9.34968512048945'	'1'	'0'	'0.3381369468171625'	3.0	'0.764464471541578'	'0'	'0'	'0'	'gen_5041_5'	'0.125774919527583'	'0'	'[0 0 0 0]'	'4.70445267175557'	'0.122313331592828'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.152875007173279'	'1'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.123486709968187'	'0.263262884269469'	'0'	'[0 0 0 0]'	'2'	'0.152875007173279'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.103324919275474 0.319894299880718 0 0 0 0 0 0 0]'	'1.35254778726865'	'Wind'
	3.0	910	'9.225314274639819'	'1'	'0'	'0.2931414341859625'	7.0	'0.601463688726537'	'0'	'0'	'0'	'gen_5045_1'	'0.15217215720797'	'0'	'[0 0 0 0]'	'3.97084814723791'	'0.150901294900104'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.187590657388442'	'1'	1	915	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0534204910303466'	'0.282160180495121'	'0'	'[0 0 0 0]'	'2'	'0.187590657388442'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.135350074209971 0.593002652212512 0 0 0 0 0 0 0]'	'1.17256573674385'	'Hydro'
	3.0	9740	'6.73293403918971'	'1'	'0'	'0.2976124256313775'	3.0	'0.763497128221812'	'0'	'0'	'0'	'gen_5229_1'	'0.0909491299521178'	'0'	'[0 0 0 0]'	'2.19749375593499'	'0.125010490226559'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.176101364248898'	'1'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.097808016075287'	'0.322644502173923'	'0'	'[0 0 0 0]'	'2'	'0.176101364248898'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.13622060100215 0.381984546021139 0 0 0 0 0 0 0]'	'1.19044970252551'	'Wind'
	100.0	600	'6.12523303502239'	'1'	'0'	'0.33397639319566'	5.0	'0.915428744871658'	'0'	'0'	'0'	'gen_5230_2'	'0.102987064241897'	'0'	'[0 0 0 0]'	'3.28062221393734'	'0.153669304103823'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.213989995891694'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0965313172165304'	'0.365363388416171'	'0'	'[0 0 0 0]'	'2'	'0.213989995891694'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.139380181227671 0.424489421675215 0 0 0 0 0 0 0]'	'1.33590557278264'	'Fossil'
	3.0	910	'5.61352256229613'	'1'	'0'	'0.3720311078469975'	7.0	'0.74173240119312'	'0'	'0'	'0'	'gen_5231_1'	'0.0102467300137505'	'0'	'[0 0 0 0]'	'4.01807729780488'	'0.201959629971534'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.312922025034204'	'1'	1	915	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0100398460892029'	'0.345077492259443'	'0'	'[0 0 0 0]'	'2'	'0.312922025034204'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.115702980337292 0.245185146695003 0 0 0 0 0 0 0]'	'1.48812443138799'	'Hydro'
	3.0	9740	'6.05379235495231'	'1'	'0'	'0.3603165998380875'	3.0	'0.739921911919257'	'0'	'0'	'0'	'gen_5233_3'	'0.0102200157905463'	'0'	'[0 0 0 0]'	'4.04112954632146'	'0.20698387010023'	2000	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.0	1000	'0.305760274389759'	'1'	1	9740	'0'	'[0 0 0 0]'	'0'	'0'	43000	'1'	5.0	'0.0102656072343234'	'0.334961609239457'	'0'	'[0 0 0 0]'	'2'	'0.305760274389759'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Wind'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.103846765680169 0.247347393259406 0 0 0 0 0 0 0]'	'1.44126639935235'	'Wind'
	100.0	600	'5.64482695443556'	'1'	'0'	'0.3727677593976425'	5.0	'0.921757557777688'	'0'	'0'	'0'	'gen_5234_1'	'0.050517378540244'	'0'	'[0 0 0 0]'	'3.23149796708208'	'0.201951610031538'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	10.4	200	'0.268113687559031'	'1'	1	600	'0'	'[0 0 0 0]'	'0'	'0'	14200	'1'	100.0	'0.0522233921196312'	'0.303159159672447'	'0'	'[0 0 0 0]'	'2'	'0.268113687559031'	'0.01'	'Combustion'	100.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Gas'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0610244330719579 0.309846977207577 0 0 0 0 0 0 0]'	'1.49107103759057'	'Fossil'
	3.0	910	'5.58797247438924'	'1'	'0'	'0.2869998430705175'	7.0	'0.769669891044311'	'0'	'0'	'0'	'gen_5235_1'	'0.0510988949274179'	'0'	'[0 0 0 0]'	'2.6615870565176'	'0.140295098836534'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.197526443671156'	'1'	1	915	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.0827419097926468'	'0.298827058867458'	'0'	'[0 0 0 0]'	'2'	'0.197526443671156'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.09009034515637911 0.419124758634716 0 0 0 0 0 0 0]'	'1.14799937228207'	'Hydro'
	3.0	910	'5.56003692662343'	'1'	'0'	'0.2764931506459825'	7.0	'0.763595954369288'	'0'	'0'	'0'	'gen_5236_2'	'0.0521085245034192'	'0'	'[0 0 0 0]'	'2.6100362072587'	'0.146810719989706'	500	'[0.8 1.27 0 0 0 0 0 0 0 0]'	7.0	200	'0.197912716191891'	'1'	1	915	'0'	'[0 0 0 0]'	'0'	'0'	56700	'1'	5.0	'0.08112469797395171'	'0.296021782608586'	'0'	'[0 0 0 0]'	'2'	'0.197912716191891'	'0.01'	'Renewable'	2.0	'10'	'[0.8 1 1.2 0 0 0 0 0 0 0]'	'Water'	1	'0'	'[0.595 1 0 0 0 0 0 0 0 0]'	'0'	'1'	'3'	'[0.8 0.0920970805417746 0.402873759800568 0 0 0 0 0 0 0]'	'1.10597260258393'	'Hydro'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_1011_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_1023_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_1024_2'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_1025_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_1027_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_1066_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_1149'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_1173_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_1181_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_1218_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_1582_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_2007_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_2008_2'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_2017_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_2033_2'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_2039_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_2071_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_2076_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_2082_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_2085_2'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_2086_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_2090_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_2246_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_2247_2'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_2345_12'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_2355_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3109_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3272_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3273_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3275_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3285_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3524_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3544_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3548_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3559_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3562_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3590_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3592_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3594_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_3649_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_4009_11'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4010_21'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4013_22'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4018_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4019_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4020_2'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4022_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4023_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4024_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4026_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4031'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_4037'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4047_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_4048_11'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4049_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4050_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_4084_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	6.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	30000	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Storage'	0.0	'0'	'0'	'Battery'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Battery'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_4085_11'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_4094_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_4095_2'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_4100_2'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_4101_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_4152_11'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_4153_21'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_4372_12'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_4373_11'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0	0	'0'	'0'	'0'	'0'	0	'0'	'0'	'0'	'0'	'gen_4376_11'	'0'	'0'	'0'	'0'	'0'	0	'0'	0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	0	'0'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'	0	'0'	'0'	'CapBank/SVC/StatCom/SynCon'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'VAr support'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_5001_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
	0.0	0	'0'	'0'	'0'	'0'	0.0	'0'	'0'	'0'	'0'	'gen_5171_1'	'0'	'0'	'0'	'0'	'0'	0	'0'	0.0	0	'0'	'0'	0	0	'0'	'0'	'0'	'0'	31300	'0'	0.0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Renewable'	0.0	'0'	'0'	'Solar'	0	'0'	'0'	'0'	'0'	'0'	'0'	'0'	'Solar'
};

%column_names% VpuPrim VpuSec name c_rating 
mpc.branch_data = {
	1.0244899999992303	1.014696050495394	'line_1027_to_1299_1_cp'	0.009772727272727273
	1.0244899999992303	1.0228208966768613	'line_1027_to_1358_1_cp'	0.010227272727272727
	1.0265702099148346	1.029636867007994	'line_1054_to_1606_1_cp'	0.019545454545454546
	1.0272722590769332	1.029636867007994	'line_1055_to_1606_2_cp'	0.01909090909090909
	1.0134422166415877	1.0159627572267977	'line_1061_to_1267_1_cp'	0.010681818181818181
	1.0134422166415877	1.0321918594066757	'line_1061_to_1274_1_cp'	0.010606060606060605
	1.0134422166415877	1.0130734023743	'line_1061_to_1311_1_cp'	0.010833333333333334
	1.0412966199698233	1.047427455654175	'line_1090_to_1092_1_cp'	0.02684
	1.0412966199698233	1.047427455654175	'line_1090_to_1092_2_cp'	0.026879999999999998
	1.019293048648907	1.010927308377204	'line_1091_to_1132_1_cp'	0.023848484848484848
	1.019293048648907	1.010927308377204	'line_1091_to_1132_2_cp'	0.023606060606060606
	1.019293048648907	1.0250777860011466	'line_1091_to_1149_1_cp'	0.023909090909090908
	1.019293048648907	1.0280674964539103	'line_1091_to_1150_1_cp'	0.023424242424242424
	1.0448957447412697	1.0357975972550688	'line_1093_to_1120_1_cp'	0.023878787878787878
	1.0448957447412697	1.0399968300576956	'line_1093_to_1138_1_cp'	0.02403030303030303
	1.0448957447412697	1.034771480601476	'line_1093_to_1140_1_cp'	0.023454545454545454
	1.068327567087969	1.0696118248711037	'line_1095_to_1104_1_cp'	0.019575757575757576
	1.068327567087969	1.0531521422773407	'line_1095_to_1109_1_cp'	0.027484848484848487
	1.068327567087969	1.059080037268648	'line_1095_to_1143_1_cp'	0.026515151515151516
	1.068327567087969	1.0544860414788229	'line_1095_to_1145_1_cp'	0.02087878787878788
	1.068327567087969	1.0544860414788229	'line_1095_to_1145_2_cp'	0.01821212121212121
	1.0258919100438	1.024377374929828	'line_1096_to_1105_1_cp'	0.02466666666666667
	1.0258919100438	1.0263938121238003	'line_1096_to_1119_1_cp'	0.019393939393939394
	1.0258919100438	1.0357975972550688	'line_1096_to_1120_1_cp'	0.02603030303030303
	1.0476213533300094	1.0552983174432637	'line_1097_to_1121_1_cp'	0.028579999999999998
	1.0476213533300094	1.0552983174432637	'line_1097_to_1121_2_cp'	0.0275
	1.0288334040629687	1.0263938121238003	'line_1098_to_1119_1_cp'	0.028484848484848484
	1.0288334040629687	1.0263938121238003	'line_1098_to_1119_2_cp'	0.027212121212121212
	1.0288334040629687	1.0224948226475856	'line_1098_to_1125_1_cp'	0.019878787878787878
	1.0288334040629687	1.033731939389554	'line_1098_to_1144_1_cp'	0.01990909090909091
	1.0555223434888397	1.0552983174432637	'line_1099_to_1121_1_cp'	0.027739999999999997
	1.0555223434888397	1.0597865293552977	'line_1099_to_1156_1_cp'	0.02868
	1.034813928084693	1.0321576277803532	'line_1100_to_1115_1_cp'	0.022909090909090907
	1.034813928084693	1.0321576277803532	'line_1100_to_1115_2_cp'	0.022818181818181817
	1.034813928084693	1.0298510962601373	'line_1100_to_1133_1_cp'	0.022818181818181817
	1.034813928084693	1.033731939389554	'line_1100_to_1144_1_cp'	0.023151515151515152
	1.0226182481800357	1.0226589958516255	'line_1101_to_1114_1_cp_merged_with_xf_1101_to_1022_1_2winding_transformer'	0.008333333333333333
	1.0217327030733752	1.0124518368931967	'line_1102_to_1103_1_cp'	0.020575757575757577
	1.0217327030733752	1.0226182481800357	'line_1102_to_1114_1_cp'	0.019575757575757576
	1.0124518368931967	1.025964178568837	'line_1103_to_1118_1_cp'	0.019545454545454546
	1.0124518368931967	1.0189536952058418	'line_1103_to_1148_1_cp'	0.021303030303030303
	1.0124518368931967	1.0067568315654	'line_1103_to_1154_1_cp'	0.02412121212121212
	1.0124518368931967	1.0153189531149125	'line_1103_to_1158_1_cp'	0.020939393939393938
	1.0696118248711037	1.047584860016429	'line_1104_to_1116_1_cp'	0.020151515151515153
	1.024377374929828	1.0226182481800357	'line_1105_to_1114_1_cp'	0.020939393939393938
	1.024377374929828	1.0263938121238003	'line_1105_to_1119_1_cp'	0.020181818181818183
	1.024377374929828	1.034771480601476	'line_1105_to_1140_1_cp'	0.025787878787878787
	1.0688982286764925	1.052733411552958	'line_1106_to_1151_1_cp'	0.020303030303030302
	1.0362767131245694	1.036875728215395	'line_1107_to_1111_1_cp'	0.023575757575757576
	1.0362767131245694	1.036875728215395	'line_1107_to_1111_2_cp'	0.023363636363636364
	1.0489657900475857	1.043067098655384	'line_1108_to_1208_1_cp'	0.011212121212121211
	1.0489657900475857	1.0411074268670295	'line_1108_to_1293_1_cp'	0.01143939393939394
	1.0531521422773407	1.059080037268648	'line_1109_to_1143_1_cp'	0.027878787878787878
	1.0531521422773407	1.0546694817107265	'line_1109_to_3650_1_cp'	0.026727272727272728
	1.0531521422773407	1.0546694817107265	'line_1109_to_3650_2_cp'	0.026696969696969698
	1.0512885777753689	1.0491509066714102	'line_1110_to_1511_1_cp'	0.026575757575757575
	1.036875728215395	1.033731939389554	'line_1111_to_1144_1_cp'	0.026393939393939397
	1.036875728215395	1.033731939389554	'line_1111_to_1144_2_cp'	0.025242424242424243
	1.031637882918312	1.034771480601476	'line_1112_to_1140_1_cp'	0.023393939393939394
	1.031637882918312	1.0367940432829892	'line_1112_to_1152_1_cp'	0.022575757575757575
	1.041741295716282	1.052733411552958	'line_1113_to_1151_1_cp'	0.020181818181818183
	1.041741295716282	1.038048778886522	'line_1113_to_2195_1_cp'	0.020515151515151514
	1.0321576277803532	1.0307221646647158	'line_1115_to_1126_1_cp'	0.019848484848484848
	1.0321576277803532	1.010927308377204	'line_1115_to_1132_1_cp'	0.024333333333333332
	1.0321576277803532	1.0544860414788229	'line_1115_to_1145_1_cp'	0.019666666666666666
	1.0321576277803532	1.0047895627659134	'line_1115_to_1146_1_cp'	0.024515151515151514
	1.032314710127017	1.034771480601476	'line_1117_to_1140_1_cp'	0.024424242424242425
	1.032314710127017	1.033731939389554	'line_1117_to_1144_1_cp'	0.023424242424242424
	1.025964178568837	1.0189536952058418	'line_1118_to_1148_1_cp'	0.02084848484848485
	1.025964178568837	1.052733411552958	'line_1118_to_1151_1_cp'	0.019727272727272725
	1.025964178568837	1.0153189531149125	'line_1118_to_1158_1_cp'	0.02033333333333333
	1.025964178568837	1.0194626718985782	'line_1118_to_2191_1_cp'	0.019545454545454546
	1.0263938121238003	1.0153189531149125	'line_1119_to_1158_1_cp'	0.02112121212121212
	1.0263938121238003	1.0153189531149125	'line_1119_to_1158_2_cp'	0.020424242424242425
	1.0552983174432637	1.0597865293552977	'line_1121_to_1156_1_cp'	0.027379999999999998
	1.0381355586787646	1.0367940432829892	'line_1123_to_1152_1_cp'	0.02327272727272727
	1.0381355586787646	1.0367940432829892	'line_1123_to_1152_2_cp'	0.023363636363636364
	1.0381355586787646	1.0284116779724406	'line_1123_to_1155_1_cp'	0.019515151515151517
	1.0248202446432104	1.033731939389554	'line_1124_to_1144_1_cp'	0.024333333333333332
	1.0248202446432104	1.0222163923104999	'line_1124_to_1147_1_cp'	0.02506060606060606
	1.0248202446432104	1.0250777860011466	'line_1124_to_1149_1_cp'	0.02396969696969697
	1.0224948226475856	1.0153189531149125	'line_1125_to_1158_1_cp'	0.020515151515151514
	1.0307221646647158	1.0544860414788229	'line_1126_to_1145_1_cp'	0.019515151515151517
	1.0457788243688528	1.0459112514508628	'line_1127_to_1244_4_cp'	0.01
	1.045682106346644	1.045877786552941	'line_1128_to_1246_2_cp'	0.009393939393939394
	1.0467036818024364	1.0466350239931759	'line_1129_to_1243_1_cp'	0.00946969696969697
	1.0469133881908312	1.0470974556639818	'line_1130_to_1245_3_cp_merged_with_line_1245_to_1340_3_cp'	0.009772727272727273
	1.010927308377204	1.0047895627659134	'line_1132_to_1146_1_cp'	0.02303030303030303
	1.010927308377204	1.0047895627659134	'line_1132_to_1146_2_cp'	0.02293939393939394
	1.010927308377204	1.0250777860011466	'line_1132_to_1149_1_cp'	0.022818181818181817
	1.010927308377204	1.0062080935474937	'line_1132_to_1153_1_cp'	0.02296969696969697
	1.0298510962601373	1.033731939389554	'line_1133_to_1144_1_cp'	0.024272727272727272
	1.0414933852248218	1.0399968300576956	'line_1134_to_1138_1_cp'	0.023393939393939394
	1.0414933852248218	1.0399968300576956	'line_1134_to_1138_2_cp'	0.02378787878787879
	1.0147465714050727	1.012614550917709	'line_1136_to_1238_1_cp'	0.00946969696969697
	1.0147465714050727	1.0150109127884652	'line_1136_to_2139_1_cp'	0.010833333333333334
	1.0399968300576956	1.033731939389554	'line_1138_to_1144_1_cp'	0.02506060606060606
	1.0399968300576956	1.0222163923104999	'line_1138_to_1147_1_cp'	0.02496969696969697
	1.0399968300576956	1.0250777860011466	'line_1138_to_1149_1_cp'	0.024909090909090912
	1.0285958942025917	1.0400720111894741	'line_1139_to_1247_1_cp'	0.010833333333333334
	1.0285958942025917	1.0281119220799961	'line_1139_to_1395_1_cp'	0.010303030303030303
	1.034771480601476	1.0367940432829892	'line_1140_to_1152_1_cp'	0.023181818181818182
	1.0543751026931767	1.0575418070326135	'line_1141_to_1569_1_cp'	0.020909090909090912
	1.033731939389554	1.0280674964539103	'line_1144_to_1150_1_cp'	0.02393939393939394
	1.0047895627659134	1.0062080935474937	'line_1146_to_1153_1_cp'	0.023151515151515152
	1.0189536952058418	1.0153189531149125	'line_1148_to_1158_1_cp'	0.020393939393939395
	1.0189536952058418	1.0194626718985782	'line_1148_to_2191_1_cp'	0.021424242424242426
	1.0284116779724406	1.0521324527610978	'line_1155_to_1157_1_cp'	0.02
	1.0258323578063713	1.033280419109938	'line_1159_to_1312_1_cp'	0.01037878787878788
	1.0258323578063713	1.0360408992512666	'line_1159_to_1331_1_cp'	0.010833333333333334
	1.0258323578063713	1.026440560604787	'line_1159_to_1335_1_cp'	0.011363636363636364
	1.0258323578063713	1.0485261302849704	'line_1159_to_1637_1_cp'	0.011590909090909091
	1.021462269930672	1.0811466389488653	'line_1160_to_1334_1_cp_merged_with_xf_1159_to_1160_5_2winding_transformer'	0.005909090909090909
	1.0540592497775523	1.0509188939258918	'line_1164_to_1273_1_cp'	0.012954545454545455
	1.0540592497775523	1.026440560604787	'line_1164_to_1335_1_cp'	0.010984848484848484
	1.0540592497775523	1.0487362623907688	'line_1164_to_1447_1_cp'	0.013712121212121212
	1.0540592497775523	1.0485261302849704	'line_1164_to_1637_1_cp'	0.010909090909090908
	1.0272735041860068	1.0196711630929016	'line_1165_to_1307_1_cp'	0.024015151515151514
	1.0272735041860068	1.014217690469269	'line_1165_to_1449_1_cp'	0.012575757575757575
	1.0272735041860068	1.014217690469269	'line_1165_to_1449_2_cp'	0.012348484848484848
	1.0272735041860068	1.0178520347514197	'line_1165_to_1492_1_cp'	0.023181818181818182
	1.0232384724272956	1.02434792616704	'line_1166_to_1300_1_cp'	0.010681818181818181
	1.0232384724272956	1.014754016544965	'line_1166_to_1459_1_cp'	0.023181818181818182
	1.0232384724272956	1.014754016544965	'line_1166_to_1459_2_cp'	0.02378787878787879
	1.0232384724272956	1.020832159543594	'line_1166_to_1472_1_cp'	0.04068181818181818
	1.0232384724272956	1.020832159543594	'line_1166_to_1472_2_cp'	0.035833333333333335
	1.0263186936575068	1.049850634187275	'line_1167_to_1211_1_cp'	0.014545454545454545
	1.0824015001190455	1.0794993607379386	'line_1168_to_1292_1_cp'	0.011287878787878788
	1.0824015001190455	1.060901708393962	'line_1168_to_1317_1_cp'	0.01462121212121212
	1.0824015001190455	1.0650080243646038	'line_1168_to_1497_1_cp'	0.014924242424242423
	1.0508568323147438	1.0519563718753107	'line_1169_to_1221_1_cp'	0.02121212121212121
	1.0508568323147438	1.0518192651669562	'line_1169_to_1316_1_cp'	0.02143939393939394
	1.0508568323147438	1.0505783583882635	'line_1169_to_1528_2_cp'	0.020681818181818183
	1.0508568323147438	1.05031089251085	'line_1169_to_1529_1_cp'	0.02075757575757576
	1.0508568323147438	1.0519506457147931	'line_1169_to_1541_2_cp'	0.026818181818181817
	1.046582155804884	1.0400720111894741	'line_1172_to_1247_1_cp'	0.017803030303030303
	1.046582155804884	1.0411175489529532	'line_1172_to_1249_1_cp'	0.018257575757575757
	1.0281270696248392	1.0182793447947824	'line_1177_to_1301_1_cp'	0.014318181818181817
	1.0281270696248392	1.013449198464946	'line_1177_to_1314_1_cp'	0.014848484848484849
	1.0281270696248392	1.0455986354537827	'line_1177_to_1384_1_cp_merged_with_xf_1384_to_1383_1_2winding_transformer'	0.013181818181818182
	1.0781271737794142	1.076083939105193	'line_1179_to_1200_3_cp'	0.01787878787878788
	1.0781271737794142	1.0684026045733053	'line_1179_to_1329_1_cp_merged_with_line_1329_to_1407_1_cp_merged_with_line_1263_to_1407_1_cp'	0.010984848484848484
	1.0781271737794142	1.03009393759855	'line_1179_to_1429_1_cp'	0.011590909090909091
	1.053454900653084	1.0410862332897213	'line_1182_to_1396_1_cp'	0.014545454545454545
	1.053454900653084	1.0129434485409985	'line_1182_to_1456_1_cp'	0.016666666666666666
	1.0544186483825417	1.045664696395035	'line_1183_to_1210_1_cp'	0.013560606060606061
	1.0544186483825417	1.0518960717009327	'line_1183_to_1257_1_cp'	0.013333333333333334
	1.0544186483825417	1.0544496735296842	'line_1183_to_1262_1_cp'	0.014242424242424242
	1.0544186483825417	1.0513606919645264	'line_1183_to_1283_1_cp'	0.01803030303030303
	1.0544186483825417	1.0513606919645264	'line_1183_to_1283_2_cp'	0.017272727272727273
	1.0544186483825417	1.049858643253906	'line_1183_to_1336_1_cp'	0.017045454545454544
	1.0544186483825417	1.0499339004046122	'line_1183_to_1337_1_cp'	0.017575757575757574
	1.0544186483825417	1.0480028044543583	'line_1183_to_1380_1_cp'	0.014015151515151515
	1.0544186483825417	1.0512852467028961	'line_1183_to_1424_1_cp'	0.013636363636363637
	1.0544186483825417	1.0520311634265047	'line_1183_to_1621_1_cp'	0.021060606060606057
	1.0544186483825417	1.0520311634265047	'line_1183_to_1621_2_cp'	0.02075757575757576
	1.0228567733458054	1.0231899205453	'line_1185_to_1188_3_cp'	0.01787878787878788
	1.0228567733458054	1.0229229621777356	'line_1185_to_1468_1_cp'	0.018484848484848486
	1.0343018150577576	1.0407905354150433	'line_1186_to_1231_1_cp_merged_with_line_1231_to_1391_1_cp'	0.01765151515151515
	1.0343018150577576	1.0409711259149865	'line_1186_to_1233_2_cp_merged_with_line_1233_to_1326_1_cp'	0.01840909090909091
	1.0343018150577576	1.0441209594729584	'line_1186_to_1465_2_cp'	0.022045454545454545
	1.0343018150577576	1.0441237738148894	'line_1186_to_1466_1_cp'	0.021818181818181816
	1.0230002811853522	1.0229229621777356	'line_1187_to_1468_1_cp'	0.0175
	1.0352964786379244	1.0341230613104333	'line_1189_to_1215_1_cp'	0.02053030303030303
	1.0352964786379244	1.0262378425565954	'line_1189_to_1240_1_cp'	0.01803030303030303
	1.0352964786379244	1.0262378425565954	'line_1189_to_1240_2_cp'	0.0175
	1.0352964786379244	1.0325355755159726	'line_1189_to_1305_1_cp'	0.020378787878787878
	1.0352964786379244	1.0308384915831605	'line_1189_to_1371_1_cp'	0.016363636363636365
	1.0352964786379244	1.0310987607359416	'line_1189_to_1457_1_cp'	0.014772727272727272
	1.0352964786379244	1.039174663744165	'line_1189_to_1469_2_cp'	0.0175
	1.0352964786379244	1.035470336204765	'line_1189_to_1470_1_cp'	0.02378787878787879
	1.0442400764898743	1.0348753672946296	'line_1190_to_1264_1_cp'	0.01446969696969697
	1.0442400764898743	1.0362573794087342	'line_1190_to_1266_1_cp'	0.021742424242424244
	1.0442400764898743	1.0362573794087342	'line_1190_to_1266_4_cp'	0.02159090909090909
	1.0442400764898743	1.0395868881997736	'line_1190_to_1406_1_cp'	0.020984848484848485
	1.0442400764898743	1.0436523615605757	'line_1190_to_1451_1_cp'	0.014848484848484849
	1.0436910880563068	1.032454552918072	'line_1191_to_1234_1_cp'	0.02090909090909091
	1.0436910880563068	1.0437587594001059	'line_1191_to_1253_1_cp'	0.01462121212121212
	1.0436910880563068	1.0362573794087342	'line_1191_to_1266_2_cp'	0.021515151515151515
	1.0436910880563068	1.0362573794087342	'line_1191_to_1266_3_cp'	0.02090909090909091
	1.0436910880563068	1.0378809310984045	'line_1191_to_1401_1_cp'	0.013712121212121212
	1.0283391919849387	1.0097033577870758	'line_1192_to_1322_1_cp'	0.008484848484848486
	1.0283391919849387	1.0299626682241394	'line_1192_to_1423_1_cp'	0.011287878787878788
	1.0624417900467933	1.046546565943881	'line_1193_to_1207_1_cp'	0.012803030303030302
	1.0624417900467933	1.0544496735296842	'line_1193_to_1262_1_cp'	0.014848484848484849
	1.0624417900467933	1.0544496735296842	'line_1193_to_1262_2_cp'	0.01446969696969697
	1.0624417900467933	1.0601256324270432	'line_1193_to_1356_1_cp'	0.013257575757575758
	1.0624417900467933	1.0601256324270432	'line_1193_to_1356_2_cp'	0.012803030303030302
	1.0624417900467933	1.0473961636197098	'line_1193_to_1464_1_cp'	0.010984848484848484
	1.0624417900467933	1.0593802208492682	'line_1193_to_1477_1_cp'	0.016893939393939395
	1.0624417900467933	1.0593802208492682	'line_1193_to_1477_2_cp'	0.015
	1.0435518438562257	1.025774620014638	'line_1195_to_1313_1_cp'	0.01696969696969697
	1.0435518438562257	1.0343219627633682	'line_1195_to_1430_1_cp'	0.01659090909090909
	1.054876457159596	1.0496382631430727	'line_1196_to_1241_1_cp'	0.014924242424242423
	1.04624801099138	1.0435764798037803	'line_1197_to_1342_1_cp_merged_with_xf_1149_to_1197_5_2winding_transformer_merged_with_line_1342_to_1463_1_cp'	0.008757575757575757
	1.0375730896435036	1.0320255058131067	'line_1198_to_1455_1_cp'	0.017272727272727273
	1.0375730896435036	1.0320255058131067	'line_1198_to_1455_2_cp'	0.01681818181818182
	1.053493328624043	1.043676916824275	'line_1199_to_1229_1_cp'	0.010757575757575757
	1.053493328624043	1.0130734023743	'line_1199_to_1311_1_cp'	0.010833333333333334
	1.053493328624043	1.0465681569769199	'line_1199_to_1479_1_cp'	0.010833333333333334
	1.053493328624043	1.072160829147553	'line_1199_to_1480_1_cp'	0.010530303030303029
	1.053493328624043	1.072160829147553	'line_1199_to_1480_2_cp'	0.010454545454545454
	1.053493328624043	1.0493989935322592	'line_1199_to_1481_1_cp'	0.014166666666666668
	1.053493328624043	1.0493989935322592	'line_1199_to_1481_2_cp'	0.013560606060606061
	1.053493328624043	1.0650080243646038	'line_1199_to_1497_1_cp'	0.010909090909090908
	1.076083939105193	1.0590709299302552	'line_1200_to_1332_2_cp'	0.013409090909090909
	1.076083939105193	1.0528726801796289	'line_1200_to_1333_1_cp'	0.012727272727272726
	1.076083939105193	1.03009393759855	'line_1200_to_1429_1_cp'	0.00803030303030303
	1.076083939105193	1.0349781850908546	'line_1200_to_1432_1_cp'	0.010833333333333334
	1.044977491001384	1.0480028044543583	'line_1203_to_1380_1_cp'	0.014545454545454545
	1.0286022926971743	1.0411074268670295	'line_1204_to_1293_1_cp'	0.015303030303030303
	1.0286022926971743	1.0411074268670295	'line_1204_to_1293_2_cp'	0.014696969696969696
	1.0286022926971743	1.0194770127116235	'line_1204_to_1306_1_cp'	0.020303030303030305
	1.0286022926971743	1.0230605090969984	'line_1204_to_1361_1_cp'	0.010833333333333334
	1.0286022926971743	1.0222325336821152	'line_1204_to_1475_1_cp'	0.020075757575757577
	1.050322532483244	1.0298421926848456	'line_1205_to_1214_1_cp'	0.015075757575757576
	1.050322532483244	1.045947803572013	'line_1205_to_1263_1_cp'	0.011136363636363637
	1.050322532483244	1.0300820967926447	'line_1205_to_1359_1_cp'	0.014848484848484849
	1.050322532483244	1.0080060671291804	'line_1205_to_1433_1_cp'	0.010909090909090908
	1.050322532483244	1.0485691079492985	'line_1205_to_1485_1_cp_merged_with_line_1400_to_1485_1_cp'	0.009242424242424243
	1.050322532483244	1.0465490145605658	'line_1205_to_1487_1_cp_merged_with_line_1429_to_1487_1_cp'	0.010909090909090908
	1.0399560701958817	1.0321918594066757	'line_1206_to_1274_1_cp'	0.011515151515151515
	1.0399560701958817	1.027526367358434	'line_1206_to_1296_1_cp'	0.010681818181818181
	1.0399560701958817	1.027526367358434	'line_1206_to_1296_2_cp'	0.010833333333333334
	1.0399560701958817	1.0476037399691698	'line_1206_to_1324_1_cp'	0.009242424242424243
	1.0399560701958817	1.0250213371713521	'line_1206_to_1414_1_cp'	0.010984848484848484
	1.0399560701958817	1.0493989935322592	'line_1206_to_1481_1_cp'	0.011136363636363637
	1.0399560701958817	1.0402902515143544	'line_1206_to_1646_1_cp_merged_with_line_1365_to_1646_1_pi'	0.011136363636363637
	1.046546565943881	1.0089585120727014	'line_1207_to_1473_1_cp'	0.011666666666666667
	1.046546565943881	1.0464545948911113	'line_1207_to_1562_1_cp_merged_with_xf_1562_to_1563_1_2winding_transformer'	0.009545454545454546
	1.043067098655384	1.0411074268670295	'line_1208_to_1293_1_cp'	0.010833333333333334
	1.049850634187275	1.0293992094601976	'line_1211_to_1222_1_cp'	0.01440909090909091
	1.0463731553350188	1.0465001204496274	'line_1212_to_1309_1_cp'	0.01393939393939394
	1.0463731553350188	1.0457926424654485	'line_1212_to_1391_1_cp'	0.01393939393939394
	1.0463731553350188	1.0457926424654485	'line_1212_to_1391_2_cp'	0.01462121212121212
	1.0298421926848456	1.0285329399192638	'line_1214_to_1223_1_cp'	0.011515151515151515
	1.0298421926848456	1.0118507217073864	'line_1214_to_1605_1_cp'	0.010984848484848484
	1.0341230613104333	1.0356356382190652	'line_1215_to_1320_1_cp'	0.018787878787878787
	1.039497299733625	1.0293992094601976	'line_1217_to_1222_1_cp'	0.014090909090909091
	1.037559999998999	1.0514443596165244	'line_1218_to_3473_1_cp'	0.010181818181818183
	1.037559999998999	1.0514443596165244	'line_1218_to_3473_2_cp'	0.010454545454545454
	1.0518313348879076	1.0521885044993409	'line_1219_to_1389_1_cp_merged_with_line_1389_to_1541_3_cp'	0.020833333333333332
	1.0383619903718933	1.0383563155346258	'line_1220_to_1232_1_cp'	0.020606060606060607
	1.0383619903718933	1.0383563155346258	'line_1220_to_1232_2_cp'	0.019318181818181818
	1.0383619903718933	1.0385306158399568	'line_1220_to_1471_1_cp_merged_with_line_1279_to_1282_2_pi_merged_with_line_1279_to_1471_1_cp'	0.06568181818181817
	1.0519563718753107	1.0490139574353037	'line_1221_to_1272_1_cp'	0.020075757575757577
	1.0519563718753107	1.0518192651669562	'line_1221_to_1316_1_cp'	0.02212121212121212
	1.0519563718753107	1.0515337926068908	'line_1221_to_1372_1_cp'	0.009545454545454546
	1.0519563718753107	1.0516374123336014	'line_1221_to_1373_2_cp'	0.00946969696969697
	1.0519563718753107	1.0549209880759356	'line_1221_to_1441_1_cp'	0.020151515151515153
	1.0519563718753107	1.0516526018032673	'line_1221_to_1460_2_cp'	0.009242424242424243
	1.0519563718753107	1.0516945777382576	'line_1221_to_1461_1_cp'	0.009545454545454546
	1.0293992094601976	1.0277318422118547	'line_1222_to_2162_1_cp'	0.014272727272727274
	1.0285329399192638	1.0256411423729992	'line_1223_to_1381_1_cp'	0.011287878787878788
	1.0361221281021893	1.036486404535581	'line_1224_to_1236_1_cp'	0.013863636363636364
	1.0361221281021893	1.035931190742759	'line_1224_to_1467_1_cp'	0.013787878787878788
	1.051543035503309	1.0492925401858084	'line_1225_to_1376_1_cp'	0.01393939393939394
	1.0199411472877478	1.0214479622648651	'line_1226_to_1256_1_cp'	0.01106060606060606
	1.0199411472877478	1.0097033577870758	'line_1226_to_1322_1_cp'	0.008636363636363636
	1.0294452597776704	1.0256411423729992	'line_1228_to_1381_1_cp'	0.00962121212121212
	1.043676916824275	1.0411175489529532	'line_1229_to_1249_1_cp'	0.011212121212121211
	1.0368372545868585	1.0378809310984045	'line_1230_to_1401_1_cp'	0.01818181818181818
	1.0368372545868585	1.0368139052806613	'line_1230_to_1403_1_cp'	0.017727272727272727
	1.0383563155346258	1.0382279576076432	'line_1232_to_1440_1_cp'	0.020378787878787878
	1.0383563155346258	1.0382279576076432	'line_1232_to_1440_2_cp'	0.02143939393939394
	1.036486404535581	1.0362520237387136	'line_1236_to_1491_1_cp'	0.013560606060606061
	1.0158374083044128	1.0174420631871053	'line_1237_to_1278_1_cp'	0.015681818181818182
	1.0158374083044128	1.0152391779693697	'line_1237_to_1288_1_cp'	0.016893939393939395
	1.012614550917709	1.0114836927303446	'line_1238_to_2102_1_cp'	0.01106060606060606
	1.0485742073906448	1.0491801591612848	'line_1239_to_1394_1_cp'	0.01393939393939394
	1.0485742073906448	1.0512852467028961	'line_1239_to_1424_1_cp'	0.015151515151515152
	1.0262378425565954	1.023523274585203	'line_1240_to_1258_1_cp'	0.016212121212121212
	1.0262378425565954	1.0229975452313227	'line_1240_to_1413_1_cp'	0.016742424242424243
	1.0496382631430727	1.0375833858353773	'line_1241_to_1431_1_cp'	0.013787878787878788
	1.052650035670747	1.052186434150731	'line_1242_to_1364_1_cp'	0.02446969696969697
	1.0466350239931759	1.0464239504803705	'line_1243_to_1340_1_cp'	0.009696969696969697
	1.0459112514508628	1.0464239504803705	'line_1244_to_1340_4_cp'	0.009393939393939394
	1.045877786552941	1.0464239504803705	'line_1246_to_1340_2_cp'	0.00984848484848485
	1.0400720111894741	1.0411175489529532	'line_1247_to_1249_1_cp'	0.017727272727272727
	1.0400720111894741	1.0423420335083424	'line_1247_to_1327_1_cp_merged_with_xf_1588_1327_1068_2_3winding_transformer_br2'	0.009393939393939394
	1.030112326633225	1.0308384915831605	'line_1254_to_1371_1_cp'	0.013333333333333334
	1.030112326633225	1.0310987607359416	'line_1254_to_1457_1_cp'	0.013409090909090909
	1.0214479622648651	1.0299626682241394	'line_1256_to_1423_1_cp'	0.00856060606060606
	1.023523274585203	1.0225714234753969	'line_1258_to_1422_1_cp'	0.009696969696969697
	1.022223159274409	1.0225714234753969	'line_1259_to_1422_2_cp'	0.009393939393939394
	1.031292661911853	1.0303493024148735	'line_1260_to_1261_1_cp'	0.016666666666666666
	1.031292661911853	1.028641930554959	'line_1260_to_1284_1_cp'	0.02121212121212121
	1.031292661911853	1.028641930554959	'line_1260_to_1284_2_cp'	0.02196969696969697
	1.0303493024148735	1.029040492748484	'line_1261_to_1341_1_cp'	0.015303030303030303
	1.0303493024148735	1.0309812157510092	'line_1261_to_1438_1_cp'	0.015681818181818182
	1.0544496735296842	1.049858643253906	'line_1262_to_1336_1_cp'	0.011742424242424243
	1.0362573794087342	1.035119153422031	'line_1266_to_1325_1_cp'	0.016439393939393938
	1.0448184449434863	1.0382279576076432	'line_1271_to_1440_1_cp'	0.020454545454545454
	1.0490139574353037	1.0356356382190652	'line_1272_to_1320_1_cp'	0.06295454545454546
	1.0490139574353037	1.0356356382190652	'line_1272_to_1320_2_cp'	0.06265151515151515
	1.0490139574353037	1.049550752634135	'line_1272_to_1382_1_cp'	0.012651515151515151
	1.0509188939258918	1.0453251972450017	'line_1273_to_1419_1_cp'	0.012651515151515151
	1.0510840468028075	1.0511007983904266	'line_1275_to_1349_1_cp'	0.010075757575757576
	1.0510840468028075	1.0519506457147931	'line_1275_to_1541_1_cp'	0.020454545454545454
	1.0510840468028075	1.0511528260054765	'line_1275_to_1604_1_cp'	0.01924242424242424
	1.0174420631871053	1.014283279184269	'line_1278_to_1294_1_cp'	0.015984848484848484
	1.0174420631871053	1.0196711630929016	'line_1278_to_1307_1_cp'	0.02212121212121212
	1.0409000730421858	1.039174663744165	'line_1281_to_1469_2_cp'	0.016666666666666666
	1.0339117260139985	1.035470336204765	'line_1282_to_1470_1_cp'	0.01712121212121212
	1.0513606919645264	1.049858643253906	'line_1283_to_1336_1_cp'	0.01803030303030303
	1.007184707162075	1.0257339491348954	'line_1285_to_1474_1_cp'	0.010909090909090908
	1.007184707162075	1.0078806936367182	'line_1285_to_1628_1_cp'	0.011212121212121211
	1.0375793290551727	1.0415666191329191	'line_1287_to_1463_1_cp'	0.017803030303030303
	1.0152391779693697	1.014283279184269	'line_1288_to_1294_1_cp'	0.01734848484848485
	1.0152391779693697	1.0194770127116235	'line_1288_to_1306_1_cp'	0.02234848484848485
	1.0496218862317197	1.0516787366281999	'line_1289_to_1387_2_cp'	0.009393939393939394
	1.0496218862317197	1.0514478617151304	'line_1289_to_1388_1_cp'	0.009696969696969697
	1.0496218862317197	1.0516526018032673	'line_1289_to_1460_2_cp'	0.009242424242424243
	1.0496218862317197	1.0516945777382576	'line_1289_to_1461_1_cp'	0.00962121212121212
	1.0794993607379386	1.0292814706209357	'line_1292_to_1297_1_cp'	0.011212121212121211
	1.0411074268670295	1.0432706583579023	'line_1293_to_1462_1_cp_merged_with_line_1408_to_1462_1_cp'	0.010606060606060605
	1.0168690037614894	1.0178520347514197	'line_1295_to_1492_1_cp'	0.023257575757575755
	1.027526367358434	1.0022554055171835	'line_1296_to_1310_1_cp'	0.009318181818181817
	1.0292814706209357	1.0319818262741114	'line_1297_to_1308_1_cp'	0.010606060606060605
	1.007602287681378	1.0153532265347205	'line_1298_to_1347_2_cp_merged_with_line_1027_to_1298_2_cp'	0.00984848484848485
	1.014696050495394	1.007602287681378	'line_1299_to_1347_1_cp'	0.010303030303030303
	1.0513160273004833	1.0512852467028961	'line_1302_to_1424_1_cp'	0.014545454545454545
	1.0325355755159726	1.0356356382190652	'line_1305_to_1320_1_cp'	0.020681818181818183
	1.0325355755159726	1.0307667540472403	'line_1305_to_1338_1_cp'	0.01765151515151515
	1.0194770127116235	1.0222325336821152	'line_1306_to_1475_1_cp'	0.021060606060606057
	1.0319818262741114	1.0281119220799961	'line_1308_to_1395_1_cp'	0.011363636363636364
	1.0319818262741114	1.072160829147553	'line_1308_to_1480_1_cp'	0.010681818181818181
	1.0465001204496274	1.0465550815576476	'line_1309_to_1530_1_cp'	0.015075757575757576
	1.0022554055171835	1.0080060671291804	'line_1310_to_1433_1_cp'	0.010833333333333334
	1.033280419109938	1.0361546150932957	'line_1312_to_1385_1_cp'	0.010909090909090908
	1.033280419109938	1.0257339491348954	'line_1312_to_1474_1_cp'	0.010909090909090908
	1.025774620014638	1.0241566966026545	'line_1313_to_1458_1_cp'	0.016363636363636365
	1.0483732074499053	1.0476037399691698	'line_1315_to_1324_1_cp'	0.00962121212121212
	1.060901708393962	1.0650080243646038	'line_1317_to_1497_1_cp'	0.010833333333333334
	1.0152424823007884	1.015261549583419	'line_1318_to_1319_1_cp'	0.007575757575757576
	1.0274795427367598	1.027755820605503	'line_1321_to_1370_1_cp'	0.01037878787878788
	1.0274795427367598	1.0274557959597728	'line_1321_to_1627_1_cp'	0.01143939393939394
	1.0453241536544267	1.0457926424654485	'line_1326_to_1391_1_cp'	0.016439393939393938
	1.0502150063523605	1.049550752634135	'line_1330_to_1382_1_cp'	0.019924242424242424
	1.0502150063523605	1.0519506457147931	'line_1330_to_1541_1_cp'	0.01946969696969697
	1.0360408992512666	1.0361546150932957	'line_1331_to_1385_1_cp'	0.01037878787878788
	1.0360408992512666	1.0385623702505455	'line_1331_to_1402_1_cp'	0.010454545454545454
	1.0590709299302552	1.0566278278135244	'line_1332_to_1345_1_cp'	0.013106060606060605
	1.0528726801796289	1.01963583316007	'line_1333_to_1483_1_cp'	0.012348484848484848
	1.021462269930672	1.0396008764685962	'line_1334_to_1392_1_cp'	0.010151515151515153
	1.021462269930672	1.004954455463716	'line_1334_to_1444_1_cp'	0.011287878787878788
	1.021462269930672	1.004954455463716	'line_1334_to_1444_2_cp'	0.01106060606060606
	1.021462269930672	1.0487362623907688	'line_1334_to_1447_1_cp'	0.010075757575757576
	1.026440560604787	1.0078806936367182	'line_1335_to_1628_1_cp'	0.010984848484848484
	1.049858643253906	1.0488745443039174	'line_1336_to_1453_1_cp'	0.011818181818181818
	1.0464239504803705	1.0460787631281212	'line_1340_to_1393_1_cp'	0.010681818181818181
	1.0464239504803705	1.0461152400004554	'line_1340_to_1478_1_cp'	0.012045454545454547
	1.029040492748484	1.0285529976080636	'line_1341_to_1488_1_cp'	0.01590909090909091
	1.0510810721138986	1.0515337926068908	'line_1343_to_1372_1_cp'	0.00946969696969697
	1.0512621448945136	1.0511007983904266	'line_1344_to_1349_1_cp'	0.012575757575757575
	1.0512621448945136	1.0516374123336014	'line_1344_to_1373_2_cp'	0.009393939393939394
	1.0162100807365908	1.0157788706128879	'line_1346_to_1443_1_cp'	0.010984848484848484
	1.007602287681378	1.0078806936367182	'line_1347_to_1628_1_cp'	0.01696969696969697
	1.007602287681378	1.0078806936367182	'line_1347_to_1628_2_cp'	0.01143939393939394
	1.007602287681378	1.0078806936367182	'line_1347_to_1628_3_cp'	0.010833333333333334
	1.0504062330208537	1.050964846093579	'line_1350_to_1368_1_cp_merged_with_line_1352_to_1368_2_cp'	0.010984848484848484
	1.0510408655353372	1.0511296108968446	'line_1352_to_1486_1_cp'	0.019924242424242424
	1.0510408655353372	1.0519506457147931	'line_1352_to_1541_1_cp'	0.019166666666666665
	1.0272669468470386	1.027755820605503	'line_1354_to_1370_1_cp'	0.00984848484848485
	1.0272669468470386	1.0271582606552017	'line_1354_to_1426_2_cp_merged_with_xf_1426_to_1624_2_2winding_transformer'	0.0036363636363636364
	1.0272669468470386	1.027158363942574	'line_1354_to_1427_1_cp_merged_with_xf_1427_to_1624_1_2winding_transformer'	0.003712121212121212
	1.0272669468470386	1.0274557959597728	'line_1354_to_1627_1_cp'	0.012045454545454547
	1.0272354776362145	1.027755820605503	'line_1355_to_1370_1_cp'	0.021060606060606057
	1.0601256324270432	1.0473961636197098	'line_1356_to_1464_1_cp'	0.012651515151515151
	1.0228208966768613	1.0224735878110327	'line_1358_to_1593_1_cp'	0.010303030303030303
	1.0238671911797608	1.0272314111810326	'line_1360_to_1362_1_cp_merged_with_xf_1362_to_1596_1_2winding_transformer'	0.009242424242424243
	1.0238671911797608	1.0224735878110327	'line_1360_to_1593_1_cp'	0.010303030303030303
	1.0230605090969984	1.0233490678136015	'line_1361_to_1450_1_cp'	0.010833333333333334
	1.0036146800603705	1.004954455463716	'line_1363_to_1444_1_cp'	0.010757575757575757
	1.0036146800603705	1.0089585120727014	'line_1363_to_1473_1_cp'	0.011287878787878788
	1.052186434150731	1.0519327339422007	'line_1364_to_1397_1_cp'	0.019848484848484848
	1.006628642900223	1.0094282038713773	'line_1369_to_1654_2_cp'	0.007272727272727273
	1.006628642900223	1.009531106902081	'line_1369_to_1655_1_cp'	0.007272727272727273
	1.006628642900223	1.0073643683704692	'line_1369_to_1656_4_cp'	0.010606060606060605
	1.027755820605503	1.0274557959597728	'line_1370_to_1627_1_cp'	0.009545454545454546
	1.027755820605503	1.0274557959597728	'line_1370_to_1627_2_cp'	0.00984848484848485
	1.0232274149931138	1.030713336022082	'line_1375_to_1400_1_cp'	0.011666666666666667
	1.0232274149931138	1.0080060671291804	'line_1375_to_1433_1_cp'	0.01037878787878788
	1.0251315983253455	1.0256411423729992	'line_1378_to_1381_1_cp'	0.01106060606060606
	1.0415276842526744	1.0395868881997736	'line_1379_to_1406_1_cp'	0.019318181818181818
	1.0256411423729992	0.9955049805691817	'line_1381_to_1435_1_cp'	0.009393939393939394
	1.0516787366281999	1.0519506457147931	'line_1387_to_1541_4_cp'	0.01
	1.0514478617151304	1.0519506457147931	'line_1388_to_1541_2_cp'	0.010151515151515153
	1.0519506457147931	1.0516849125534826	'line_1390_to_1541_1_cp_merged_with_line_1280_to_1390_1_cp_merged_with_line_1280_to_1281_1_pi'	0.05666666666666667
	1.0457926424654485	1.0460787631281212	'line_1391_to_1393_1_cp'	0.014848484848484849
	1.0457926424654485	1.0461152400004554	'line_1391_to_1478_1_cp'	0.013333333333333334
	1.0396008764685962	1.0453251972450017	'line_1392_to_1419_1_cp'	0.009924242424242424
	1.0410862332897213	1.044407400960956	'line_1396_to_1416_1_cp'	0.013712121212121212
	1.0410862332897213	1.0129434485409985	'line_1396_to_1456_1_cp'	0.01734848484848485
	1.0519327339422007	1.0520311634265047	'line_1397_to_1621_1_cp'	0.018106060606060608
	1.0519327339422007	1.0518629825662682	'line_1397_to_1630_1_cp'	0.01628787878787879
	1.030713336022082	1.03009393759855	'line_1400_to_1429_1_cp'	0.008787878787878787
	1.0378809310984045	1.0358166880912432	'line_1401_to_1425_1_cp'	0.013636363636363637
	1.0385623702505455	1.0299626682241394	'line_1402_to_1423_1_cp'	0.009015151515151514
	1.0368139052806613	1.0358166880912432	'line_1403_to_1425_1_cp'	0.016893939393939395
	1.0158392063249742	1.0157788706128879	'line_1404_to_1443_2_cp'	0.011136363636363637
	1.0158356298417712	1.0157788706128879	'line_1405_to_1443_1_cp'	0.010530303030303029
	1.0250213371713521	1.0465681569769199	'line_1414_to_1479_1_cp'	0.01106060606060606
	1.0358166880912432	1.035931190742759	'line_1425_to_1467_1_cp'	0.014318181818181817
	1.03009393759855	1.0349781850908546	'line_1429_to_1432_1_cp'	0.010984848484848484
	1.0343219627633682	1.0263117833523931	'line_1430_to_1489_1_cp'	0.01734848484848485
	1.0007516510241468	1.0006856153596175	'line_1434_to_1626_1_cp'	0.007727272727272728
	0.9955049805691817	0.9927371227350636	'line_1435_to_1437_1_cp'	0.00984848484848485
	0.9955049805691817	1.0118507217073864	'line_1435_to_1605_1_cp'	0.010909090909090908
	1.0309812157510092	1.0320255058131067	'line_1438_to_1455_1_cp'	0.01659090909090909
	1.0309812157510092	1.0320255058131067	'line_1438_to_1455_2_cp'	0.016439393939393938
	1.0309812157510092	1.0285529976080636	'line_1438_to_1488_1_cp'	0.009242424242424243
	1.0342790785937175	1.0343276375847523	'line_1439_to_1446_1_cp'	0.014242424242424242
	1.0345854990885917	1.0345247327674325	'line_1442_to_1445_1_cp'	0.014924242424242423
	1.0157788706128879	1.01963583316007	'line_1443_to_1483_1_cp'	0.010454545454545454
	1.0139044435716227	1.0129434485409985	'line_1454_to_1456_1_cp'	0.014242424242424242
	1.0241566966026545	1.0229229621777356	'line_1458_to_1468_1_cp'	0.01446969696969697
	1.014754016544965	1.020832159543594	'line_1459_to_1472_1_cp'	0.017954545454545456
	1.014754016544965	1.020832159543594	'line_1459_to_1472_2_cp'	0.01840909090909091
	1.0473961636197098	1.0089585120727014	'line_1464_to_1473_1_cp'	0.011287878787878788
	1.0465681569769199	1.0493989935322592	'line_1479_to_1481_1_cp'	0.011212121212121211
	1.072160829147553	1.0650080243646038	'line_1480_to_1497_1_cp'	0.010984848484848484
	1.0511296108968446	1.0511528260054765	'line_1486_to_1604_1_cp'	0.020378787878787878
	1.0566940544985464	1.0568506101320945	'line_1519_to_1520_1_cp_merged_with_xf_1520_to_1001_2_2winding_transformer'	0.06090909090909091
	1.0566940544985464	1.0568296234248873	'line_1519_to_1521_2_cp'	0.01636363636363636
	1.0760494684867072	1.0768673729687939	'line_1522_to_1581_1_cp'	0.006363636363636363
	1.0760827356218572	1.0768673729687939	'line_1524_to_1581_2_cp'	0.006363636363636363
	1.1002243906109235	1.1010638228553558	'line_1531_to_1603_1_cp'	0.01393939393939394
	1.0130665024515986	1.0069522126167116	'line_1554_to_1613_1_cp'	0.011212121212121211
	1.0400141769924005	1.0399947577198563	'line_1570_to_1571_1_cp'	0.007272727272727273
	1.0299692314781874	1.029459614170877	'line_1579_to_1648_1_cp'	0.007424242424242424
	1.0450795543580365	1.0449298087153656	'line_1580_to_1594_1_cp'	0.00787878787878788
	1.0297917236103422	1.013106228624794	'line_1587_to_2293_1_cp'	0.008484848484848486
	1.039361395814962	1.029459614170877	'line_1591_to_1648_1_cp'	0.007272727272727273
	1.0449298087153656	1.0282594504516043	'line_1594_to_1595_1_cp'	0.008333333333333333
	1.0449298087153656	1.0424389191789956	'line_1594_to_1601_1_cp'	0.010303030303030303
	1.0449298087153656	1.0443717620104016	'line_1594_to_1658_1_cp'	0.010303030303030303
	1.0449298087153656	1.0443717620104016	'line_1594_to_1658_2_cp'	0.012878787878787878
	1.0449298087153656	1.0443717620104016	'line_1594_to_1658_3_cp'	0.012424242424242423
	1.0282594504516043	1.0216717216856033	'line_1595_to_1596_1_cp'	0.006666666666666667
	1.0282594504516043	1.0216717216856033	'line_1595_to_1596_2_cp'	0.010151515151515153
	1.0282594504516043	1.0318384685139366	'line_1595_to_1598_1_cp'	0.00984848484848485
	1.0318384685139366	1.0424389191789956	'line_1598_to_1601_1_cp'	0.008484848484848486
	1.0424389191789956	1.0443717620104016	'line_1601_to_1658_1_cp'	0.010454545454545454
	0.9537639575112281	0.9536100468973454	'line_1607_to_1608_2_cp_merged_with_xf_1608_to_1015_1_2winding_transformer'	0.09666666666666666
	0.9537639575112281	0.9536244805792218	'line_1607_to_1609_1_cp_merged_with_xf_1609_to_1016_2_2winding_transformer'	0.13939393939393938
	1.0520311634265047	1.0518629825662682	'line_1621_to_1630_1_cp'	0.019090909090909092
	1.020646662420381	1.0291599999976884	'line_2005_to_2007_1_cp'	0.007575757575757576
	1.0193619055493546	1.0302099999977177	'line_2006_to_2008_2_cp'	0.00787878787878788
	0.9999037036198694	1.0042217700329454	'line_2068_to_2262_1_cp'	0.011515151515151515
	1.1191266001439897	1.0198456073735385	'line_2096_to_2280_1_cp'	0.010909090909090908
	1.0095543391989312	1.0318398199133303	'line_2099_to_2100_1_cp'	0.014772727272727272
	1.02389479359291	1.0276028619264685	'line_2104_to_2146_1_cp'	0.024272727272727272
	1.0270836908151615	1.0391178703768236	'line_2105_to_2108_1_cp'	0.0175
	1.0270836908151615	1.03180031538688	'line_2105_to_2109_1_cp'	0.01440909090909091
	1.0270836908151615	1.0283297221692886	'line_2105_to_2154_1_cp'	0.016954545454545455
	1.0270836908151615	1.0283297221692886	'line_2105_to_2154_2_cp'	0.01390909090909091
	1.0270836908151615	1.0134841085503254	'line_2105_to_2176_1_cp'	0.01459090909090909
	1.0270836908151615	1.032437238217559	'line_2105_to_2177_1_cp'	0.014045454545454545
	1.0364941520231346	1.0445815582714937	'line_2106_to_2129_1_cp'	0.014909090909090908
	1.0364941520231346	1.032437238217559	'line_2106_to_2177_1_cp'	0.014136363636363636
	1.0391178703768236	1.037898864250145	'line_2108_to_2125_1_cp'	0.01718181818181818
	1.0391178703768236	1.0561441579753095	'line_2108_to_2145_1_cp'	0.013636363636363636
	1.03180031538688	1.0283297221692886	'line_2109_to_2154_1_cp'	0.014227272727272727
	1.0278826120867424	1.0276028619264685	'line_2112_to_2146_1_cp'	0.025136363636363637
	1.0293753296471237	1.029314972054619	'line_2113_to_2181_2_cp'	0.023636363636363636
	1.0389037801581105	1.0388375032417827	'line_2114_to_2182_1_cp'	0.025090909090909087
	0.9994914159174169	0.9990847049426628	'line_2117_to_2167_1_cp'	0.023090909090909092
	1.0104222156038478	1.0123657147415706	'line_2118_to_2121_1_cp'	0.02559090909090909
	1.0104222156038478	1.0123657147415706	'line_2118_to_2121_2_cp'	0.023954545454545454
	1.0104222156038478	1.0089699071460618	'line_2118_to_2174_1_cp'	0.025181818181818184
	1.0104222156038478	1.0089699071460618	'line_2118_to_2174_2_cp'	0.025181818181818184
	1.0104222156038478	1.0164286663626432	'line_2118_to_2185_1_cp_merged_with_line_2173_to_2185_1_cp_merged_with_line_2173_to_2188_1_cp'	0.012136363636363636
	1.0654399949716435	1.069879217701255	'line_2119_to_2148_1_cp_merged_with_xf_2119_to_2014_1_2winding_transformer'	0.016954545454545455
	1.0635490338094427	1.04073141734993	'line_2120_to_2126_1_cp'	0.013954545454545454
	1.0635490338094427	1.04073141734993	'line_2120_to_2126_2_cp'	0.013500000000000002
	1.0635490338094427	1.0654399949716435	'line_2120_to_2148_1_cp'	0.017454545454545455
	1.0635490338094427	1.0654399949716435	'line_2120_to_2148_2_cp'	0.01718181818181818
	1.0635490338094427	1.0302542807874677	'line_2120_to_2169_1_cp'	0.017454545454545455
	1.0493858638064606	1.0654399949716435	'line_2122_to_2148_1_cp'	0.01709090909090909
	1.0493858638064606	1.0654399949716435	'line_2122_to_2148_2_cp'	0.016863636363636362
	1.0493858638064606	1.029314972054619	'line_2122_to_2181_1_cp'	0.017863636363636363
	1.037898864250145	1.0302542807874677	'line_2125_to_2169_1_cp'	0.01718181818181818
	1.04073141734993	1.0302542807874677	'line_2126_to_2169_1_cp'	0.013590909090909093
	1.04073141734993	1.0302542807874677	'line_2126_to_2169_2_cp'	0.014090909090909091
	1.0265782328339241	1.0276028619264685	'line_2128_to_2146_1_cp'	0.01690909090909091
	1.0265782328339241	1.0276028619264685	'line_2128_to_2146_2_cp'	0.016954545454545455
	1.0265782328339241	1.0271275880037158	'line_2128_to_2160_1_cp'	0.017045454545454544
	1.0265782328339241	1.0271614222991463	'line_2128_to_2161_2_cp'	0.017045454545454544
	1.0265782328339241	1.0222625848284896	'line_2128_to_2189_1_cp'	0.017863636363636363
	1.0445815582714937	1.0277318422118547	'line_2129_to_2162_1_cp'	0.014727272727272728
	1.033339924337191	1.034462527132706	'line_2133_to_2135_3_cp_merged_with_xf_2199_to_2133_3_2winding_transformer'	0.04790909090909091
	1.033339924337191	1.0237023120942723	'line_2135_to_2187_2_cp'	0.01890909090909091
	1.0052295701868754	1.013034126931125	'line_2138_to_2163_1_cp'	0.01840909090909091
	1.0052295701868754	1.013034126931125	'line_2138_to_2163_2_cp'	0.019
	1.0052295701868754	1.0024287945958177	'line_2138_to_2186_1_cp'	0.02009090909090909
	1.0561441579753095	1.042083523181313	'line_2145_to_2179_1_cp'	0.01368181818181818
	1.0276028619264685	1.0222625848284896	'line_2146_to_2189_1_cp'	0.018454545454545453
	1.0306345320551191	1.027985355911396	'line_2147_to_2180_1_cp'	0.019136363636363635
	1.0306345320551191	1.029314972054619	'line_2147_to_2181_2_cp'	0.019227272727272728
	1.0306345320551191	1.0293437913519732	'line_2147_to_2184_1_cp'	0.024863636363636362
	1.0306345320551191	1.0293437913519732	'line_2147_to_2184_2_cp'	0.024454545454545455
	0.9869244155817227	0.9869187306539968	'line_2149_to_2150_1_cp_merged_with_xf_2202_to_2149_1_2winding_transformer'	0.03563636363636363
	1.0177457459013304	1.0124597568092257	'line_2151_to_2175_2_cp'	0.021666666666666667
	1.0124597568092257	1.0155319559131113	'line_2152_to_2175_1_cp_merged_with_xf_2152_to_2342_2_2winding_transformer'	0.03090909090909091
	1.0283297221692886	1.0134841085503254	'line_2154_to_2176_1_cp'	0.018045454545454545
	1.0096840375413823	1.014455037066262	'line_2158_to_2164_1_cp'	0.017045454545454544
	1.0096840375413823	1.014455037066262	'line_2158_to_2164_2_cp'	0.017545454545454545
	1.0277318422118547	1.042083523181313	'line_2162_to_2179_1_cp'	0.013772727272727272
	1.013034126931125	0.9990847049426628	'line_2163_to_2167_1_cp'	0.02159090909090909
	1.013034126931125	0.9990847049426628	'line_2163_to_2167_2_cp'	0.02090909090909091
	1.013034126931125	1.029314972054619	'line_2163_to_2181_1_cp'	0.02609090909090909
	1.013034126931125	1.0024287945958177	'line_2163_to_2186_1_cp'	0.018954545454545453
	1.014455037066262	1.0143264102623815	'line_2164_to_2165_1_cp_merged_with_xf_2206_to_2165_1_2winding_transformer'	0.08163636363636365
	1.014455037066262	1.0214304760171413	'line_2164_to_2168_1_cp'	0.025227272727272727
	1.014455037066262	1.0281879523224695	'line_2164_to_2178_1_cp'	0.023272727272727275
	1.014455037066262	1.0024287945958177	'line_2164_to_2186_2_cp'	0.019454545454545457
	1.014455037066262	1.0024287945958177	'line_2164_to_2186_3_cp'	0.01890909090909091
	1.014455037066262	1.0024287945958177	'line_2164_to_2186_4_cp'	0.0195
	1.0214304760171413	1.027985355911396	'line_2168_to_2180_1_cp'	0.019
	1.0281879523224695	1.0388375032417827	'line_2178_to_2182_1_cp'	0.016409090909090908
	1.0344594764285133	1.0194626718985782	'line_2190_to_2191_1_cp'	0.021272727272727273
	1.0344594764285133	1.0194626718985782	'line_2190_to_2191_2_cp'	0.019575757575757576
	1.0344594764285133	1.0322008155706763	'line_2190_to_2192_2_cp'	0.019545454545454546
	1.0344594764285133	1.0295076175591582	'line_2190_to_2193_1_cp_merged_with_line_2193_to_2194_1_RLC'	0.02033333333333333
	1.0344594764285133	1.038048778886522	'line_2190_to_2195_1_cp'	0.02112121212121212
	1.0620907885731898	1.0501514889947825	'line_2196_to_4151_1_cp'	0.0188
	1.0620907885731898	1.0501514889947825	'line_2196_to_4151_2_cp'	0.018945454545454547
	1.0418947584691465	1.0365619856178674	'line_2198_to_2199_1_cp'	0.03096
	1.0418947584691465	1.0426310460289758	'line_2198_to_2206_1_cp'	0.03098
	1.0365619856178674	1.0360913314288451	'line_2199_to_2202_1_cp'	0.03068
	1.0365619856178674	1.0360913314288451	'line_2199_to_2202_2_cp'	0.02996
	1.0365619856178674	1.0360913314288451	'line_2199_to_2202_3_cp'	0.030359999999999998
	1.0365619856178674	1.0426310460289758	'line_2199_to_2206_1_cp'	0.02862
	1.0365619856178674	1.0422310028446866	'line_2199_to_2207_1_cp'	0.03138
	1.0365619856178674	1.0422310028446866	'line_2199_to_2207_2_cp'	0.030359999999999998
	1.0312955996739888	1.0447962211422892	'line_2200_to_2204_1_cp'	0.0265
	1.0312955996739888	1.026360517721799	'line_2200_to_2205_1_cp'	0.027420000000000003
	1.0312955996739888	1.026360517721799	'line_2200_to_2205_2_cp'	0.02714
	1.0312955996739888	1.0391495489857399	'line_2200_to_2209_1_cp'	0.027260000000000003
	1.04037655437862	1.0422310028446866	'line_2201_to_2207_1_cp'	0.03032
	1.04037655437862	1.042455349871639	'line_2201_to_2208_1_cp'	0.03034
	1.0360913314288451	1.0365999999974678	'line_2202_to_5001_1_cp'	0.03322
	1.0442912206410735	1.0447962211422892	'line_2203_to_2204_1_cp'	0.02784
	1.0442912206410735	1.042455349871639	'line_2203_to_2208_1_cp'	0.02944
	1.0442912206410735	1.042455349871639	'line_2203_to_2208_2_cp'	0.03066
	1.0442912206410735	1.0391495489857399	'line_2203_to_2209_1_cp'	0.02872
	1.0426310460289758	1.0422310028446866	'line_2206_to_2207_1_cp'	0.031039999999999998
	1.0422310028446866	1.042455349871639	'line_2207_to_2208_1_cp'	0.03066
	1.0422310028446866	1.042455349871639	'line_2207_to_2208_2_cp'	0.030699999999999998
	1.0440004550199131	1.04307708634428	'line_2210_to_2217_1_cp'	0.012424242424242423
	1.0440004550199131	1.0421770232598715	'line_2210_to_2218_1_cp'	0.014393939393939393
	1.0440004550199131	1.0368412117913928	'line_2210_to_2252_1_cp'	0.013484848484848485
	1.0440004550199131	1.0422473760135194	'line_2210_to_2294_1_cp'	0.014393939393939393
	1.042730986394065	1.0400164024998542	'line_2211_to_2221_1_cp'	0.011363636363636364
	1.009067985406847	0.9900208978318991	'line_2213_to_2215_1_cp'	0.007727272727272728
	1.009067985406847	0.9822646387116701	'line_2213_to_2216_1_cp'	0.00696969696969697
	1.0017018149568493	0.9900208978318991	'line_2214_to_2215_1_cp'	0.012272727272727274
	1.0017018149568493	0.9900208978318991	'line_2214_to_2215_2_cp'	0.013030303030303031
	1.0017018149568493	0.9834928899077741	'line_2214_to_2226_1_cp'	0.005606060606060606
	0.9822646387116701	0.9823000859441028	'line_2216_to_2240_1_cp'	0.00696969696969697
	1.0421770232598715	1.0400164024998542	'line_2218_to_2221_1_cp'	0.014696969696969696
	1.0064267947848775	1.0198456073735385	'line_2219_to_2280_1_cp'	0.012878787878787878
	1.0064267947848775	1.006706870991193	'line_2219_to_2282_1_cp'	0.013030303030303031
	1.0400164024998542	0.9726980524251206	'line_2221_to_2225_1_cp'	0.006666666666666667
	1.0400164024998542	1.0368412117913928	'line_2221_to_2252_1_cp'	0.013636363636363637
	1.0400164024998542	1.0422473760135194	'line_2221_to_2294_1_cp'	0.014393939393939393
	0.9726980524251206	0.9834928899077741	'line_2225_to_2226_1_cp'	0.005151515151515152
	1.030997562284866	1.0234818229410212	'line_2229_to_2251_1_cp'	0.007272727272727273
	0.994340766423584	0.9934385199584951	'line_2230_to_2238_1_cp'	0.012878787878787878
	1.0200330277634329	0.9838416523871392	'line_2234_to_2235_1_cp'	0.012727272727272726
	1.0200330277634329	0.9838416523871392	'line_2234_to_2235_2_cp'	0.012878787878787878
	0.9838416523871392	0.956721029311477	'line_2235_to_2257_1_cp'	0.007121212121212121
	1.0144860053343752	0.9934385199584951	'line_2236_to_2238_1_cp'	0.011818181818181818
	0.9899854249849279	0.9823000859441028	'line_2239_to_2240_1_cp'	0.013787878787878788
	0.9899854249849279	0.9823000859441028	'line_2239_to_2240_2_cp'	0.007121212121212121
	0.9899854249849279	1.0043201676527163	'line_2239_to_2266_1_cp'	0.006818181818181819
	1.0207784393983206	1.0248053419219398	'line_2242_to_2254_1_cp'	0.012575757575757575
	1.0207784393983206	1.0042748019088688	'line_2242_to_2261_1_cp'	0.010151515151515153
	1.0334726412811348	1.0250530594832699	'line_2244_to_2253_1_cp_merged_with_line_2242_to_2253_2_cp'	0.012575757575757575
	1.0352174218420755	1.0248053419219398	'line_2245_to_2254_2_cp'	0.012727272727272726
	1.0234818229410212	0.9909058445427912	'line_2251_to_2256_1_cp'	0.00696969696969697
	1.0027719353896971	1.0042748019088688	'line_2255_to_2261_1_cp'	0.012575757575757575
	1.0027719353896971	1.0042748019088688	'line_2255_to_2261_3_cp'	0.015
	1.0027719353896971	1.0042748019088688	'line_2255_to_2261_4_cp'	0.014090909090909091
	1.0027719353896971	1.0042217700329454	'line_2255_to_2262_2_cp'	0.012575757575757575
	0.9909058445427912	0.956721029311477	'line_2256_to_2257_1_cp'	0.007272727272727273
	1.0042748019088688	1.0038935475631665	'line_2258_to_2261_2_cp_merged_with_xf_2258_to_2065_1_2winding_transformer'	0.015
	1.0042217700329454	1.0039229430852405	'line_2259_to_2262_3_cp_merged_with_xf_2259_to_2066_2_2winding_transformer'	0.015151515151515152
	1.0599256241955863	1.0617154866256109	'line_2265_to_2351_1_cp'	0.013181818181818182
	1.050742958373633	1.0617154866256109	'line_2269_to_2351_1_cp'	0.013181818181818182
	1.0198456073735385	1.0201535774737627	'line_2280_to_2283_1_cp'	0.007121212121212121
	1.0198456073735385	1.0617154866256109	'line_2280_to_2351_1_cp'	0.006818181818181819
	0.9962468899464141	0.9955203572134046	'line_2307_to_2311_5_cp'	0.010454545454545454
	0.9955470278351464	0.9955203572134046	'line_2309_to_2311_7_cp'	0.010454545454545454
	1.0586627881895136	1.0537960653691603	'line_3004_to_3005_1_cp'	0.007272727272727273
	1.0586627881895136	1.0446542061095188	'line_3004_to_3006_1_cp'	0.00696969696969697
	1.0537960653691603	1.0446542061095188	'line_3005_to_3006_1_cp'	0.005151515151515152
	1.0289021717767772	1.0319209151355748	'line_3009_to_3116_1_cp'	0.010833333333333334
	1.0289021717767772	1.0381878521793053	'line_3009_to_3475_2_cp'	0.010909090909090908
	1.0290967552575576	1.0305140831513082	'line_3010_to_3174_1_cp'	0.010984848484848484
	1.0290967552575576	1.0381878521793053	'line_3010_to_3475_1_cp'	0.010833333333333334
	1.0364131468162001	1.050252844377841	'line_3014_to_3491_1_cp'	0.006454545454545454
	1.050252844377841	1.0221888622885926	'line_3015_to_3491_2_cp_merged_with_xf_3015_to_3016_2_2winding_transformer'	0.0032727272727272726
	1.0337479247836963	1.0310037495537765	'line_3017_to_3019_2_cp'	0.016181818181818183
	1.0337479247836963	1.0409391994852273	'line_3017_to_3314_2_cp'	0.012363636363636365
	1.0337479247836963	1.051417699010259	'line_3017_to_3636_2_cp'	0.012363636363636365
	1.0337348764814718	1.0310037495537765	'line_3018_to_3019_1_cp'	0.01672727272727273
	1.0337348764814718	1.0375448374861882	'line_3018_to_3312_1_cp'	0.012181818181818183
	1.0337348764814718	1.051417699010259	'line_3018_to_3636_1_cp'	0.012
	1.036592902205884	1.0381878521793053	'line_3021_to_3475_1_cp'	0.010454545454545454
	1.036592902205884	1.0381878521793053	'line_3021_to_3475_2_cp'	0.010454545454545454
	1.036592902205884	1.03017765229874	'line_3021_to_3634_1_cp'	0.011212121212121211
	1.0161907348636712	1.0262077023790948	'line_3023_to_3063_1_cp'	0.00840909090909091
	1.0161907348636712	1.0262077023790948	'line_3023_to_3063_2_cp'	0.009015151515151514
	1.0161907348636712	1.0141913476922	'line_3023_to_3114_1_cp'	0.008712121212121211
	1.0161907348636712	1.0155621430116106	'line_3023_to_3195_1_cp'	0.008712121212121211
	1.0292877452362879	1.0365651457876486	'line_3024_to_3261_1_cp'	0.008787878787878787
	1.0292877452362879	1.0365651457876486	'line_3024_to_3261_2_cp'	0.008484848484848486
	1.0292877452362879	1.0082411253773038	'line_3024_to_3497_1_cp'	0.013712121212121212
	1.0292877452362879	1.0084549554835758	'line_3024_to_3498_2_cp'	0.014393939393939393
	1.0212929361904561	1.0248033998463584	'line_3034_to_3187_1_cp'	0.010909090909090908
	1.0212929361904561	1.0248033998463584	'line_3034_to_3187_2_cp'	0.010757575757575757
	1.0212929361904561	1.0330303792594357	'line_3034_to_3476_1_cp'	0.013409090909090909
	1.0212929361904561	1.0330303792594357	'line_3034_to_3476_2_cp'	0.013106060606060605
	1.0248520074786522	1.023206773303602	'line_3039_to_3050_2_cp'	0.00856060606060606
	1.0248520074786522	1.0222648268900538	'line_3039_to_3051_1_cp'	0.00856060606060606
	1.0248520074786522	1.0303570833809834	'line_3039_to_3060_1_cp'	0.012878787878787878
	1.0248520074786522	1.0293831318153166	'line_3039_to_3217_2_cp'	0.012045454545454547
	1.0248520074786522	1.0294163002118872	'line_3039_to_3218_1_cp'	0.012272727272727274
	1.007439738157707	1.02049328440315	'line_3044_to_3482_2_cp'	0.010151515151515153
	1.0468016831212672	1.0438479914377945	'line_3048_to_3229_1_cp'	0.012181818181818183
	1.0468016831212672	1.0535089489250082	'line_3048_to_3471_1_cp'	0.012090909090909091
	1.023206773303602	1.0194107442405447	'line_3050_to_3054_1_cp'	0.008712121212121211
	1.0194107442405447	1.0303570833809834	'line_3054_to_3060_1_cp'	0.00893939393939394
	1.0392825932556982	1.0247578348022273	'line_3056_to_3342_1_cp'	0.00909090909090909
	1.0392825932556982	1.050252844377841	'line_3056_to_3491_1_cp'	0.00909090909090909
	1.0392825932556982	1.050252844377841	'line_3056_to_3491_2_cp'	0.019909090909090908
	1.042331573253571	1.0413509586038536	'line_3058_to_3371_1_cp'	0.013181818181818182
	1.042331573253571	1.0466991902690372	'line_3058_to_3506_1_cp'	0.014272727272727274
	1.042331573253571	1.0466991902690372	'line_3058_to_3506_2_cp'	0.014
	1.0303570833809834	1.03816112705531	'line_3060_to_3151_1_cp'	0.012651515151515151
	1.0303570833809834	1.0320365934262394	'line_3060_to_3274_1_cp'	0.00893939393939394
	1.0283495431315726	1.03816112705531	'line_3061_to_3151_1_cp'	0.012878787878787878
	1.0283495431315726	1.0294897149655908	'line_3061_to_3232_1_cp'	0.013106060606060605
	1.0283495431315726	1.0336999999991696	'line_3061_to_3272_1_cp'	0.010984848484848484
	1.0283495431315726	1.0320365934262394	'line_3061_to_3274_1_cp'	0.008787878787878787
	1.0283495431315726	1.023950688413203	'line_3061_to_3492_1_cp'	0.013030303030303031
	1.0283495431315726	1.023950688413203	'line_3061_to_3492_2_cp'	0.013333333333333334
	1.0283495431315726	1.023950688413203	'line_3061_to_3492_3_cp'	0.013712121212121212
	1.0262077023790948	1.026257734190062	'line_3063_to_3164_1_cp'	0.00893939393939394
	1.0262077023790948	1.0333453208008818	'line_3063_to_3165_1_cp'	0.008636363636363636
	1.0262077023790948	1.0378525164901766	'line_3063_to_3169_1_cp'	0.008863636363636363
	1.0262077023790948	1.0261596695477804	'line_3063_to_3196_1_cp'	0.012954545454545455
	1.0262077023790948	1.0180065325638106	'line_3063_to_3262_1_cp'	0.013106060606060605
	1.0262077023790948	1.025893687193441	'line_3063_to_3277_1_cp'	0.008484848484848486
	1.0262077023790948	1.031229999998896	'line_3063_to_3285_1_cp'	0.012575757575757575
	1.0234824138305099	1.0333453208008818	'line_3065_to_3165_1_cp'	0.00856060606060606
	1.0234824138305099	1.0305333547113553	'line_3065_to_3167_1_cp'	0.013409090909090909
	1.0234824138305099	1.025893687193441	'line_3065_to_3277_1_cp'	0.008712121212121211
	1.0273243291009568	1.0266838376064782	'line_3067_to_3068_1_cp'	0.008863636363636363
	1.0266838376064782	1.027317057971494	'line_3068_to_3096_1_cp'	0.01
	1.0266838376064782	1.0223933312724258	'line_3068_to_3259_1_cp'	0.010454545454545454
	1.024493312990593	1.0281710210677515	'line_3069_to_3201_1_cp'	0.012499999999999999
	1.024493312990593	1.0281710210677515	'line_3069_to_3201_2_cp'	0.01446969696969697
	1.0413748054288365	1.0319209151355748	'line_3072_to_3116_1_cp'	0.011136363636363637
	1.0413748054288365	1.0472669530587848	'line_3072_to_3479_1_cp'	0.012196969696969697
	1.0412610839276606	1.0319209151355748	'line_3073_to_3116_2_cp'	0.010909090909090908
	1.0412610839276606	1.0472669530587848	'line_3073_to_3479_2_cp'	0.01196969696969697
	1.0384628061631807	1.034834466598855	'line_3076_to_3276_1_cp'	0.008787878787878787
	1.0384628061631807	1.037946953243329	'line_3076_to_3283_1_cp'	0.007727272727272728
	1.0384628061631807	1.0377671163881246	'line_3076_to_3401_1_cp'	0.00787878787878788
	1.0212063782331802	1.0222185219794357	'line_3077_to_3643_1_cp'	0.00840909090909091
	1.0212842280787977	1.0222185219794357	'line_3078_to_3643_2_cp'	0.008863636363636363
	1.0264331222195273	1.0276365114212522	'line_3080_to_3189_1_cp'	0.01659090909090909
	1.0264331222195273	1.0237657358023062	'line_3080_to_3240_1_cp'	0.015681818181818182
	1.0264331222195273	1.0220542253947085	'line_3080_to_3523_1_cp'	0.01962121212121212
	1.0264331222195273	1.0254758714941408	'line_3080_to_3529_1_cp'	0.018787878787878787
	1.0180851316148378	1.0211714148276538	'line_3083_to_3182_1_cp'	0.015984848484848484
	1.0180851316148378	1.0237657358023062	'line_3083_to_3240_1_cp'	0.016136363636363636
	1.0196292363902562	1.019650000724481	'line_3088_to_3092_2_cp_merged_with_xf_3092_to_3448_1_2winding_transformer'	0.0067424242424242425
	1.0196292363902562	1.0220542253947085	'line_3088_to_3523_1_cp'	0.00856060606060606
	1.023034492430331	1.0220542253947085	'line_3089_to_3523_2_cp'	0.008863636363636363
	1.0102681581421296	1.0111342091242483	'line_3094_to_3225_1_cp'	0.00909090909090909
	1.0102681581421296	1.0111342091242483	'line_3094_to_3225_2_cp'	0.008636363636363636
	1.0102681581421296	1.0142144909771507	'line_3094_to_3516_1_cp'	0.014015151515151515
	1.0102681581421296	1.0142144909771507	'line_3094_to_3516_2_cp'	0.013787878787878788
	1.027317057971494	1.0256015392868196	'line_3096_to_3198_1_cp'	0.012727272727272726
	1.027317057971494	1.025680809310325	'line_3096_to_3199_2_cp'	0.013333333333333334
	1.027317057971494	1.0273200096005546	'line_3096_to_3207_2_cp_merged_with_xf_3207_to_3459_1_2winding_transformer'	0.03143939393939394
	1.027317057971494	1.0273199678451659	'line_3096_to_3208_1_cp_merged_with_xf_3208_to_3460_2_2winding_transformer'	0.03181818181818182
	1.027317057971494	1.0260032432359902	'line_3096_to_3209_3_cp'	0.01583333333333333
	1.027317057971494	1.0223933312724258	'line_3096_to_3259_1_cp'	0.01037878787878788
	1.027317057971494	1.0263641792535871	'line_3096_to_3486_1_cp'	0.016363636363636365
	1.027317057971494	1.0263641792535871	'line_3096_to_3486_2_cp'	0.015075757575757576
	1.0313869276633363	1.050252844377841	'line_3099_to_3491_1_cp'	0.006272727272727272
	1.0313869276633363	1.050252844377841	'line_3099_to_3491_2_cp'	0.012545454545454544
	1.0136379584724031	1.03017765229874	'line_3101_to_3634_2_cp'	0.010303030303030303
	1.0243597437509022	1.03017765229874	'line_3102_to_3634_1_cp'	0.018712121212121215
	1.016679520434572	1.02049328440315	'line_3106_to_3482_1_cp'	0.010303030303030303
	1.0344986467366872	1.0438531915860265	'line_3108_to_3159_1_cp'	0.008712121212121211
	1.0344986467366872	1.0281710210677515	'line_3108_to_3201_1_cp'	0.014318181818181817
	1.0344986467366872	1.0331436936848408	'line_3108_to_3243_2_cp'	0.012045454545454547
	1.0344986467366872	1.0332071580202205	'line_3108_to_3244_1_cp_merged_with_xf_3244_to_3659_2_2winding_transformer'	0.01196969696969697
	1.0344986467366872	1.036419001025182	'line_3108_to_3258_1_cp'	0.010151515151515153
	1.0344986467366872	1.0309429234681395	'line_3108_to_3483_1_cp'	0.013257575757575758
	1.0255512138954759	1.0261596695477804	'line_3111_to_3196_1_cp'	0.013257575757575758
	1.0255512138954759	1.0309429234681395	'line_3111_to_3483_1_cp'	0.013257575757575758
	1.0141913476922	1.0323362813759733	'line_3114_to_3172_1_cp'	0.008484848484848486
	1.0319209151355748	1.0317034245921772	'line_3116_to_3542_1_cp'	0.010681818181818181
	1.0408894579565917	1.0599303152185673	'line_3117_to_3120_1_cp'	0.00909090909090909
	1.0408894579565917	1.023950688413203	'line_3117_to_3492_1_cp'	0.013409090909090909
	1.04772728170845	1.0514443596165244	'line_3123_to_3473_1_cp'	0.01718181818181818
	1.04772728170845	1.0497379833164973	'line_3123_to_3633_1_cp'	0.01718181818181818
	1.0699679469431158	1.070013416254163	'line_3128_to_3291_1_cp_merged_with_xf_3291_to_3292_1_2winding_transformer'	0.011363636363636364
	1.0699679469431158	1.0263641792535871	'line_3128_to_3486_1_cp'	0.008636363636363636
	1.020704761077681	1.0247578348022273	'line_3129_to_3342_1_cp'	0.008909090909090908
	1.020704761077681	1.0408467884179144	'line_3129_to_3467_1_cp'	0.009545454545454546
	1.0532851732957473	1.0561730206506255	'line_3131_to_3519_1_cp'	0.011818181818181818
	1.0532851732957473	1.0502354939871437	'line_3131_to_3534_1_cp'	0.012363636363636365
	1.0394759467047827	1.0321125855093827	'line_3134_to_3340_1_cp'	0.01
	1.0394759467047827	1.0497379833164973	'line_3134_to_3633_1_cp'	0.011727272727272727
	1.0394759467047827	1.0497379833164973	'line_3134_to_3633_2_cp'	0.012181818181818183
	1.0132171713919789	1.0365651457876486	'line_3137_to_3261_1_cp'	0.008787878787878787
	1.0132171713919789	1.0365651457876486	'line_3137_to_3261_2_cp'	0.008636363636363636
	1.0226912664881447	1.0263641792535871	'line_3140_to_3486_2_cp'	0.012045454545454547
	1.0226912664881447	1.0222185219794357	'line_3140_to_3643_2_cp'	0.010227272727272727
	1.0226651991514544	1.0263641792535871	'line_3141_to_3486_1_cp'	0.011136363636363637
	1.0226651991514544	1.0222185219794357	'line_3141_to_3643_1_cp'	0.010833333333333334
	1.0378711659414113	1.0350468100250783	'line_3142_to_3270_1_cp'	0.010454545454545454
	1.0378711659414113	1.037946953243329	'line_3142_to_3283_1_cp'	0.010454545454545454
	1.0378711659414113	1.0398279138845585	'line_3142_to_3310_1_cp'	0.010151515151515153
	1.021431058605197	1.0220542253947085	'line_3143_to_3523_2_cp'	0.010681818181818181
	1.0217126032794825	1.0220542253947085	'line_3144_to_3523_1_cp'	0.010984848484848484
	1.0260032432359902	1.0245840758066787	'line_3146_to_3209_1_cp_merged_with_xf_3146_to_3147_1_2winding_transformer'	0.017045454545454544
	1.0406817513844733	1.0377671163881246	'line_3147_to_3401_1_cp'	0.007727272727272728
	0.9912296672925697	1.0263641792535871	'line_3148_to_3486_1_cp'	0.008863636363636363
	1.0412072312580054	1.03816112705531	'line_3150_to_3151_1_cp'	0.009166666666666667
	1.0379228081903622	1.0287009106648917	'line_3152_to_3510_1_cp'	0.00893939393939394
	1.0205736616202894	1.02049328440315	'line_3153_to_3482_1_cp'	0.009242424242424243
	1.0250303845508895	1.0237142913897863	'line_3157_to_3216_1_cp'	0.01734848484848485
	1.0554790935884322	1.054828266288986	'line_3158_to_3612_1_cp'	0.028290909090909092
	1.0554790935884322	1.0547772558188189	'line_3158_to_3613_2_cp'	0.027163636363636362
	1.0554790935884322	1.052099348636059	'line_3158_to_3624_1_cp'	0.02650909090909091
	1.0554790935884322	1.052099348636059	'line_3158_to_3624_2_cp'	0.02530909090909091
	1.0397368055003409	1.0309429234681395	'line_3160_to_3483_1_cp'	0.009015151515151514
	1.032789804352927	1.03525990207259	'line_3161_to_3162_1_cp'	0.009015151515151514
	1.032789804352927	1.031229999998896	'line_3161_to_3285_1_cp'	0.012954545454545455
	1.032789804352927	1.0309429234681395	'line_3161_to_3483_1_cp'	0.013030303030303031
	1.0371078426096563	1.0354401604178536	'line_3163_to_3385_1_cp'	0.010181818181818183
	1.0371078426096563	1.0535089489250082	'line_3163_to_3471_1_cp'	0.010545454545454545
	1.0371078426096563	1.0433466205221438	'line_3163_to_3504_1_cp'	0.015363636363636362
	1.0371078426096563	1.0433466205221438	'line_3163_to_3504_2_cp'	0.015818181818181818
	1.0371078426096563	1.0303045144144383	'line_3163_to_3635_1_cp'	0.009363636363636364
	1.0305333547113553	1.0358121268195037	'line_3167_to_3168_1_cp'	0.008636363636363636
	1.0305333547113553	1.023950688413203	'line_3167_to_3492_1_cp'	0.014015151515151515
	1.0496325421037545	1.050252844377841	'line_3170_to_3491_2_cp'	0.013
	1.0445828389285827	1.050252844377841	'line_3171_to_3491_1_cp'	0.013
	1.0323362813759733	1.0309946199603235	'line_3172_to_3246_1_cp'	0.012045454545454547
	1.0323362813759733	1.0290503937424909	'line_3172_to_3247_1_cp'	0.008712121212121211
	1.0323362813759733	1.037014828936919	'line_3172_to_3518_1_cp'	0.011590909090909091
	1.0323362813759733	0.9685350983831894	'line_3172_to_3626_1_cp'	0.008712121212121211
	1.0323362813759733	0.9685350983831894	'line_3172_to_3626_2_cp'	0.008636363636363636
	1.040143631965375	1.0381878521793053	'line_3173_to_3475_1_cp'	0.010681818181818181
	1.0305140831513082	1.0317034245921772	'line_3174_to_3542_1_cp'	0.010909090909090908
	1.0493864438536065	1.0514443596165244	'line_3177_to_3473_1_cp'	0.01681818181818182
	1.0493864438536065	1.0497379833164973	'line_3177_to_3633_1_cp'	0.016272727272727272
	1.0211714148276538	1.0220542253947085	'line_3182_to_3523_1_cp'	0.015454545454545455
	1.0335096765157539	1.036470356172734	'line_3184_to_3263_1_cp'	0.014242424242424242
	1.0248033998463584	1.03017765229874	'line_3187_to_3634_1_cp'	0.011287878787878788
	1.0248033998463584	1.03017765229874	'line_3187_to_3634_2_cp'	0.010681818181818181
	1.0276365114212522	1.027738328718888	'line_3189_to_3223_1_cp'	0.017045454545454544
	1.0260256752433605	1.0260032432359902	'line_3190_to_3209_1_cp'	0.015075757575757576
	1.0442693846390336	1.0442771788481782	'line_3192_to_3231_1_cp'	0.012909090909090908
	1.0442693846390336	1.0408467884179144	'line_3192_to_3467_1_cp'	0.009454545454545455
	1.0442693846390336	1.0466991902690372	'line_3192_to_3506_1_cp'	0.012545454545454544
	1.0442693846390336	1.0502354939871437	'line_3192_to_3534_1_cp'	0.012363636363636365
	1.014317652655015	1.0155621430116106	'line_3194_to_3195_1_cp'	0.008787878787878787
	1.0155621430116106	1.0290503937424909	'line_3195_to_3247_1_cp'	0.008484848484848486
	1.0281710210677515	1.0309429234681395	'line_3201_to_3483_1_cp'	0.012954545454545455
	1.0281710210677515	1.0309429234681395	'line_3201_to_3483_2_cp'	0.012651515151515151
	1.0281710210677515	1.0309429234681395	'line_3201_to_3483_3_cp'	0.013560606060606061
	1.045692882580452	1.0477999490967573	'line_3203_to_3496_3_cp'	0.013818181818181818
	1.0455776822444391	1.0477999490967573	'line_3204_to_3496_2_cp'	0.01390909090909091
	1.0460479933504254	1.0477999490967573	'line_3205_to_3496_1_cp'	0.013818181818181818
	1.0417517919463866	1.051812300556659	'line_3210_to_3267_1_cp_merged_with_xf_3210_to_3463_2_2winding_transformer'	0.024090909090909093
	1.0247363026510183	1.0254758714941408	'line_3211_to_3529_1_cp'	0.01553030303030303
	1.0247363026510183	1.0222185219794357	'line_3211_to_3643_1_cp'	0.01553030303030303
	1.0439937622318372	1.0440427095297347	'line_3214_to_3255_1_cp'	0.018818181818181817
	1.0439937622318372	1.0430345232415545	'line_3214_to_3256_2_cp'	0.019090909090909092
	1.0439937622318372	1.050252844377841	'line_3214_to_3491_1_cp'	0.019727272727272725
	1.0439937622318372	1.050252844377841	'line_3214_to_3491_2_cp'	0.019272727272727275
	1.0439937622318372	1.0385644359497237	'line_3214_to_3625_1_cp'	0.006454545454545454
	1.0439937622318372	1.0385644359497237	'line_3214_to_3625_2_cp'	0.006363636363636363
	1.0237142913897863	1.025124583962491	'line_3216_to_3533_1_cp'	0.01734848484848485
	1.0499312414050945	1.0479708469732791	'line_3222_to_3226_1_cp'	0.011636363636363637
	1.0499312414050945	1.0466991902690372	'line_3222_to_3506_1_cp'	0.012090909090909091
	1.0499312414050945	1.0561730206506255	'line_3222_to_3519_1_cp'	0.011636363636363637
	1.0499312414050945	1.0561730206506255	'line_3222_to_3519_2_cp'	0.012181818181818183
	1.0499312414050945	1.0417897728865064	'line_3222_to_3623_1_cp'	0.011818181818181818
	1.027738328718888	1.0254758714941408	'line_3223_to_3529_1_cp'	0.016212121212121212
	1.0111342091242483	1.0085726181355212	'line_3225_to_3332_1_cp'	0.007954545454545455
	1.0111342091242483	1.0085726181355212	'line_3225_to_3332_2_cp'	0.008484848484848486
	1.0479708469732791	1.0477999490967573	'line_3226_to_3496_1_cp'	0.012090909090909091
	1.0438479914377945	1.0535089489250082	'line_3229_to_3471_1_cp'	0.011727272727272727
	1.0438479914377945	1.0417897728865064	'line_3229_to_3623_1_cp'	0.012363636363636365
	1.0438479914377945	1.0417897728865064	'line_3229_to_3623_2_cp'	0.012363636363636365
	1.0442771788481782	1.0502354939871437	'line_3231_to_3534_1_cp'	0.013454545454545455
	1.0294897149655908	1.0322427112451167	'line_3232_to_3298_1_cp'	0.012424242424242423
	1.0421800287062937	1.0423502883623337	'line_3237_to_3382_2_cp'	0.019181818181818182
	1.0422072976536199	1.0423502883623337	'line_3238_to_3382_1_cp'	0.019818181818181818
	1.0431882012334865	1.0309429234681395	'line_3241_to_3483_1_cp'	0.012499999999999999
	1.0411988496748878	1.0309429234681395	'line_3242_to_3483_1_cp'	0.011893939393939394
	1.0309946199603235	1.0223933312724258	'line_3246_to_3259_1_cp'	0.012272727272727274
	1.0385916052356507	1.037014828936919	'line_3248_to_3518_1_cp'	0.015378787878787877
	1.0385644359497237	1.038471748079231	'line_3252_to_3625_1_cp_merged_with_xf_3252_to_3466_1_2winding_transformer'	0.007
	1.0223933312724258	1.037014828936919	'line_3259_to_3518_1_cp'	0.012121212121212121
	1.0365651457876486	1.0341371793262377	'line_3261_to_3278_1_cp'	0.019393939393939394
	1.0365651457876486	1.0341371793262377	'line_3261_to_3278_2_cp'	0.020227272727272726
	1.036470356172734	1.038462198390625	'line_3263_to_3530_2_cp'	0.026136363636363638
	1.036470356172734	1.0383444830282431	'line_3263_to_3531_1_cp_merged_with_xf_3531_to_3604_1_2winding_transformer'	0.033030303030303035
	1.0417517919463866	1.0398279138845585	'line_3267_to_3310_1_cp'	0.011818181818181818
	1.0350468100250783	1.0338959970782755	'line_3270_to_3305_1_cp'	0.008333333333333333
	1.0319199999992439	1.0320365934262394	'line_3273_to_3274_1_cp'	0.012196969696969697
	1.0302399999994265	1.0287009106648917	'line_3275_to_3510_1_cp'	0.010833333333333334
	1.034834466598855	1.0374447783493908	'line_3276_to_3642_1_cp'	0.008636363636363636
	1.0341371793262377	1.0288908584322645	'line_3278_to_3279_1_cp'	0.015303030303030303
	1.0341371793262377	1.0288908584322645	'line_3278_to_3279_2_cp'	0.015
	1.0288908584322645	1.0248922984275333	'line_3279_to_3280_1_cp'	0.010757575757575757
	1.0288908584322645	1.0248922984275333	'line_3279_to_3280_2_cp'	0.010681818181818181
	1.0373641283680364	1.039204601596509	'line_3282_to_3536_1_cp'	0.020075757575757577
	1.0373641283680364	1.039204601596509	'line_3282_to_3536_2_cp'	0.020681818181818183
	1.0250638811143742	1.0247705604482025	'line_3284_to_3646_1_cp'	0.013106060606060605
	1.0250638811143742	1.0247705604482025	'line_3284_to_3646_2_cp'	0.012878787878787878
	1.034434088164897	1.0382246113267681	'line_3287_to_3618_1_cp'	0.010606060606060605
	1.034434088164897	1.0382246113267681	'line_3287_to_3618_2_cp'	0.010681818181818181
	1.0352842296870872	1.0382246113267681	'line_3288_to_3618_1_cp'	0.015303030303030303
	1.0352842296870872	1.0382246113267681	'line_3288_to_3618_2_cp'	0.01590909090909091
	1.0348222161511544	1.0360699531968802	'line_3289_to_3540_1_cp'	0.01590909090909091
	1.0348222161511544	1.0360699531968802	'line_3289_to_3540_2_cp'	0.015681818181818182
	1.0497464753396863	1.0497379833164973	'line_3299_to_3633_1_cp'	0.011909090909090909
	1.0361876812149728	1.0382246113267681	'line_3300_to_3618_1_cp'	0.019318181818181818
	1.0361876812149728	1.0382246113267681	'line_3300_to_3618_2_cp'	0.019924242424242424
	1.0338959970782755	1.0374447783493908	'line_3305_to_3642_1_cp'	0.010303030303030303
	1.0452266848180753	1.04478752402215	'line_3306_to_3397_1_cp'	0.008909090909090908
	1.0452266848180753	1.0471303962595127	'line_3306_to_3441_1_cp'	0.008636363636363636
	1.0451510693659691	1.04478752402215	'line_3307_to_3397_2_cp'	0.009181818181818182
	1.0451510693659691	1.0471303962595127	'line_3307_to_3441_2_cp'	0.008272727272727274
	1.0398279138845585	1.0374447783493908	'line_3310_to_3642_1_cp'	0.010606060606060605
	1.049486009129081	1.051417699010259	'line_3311_to_3636_1_cp'	0.014818181818181817
	1.0375448374861882	1.0373983545146608	'line_3312_to_3313_1_cp_merged_with_xf_3313_to_3316_1_2winding_transformer'	0.01718181818181818
	1.0375448374861882	1.0445232277893008	'line_3312_to_3480_1_cp_merged_with_xf_3480_to_3479_3_2winding_transformer'	0.020454545454545454
	1.0409391994852273	1.0395509659643336	'line_3314_to_3315_2_cp'	0.016454545454545454
	1.0352876483080564	1.0433466205221438	'line_3322_to_3504_1_cp'	0.009909090909090909
	1.0482300312947954	1.0514443596165244	'line_3324_to_3473_2_cp'	0.013
	1.0484301645581464	1.0514443596165244	'line_3325_to_3473_1_cp'	0.012909090909090908
	1.0430669908714074	1.0440330782904845	'line_3333_to_3413_1_cp'	0.019727272727272725
	1.041196059758098	1.0412245310934127	'line_3334_to_3358_1_cp'	0.007909090909090909
	1.041196059758098	1.0411083938234091	'line_3334_to_3359_2_cp'	0.008272727272727274
	1.046278241714451	1.0535089489250082	'line_3338_to_3471_2_cp'	0.015363636363636362
	1.0321125855093827	1.0303045144144383	'line_3340_to_3635_1_cp'	0.00981818181818182
	1.051417699010259	1.0520516223168137	'line_3348_to_3636_2_cp_merged_with_xf_3348_to_3351_2_2winding_transformer'	0.012272727272727274
	1.0483204427834454	1.0431795067776772	'line_3350_to_3354_1_cp_merged_with_xf_3350_to_3351_3_2winding_transformer'	0.013272727272727273
	1.0483204427834454	1.051417699010259	'line_3354_to_3636_1_cp'	0.019272727272727275
	1.0483204427834454	1.051417699010259	'line_3354_to_3636_2_cp'	0.01890909090909091
	1.04400021643653	1.0471094136655563	'line_3357_to_3503_1_cp'	0.01609090909090909
	1.04400021643653	1.0471094136655563	'line_3357_to_3503_2_cp'	0.01672727272727273
	1.041980510275131	1.0423502883623337	'line_3369_to_3382_1_cp'	0.008272727272727274
	1.0431337441186554	1.0426827070742364	'line_3374_to_3402_1_cp'	0.011727272727272727
	1.0431337441186554	1.0426827070742364	'line_3374_to_3402_2_cp'	0.011909090909090909
	1.0431337441186554	1.0471094136655563	'line_3374_to_3503_1_cp'	0.01681818181818182
	1.0431337441186554	1.0471094136655563	'line_3374_to_3503_2_cp'	0.017545454545454545
	1.0372968806134701	1.0377671163881246	'line_3375_to_3401_1_cp'	0.00803030303030303
	1.0381470649105926	1.0374447783493908	'line_3376_to_3642_1_cp'	0.007121212121212121
	1.0369333370546192	1.0433466205221438	'line_3378_to_3504_2_cp'	0.009
	1.0423502883623337	1.051417699010259	'line_3382_to_3636_1_cp'	0.017
	1.0423502883623337	1.051417699010259	'line_3382_to_3636_2_cp'	0.017
	1.0483519049452519	1.0497379833164973	'line_3386_to_3633_1_cp'	0.012454545454545456
	1.0472670667608863	1.0502354939871437	'line_3390_to_3534_2_cp'	0.012
	1.0502354939871437	1.0465584374460317	'line_3391_to_3534_1_cp_merged_with_xf_3391_to_3392_1_2winding_transformer'	0.014727272727272728
	1.0487200867191047	1.051417699010259	'line_3393_to_3636_1_cp'	0.013727272727272727
	1.0477034673644974	1.0557505026495	'line_3395_to_3470_1_cp'	0.010272727272727272
	1.0477034673644974	1.0557505026495	'line_3395_to_3470_2_cp'	0.010272727272727272
	1.0377671163881246	1.0374447783493908	'line_3401_to_3642_1_cp'	0.007727272727272728
	1.051310129278051	1.0514443596165244	'line_3404_to_3473_2_cp'	0.013727272727272727
	1.0411760475997065	1.0477999490967573	'line_3408_to_3496_1_cp'	0.010727272727272726
	1.0479226025787682	1.0440330782904845	'line_3411_to_3413_1_cp'	0.01890909090909091
	1.0479226025787682	1.0535089489250082	'line_3411_to_3471_1_cp'	0.019545454545454543
	1.0479226025787682	1.0471094136655563	'line_3411_to_3503_1_cp'	0.018
	1.0478903356401428	1.0440330782904845	'line_3412_to_3413_2_cp'	0.017818181818181816
	1.0478903356401428	1.0535089489250082	'line_3412_to_3471_2_cp'	0.019454545454545457
	1.0478903356401428	1.0471094136655563	'line_3412_to_3503_2_cp'	0.018363636363636363
	1.0471303962595127	1.0514443596165244	'line_3441_to_3473_1_cp'	0.014181818181818183
	1.0471303962595127	1.0514443596165244	'line_3441_to_3473_2_cp'	0.014727272727272728
	1.0557505026495	1.0466991902690372	'line_3470_to_3506_1_cp'	0.012
	1.0557505026495	1.0466991902690372	'line_3470_to_3506_2_cp'	0.011909090909090909
	1.0535089489250082	1.0471094136655563	'line_3471_to_3503_1_cp'	0.012545454545454544
	1.0535089489250082	1.0433466205221438	'line_3471_to_3504_1_cp'	0.016545454545454547
	1.0535089489250082	1.0433466205221438	'line_3471_to_3504_2_cp'	0.016181818181818183
	1.0330303792594357	1.0334500336914931	'line_3476_to_3627_1_cp'	0.008484848484848486
	1.0074265592053895	1.025124583962491	'line_3477_to_3533_1_cp'	0.017196969696969697
	1.0074265592053895	1.025124583962491	'line_3477_to_3533_2_cp'	0.01628787878787879
	1.0363987764622986	1.0472669530587848	'line_3478_to_3479_1_cp'	0.01583333333333333
	1.0363987764622986	1.0472669530587848	'line_3478_to_3479_2_cp'	0.01583333333333333
	1.02049328440315	1.0287009106648917	'line_3482_to_3510_1_cp'	0.00909090909090909
	1.0263641792535871	1.0254758714941408	'line_3486_to_3529_1_cp'	0.020075757575757577
	1.0263641792535871	1.0254758714941408	'line_3486_to_3529_2_cp'	0.020303030303030305
	1.060882608976029	1.0508630566964587	'line_3490_to_3568_1_cp'	0.02
	1.060882608976029	1.0648617155123072	'line_3490_to_3589_1_cp'	0.0276
	1.060882608976029	1.0648617155123072	'line_3490_to_3589_2_cp'	0.027090909090909093
	1.0477999490967573	1.0417897728865064	'line_3496_to_3623_1_cp'	0.011909090909090909
	1.0142144909771507	1.0155212294358598	'line_3516_to_3628_1_cp'	0.012196969696969697
	1.0142144909771507	1.0152639613016816	'line_3516_to_3629_2_cp'	0.012045454545454547
	1.0561730206506255	1.0502354939871437	'line_3519_to_3534_1_cp'	0.011636363636363637
	1.0254758714941408	1.0222185219794357	'line_3529_to_3643_1_cp'	0.015075757575757576
	1.038753641400372	1.03017765229874	'line_3532_to_3634_1_cp'	0.018636363636363635
	1.038753641400372	1.03017765229874	'line_3532_to_3634_2_cp'	0.018560606060606062
	1.0382599197656872	1.0360699531968802	'line_3539_to_3540_1_cp'	0.02053030303030303
	1.0382599197656872	1.0360699531968802	'line_3539_to_3540_2_cp'	0.02121212121212121
	1.063932517287146	1.0621993293262253	'line_3543_to_3547_1_cp'	0.019454545454545454
	1.063932517287146	1.0600477040099225	'line_3543_to_3556_1_cp'	0.018545454545454546
	1.063932517287146	1.063197518908151	'line_3543_to_3560_1_cp'	0.0256
	1.063932517287146	1.0600727481481458	'line_3543_to_3567_1_cp'	0.017927272727272726
	1.063932517287146	1.0508630566964587	'line_3543_to_3568_1_cp'	0.025054545454545454
	1.063932517287146	1.0610454520109465	'line_3543_to_3593_1_cp'	0.019163636363636362
	1.0601934803605564	1.0594247540177588	'line_3545_to_3570_2_cp'	0.020181818181818183
	1.0601934803605564	1.059464123859464	'line_3545_to_3571_3_cp_merged_with_xf_3503_to_3571_2_2winding_transformer'	0.020218181818181816
	1.0601934803605564	1.0598842077039574	'line_3545_to_3572_3_cp'	0.019163636363636362
	1.0601934803605564	1.0648617155123072	'line_3545_to_3589_1_cp'	0.020145454545454546
	1.0601934803605564	1.0610454520109465	'line_3545_to_3593_1_cp'	0.019672727272727272
	1.0601934803605564	1.0585753021155468	'line_3545_to_3595_1_cp'	0.018145454545454548
	1.0537634095323822	1.0648617155123072	'line_3546_to_3589_1_cp'	0.02130909090909091
	1.0537634095323822	1.0648617155123072	'line_3546_to_3589_2_cp'	0.02098181818181818
	1.0621993293262253	1.0576701309892378	'line_3547_to_3549_1_cp'	0.019745454545454545
	1.0621993293262253	1.0576701309892378	'line_3547_to_3549_2_cp'	0.018545454545454546
	1.0621993293262253	1.0600477040099225	'line_3547_to_3556_1_cp'	0.018436363636363636
	1.0621993293262253	1.0570367995882426	'line_3547_to_3606_1_cp'	0.018763636363636364
	1.0576701309892378	1.0312093938003979	'line_3549_to_3598_1_cp'	0.018945454545454547
	1.0576701309892378	1.0570367995882426	'line_3549_to_3606_1_cp'	0.018545454545454546
	1.0576701309892378	1.0331691864182764	'line_3549_to_3608_1_cp'	0.019672727272727272
	1.0576701309892378	1.0331691864182764	'line_3549_to_3608_2_cp'	0.01850909090909091
	1.0331691864182764	1.033222232117681	'line_3551_to_3608_4_cp_merged_with_xf_3551_to_3421_3_2winding_transformer'	0.0224
	1.0331691864182764	1.0333016271516908	'line_3552_to_3608_5_cp_merged_with_xf_3552_to_3422_4_2winding_transformer'	0.02250909090909091
	1.0272074711095325	1.0312093938003979	'line_3554_to_3598_2_cp'	0.026109090909090908
	1.0312093938003979	1.027029924598676	'line_3555_to_3598_1_cp_merged_with_xf_3477_to_3555_1_2winding_transformer'	0.03621818181818182
	1.0385447236287	1.0556265742422064	'line_3557_to_3558_1_cp'	0.02
	1.0385447236287	1.0523621819234963	'line_3557_to_3569_1_cp'	0.021018181818181818
	1.0385447236287	1.0331691864182764	'line_3557_to_3608_1_cp'	0.020327272727272725
	1.0385447236287	1.0370597321930695	'line_3557_to_3611_1_cp'	0.019854545454545455
	1.0385447236287	1.037183002392764	'line_3557_to_3640_2_cp'	0.026109090909090908
	1.0385447236287	1.037183002392764	'line_3557_to_3640_3_cp'	0.027090909090909093
	1.0556265742422064	1.0523621819234963	'line_3558_to_3569_1_cp'	0.021236363636363637
	1.0556265742422064	1.0523621819234963	'line_3558_to_3569_2_cp'	0.026436363636363636
	1.0556265742422064	1.0523621819234963	'line_3558_to_3569_3_cp'	0.0256
	1.0556265742422064	1.0536492981037135	'line_3558_to_3591_1_cp'	0.019745454545454545
	1.0556265742422064	1.0536492981037135	'line_3558_to_3591_2_cp'	0.024872727272727272
	1.0556265742422064	1.0536492981037135	'line_3558_to_3591_3_cp'	0.026436363636363636
	1.063197518908151	1.0508630566964587	'line_3560_to_3568_1_cp'	0.0264
	1.063197518908151	1.0508630566964587	'line_3560_to_3568_2_cp'	0.026327272727272727
	1.063197518908151	1.063200537038088	'line_3560_to_3578_2_cp_merged_with_xf_3578_to_3429_2_2winding_transformer'	0.022145454545454545
	1.063197518908151	1.0610454520109465	'line_3560_to_3593_1_cp'	0.025054545454545454
	1.063197518908151	1.0624804034763125	'line_3560_to_3605_1_cp'	0.02490909090909091
	1.0395799062155262	1.053299234493907	'line_3561_to_3584_1_cp'	0.021054545454545454
	1.0395799062155262	1.053299234493907	'line_3561_to_3584_2_cp'	0.02047272727272727
	1.0395799062155262	1.0536492981037135	'line_3561_to_3591_1_cp'	0.019927272727272727
	1.0395799062155262	1.0536492981037135	'line_3561_to_3591_2_cp'	0.01989090909090909
	1.0395799062155262	1.0536492981037135	'line_3561_to_3591_3_cp'	0.019854545454545455
	1.0602516925140375	1.0597339806218262	'line_3563_to_3652_2_cp'	0.02593939393939394
	1.0597339806218262	1.0603091125979949	'line_3564_to_3652_1_cp_merged_with_xf_3490_to_3564_3_2winding_transformer'	0.03127272727272727
	1.0588278986088457	1.0523621819234963	'line_3565_to_3569_1_cp'	0.020218181818181816
	1.0588278986088457	1.0523621819234963	'line_3565_to_3569_2_cp'	0.021236363636363637
	1.0610454520109465	1.059240277680454	'line_3566_to_3593_1_cp_merged_with_xf_3496_to_3566_1_2winding_transformer'	0.01901818181818182
	1.0508630566964587	1.0507649393977365	'line_3568_to_3574_5_cp_merged_with_xf_3574_to_3425_3_2winding_transformer'	0.027963636363636364
	1.0508630566964587	1.050810403800023	'line_3568_to_3575_3_cp_merged_with_xf_3575_to_3423_1_2winding_transformer'	0.02898181818181818
	1.0508630566964587	1.051020862771381	'line_3568_to_3577_6_cp_merged_with_xf_3577_to_3426_4_2winding_transformer'	0.028145454545454546
	1.0508630566964587	1.0610454520109465	'line_3568_to_3593_1_cp'	0.026327272727272727
	1.0508630566964587	1.0610454520109465	'line_3568_to_3593_2_cp'	0.024763636363636363
	1.0508630566964587	1.052099348636059	'line_3568_to_3624_1_cp'	0.02618181818181818
	1.0508630566964587	1.052099348636059	'line_3568_to_3624_2_cp'	0.02690909090909091
	1.0508630566964587	1.052099348636059	'line_3568_to_3624_3_cp'	0.026436363636363636
	1.0508630566964587	1.052099348636059	'line_3568_to_3624_4_cp'	0.025890909090909093
	1.0523621819234963	1.037183002392764	'line_3569_to_3640_1_cp'	0.027309090909090908
	1.0523621819234963	1.037183002392764	'line_3569_to_3640_2_cp'	0.026654545454545455
	1.0598842077039574	1.0648617155123072	'line_3572_to_3589_1_cp'	0.019418181818181817
	1.0302235388848124	1.0312093938003979	'line_3573_to_3598_1_cp'	0.022036363636363635
	1.0302235388848124	1.052099348636059	'line_3573_to_3624_1_cp'	0.025527272727272725
	1.0302235388848124	1.052099348636059	'line_3573_to_3624_2_cp'	0.026254545454545454
	1.0302235388848124	1.037183002392764	'line_3573_to_3640_1_cp'	0.020763636363636363
	1.0302235388848124	1.037183002392764	'line_3573_to_3640_2_cp'	0.020254545454545456
	1.0302235388848124	1.037183002392764	'line_3573_to_3640_3_cp'	0.020763636363636363
	1.0611959350441298	1.0648617155123072	'line_3582_to_3589_1_cp'	0.02036363636363636
	1.0612735152405322	1.0648617155123072	'line_3583_to_3589_2_cp'	0.020690909090909093
	1.053299234493907	1.0501800287903813	'line_3584_to_3596_1_cp'	0.019563636363636363
	1.053299234493907	1.0504407502734079	'line_3584_to_3597_2_cp'	0.019490909090909093
	1.0648617155123072	1.0638629713407313	'line_3589_to_3601_1_cp'	0.02221818181818182
	1.0648617155123072	1.0637377689149983	'line_3589_to_3610_1_cp'	0.025745454545454547
	1.0648617155123072	1.0637377689149983	'line_3589_to_3610_2_cp'	0.024945454545454545
	1.0610454520109465	1.0585753021155468	'line_3593_to_3595_1_cp'	0.019454545454545454
	1.0610454520109465	1.0637377689149983	'line_3593_to_3610_1_cp'	0.025345454545454546
	1.0312093938003979	1.0331691864182764	'line_3598_to_3608_1_cp'	0.018945454545454547
	1.0335553205756436	1.0331691864182764	'line_3604_to_3608_1_cp'	0.01829090909090909
	1.0335553205756436	1.0370597321930695	'line_3604_to_3611_1_cp'	0.019418181818181817
	1.0624804034763125	1.0637377689149983	'line_3605_to_3610_2_cp'	0.02650909090909091
	1.0561485638956767	1.059126456398943	'line_3607_to_3609_1_cp'	0.026472727272727273
	1.0561485638956767	1.059126456398943	'line_3607_to_3609_2_cp'	0.027127272727272726
	1.0561485638956767	1.048452835790591	'line_3607_to_3615_1_cp'	0.02090909090909091
	1.0561485638956767	1.0543145967770917	'line_3607_to_3616_1_cp'	0.025854545454545456
	1.0561485638956767	1.052099348636059	'line_3607_to_3624_1_cp'	0.026945454545454547
	1.0561485638956767	1.052099348636059	'line_3607_to_3624_2_cp'	0.02458181818181818
	1.0436368126672984	1.048452835790591	'line_3614_to_3615_1_cp'	0.020690909090909093
	1.0436368126672984	1.048452835790591	'line_3614_to_3615_2_cp'	0.02010909090909091
	1.0436368126672984	1.042144855951937	'line_3614_to_3617_1_cp'	0.020036363636363637
	1.0436368126672984	1.042144855951937	'line_3614_to_3617_2_cp'	0.02010909090909091
	1.048452835790591	1.0543145967770917	'line_3615_to_3616_1_cp'	0.02687272727272727
	1.042144855951937	1.0413848756529211	'line_3617_to_3620_1_cp_merged_with_xf_3620_to_3539_2_2winding_transformer'	0.0172
	1.0580095268548524	1.0546694817107265	'line_3648_to_3650_1_cp'	0.025727272727272727
	1.0580095268548524	1.0546694817107265	'line_3648_to_3650_2_cp'	0.025151515151515154
	1.0546694817107265	1.0597339806218262	'line_3650_to_3652_1_cp'	0.026757575757575758
	1.0546694817107265	1.0597339806218262	'line_3650_to_3652_2_cp'	0.025818181818181817
	1.0597339806218262	1.0597580221510017	'line_3652_to_3654_2_cp_merged_with_xf_3654_to_3656_2_2winding_transformer'	0.04448484848484848
	1.0512629330519043	1.0497557112770244	'line_4002_to_4109_1_cp'	0.01850909090909091
	1.0512629330519043	1.0513971297174207	'line_4002_to_4144_1_cp'	0.02
	1.0512629330519043	1.052370252284896	'line_4002_to_4154_1_cp'	0.02
	0.9870118041005609	0.9950263435066339	'line_4032_to_4371_1_cp'	0.009393939393939394
	0.9870118041005609	0.9950263435066339	'line_4032_to_4371_2_cp'	0.00909090909090909
	1.014811006728427	1.014619163325037	'line_4071_to_4324_1_cp'	0.011515151515151515
	1.014811006728427	1.0124286013130117	'line_4071_to_4325_1_cp'	0.011212121212121211
	1.0143074919818562	1.0142649095340062	'line_4091_to_4307_1_cp'	0.01696969696969697
	1.0143074919818562	1.014260677706131	'line_4091_to_4320_1_cp'	0.017424242424242422
	0.9846334386378627	0.9844900000047887	'line_4102_to_4152_1_cp'	0.04181818181818182
	1.0018388432699485	1.0020800000008054	'line_4103_to_4153_2_cp'	0.04181818181818182
	1.0533674654903433	1.0515441901776699	'line_4104_to_4106_1_cp'	0.019454545454545454
	1.0533674654903433	1.0525380716279742	'line_4104_to_4117_1_cp'	0.019345454545454548
	1.0515441901776699	1.0307728244421488	'line_4106_to_4107_1_cp'	0.01898181818181818
	1.0307728244421488	1.0497557112770244	'line_4107_to_4109_1_cp'	0.018836363636363634
	1.0307728244421488	1.0240839875867278	'line_4107_to_4111_1_cp'	0.01927272727272727
	1.0307728244421488	1.0240839875867278	'line_4107_to_4111_2_cp'	0.021381818181818182
	1.0307728244421488	1.016067558714497	'line_4107_to_4113_1_cp'	0.0196
	1.0307728244421488	1.0398434958082252	'line_4107_to_4115_1_cp'	0.018545454545454546
	1.0307728244421488	1.0439415808359032	'line_4107_to_4116_1_cp'	0.018654545454545455
	1.045087042934149	1.0456053455762444	'line_4110_to_4114_1_cp'	0.019163636363636362
	1.045087042934149	1.0398434958082252	'line_4110_to_4115_1_cp'	0.018145454545454548
	1.045087042934149	1.0402915457108286	'line_4110_to_4143_1_cp'	0.019054545454545456
	1.0439415808359032	1.0434651639778583	'line_4116_to_4150_1_cp'	0.0196
	1.0525380716279742	1.0409482147080016	'line_4117_to_4124_1_cp'	0.01963636363636364
	1.0525380716279742	1.0571477181747104	'line_4117_to_4131_1_cp'	0.019345454545454548
	1.0525380716279742	1.052370252284896	'line_4117_to_4154_1_cp'	0.019090909090909092
	1.0409482147080016	1.0571477181747104	'line_4124_to_4131_1_cp'	0.0244
	1.0409482147080016	1.0447721912234567	'line_4124_to_4135_1_cp'	0.020254545454545456
	1.0409482147080016	1.0434651639778583	'line_4124_to_4150_1_cp'	0.019490909090909093
	1.0024232896306886	1.0051099104030174	'line_4126_to_4196_1_cp'	0.011590909090909091
	1.0571477181747104	1.0534779727970653	'line_4131_to_4145_1_cp'	0.024072727272727273
	1.0571477181747104	1.062471148027493	'line_4131_to_4149_1_cp'	0.020181818181818183
	1.0118198239026805	1.0161825070249157	'line_4132_to_4235_1_cp'	0.008181818181818182
	1.0118198239026805	1.0096144000161302	'line_4132_to_4343_1_cp'	0.008333333333333333
	1.048193041801558	1.0485248834422327	'line_4137_to_4142_1_cp'	0.0176
	1.0623972172262666	1.0501514889947825	'line_4138_to_4151_1_cp'	0.019527272727272726
	1.0636350732821178	1.0501514889947825	'line_4139_to_4151_2_cp'	0.019927272727272727
	1.0777630992618186	1.062471148027493	'line_4141_to_4149_1_cp'	0.019490909090909093
	1.0485248834422327	1.0497596627102626	'line_4142_to_4146_1_cp'	0.02007272727272727
	1.0534779727970653	1.0497596627102626	'line_4145_to_4146_1_cp'	0.024472727272727274
	1.0497596627102626	1.062471148027493	'line_4146_to_4149_1_cp'	0.021018181818181818
	1.0043943705638387	1.0063544174367105	'line_4156_to_4165_1_cp'	0.012196969696969697
	1.0081364614109256	1.0188641075154787	'line_4158_to_4160_1_cp'	0.013181818181818182
	1.0081364614109256	1.0063544174367105	'line_4158_to_4165_1_cp'	0.011666666666666667
	1.0188641075154787	1.0292348921906478	'line_4160_to_4161_1_cp_merged_with_xf_4161_to_4347_1_2winding_transformer'	0.00893939393939394
	1.0188641075154787	1.002785550198709	'line_4160_to_4166_1_cp'	0.013636363636363637
	1.011205567754147	1.002785550198709	'line_4162_to_4166_1_cp'	0.00909090909090909
	1.0126950378249167	1.0394429915916916	'line_4163_to_4170_1_cp'	0.00893939393939394
	1.0126950378249167	1.0128230236856377	'line_4163_to_4203_1_cp'	0.02075757575757576
	1.0063544174367105	0.9968714659145295	'line_4165_to_4222_1_cp'	0.015681818181818182
	1.0063544174367105	1.0063985851630832	'line_4165_to_4223_2_cp'	0.016212121212121212
	1.0427803442764758	1.0421126300352257	'line_4167_to_4168_1_cp'	0.008636363636363636
	1.0427803442764758	1.0394429915916916	'line_4167_to_4170_1_cp'	0.00909090909090909
	1.0427803442764758	1.047830382464256	'line_4167_to_4182_1_cp'	0.01106060606060606
	1.0002844266855877	1.0010206983293426	'line_4171_to_4172_1_cp'	0.011515151515151515
	1.0002844266855877	0.9965644594504206	'line_4171_to_4173_1_cp_merged_with_xf_4173_to_4366_1_2winding_transformer'	0.008181818181818182
	1.0002844266855877	1.013819110475272	'line_4171_to_4183_1_cp'	0.012651515151515151
	1.0002844266855877	1.006160606793215	'line_4171_to_4195_1_cp'	0.011590909090909091
	1.0176134654812703	1.013819110475272	'line_4174_to_4183_1_cp'	0.012121212121212121
	1.0176134654812703	1.019258511405663	'line_4174_to_4200_1_cp'	0.01196969696969697
	1.019258511405663	1.0206689400998235	'line_4175_to_4200_1_cp_merged_with_line_4175_to_4190_1_cp'	0.012499999999999999
	1.0241909344120061	1.0241487717932833	'line_4176_to_4184_1_cp'	0.012272727272727274
	1.0241909344120061	1.0249765387843643	'line_4176_to_4191_1_cp'	0.012272727272727274
	1.0198042537637826	1.0096925776512176	'line_4177_to_4178_1_cp'	0.012727272727272726
	1.0198042537637826	1.0241487717932833	'line_4177_to_4184_1_cp'	0.012424242424242423
	1.0096925776512176	1.0008666252530667	'line_4178_to_4179_1_cp'	0.01196969696969697
	1.0008666252530667	0.9995730188613575	'line_4179_to_4180_1_cp'	0.012196969696969697
	0.9995730188613575	1.0241487717932833	'line_4180_to_4184_1_cp'	0.010151515151515153
	0.9995730188613575	1.0115021193844083	'line_4180_to_4185_1_cp'	0.01553030303030303
	0.9995730188613575	1.0115021193844083	'line_4180_to_4185_2_cp'	0.008712121212121211
	1.013819110475272	1.0152900072439068	'line_4183_to_4188_1_cp'	0.012272727272727274
	1.0115021193844083	1.0092808212118136	'line_4185_to_4187_2_cp_merged_with_xf_4187_4230_4495_2_3winding_transformer_br1'	0.01696969696969697
	1.0049030252240545	1.0113088183501295	'line_4189_to_4193_1_cp'	0.012499999999999999
	1.0220867303838597	1.0113088183501295	'line_4190_to_4193_1_cp'	0.012272727272727274
	1.0220867303838597	1.0051099104030174	'line_4190_to_4196_1_cp'	0.00962121212121212
	1.0137523398236978	1.0113088183501295	'line_4192_to_4193_1_cp'	0.011515151515151515
	1.0137523398236978	1.025132081419084	'line_4192_to_4194_1_cp'	0.012121212121212121
	1.025132081419084	1.023050206940531	'line_4194_to_4204_1_cp'	0.01606060606060606
	1.006160606793215	1.0051099104030174	'line_4195_to_4196_1_cp'	0.011742424242424243
	1.0051099104030174	1.0054383499249433	'line_4196_to_4197_1_cp'	0.009924242424242424
	1.0054383499249433	1.0236512990929916	'line_4197_to_4198_1_cp'	0.009015151515151514
	1.023609329340016	1.0218545672489499	'line_4201_to_4202_2_cp'	0.015681818181818182
	1.0218545672489499	1.0181696426463736	'line_4202_to_4212_1_cp'	0.015984848484848484
	1.023050206940531	1.0197211652870053	'line_4204_to_4206_1_cp'	0.011363636363636364
	1.0197211652870053	1.0172327333403517	'line_4206_to_4207_1_cp'	0.011287878787878788
	1.0168035074729045	1.015700233495428	'line_4208_to_4209_1_cp'	0.011666666666666667
	1.015700233495428	1.0161697322806114	'line_4209_to_4210_1_cp'	0.012803030303030302
	1.0161697322806114	1.0162335579623598	'line_4210_to_4211_1_cp'	0.01575757575757576
	1.0161697322806114	1.0313389643681259	'line_4210_to_4213_1_cp'	0.012499999999999999
	1.0162335579623598	1.0181696426463736	'line_4211_to_4212_1_cp'	0.015454545454545455
	1.0313389643681259	1.0438487351258332	'line_4213_to_4215_2_cp'	0.016136363636363636
	1.0438487351258332	1.056347701514769	'line_4215_to_4217_1_cp'	0.01590909090909091
	1.0325991827352645	1.0176441982504325	'line_4216_to_4218_1_cp'	0.015681818181818182
	1.0325991827352645	1.0203785673390493	'line_4216_to_4220_1_cp'	0.019090909090909092
	1.0325991827352645	1.0437560991902743	'line_4216_to_4224_1_cp'	0.016136363636363636
	1.056347701514769	1.0437560991902743	'line_4217_to_4224_1_cp'	0.016212121212121212
	1.0176441982504325	1.0101086539589106	'line_4218_to_4219_1_cp'	0.00962121212121212
	1.0101086539589106	1.0203785673390493	'line_4219_to_4220_1_cp'	0.00946969696969697
	1.0203785673390493	1.017403885050437	'line_4220_to_4221_1_cp'	0.020606060606060607
	0.9875839377386504	0.9856989629502306	'line_4229_to_4230_3_cp'	0.017424242424242422
	1.0105915029713868	1.0097195360942486	'line_4231_to_4232_1_cp'	0.01787878787878788
	1.0105915029713868	1.0124294572288566	'line_4231_to_4275_1_cp'	0.028636363636363633
	1.0097195360942486	1.0103988397303865	'line_4232_to_4274_1_cp'	0.017272727272727273
	1.0190465030629594	1.0161825070249157	'line_4234_to_4235_1_cp'	0.017727272727272727
	1.0161825070249157	1.0156737457570573	'line_4235_to_4337_1_cp'	0.00909090909090909
	1.0161825070249157	1.0178960401353152	'line_4235_to_4382_1_cp'	0.010909090909090908
	1.0183687797308527	1.0187800276717778	'line_4236_to_4237_1_cp'	0.018484848484848486
	1.0183687797308527	1.0156737457570573	'line_4236_to_4337_1_cp'	0.01196969696969697
	1.0187800276717778	1.018297082509497	'line_4237_to_4240_1_cp'	0.01712121212121212
	1.0234463867094654	1.019467545408807	'line_4238_to_4241_1_cp'	0.017727272727272727
	1.0219919319192932	1.018297082509497	'line_4239_to_4240_1_cp'	0.012121212121212121
	1.019467545408807	1.0172843226158692	'line_4241_to_4248_1_cp'	0.01803030303030303
	1.02290769319254	1.0170879792837024	'line_4243_to_4246_1_cp'	0.012424242424242423
	1.02290769319254	1.0176224845909145	'line_4243_to_4249_1_cp'	0.012727272727272726
	1.02290769319254	1.0208045677386879	'line_4243_to_4331_1_cp'	0.014696969696969696
	1.02290769319254	1.024359092176964	'line_4243_to_4335_1_cp'	0.018787878787878787
	1.02290769319254	1.024359092176964	'line_4243_to_4335_2_cp'	0.01818181818181818
	1.0128014855082244	1.0117678906130299	'line_4244_to_4245_1_cp'	0.00909090909090909
	1.0128014855082244	1.0117678906130299	'line_4244_to_4245_2_cp'	0.00909090909090909
	1.0128014855082244	1.0228482086001356	'line_4244_to_4247_1_cp'	0.009696969696969697
	1.0170879792837024	1.0145022614042054	'line_4246_to_4332_1_cp'	0.01196969696969697
	1.0228482086001356	1.024359092176964	'line_4247_to_4335_1_cp'	0.01787878787878788
	1.0172843226158692	1.0156737457570573	'line_4248_to_4337_1_cp'	0.016666666666666666
	1.01534522466294	1.0133891809905313	'line_4250_to_4251_1_cp'	0.01196969696969697
	1.0133891809905313	1.0127063925646622	'line_4251_to_4254_1_cp'	0.01196969696969697
	1.0176006133764464	1.02048575706983	'line_4253_to_4327_1_cp'	0.007121212121212121
	1.0127063925646622	1.0128629577172787	'line_4254_to_4256_1_cp'	0.01803030303030303
	1.0128435006969732	1.0148973122901432	'line_4255_to_4292_1_cp'	0.01590909090909091
	1.0128629577172787	1.0127362103131055	'line_4256_to_4264_1_cp'	0.01393939393939394
	1.0133323221374182	1.0124620566971405	'line_4257_to_4258_1_cp'	0.010454545454545454
	1.0133323221374182	1.0128743020257298	'line_4257_to_4259_1_cp'	0.010151515151515153
	1.0133323221374182	1.0145022614042054	'line_4257_to_4332_1_cp'	0.012121212121212121
	1.0159345385074052	1.013864589769762	'line_4260_to_4265_1_cp'	0.020303030303030305
	1.0159345385074052	1.0132950623863908	'line_4260_to_4341_1_cp'	0.01106060606060606
	1.023676870114796	1.023676099374492	'line_4262_to_4326_2_cp'	0.02075757575757576
	1.0127362103131055	1.013864589769762	'line_4264_to_4265_1_cp'	0.017272727272727273
	1.0127362103131055	1.0125503598255505	'line_4264_to_4268_1_cp'	0.01803030303030303
	1.015371675829677	1.0139896418954444	'line_4266_to_4270_1_cp'	0.008333333333333333
	1.015371675829677	1.0130723789650553	'line_4266_to_4271_1_cp'	0.008333333333333333
	1.015371675829677	1.0134299381865317	'line_4266_to_4272_1_cp'	0.01818181818181818
	1.015371675829677	1.01367922130643	'line_4266_to_4273_1_cp'	0.01787878787878788
	1.015371675829677	1.01367922130643	'line_4266_to_4273_2_cp'	0.017272727272727273
	1.015371675829677	1.0124294572288566	'line_4266_to_4275_1_cp'	0.018484848484848486
	1.015371675829677	1.0148973122901432	'line_4266_to_4292_2_cp'	0.015606060606060606
	1.0132766235667061	1.0125503598255505	'line_4267_to_4268_1_cp'	0.01696969696969697
	1.0132766235667061	1.0132288166486518	'line_4267_to_4269_1_cp_merged_with_xf_4269_to_4443_1_2winding_transformer'	0.0048484848484848485
	1.0132766235667061	1.0148973122901432	'line_4267_to_4292_1_cp'	0.018333333333333333
	1.0134299381865317	1.0124294572288566	'line_4272_to_4275_1_cp'	0.01696969696969697
	1.01367922130643	1.0103988397303865	'line_4273_to_4274_1_cp'	0.017424242424242422
	1.0156076445958928	1.0154464247304746	'line_4276_to_4283_1_cp_merged_with_xf_4283_to_4454_1_2winding_transformer'	0.004696969696969697
	1.0156076445958928	1.0126051665769529	'line_4276_to_4289_1_cp'	0.016515151515151517
	1.0147770871272799	1.0142211606167597	'line_4278_to_4295_1_cp'	0.01696969696969697
	1.0147770871272799	1.015338466247688	'line_4278_to_4296_1_cp'	0.012121212121212121
	1.0147371065457174	1.015011979916346	'line_4279_to_4280_1_cp'	0.007272727272727273
	1.0147371065457174	1.01503050518731	'line_4279_to_4288_1_cp'	0.01590909090909091
	1.0147371065457174	1.0150865777215208	'line_4279_to_4294_1_cp'	0.013787878787878788
	1.0155636829312802	1.0164786257871992	'line_4281_to_4297_1_cp'	0.01575757575757576
	1.0133301852488363	1.0087303359984023	'line_4286_to_4287_1_cp'	0.007727272727272728
	1.0133301852488363	1.0149403132238908	'line_4286_to_4311_1_cp'	0.017272727272727273
	1.0150865777215208	1.0142211606167597	'line_4294_to_4295_1_cp'	0.012878787878787878
	1.0200382515808772	1.020000934187858	'line_4298_to_4315_1_cp'	0.010454545454545454
	1.017589124516057	1.0149403132238908	'line_4300_to_4311_1_cp'	0.018484848484848486
	1.017589124516057	1.0149403132238908	'line_4300_to_4311_2_cp'	0.017272727272727273
	1.017589124516057	1.0148922709240782	'line_4300_to_4339_1_cp'	0.014242424242424242
	1.017589124516057	1.0148922709240782	'line_4300_to_4339_2_cp'	0.017272727272727273
	1.013913547043891	1.0149966254700715	'line_4301_to_4302_1_cp'	0.01681818181818182
	1.013913547043891	1.0148922709240782	'line_4301_to_4339_1_cp'	0.017575757575757574
	1.0149966254700715	1.0167297927547956	'line_4302_to_4303_1_cp'	0.012424242424242423
	1.0149966254700715	1.014782842832906	'line_4302_to_4342_1_cp'	0.018333333333333333
	1.0167297927547956	1.0193620407669026	'line_4303_to_4304_1_cp'	0.012727272727272726
	1.0167297927547956	1.0148118280813296	'line_4303_to_4305_1_cp'	0.00909090909090909
	1.0167297927547956	1.016797285950203	'line_4303_to_4306_2_cp'	0.009242424242424243
	1.0142649095340062	1.0148922709240782	'line_4307_to_4339_1_cp'	0.017575757575757574
	1.017488173762634	1.0168463925479674	'line_4308_to_4319_1_cp'	0.013636363636363637
	1.0138395594483125	1.0149403132238908	'line_4309_to_4311_1_cp'	0.010606060606060605
	1.0149403132238908	1.0147517711716025	'line_4311_to_4312_1_cp'	0.01712121212121212
	1.0149403132238908	1.0136718309544634	'line_4311_to_4317_1_cp'	0.007575757575757576
	1.0149403132238908	1.0143294645966325	'line_4311_to_4318_1_cp'	0.01196969696969697
	1.0149403132238908	1.014782842832906	'line_4311_to_4342_1_cp'	0.017424242424242422
	1.0147517711716025	1.014924306880902	'line_4312_to_4313_1_cp'	0.01681818181818182
	1.014924306880902	1.016845711316536	'line_4313_to_4314_1_cp'	0.01818181818181818
	1.016845711316536	1.020000934187858	'line_4314_to_4315_1_cp'	0.01590909090909091
	1.0208096684231376	1.0214857918147628	'line_4316_to_4333_1_cp_merged_with_xf_4147_to_4333_2_2winding_transformer'	0.06348484848484849
	1.0143294645966325	1.0148922709240782	'line_4318_to_4339_1_cp'	0.01803030303030303
	1.0168463925479674	1.014260677706131	'line_4319_to_4320_1_cp'	0.01696969696969697
	1.0168463925479674	1.014260677706131	'line_4319_to_4320_2_cp'	0.01681818181818182
	1.0168463925479674	1.0116671609554975	'line_4319_to_4321_1_cp'	0.01712121212121212
	1.0168463925479674	1.0169462639455746	'line_4319_to_4322_1_cp'	0.00787878787878788
	1.0168463925479674	1.014619163325037	'line_4319_to_4324_1_cp'	0.011818181818181818
	1.014260677706131	1.0118480240942755	'line_4320_to_4323_1_cp'	0.011515151515151515
	1.0116671609554975	1.0118480240942755	'line_4321_to_4323_1_cp'	0.01106060606060606
	1.0116671609554975	1.0118759096107686	'line_4321_to_4338_1_cp'	0.011515151515151515
	1.0124286013130117	1.0118759096107686	'line_4325_to_4338_1_cp'	0.011212121212121211
	1.0096144000161302	1.0126780501745705	'line_4343_to_4344_1_cp'	0.008636363636363636
	1.0126780501745705	1.0178960401353152	'line_4344_to_4382_1_cp'	0.010909090909090908
	1.0172562450164322	1.0123486124975203	'line_4364_to_4366_2_cp'	0.00909090909090909
	1.010321089140466	1.0123486124975203	'line_4365_to_4366_1_cp'	0.007272727272727273
	1.0322179518767036	1.0321434824700746	'line_5049_to_5053_1_cp'	0.014545454545454545
	1.0296384456928327	1.0321434824700746	'line_5050_to_5053_1_cp'	0.010454545454545454
	1.0298306914594846	1.0321434824700746	'line_5051_to_5053_1_cp'	0.010818181818181817
	1.029358766737101	1.0298241028327855	'line_5052_to_5056_1_cp'	0.019818181818181818
	1.0321434824700746	1.0246072245334255	'line_5053_to_5054_1_cp'	0.01109090909090909
	1.0246072245334255	1.0155911786184337	'line_5054_to_5069_1_cp'	0.01109090909090909
	1.0280800159212082	1.0298241028327855	'line_5055_to_5056_1_cp'	0.007727272727272727
	1.030239148425398	1.0302264649004873	'line_5057_to_5063_1_cp'	0.018818181818181817
	1.0298979163191582	1.0302264649004873	'line_5058_to_5063_1_cp'	0.010363636363636363
	1.0298979163191582	1.0307168732910854	'line_5058_to_5064_1_cp'	0.010636363636363637
	1.0273426353222792	1.025492267571251	'line_5059_to_5060_1_cp'	0.008818181818181819
	1.0273426353222792	1.0381236669216882	'line_5059_to_5061_1_cp'	0.008454545454545454
	1.0273426353222792	1.0300101706900573	'line_5059_to_5128_1_cp'	0.019545454545454543
	1.025492267571251	1.0381236669216882	'line_5060_to_5061_1_cp'	0.008272727272727274
	1.0381236669216882	1.0369786690845	'line_5061_to_5062_1_cp'	0.010727272727272726
	1.0381236669216882	1.0302264649004873	'line_5061_to_5063_2_cp'	0.010636363636363637
	1.0381236669216882	1.0375979610570718	'line_5061_to_5125_1_cp'	0.010636363636363637
	1.0369786690845	1.0307168732910854	'line_5062_to_5064_1_cp'	0.010454545454545454
	1.0302264649004873	1.0231642600894901	'line_5063_to_5065_1_cp'	0.016181818181818183
	1.0302264649004873	1.025611277320098	'line_5063_to_5066_1_cp'	0.013454545454545455
	1.0302264649004873	1.0262321341501854	'line_5063_to_5067_1_cp'	0.016181818181818183
	1.0302264649004873	1.0262321341501854	'line_5063_to_5067_2_cp'	0.01509090909090909
	1.0231642600894901	1.025611277320098	'line_5065_to_5066_1_cp'	0.010636363636363637
	1.0054221923977726	1.0155911786184337	'line_5068_to_5069_1_cp'	0.010636363636363637
	1.0155911786184337	1.0162345576105354	'line_5069_to_5126_1_cp'	0.010727272727272726
	1.0321907632602818	1.0286410735762936	'line_5070_to_5072_2_cp'	0.010727272727272726
	1.0321907632602818	1.032214299252591	'line_5070_to_5127_1_cp'	0.00909090909090909
	1.0294664820108792	1.0286410735762936	'line_5071_to_5072_1_cp'	0.010818181818181817
	1.0180320222085428	1.017275017169279	'line_5073_to_5074_1_cp'	0.012545454545454544
	1.0180320222085428	1.0208968671416527	'line_5073_to_5075_1_cp'	0.014636363636363637
	1.0180320222085428	1.0162348517264008	'line_5073_to_5123_1_cp'	0.012545454545454544
	1.017275017169279	1.0162348517264008	'line_5074_to_5123_1_cp'	0.012272727272727274
	1.0208968671416527	1.0259983244759345	'line_5075_to_5137_1_cp'	0.013454545454545455
	1.0521049759471799	1.0529728279596535	'line_5076_to_5077_1_cp_merged_with_xf_5076_to_5019_1_2winding_transformer'	0.004181818181818182
	1.0521049759471799	1.052307147666922	'line_5077_to_5086_1_cp'	0.007454545454545454
	1.0521049759471799	1.0491067870017945	'line_5077_to_5223_1_cp'	0.008181818181818182
	1.0444177798915129	1.0390372764710192	'line_5081_to_5116_1_cp'	0.011272727272727273
	1.0444177798915129	1.0491067870017945	'line_5081_to_5223_1_cp'	0.011545454545454546
	1.0390372764710192	1.0442006804190964	'line_5082_to_5116_2_cp_merged_with_line_5082_to_5223_2_cp'	0.010909090909090908
	1.0263217843673609	1.0220314331512619	'line_5084_to_5112_2_cp'	0.012818181818181817
	1.0263217843673609	1.0491067870017945	'line_5084_to_5223_2_cp'	0.008909090909090908
	1.0262616700356781	1.0220314331512619	'line_5085_to_5112_1_cp'	0.013454545454545455
	1.0262616700356781	1.0491067870017945	'line_5085_to_5223_1_cp'	0.008545454545454545
	1.02363142854976	1.0224268429166419	'line_5089_to_5095_1_cp'	0.014636363636363637
	1.02363142854976	1.0390372764710192	'line_5089_to_5116_1_cp'	0.008909090909090908
	1.0258335709655355	1.024653767082861	'line_5090_to_5091_1_cp'	0.014272727272727274
	1.0258335709655355	1.024653767082861	'line_5090_to_5091_2_cp'	0.014272727272727274
	1.0258335709655355	1.024653767082861	'line_5090_to_5091_3_cp'	0.019272727272727275
	1.0258335709655355	1.0229353069516054	'line_5090_to_5092_1_cp'	0.01509090909090909
	1.0258335709655355	1.0218661369411564	'line_5090_to_5102_2_cp'	0.010909090909090908
	1.0258335709655355	1.0224164644898102	'line_5090_to_5103_1_cp'	0.010818181818181817
	1.0258335709655355	1.0220314331512619	'line_5090_to_5112_1_cp'	0.011
	1.024653767082861	1.0229353069516054	'line_5091_to_5092_1_cp'	0.012
	1.024653767082861	1.0245275685238828	'line_5091_to_5093_1_cp_merged_with_xf_5093_5202_5203_1_3winding_transformer_br1'	0.005454545454545454
	1.024653767082861	1.0220314331512619	'line_5091_to_5112_1_cp'	0.011272727272727273
	1.0229353069516054	1.0224268429166419	'line_5092_to_5095_2_cp'	0.014272727272727274
	1.0224268429166419	1.0215047718264618	'line_5095_to_5100_1_cp'	0.010818181818181817
	1.0224268429166419	1.020436692358242	'line_5095_to_5111_1_cp'	0.010454545454545454
	1.0224268429166419	1.0220519473997536	'line_5095_to_5131_1_cp'	0.015363636363636362
	1.0224268429166419	1.0220251670322253	'line_5095_to_5132_2_cp'	0.015272727272727273
	1.0219940718710745	1.0220519473997536	'line_5097_to_5131_1_cp'	0.014727272727272728
	1.0219387283862174	1.0220251670322253	'line_5098_to_5132_2_cp'	0.01609090909090909
	1.0172684773958582	1.0215047718264618	'line_5099_to_5100_1_cp'	0.005454545454545454
	1.0215047718264618	1.0206281838630409	'line_5100_to_5110_1_cp_merged_with_xf_5110_to_5213_2_2winding_transformer'	0.004363636363636364
	1.0217819050202008	1.0218661369411564	'line_5101_to_5102_2_cp'	0.011
	1.0217819050202008	1.0224164644898102	'line_5101_to_5103_1_cp'	0.010181818181818183
	1.0218661369411564	1.0161858248134827	'line_5102_to_5106_1_cp'	0.011
	1.0224164644898102	1.0185261848798728	'line_5103_to_5104_1_cp'	0.0057272727272727275
	1.0185261848798728	1.0161858248134827	'line_5104_to_5106_1_cp'	0.005363636363636363
	1.0161858248134827	1.0145790484582364	'line_5106_to_5136_1_cp'	0.007454545454545454
	1.0142969916955673	1.0145790484582364	'line_5109_to_5136_1_cp'	0.014545454545454545
	1.0220314331512619	1.0491067870017945	'line_5112_to_5223_1_cp'	0.009
	1.0147684000122736	1.01631743605445	'line_5113_to_5119_1_cp'	0.011818181818181818
	1.0147684000122736	1.01631743605445	'line_5113_to_5119_2_cp'	0.020545454545454544
	1.0318104127705299	1.0298569916179592	'line_5114_to_5118_6_cp'	0.013545454545454545
	1.0298569916179592	1.0298802993289518	'line_5115_to_5118_5_cp_merged_with_xf_5038_to_5115_2_2winding_transformer'	0.014727272727272728
	1.0390372764710192	1.0298569916179592	'line_5116_to_5118_3_cp'	0.013818181818181818
	1.0298569916179592	1.0303426787348282	'line_5117_to_5118_1_cp_merged_with_line_5034_to_5242_1_cp_merged_with_xf_5117_to_5242_1_2winding_transformer'	0.0007272727272727273
	1.0298569916179592	1.01631743605445	'line_5118_to_5119_3_cp'	0.011181818181818182
	1.0298569916179592	1.01631743605445	'line_5118_to_5119_4_cp'	0.011
	1.0298569916179592	1.01893794075006	'line_5118_to_5121_1_cp'	0.007909090909090909
	1.01631743605445	1.0162348517264008	'line_5119_to_5123_1_cp'	0.015545454545454545
	1.01631743605445	1.0162348517264008	'line_5119_to_5123_2_cp'	0.015818181818181818
	1.01893794075006	1.0145211168227537	'line_5121_to_5130_1_cp'	0.0076363636363636364
	1.0145842993272518	1.0147477475748472	'line_5122_to_5124_1_cp'	0.02218181818181818
	1.0145842993272518	1.0142140452244117	'line_5122_to_5129_1_cp'	0.02263636363636364
	1.0637339871937446	1.0586963749674714	'line_5139_to_5143_1_cp'	0.02
	1.062747550173364	1.0586963749674714	'line_5140_to_5143_2_cp'	0.01977272727272727
	1.0601433689426427	1.0586963749674714	'line_5141_to_5143_1_cp'	0.020590909090909094
	1.060235533640715	1.0586963749674714	'line_5142_to_5143_1_cp'	0.020363636363636365
	1.0586963749674714	1.0483912402037672	'line_5143_to_5149_1_cp'	0.020363636363636365
	1.0586963749674714	1.0483912402037672	'line_5143_to_5149_2_cp'	0.021363636363636366
	1.051989765801392	1.0483912402037672	'line_5144_to_5149_1_cp'	0.01681818181818182
	1.0483912402037672	1.0506108219302883	'line_5145_to_5149_2_cp_merged_with_xf_5145_to_5229_1_2winding_transformer'	0.0071818181818181824
	1.0490206172661318	1.0483912402037672	'line_5147_to_5149_1_cp'	0.015636363636363636
	1.0483912402037672	1.0476162820875692	'line_5148_to_5149_1_cp_merged_with_xf_5148_to_5061_1_2winding_transformer'	0.010181818181818183
	1.0483912402037672	1.0288293859528455	'line_5149_to_5153_1_cp'	0.0195
	1.0483912402037672	1.0288293859528455	'line_5149_to_5153_2_cp'	0.01890909090909091
	1.0483912402037672	1.0482670120936812	'line_5149_to_5169_1_cp'	0.015045454545454546
	1.0288293859528455	1.0384657423396055	'line_5153_to_5170_1_cp'	0.014318181818181818
	1.0288293859528455	1.0384657423396055	'line_5153_to_5170_2_cp'	0.014818181818181817
	1.0492486487961408	1.048939754611731	'line_5155_to_5160_1_cp'	0.01531818181818182
	1.0492486487961408	1.0385769617593068	'line_5155_to_5162_1_cp'	0.01390909090909091
	1.0492486487961408	1.0507835169384796	'line_5155_to_5168_1_cp'	0.014909090909090908
	1.0492486487961408	1.0507835169384796	'line_5155_to_5168_2_cp'	0.020045454545454547
	1.048939754611731	1.0385769617593068	'line_5160_to_5162_1_cp'	0.015
	1.0442256085593427	1.0385769617593068	'line_5161_to_5162_1_cp'	0.018727272727272728
	1.0442256085593427	1.0385769617593068	'line_5161_to_5162_2_cp'	0.018227272727272727
	1.057482072980616	1.0507835169384796	'line_5163_to_5168_1_cp'	0.017863636363636363
	1.057482072980616	1.0507835169384796	'line_5163_to_5168_2_cp'	0.017681818181818184
	1.0482670120936812	1.048909585313525	'line_5164_to_5169_4_cp_merged_with_xf_5164_to_5039_3_2winding_transformer'	0.007863636363636364
	1.0482670120936812	1.0489740376114627	'line_5166_to_5169_2_cp_merged_with_xf_5166_to_5041_5_2winding_transformer'	0.007772727272727272
	1.0482670120936812	1.048290714448191	'line_5167_to_5169_1_cp_merged_with_xf_5167_to_5042_6_2winding_transformer'	0.008181818181818182
	1.0507835169384796	1.0482670120936812	'line_5168_to_5169_1_cp'	0.020727272727272726
	1.0507835169384796	1.0482670120936812	'line_5168_to_5169_2_cp'	0.020954545454545455
	1.0482670120936812	1.0384657423396055	'line_5169_to_5170_1_cp'	0.014681818181818181
	1.0482670120936812	1.0384657423396055	'line_5169_to_5170_2_cp'	0.014636363636363637
	0.998542019939164	1.0001537058556877	'line_5215_to_5220_2_cp'	0.007727272727272728
	0.998542019939164	1.0001537058556877	'line_5215_to_5220_3_cp'	0.007727272727272728
	1.0360002483400574	1.0363827651421698	'line_1194_to_1496_1_pi_merged_with_line_1194_to_1195_1_pi'	0.05159090909090909
	1.032454552918072	1.0324393510186733	'line_1234_to_1493_1_pi_merged_with_xf_1493_to_1647_2_2winding_transformer'	0.0036363636363636364
	1.0490139574353037	1.0480673738284934	'line_1268_to_1272_4_pi_merged_with_xf_1268_to_1032_4_2winding_transformer'	0.011363636363636364
	1.0375793290551727	1.0360002483400574	'line_1287_to_1496_1_pi'	0.016742424242424243
	1.0141415357989325	1.0149999411157071	'line_1357_to_1597_1_pi'	0.01
	1.0141415357989325	1.0192112275241856	'line_1357_to_1651_1_pi'	0.00984848484848485
	1.0361546150932957	1.0361547191534721	'line_1385_to_1386_1_pi_merged_with_xf_1386_to_1607_1_2winding_transformer'	0.035
	1.0223197549352394	1.0241812893084454	'line_1411_to_1412_1_pi_merged_with_xf_1107_to_1412_1_2winding_transformer'	0.024772727272727273
	1.044407400960956	1.0510370744888622	'line_1416_to_1417_1_pi_merged_with_line_1182_to_1417_1_cp'	0.01462121212121212
	1.0126033666070855	1.0138023160347798	'line_1498_to_1599_1_pi'	0.010303030303030303
	1.0126033666070855	1.0192112275241856	'line_1498_to_1651_1_pi'	0.010757575757575757
	1.1057845099743844	1.1010638228553558	'line_1544_to_1603_1_pi'	0.014848484848484849
	1.0149999411157071	1.011370490214601	'line_1597_to_1600_1_pi'	0.00984848484848485
	1.0149999411157071	1.0192112275241856	'line_1597_to_1651_1_pi'	0.009696969696969697
	1.0138023160347798	1.0192112275241856	'line_1599_to_1651_1_pi'	0.010151515151515153
	1.011370490214601	1.0192112275241856	'line_1600_to_1651_1_pi'	0.007424242424242424
	1.0604899999970583	1.0462333790509246	'line_2017_to_2353_2_pi'	0.0665
	1.0873399999965068	1.0591525466792904	'line_2039_to_2354_2_pi_merged_with_line_2145_to_2354_1_pi'	0.06931818181818182
	1.0278826120867424	1.029454202453725	'line_2110_to_2112_2_pi_merged_with_line_2110_to_2159_1_cp'	0.015454545454545453
	1.029753439583925	1.0278826120867424	'line_2111_to_2112_1_pi'	0.015
	1.030200310098605	1.0220187036544486	'line_2123_to_2124_1_pi_merged_with_xf_2124_to_2233_2_2winding_transformer'	0.014681818181818181
	1.0440004550199131	1.0390706760003323	'line_2210_to_2212_1_pi_merged_with_xf_2104_to_2212_1_2winding_transformer'	0.038181818181818185
	1.0250012222154299	1.0201940927978503	'line_2276_to_2287_1_pi'	0.014242424242424242
	1.0250012222154299	1.0187949182780185	'line_2276_to_2288_1_pi'	0.014545454545454545
	1.0622110551393678	1.0628296706267668	'line_2303_to_2304_2_pi'	0.09409090909090909
	1.0237142913897863	1.0237031721367023	'line_3030_to_3216_1_pi_merged_with_xf_3030_to_3032_1_2winding_transformer'	0.018787878787878787
	1.0237142913897863	1.0237038841104067	'line_3031_to_3216_2_pi_merged_with_xf_3031_to_3032_2_2winding_transformer'	0.019090909090909092
	1.0599303152185673	1.0599303147621424	'line_3119_to_3120_1_pi_merged_with_xf_3119_to_3447_1_2winding_transformer'	0.013484848484848485
	1.0365651457876486	1.0365724205560651	'line_3261_to_3538_1_pi_merged_with_xf_3615_to_3538_1_2winding_transformer'	0.04757575757575758
	1.051417699010259	1.0513706972245063	'line_3317_to_3636_1_pi_merged_with_xf_3317_to_3320_2_2winding_transformer'	0.01609090909090909
	1.051417699010259	1.0513663539467708	'line_3318_to_3636_2_pi_merged_with_xf_3318_to_3320_3_2winding_transformer'	0.017636363636363638
	1.0471094136655563	1.0470884532630274	'line_3346_to_3503_1_pi_merged_with_xf_3346_to_3347_1_2winding_transformer'	0.007545454545454545
	1.0075034421260247	1.0075157574982727	'line_3365_to_3511_5_pi_merged_with_xf_3633_to_3511_6_2winding_transformer'	0.06121212121212121
	0.9885604306035383	0.9885956825044899	'line_3367_to_3513_2_pi_merged_with_xf_3633_3514_3513_4_3winding_transformer_br3'	0.026363636363636363
	1.0250698538813603	1.0250825312674272	'line_3407_to_3658_1_pi_merged_with_xf_3172_to_3658_1_2winding_transformer'	0.03393939393939394
	1.0251234690383717	1.0248533939357574	'line_3501_to_3508_1_pi_merged_with_xf_3508_to_3427_6_2winding_transformer'	0.008636363636363636
	1.0144731168291932	1.0219919319192932	'line_4123_to_4239_1_pi'	0.011818181818181818
	1.0249765387843643	1.0250048391176076	'line_4164_to_4191_1_pi_merged_with_xf_4164_to_4350_1_2winding_transformer'	0.020454545454545454
	1.022908616305847	1.0169561076412656	'line_4362_to_4363_1_pi_merged_with_xf_4362_to_4019_2_2winding_transformer'	0.03212121212121212
	1.0172562450164322	1.010321089140466	'line_4364_to_4365_1_pi'	0.011212121212121211
	1.0406777360759796	1.033861945066547	'Dec10_line_4129_to_4147_1_dec'	0.024145454545454543
	1.0406777360759796	1.0406274480653928	'Dec11_line_4129_to_4148_1_dec'	0.024472727272727274
	1.0447721912234567	1.0446225641827658	'Dec12_line_4135_to_4136_1_dec'	0.022109090909090908
	1.0447721912234567	1.048193041801558	'Dec13_line_4135_to_4137_1_dec'	0.025490909090909092
	1.0144731168291932	1.0148973122901432	'Dec14_line_4123_to_4292_1_dec'	0.019848484848484848
	1.0236313626706184	1.02290769319254	'Dec15_line_4226_to_4243_1_dec'	0.01893939393939394
	1.0236313626706184	1.02290769319254	'Dec16_line_4226_to_4243_2_dec'	0.01818181818181818
	1.0236313626706184	1.0148973122901432	'Dec17_line_4226_to_4292_2_dec'	0.01681818181818182
	1.0236313626706184	1.023676099374492	'Dec18_line_4226_to_4326_2_dec'	0.02
	1.0236313626706184	1.02048575706983	'Dec19_line_4226_to_4327_1_dec'	0.01803030303030303
	1.0406718804876574	1.0409482147080016	'Dec1_line_4112_to_4124_1_dec'	0.02509090909090909
	1.0214517544261588	1.0190465030629594	'Dec20_line_4233_to_4234_1_dec'	0.01893939393939394
	1.0214517544261588	1.0183687797308527	'Dec21_line_4233_to_4236_1_dec'	0.01818181818181818
	1.0124294572288566	1.0126051665769529	'Dec22_line_4275_to_4289_1_dec'	0.017424242424242422
	1.0156076445958928	1.0147371065457174	'Dec23_line_4276_to_4279_1_dec'	0.01681818181818182
	1.0156076445958928	1.0155636829312802	'Dec24_line_4276_to_4281_1_dec'	0.018333333333333333
	1.016638771161683	1.0157180982873784	'Dec25_line_4277_to_4285_1_dec'	0.019545454545454546
	1.0157180982873784	1.0133301852488363	'Dec26_line_4285_to_4286_1_dec'	0.019090909090909092
	1.0164786257871992	1.0180711441037225	'Dec27_line_4297_to_4334_1_dec'	0.02515151515151515
	1.0406718804876574	1.0387360565117372	'Dec2_line_4112_to_4133_1_dec'	0.019490909090909093
	1.0406718804876574	1.0383878552188455	'Dec3_line_4112_to_4134_1_dec'	0.020327272727272725
	1.0406718804876574	1.0447721912234567	'Dec4_line_4112_to_4135_1_dec'	0.021745454545454547
	1.0409482147080016	1.040031698496496	'Dec5_line_4124_to_4125_1_dec'	0.023999999999999997
	1.0409482147080016	1.0402915457108286	'Dec6_line_4124_to_4143_1_dec'	0.01730909090909091
	1.040031698496496	1.0407798896005183	'Dec7_line_4125_to_4128_1_dec'	0.023854545454545455
	1.0407798896005183	1.0406274480653928	'Dec8_line_4128_to_4148_1_dec'	0.023818181818181818
	1.0406777360759796	1.0497596627102626	'Dec9_line_4129_to_4146_1_dec'	0.02432727272727273
	1.0636350732821178	1.0771356990356977	'line_4139_to_4140_2_RLC_merged_with_line_4140_to_4149_2_cp'	0.019345454545454548
	1.0	1.0	'xf_1002_to_1006_10_2winding_transformer'	0.12130434782608696
	1.0	1.0	'xf_1003_to_1006_11_2winding_transformer'	0.11956521739130435
	1.0454545454545454	1.045454545454545	'xf_1009_to_1606_3_2winding_transformer'	0.057272727272727274
	1.0454545454545454	1.045454545454545	'xf_1010_to_1606_4_2winding_transformer'	0.05181818181818181
	1.0	1.0	'xf_1012_to_1383_4_2winding_transformer'	3.855072463768117
	1.0	1.0	'xf_1013_to_1383_2_2winding_transformer'	4.202898550724639
	1.0	1.0	'xf_1014_to_1383_3_2winding_transformer'	5.202898550724639
	1.0499999999999998	1.0	'xf_1023_to_1564_4_2winding_transformer'	7.2608695652173925
	1.0499999999999998	1.0	'xf_1024_to_1564_5_2winding_transformer'	6.304347826086958
	1.0	1.0	'xf_1025_to_1565_1_2winding_transformer'	7.3768115942029
	0.9749999999999999	1.0	'xf_1061_to_1083_1_2winding_transformer'	0.012424242424242423
	0.9749999999999999	1.0	'xf_1061_to_1083_2_2winding_transformer'	0.012954545454545455
	1.0335	1.0	'xf_1090_to_1004_5_2winding_transformer'	0.01488
	1.0335	1.0	'xf_1090_to_1004_6_2winding_transformer'	0.01446
	1.0335	1.0	'xf_1090_to_1005_7_2winding_transformer'	0.01462
	1.0335	1.0	'xf_1090_to_1005_8_2winding_transformer'	0.01478
	0.9943393939393941	1.0	'xf_1091_to_1002_1_2winding_transformer'	0.02596969696969697
	0.9943393939393941	1.0	'xf_1091_to_1002_2_2winding_transformer'	0.025515151515151515
	0.9943393939393941	1.0	'xf_1091_to_1003_3_2winding_transformer'	0.025545454545454545
	0.9943393939393941	1.0	'xf_1091_to_1003_4_2winding_transformer'	0.025757575757575757
	1.1250000000000002	1.05	'xf_1095_to_1159_3_2winding_transformer'	0.020575757575757577
	1.1250000000000002	1.05	'xf_1095_to_1159_4_2winding_transformer'	0.02196969696969697
	1.04675	1.0	'xf_1099_to_1019_5_2winding_transformer'	0.01598
	1.04675	1.0	'xf_1099_to_1019_6_2winding_transformer'	0.015380000000000001
	1.04675	1.0	'xf_1099_to_1020_7_2winding_transformer'	0.01524
	1.04675	1.0	'xf_1099_to_1020_8_2winding_transformer'	0.01492
	1.027472727272727	1.0	'xf_1100_to_1017_1_2winding_transformer'	0.025272727272727273
	1.027472727272727	1.0	'xf_1100_to_1017_2_2winding_transformer'	0.024272727272727272
	1.027472727272727	1.0	'xf_1100_to_1018_3_2winding_transformer'	0.025848484848484846
	1.027472727272727	1.0	'xf_1100_to_1018_4_2winding_transformer'	0.026575757575757575
	1.0	1.0	'xf_1102_to_1564_1_2winding_transformer'	0.015515151515151515
	1.0	1.0	'xf_1102_to_1564_2_2winding_transformer'	0.014515151515151516
	0.9730000000000004	1.0	'xf_1102_to_1565_3_2winding_transformer'	0.011
	1.03	1.05	'xf_1103_to_1165_1_2winding_transformer'	0.021454545454545455
	1.0400000000000003	1.05	'xf_1103_to_1165_4_2winding_transformer'	0.021696969696969697
	1.0700000000000003	1.05	'xf_1104_to_1164_1_2winding_transformer'	0.02081818181818182
	1.0500000000000003	1.05	'xf_1105_to_1166_1_2winding_transformer'	0.02009090909090909
	1.0500000000000003	1.05	'xf_1105_to_1166_2_2winding_transformer'	0.021424242424242426
	1.0500000000000003	1.05	'xf_1105_to_1166_3_2winding_transformer'	0.021272727272727273
	1.0500000000000003	1.05	'xf_1105_to_1166_4_2winding_transformer'	0.02009090909090909
	1.0400000000000003	1.05	'xf_1106_to_1168_1_2winding_transformer'	0.02218181818181818
	1.0400000000000003	1.05	'xf_1106_to_1168_2_2winding_transformer'	0.021333333333333333
	1.0700000000000003	1.05	'xf_1107_to_1409_2_2winding_transformer'	0.022545454545454546
	1.0700000000000003	1.05	'xf_1107_to_1410_3_2winding_transformer_merged_with_line_1410_to_1411_3_pi'	0.01006060606060606
	1.0400000000000003	1.05	'xf_1110_to_1169_1_2winding_transformer'	0.021515151515151515
	1.0400000000000003	1.05	'xf_1110_to_1169_2_2winding_transformer'	0.021606060606060604
	1.0400000000000003	1.05	'xf_1110_to_1169_3_2winding_transformer'	0.021212121212121213
	1.1000000000000003	1.05	'xf_1111_to_1170_1_2winding_transformer_merged_with_line_1170_to_1370_2_cp'	0.019484848484848483
	1.1000000000000003	1.05	'xf_1111_to_1171_2_2winding_transformer'	0.023454545454545454
	1.1000000000000003	1.05	'xf_1112_to_1538_1_2winding_transformer'	0.01303030303030303
	1.1000000000000003	1.05	'xf_1112_to_1538_2_2winding_transformer'	0.013454545454545455
	1.0400000000000003	1.05	'xf_1113_to_1172_1_2winding_transformer'	0.02084848484848485
	1.0400000000000003	1.05	'xf_1113_to_1172_2_2winding_transformer'	0.020424242424242425
	1.0	1.0	'xf_1114_to_1029_1_2winding_transformer'	0.008848484848484849
	1.0	1.0	'xf_1114_to_1030_2_2winding_transformer'	0.008666666666666666
	1.0606060606060606	1.0	'xf_1115_to_1034_1_2winding_transformer'	0.03445454545454545
	1.0606060606060606	1.0	'xf_1115_to_1036_3_2winding_transformer'	0.03166666666666666
	1.0606060606060606	1.0	'xf_1115_to_1037_4_2winding_transformer'	0.03118181818181818
	1.003	1.0909090909090906	'xf_1115_to_1544_5_2winding_transformer'	0.005424242424242424
	1.0060000000000002	1.0363636363636364	'xf_1115_to_1546_6_2winding_transformer'	0.005393939393939394
	1.1000000000000003	1.05	'xf_1116_to_1628_1_2winding_transformer'	0.02087878787878788
	1.1000000000000003	1.05	'xf_1116_to_1628_2_2winding_transformer'	0.021272727272727273
	1.0400000000000003	1.05	'xf_1117_to_1174_1_2winding_transformer_merged_with_line_1174_to_1491_1_cp'	0.02084848484848485
	1.0400000000000003	1.05	'xf_1117_to_1175_2_2winding_transformer'	0.022424242424242426
	1.0400000000000003	1.05	'xf_1117_to_1176_3_2winding_transformer_merged_with_line_1176_to_1491_3_cp'	0.02178787878787879
	0.9899999999999998	1.0	'xf_1119_to_1177_1_2winding_transformer'	0.01484848484848485
	1.0500000000000003	1.05	'xf_1120_to_1178_1_2winding_transformer'	0.02190909090909091
	1.0700000000000003	1.05	'xf_1120_to_1548_2_2winding_transformer'	0.012757575757575757
	1.010906060606061	1.0	'xf_1123_to_1044_1_2winding_transformer'	0.04818181818181818
	1.010906060606061	1.0	'xf_1123_to_1045_2_2winding_transformer'	0.05372727272727273
	1.0	1.05	'xf_1123_to_1179_3_2winding_transformer'	0.022424242424242426
	1.0352050909090913	1.0	'xf_1124_to_1047_2_2winding_transformer'	0.025636363636363638
	1.0	1.0	'xf_1124_to_1049_1_2winding_transformer'	0.015666666666666666
	1.0	1.0	'xf_1124_to_1050_2_2winding_transformer'	0.015151515151515152
	1.0	1.0	'xf_1124_to_1051_3_2winding_transformer'	0.014939393939393938
	1.0	1.0	'xf_1124_to_1052_4_2winding_transformer'	0.015181818181818182
	1.03	1.05	'xf_1124_to_1180_3_2winding_transformer_merged_with_line_1180_to_1463_1_pi'	0.02033333333333333
	1.0	1.0303030303030305	'xf_1124_to_1551_5_2winding_transformer'	0.004939393939393939
	1.0	1.0303030303030305	'xf_1124_to_1552_4_2winding_transformer'	0.004787878787878788
	1.0270000000000001	1.0	'xf_1125_to_1181_1_2winding_transformer'	0.006333333333333333
	1.0270000000000001	1.0	'xf_1125_to_1181_3_2winding_transformer'	0.014787878787878787
	1.0100000000000002	1.05	'xf_1126_to_1182_1_2winding_transformer'	0.022303030303030304
	1.0100000000000002	1.05	'xf_1126_to_1182_2_2winding_transformer'	0.021424242424242426
	0.9899999999999998	1.05	'xf_1132_to_1183_1_2winding_transformer'	0.021424242424242426
	0.9899999999999998	1.05	'xf_1132_to_1183_2_2winding_transformer'	0.022696969696969698
	0.9899999999999998	1.05	'xf_1132_to_1183_3_2winding_transformer'	0.022636363636363635
	1.06	1.05	'xf_1133_to_1184_1_2winding_transformer'	0.020999999999999998
	1.06	1.05	'xf_1133_to_1184_2_2winding_transformer'	0.021757575757575757
	1.0800000000000005	1.05	'xf_1134_to_1185_1_2winding_transformer'	0.028272727272727272
	1.0800000000000005	1.05	'xf_1134_to_1185_2_2winding_transformer'	0.028242424242424242
	1.0800000000000005	1.05	'xf_1134_to_1185_3_2winding_transformer'	0.02724242424242424
	1.0800000000000005	1.05	'xf_1134_to_1185_4_2winding_transformer'	0.020424242424242425
	1.01	1.0000000000000002	'xf_1136_to_1059_1_2winding_transformer'	0.00840909090909091
	1.04	1.0000000000000002	'xf_1136_to_1060_2_2winding_transformer'	0.008181818181818182
	1.0700000000000003	1.05	'xf_1138_to_1186_1_2winding_transformer'	0.02012121212121212
	1.1000000000000003	1.05	'xf_1138_to_1186_2_2winding_transformer'	0.022424242424242426
	1.0700000000000003	1.05	'xf_1138_to_1186_3_2winding_transformer'	0.021484848484848485
	1.0700000000000003	1.05	'xf_1138_to_1186_4_2winding_transformer'	0.021545454545454545
	1.0700000000000003	1.05	'xf_1138_to_1186_5_2winding_transformer'	0.021151515151515154
	1.09	1.05	'xf_1140_to_1189_1_2winding_transformer'	0.02327272727272727
	0.9000000000000004	1.05	'xf_1140_to_1189_2_2winding_transformer'	0.021696969696969697
	1.09	1.05	'xf_1140_to_1189_3_2winding_transformer'	0.021484848484848485
	1.09	1.05	'xf_1140_to_1189_5_2winding_transformer'	0.022
	1.09	1.05	'xf_1140_to_1189_6_2winding_transformer'	0.022
	1.0	1.0	'xf_1142_to_1642_2_2winding_transformer'	0.007303030303030303
	1.0	1.0	'xf_1142_to_1642_5_2winding_transformer'	0.00693939393939394
	1.0400000000000003	1.05	'xf_1144_to_1190_3_2winding_transformer'	0.02221212121212121
	1.0400000000000003	1.05	'xf_1144_to_1190_4_2winding_transformer'	0.022363636363636363
	1.0400000000000003	1.05	'xf_1144_to_1190_5_2winding_transformer'	0.021757575757575757
	1.0200000000000005	1.05	'xf_1144_to_1191_1_2winding_transformer'	0.022575757575757575
	1.0200000000000005	1.05	'xf_1144_to_1191_2_2winding_transformer'	0.02296969696969697
	1.0750000000000004	1.05	'xf_1145_to_1192_1_2winding_transformer'	0.011454545454545453
	1.0750000000000004	1.05	'xf_1145_to_1192_2_2winding_transformer'	0.011393939393939394
	1.0200000000000005	1.0	'xf_1145_to_1192_3_2winding_transformer'	0.011696969696969697
	0.9800000000000002	1.05	'xf_1146_to_1193_1_2winding_transformer'	0.022909090909090907
	0.9800000000000002	1.05	'xf_1146_to_1193_2_2winding_transformer'	0.019545454545454546
	0.9800000000000002	1.05	'xf_1146_to_1193_3_2winding_transformer'	0.019666666666666666
	1.0100000000000002	1.05	'xf_1147_to_1195_1_2winding_transformer'	0.022818181818181817
	1.0100000000000002	1.05	'xf_1147_to_1195_2_2winding_transformer'	0.022636363636363635
	1.0108742424242425	1.0	'xf_1149_to_1081_1_2winding_transformer'	0.023181818181818182
	1.0108742424242425	1.0	'xf_1149_to_1081_2_2winding_transformer'	0.023151515151515152
	1.0108742424242425	1.0	'xf_1149_to_1082_3_2winding_transformer'	0.021606060606060604
	1.0108742424242425	1.0	'xf_1149_to_1082_4_2winding_transformer'	0.023545454545454543
	1.0100000000000002	1.05	'xf_1149_to_1196_6_2winding_transformer'	0.012606060606060607
	1.0400000000000003	1.05	'xf_1150_to_1198_1_2winding_transformer'	0.021757575757575757
	1.0400000000000003	1.05	'xf_1150_to_1198_2_2winding_transformer'	0.02218181818181818
	1.0400000000000003	1.05	'xf_1150_to_1198_3_2winding_transformer'	0.021242424242424243
	1.0500000000000003	1.05	'xf_1151_to_1199_1_2winding_transformer'	0.02693939393939394
	1.0500000000000003	1.05	'xf_1151_to_1199_2_2winding_transformer'	0.021181818181818184
	1.0	1.05	'xf_1152_to_1200_3_2winding_transformer'	0.02181818181818182
	1.0	1.05	'xf_1152_to_1200_4_2winding_transformer'	0.021666666666666667
	1.0	1.05	'xf_1153_to_1201_1_2winding_transformer'	0.020696969696969696
	1.0	1.05	'xf_1153_to_1201_2_2winding_transformer'	0.02212121212121212
	1.0200000000000005	1.05	'xf_1154_to_1204_1_2winding_transformer'	0.02109090909090909
	1.0200000000000005	1.05	'xf_1154_to_1204_2_2winding_transformer'	0.020393939393939395
	1.03	1.05	'xf_1155_to_1205_1_2winding_transformer'	0.02187878787878788
	1.03	1.05	'xf_1155_to_1205_2_2winding_transformer'	0.02215151515151515
	1.05	1.0454545454545454	'xf_1156_to_1157_1_2winding_transformer'	0.05682
	1.0100000000000002	1.05	'xf_1158_to_1206_1_2winding_transformer'	0.011212121212121213
	1.0100000000000002	1.05	'xf_1158_to_1206_3_2winding_transformer'	0.011909090909090909
	0.9799999999999999	1.0	'xf_1159_to_1527_1_2winding_transformer'	0.011515151515151515
	0.9799999999999999	1.0	'xf_1159_to_1527_2_2winding_transformer'	0.011590909090909091
	1.02	1.0	'xf_1164_to_1535_2_2winding_transformer'	0.022727272727272728
	1.02	1.0	'xf_1164_to_1535_3_2winding_transformer'	0.023484848484848487
	1.0184999999999997	1.0	'xf_1165_to_1103_2_2winding_transformer'	0.0653030303030303
	1.0079999999999998	1.0	'xf_1165_to_1103_3_2winding_transformer'	0.06659090909090909
	1.02	1.0	'xf_1179_to_1549_5_2winding_transformer'	0.02121212121212121
	1.02	1.0	'xf_1179_to_1550_4_2winding_transformer'	0.021893939393939396
	0.9599999999999999	1.0	'xf_1181_to_1053_2_2winding_transformer'	0.0196969696969697
	0.9555000000000001	1.0	'xf_1189_to_1140_4_2winding_transformer'	0.05606060606060606
	1.0	0.9952727272727271	'xf_1200_to_1515_2_2winding_transformer'	0.008257575757575759
	1.0	0.9952727272727271	'xf_1200_to_1516_1_2winding_transformer'	0.008484848484848486
	1.0250000000000001	1.0	'xf_1200_to_1560_5_2winding_transformer'	0.012196969696969697
	1.0250000000000001	1.0	'xf_1200_to_1560_6_2winding_transformer'	0.011590909090909091
	1.0	1.0	'xf_1206_to_1517_2_2winding_transformer'	0.007348484848484848
	1.0	1.0	'xf_1208_to_1209_1_2winding_transformer'	0.011893939393939394
	1.0	1.0	'xf_1208_to_1209_2_2winding_transformer'	0.012575757575757575
	1.05	1.0	'xf_1211_to_1561_1_2winding_transformer'	0.0034545454545454545
	1.0	1.0	'xf_1212_to_1499_1_2winding_transformer'	0.0035606060606060605
	1.0	1.0	'xf_1212_to_1499_2_2winding_transformer'	0.0035606060606060605
	1.0199999999999996	1.0	'xf_1217_to_1606_1_2winding_transformer'	0.008818181818181819
	1.0199999999999996	1.0	'xf_1217_to_1606_2_2winding_transformer'	0.009045454545454546
	1.0215	1.0	'xf_1218_to_1651_1_2winding_transformer'	0.017727272727272727
	1.0215	1.0	'xf_1218_to_1651_2_2winding_transformer'	0.017545454545454545
	1.025	1.0	'xf_1218_to_1651_3_2winding_transformer'	0.01690909090909091
	1.05	1.0	'xf_1225_to_1021_1_2winding_transformer'	0.04090909090909091
	1.05	1.0	'xf_1225_to_1021_2_2winding_transformer'	0.03984848484848485
	0.9900000000000001	1.0	'xf_1262_to_1567_1_2winding_transformer'	0.014090909090909091
	0.9900000000000001	1.0	'xf_1262_to_1567_2_2winding_transformer'	0.013409090909090909
	0.9900000000000001	1.0	'xf_1263_to_1568_1_2winding_transformer'	0.022196969696969698
	0.9900000000000001	1.0	'xf_1263_to_1568_2_2winding_transformer'	0.02212121212121212
	1.05	1.0	'xf_1267_to_1031_1_2winding_transformer'	0.016136363636363636
	0.9900000000000001	1.0	'xf_1269_to_1032_2_2winding_transformer'	0.013409090909090909
	0.9900000000000001	1.0	'xf_1270_to_1032_3_2winding_transformer'	0.014166666666666668
	0.9900000000000001	1.0	'xf_1272_to_1032_1_2winding_transformer'	0.013863636363636364
	1.160208	1.0	'xf_1274_to_1033_1_2winding_transformer'	0.007651515151515151
	1.0	1.0	'xf_1281_to_1576_1_2winding_transformer'	0.009393939393939394
	1.0	1.0	'xf_1281_to_1576_2_2winding_transformer'	0.00909090909090909
	1.0	1.0	'xf_1282_to_1577_3_2winding_transformer'	0.009393939393939394
	1.0	1.0	'xf_1282_to_1577_4_2winding_transformer'	0.009318181818181817
	0.9625	1.0	'xf_1286_to_1578_1_2winding_transformer'	0.021060606060606057
	1.0	1.0	'xf_1287_to_1547_1_2winding_transformer'	0.0034090909090909094
	1.0	1.0	'xf_1287_to_1547_2_2winding_transformer'	0.003484848484848485
	1.0	1.0	'xf_1293_to_1503_1_2winding_transformer'	0.011515151515151515
	1.0	1.0	'xf_1293_to_1503_2_2winding_transformer'	0.011515151515151515
	1.0	1.0	'xf_1297_to_1507_1_2winding_transformer'	0.012878787878787878
	1.0	1.0	'xf_1297_to_1507_2_2winding_transformer'	0.012499999999999999
	0.9374999999999999	1.0	'xf_1303_to_1581_1_2winding_transformer'	0.009015151515151514
	0.95	1.0	'xf_1304_to_1581_2_2winding_transformer'	0.009166666666666667
	1.0	1.0	'xf_1308_to_1583_1_2winding_transformer'	0.012575757575757575
	1.0	1.0	'xf_1308_to_1583_2_2winding_transformer'	0.012727272727272726
	1.0	1.0	'xf_1310_to_1508_1_2winding_transformer'	0.013409090909090909
	1.0	1.0	'xf_1310_to_1508_2_2winding_transformer'	0.013030303030303031
	0.9833300000000003	1.0	'xf_1311_to_1056_1_2winding_transformer'	0.0067424242424242425
	0.9833300000000003	1.0	'xf_1311_to_1056_2_2winding_transformer'	0.011212121212121211
	1.0255	1.0	'xf_1312_to_1584_1_2winding_transformer'	0.011515151515151515
	1.0255	1.0	'xf_1312_to_1584_2_2winding_transformer'	0.01143939393939394
	1.0	1.0	'xf_1313_to_1509_2_2winding_transformer'	0.023863636363636365
	1.0	1.0	'xf_1313_to_1509_3_2winding_transformer'	0.02212121212121212
	1.0	1.0	'xf_1313_to_1509_4_2winding_transformer'	0.02265151515151515
	1.0	1.0	'xf_1313_to_1585_1_2winding_transformer'	0.00946969696969697
	1.0	1.0	'xf_1316_to_1555_1_2winding_transformer'	0.0031818181818181815
	1.0	1.0	'xf_1316_to_1555_2_2winding_transformer'	0.0031818181818181815
	1.0	1.0	'xf_1316_to_1555_3_2winding_transformer'	0.0034090909090909094
	1.044	1.0	'xf_1317_to_1586_1_2winding_transformer'	0.011742424242424243
	1.044	1.0	'xf_1317_to_1586_2_2winding_transformer'	0.011742424242424243
	1.044	1.0	'xf_1317_to_1586_3_2winding_transformer'	0.01143939393939394
	0.9500000000000002	1.0	'xf_1318_to_1057_1_2winding_transformer'	0.03212121212121212
	1.0	1.0	'xf_1322_to_1510_1_2winding_transformer'	0.012196969696969697
	1.0	1.0	'xf_1322_to_1510_2_2winding_transformer'	0.012121212121212121
	1.045	1.0	'xf_1324_to_1048_1_2winding_transformer'	0.007121212121212121
	1.0	1.0	'xf_1324_to_1062_1_2winding_transformer'	0.010303030303030303
	1.0	1.0	'xf_1326_to_1556_1_2winding_transformer'	0.0034090909090909094
	1.0	1.0	'xf_1326_to_1556_2_2winding_transformer'	0.0034090909090909094
	1.0	1.0	'xf_1331_to_1512_1_2winding_transformer'	0.023106060606060606
	1.0	1.0	'xf_1331_to_1512_2_2winding_transformer'	0.024242424242424242
	0.9625	1.0	'xf_1332_to_1513_2_2winding_transformer'	0.011818181818181818
	1.05	1.0	'xf_1333_to_1513_1_2winding_transformer'	0.007348484848484848
	0.9749999999999999	1.0	'xf_1334_to_1589_1_2winding_transformer'	0.012499999999999999
	0.9749999999999999	1.0	'xf_1334_to_1589_2_2winding_transformer'	0.012499999999999999
	0.9874999999999999	1.0	'xf_1335_to_1591_1_2winding_transformer'	0.012196969696969697
	0.9874999999999999	1.0	'xf_1335_to_1591_2_2winding_transformer'	0.012499999999999999
	0.9874999999999999	1.0	'xf_1335_to_1591_3_2winding_transformer'	0.01196969696969697
	1.0	1.0	'xf_1336_to_1592_1_2winding_transformer'	0.008636363636363636
	1.0	1.0	'xf_1336_to_1592_2_2winding_transformer'	0.00893939393939394
	1.0	1.0	'xf_1336_to_1592_3_2winding_transformer'	0.009015151515151514
	1.0	1.0	'xf_1337_to_1557_1_2winding_transformer'	0.0032575757575757577
	1.0	1.0	'xf_1337_to_1557_2_2winding_transformer'	0.003484848484848485
	0.95	1.0	'xf_1347_to_1594_1_2winding_transformer'	0.012727272727272726
	0.95	1.0	'xf_1347_to_1594_2_2winding_transformer'	0.011893939393939394
	0.95	1.0	'xf_1347_to_1594_3_2winding_transformer'	0.012045454545454547
	1.0125	1.0	'xf_1351_to_1559_1_2winding_transformer'	0.010303030303030303
	1.0	1.0	'xf_1370_to_1369_1_2winding_transformer'	0.013636363636363637
	1.0	1.0	'xf_1370_to_1369_2_2winding_transformer'	0.01393939393939394
	1.0	1.0	'xf_1370_to_1369_3_2winding_transformer'	0.013560606060606061
	1.0	1.0	'xf_1374_to_1518_1_2winding_transformer'	0.0034090909090909094
	1.0	1.0	'xf_1374_to_1518_2_2winding_transformer'	0.0034090909090909094
	1.0	1.0	'xf_1374_to_1518_3_2winding_transformer'	0.0033333333333333335
	0.9599999999999999	1.0	'xf_1375_to_1519_1_2winding_transformer'	0.004545454545454545
	0.9599999999999999	1.0	'xf_1375_to_1519_2_2winding_transformer'	0.004696969696969697
	1.0	1.0	'xf_1392_to_1611_1_2winding_transformer'	0.00393939393939394
	1.0125	1.0	'xf_1392_to_1612_2_2winding_transformer'	0.00393939393939394
	1.0	1.0	'xf_1393_to_1534_1_2winding_transformer'	0.0034090909090909094
	1.0	1.0	'xf_1393_to_1534_2_2winding_transformer'	0.0031818181818181815
	1.0	1.0	'xf_1393_to_1534_3_2winding_transformer'	0.003863636363636364
	1.0250000000000001	1.0	'xf_1402_to_1613_1_2winding_transformer'	0.011742424242424243
	1.0250000000000001	1.0	'xf_1402_to_1613_2_2winding_transformer'	0.01106060606060606
	1.0375000000000003	1.0	'xf_1408_to_1614_2_2winding_transformer'	0.01143939393939394
	1.0375000000000003	1.0	'xf_1408_to_1615_1_2winding_transformer'	0.011742424242424243
	0.9749999999999999	1.0	'xf_1414_to_1620_1_2winding_transformer'	0.01143939393939394
	0.9749999999999999	1.0	'xf_1414_to_1620_2_2winding_transformer'	0.011287878787878788
	1.0375000000000003	1.0	'xf_1419_to_1622_1_2winding_transformer'	0.011742424242424243
	1.0375000000000003	1.0	'xf_1419_to_1622_2_2winding_transformer'	0.011818181818181818
	0.9749999999999999	1.0	'xf_1423_to_1623_1_2winding_transformer'	0.011590909090909091
	0.9749999999999999	1.0	'xf_1423_to_1623_2_2winding_transformer'	0.011287878787878788
	1.0	1.0	'xf_1428_to_1501_3_2winding_transformer'	0.013560606060606061
	1.01	1.0	'xf_1432_to_1625_1_2winding_transformer'	0.02287878787878788
	1.01	1.0	'xf_1432_to_1625_2_2winding_transformer'	0.023333333333333334
	1.0125	1.0	'xf_1433_to_1626_1_2winding_transformer'	0.01196969696969697
	1.0125	1.0	'xf_1433_to_1626_2_2winding_transformer'	0.01196969696969697
	0.9625	1.0	'xf_1434_to_1571_1_2winding_transformer'	0.03015151515151515
	0.9874999999999999	1.0	'xf_1437_to_1436_1_2winding_transformer'	0.024696969696969696
	1.0	1.0	'xf_1440_to_1575_1_2winding_transformer'	0.015227272727272726
	1.0	1.0	'xf_1440_to_1575_2_2winding_transformer'	0.014772727272727272
	1.0	1.0	'xf_1440_to_1575_3_2winding_transformer'	0.014924242424242423
	0.9625	1.0	'xf_1444_to_1629_1_2winding_transformer'	0.012196969696969697
	0.9625	1.0	'xf_1444_to_1629_2_2winding_transformer'	0.011363636363636364
	0.9625	1.0	'xf_1444_to_1629_3_2winding_transformer'	0.012272727272727274
	1.0250000000000001	1.0	'xf_1447_to_1631_2_2winding_transformer'	0.004090909090909091
	1.0125	1.0	'xf_1447_to_1632_1_2winding_transformer'	0.003787878787878788
	1.0125	1.0	'xf_1449_to_1633_1_2winding_transformer'	0.025227272727272727
	1.0125	1.0	'xf_1449_to_1633_2_2winding_transformer'	0.02446969696969697
	1.0	1.0	'xf_1458_to_1636_1_2winding_transformer'	0.0033333333333333335
	1.0	1.0	'xf_1458_to_1636_2_2winding_transformer'	0.0031060606060606057
	1.0	1.0	'xf_1460_to_1553_1_2winding_transformer'	0.003484848484848485
	1.0	1.0	'xf_1460_to_1553_4_2winding_transformer'	0.0031818181818181815
	1.0	1.0	'xf_1461_to_1553_2_2winding_transformer'	0.0028787878787878787
	1.0	1.0	'xf_1461_to_1553_3_2winding_transformer'	0.0031060606060606057
	1.0250000000000001	1.0	'xf_1472_to_1058_1_2winding_transformer'	0.06848484848484848
	0.95	1.0	'xf_1473_to_1638_3_2winding_transformer'	0.012424242424242423
	0.95	1.0	'xf_1473_to_1638_4_2winding_transformer'	0.011742424242424243
	0.9374999999999999	1.0	'xf_1473_to_1639_1_2winding_transformer'	0.007272727272727273
	0.9374999999999999	1.0	'xf_1473_to_1639_2_2winding_transformer'	0.007651515151515151
	1.0	1.0	'xf_1478_to_1640_1_2winding_transformer'	0.003484848484848485
	1.0	1.0	'xf_1478_to_1640_2_2winding_transformer'	0.003484848484848485
	0.9874999999999999	1.0	'xf_1479_to_1645_1_2winding_transformer'	0.012575757575757575
	1.0	1.0	'xf_1480_to_1069_1_2winding_transformer'	0.026893939393939394
	1.0	1.0	'xf_1480_to_1070_2_2winding_transformer'	0.025606060606060604
	1.0	1.0	'xf_1480_to_1071_3_2winding_transformer'	0.027121212121212122
	1.0	1.0	'xf_1480_to_1072_4_2winding_transformer'	0.02553030303030303
	1.0125	1.0	'xf_1481_to_1482_1_2winding_transformer'	0.023863636363636365
	1.0125	1.0	'xf_1481_to_1482_2_2winding_transformer'	0.02462121212121212
	1.0	1.0	'xf_1483_to_1590_1_2winding_transformer'	0.01446969696969697
	1.0	1.0	'xf_1483_to_1590_2_2winding_transformer'	0.015454545454545455
	1.0	1.0	'xf_1489_to_1558_1_2winding_transformer'	0.0032575757575757577
	1.0	1.0	'xf_1489_to_1558_2_2winding_transformer'	0.0032575757575757577
	1.0	1.0	'xf_1494_to_1647_1_2winding_transformer'	0.003712121212121212
	1.0	1.0	'xf_1495_to_1652_1_2winding_transformer'	0.014772727272727272
	1.0	1.0	'xf_1495_to_1653_2_2winding_transformer'	0.015151515151515152
	1.0	1.0	'xf_1495_to_1653_3_2winding_transformer'	0.015606060606060606
	1.0	1.0	'xf_1496_to_1649_1_2winding_transformer'	0.003484848484848485
	1.0	1.0	'xf_1496_to_1649_2_2winding_transformer'	0.0034090909090909094
	1.0	1.0	'xf_1497_to_1650_1_2winding_transformer'	0.010303030303030303
	1.0	1.0	'xf_1497_to_1650_2_2winding_transformer'	0.010151515151515153
	1.0	1.0	'xf_1521_to_1000_1_2winding_transformer'	0.11454545454545455
	1.0	1.0	'xf_1528_to_1610_3_2winding_transformer'	0.01393939393939394
	1.0	1.0	'xf_1529_to_1610_1_2winding_transformer'	0.014545454545454545
	1.0	1.0	'xf_1530_to_1610_2_2winding_transformer'	0.008484848484848486
	0.9874999999999999	1.0	'xf_1554_to_1582_1_2winding_transformer'	0.024090909090909093
	1.0200000000000005	1.05	'xf_1569_to_1221_1_2winding_transformer'	0.02184848484848485
	1.1000000000000003	1.05	'xf_1569_to_1541_1_2winding_transformer'	0.021424242424242426
	0.9737500000000002	0.9565217391304348	'xf_1602_to_1088_1_2winding_transformer'	0.03363636363636364
	0.9737500000000002	0.9565217391304348	'xf_1602_to_1089_2_2winding_transformer'	0.03363636363636364
	0.95	1.0	'xf_1627_to_1574_1_2winding_transformer'	0.016212121212121212
	0.95	1.0	'xf_1627_to_1574_2_2winding_transformer'	0.01393939393939394
	0.95	1.0	'xf_1627_to_1574_3_2winding_transformer'	0.014696969696969696
	1.0	1.0454545454545454	'xf_1654_to_1085_2_2winding_transformer'	0.029393939393939392
	1.0	1.0454545454545454	'xf_1655_to_1084_1_2winding_transformer'	0.031212121212121212
	1.0	1.0454545454545454	'xf_1656_to_1087_4_2winding_transformer'	0.03848484848484848
	1.0454545454545454	1.0	'xf_1657_to_1086_3_2winding_transformer_merged_with_line_1369_to_1657_3_cp'	0.08454545454545455
	1.025	1.0	'xf_2001_to_2297_3_2winding_transformer'	2.202898550724638
	1.025	1.0	'xf_2002_to_2296_4_2winding_transformer'	1.9710144927536237
	1.0	1.0	'xf_2068_to_2069_1_2winding_transformer'	0.01803030303030303
	1.0	1.0	'xf_2068_to_2070_2_2winding_transformer'	0.01924242424242424
	1.0499999999999998	1.0	'xf_2076_to_2345_2_2winding_transformer'	5.8405797101449295
	1.075	1.0	'xf_2077_to_2270_1_2winding_transformer'	0.012909090909090908
	1.075	1.0	'xf_2077_to_2270_2_2winding_transformer'	0.012045454545454545
	1.0	1.0	'xf_2077_to_2314_7_2winding_transformer'	0.00490909090909091
	1.0	1.0	'xf_2077_to_2314_8_2winding_transformer'	0.00490909090909091
	1.0	1.0	'xf_2077_to_2348_4_2winding_transformer'	0.0265
	1.0	1.0	'xf_2077_to_2348_5_2winding_transformer'	0.027136363636363636
	1.0	1.0	'xf_2077_to_2348_6_2winding_transformer'	0.028227272727272726
	1.0	1.0	'xf_2082_to_2162_1_2winding_transformer'	0.049878787878787884
	1.0	1.0	'xf_2083_to_2086_1_2winding_transformer_merged_with_line_2083_to_2163_1_pi'	0.2590476190476191
	1.0	1.0	'xf_2084_to_2085_2_2winding_transformer_merged_with_line_2084_to_2164_2_pi'	0.2561904761904762
	1.0250000000000001	1.0	'xf_2100_to_2005_1_2winding_transformer'	0.030378787878787877
	1.0250000000000001	1.0	'xf_2100_to_2006_2_2winding_transformer'	0.032424242424242425
	0.9749999999999999	1.0	'xf_2101_to_2227_3_2winding_transformer'	0.024924242424242425
	0.9749999999999999	1.0	'xf_2101_to_2228_4_2winding_transformer'	0.026136363636363638
	1.0176454545454543	1.0031746031746032	'xf_2104_to_2040_1_2winding_transformer'	0.01240909090909091
	1.0176454545454543	1.0031746031746032	'xf_2104_to_2041_2_2winding_transformer'	0.012136363636363636
	0.9414999999999999	1.0	'xf_2104_to_2097_3_2winding_transformer'	0.01531818181818182
	0.9414999999999999	1.0	'xf_2104_to_2210_2_2winding_transformer'	0.014909090909090908
	1.0279954545454544	1.0227272727272725	'xf_2105_to_2214_1_2winding_transformer'	0.013136363636363637
	1.0279954545454544	1.0227272727272725	'xf_2105_to_2214_2_2winding_transformer'	0.012954545454545455
	1.0323863636363637	1.0	'xf_2106_to_2098_1_2winding_transformer_merged_with_line_2098_to_2101_1_cp'	0.02009090909090909
	1.0937499999999996	1.0	'xf_2107_to_2003_1_2winding_transformer'	0.006772727272727272
	1.0937499999999996	1.0	'xf_2107_to_2004_2_2winding_transformer'	0.0064090909090909086
	1.0629136363636362	1.0227272727272725	'xf_2108_to_2220_1_2winding_transformer'	0.011363636363636364
	1.0629136363636362	1.0227272727272725	'xf_2108_to_2220_2_2winding_transformer'	0.013863636363636363
	1.045454545454545	1.0227272727272725	'xf_2108_to_2298_4_2winding_transformer'	0.006545454545454545
	1.045454545454545	1.0227272727272725	'xf_2108_to_2299_3_2winding_transformer'	0.006727272727272728
	1.0323863636363637	1.0	'xf_2109_to_2099_1_2winding_transformer'	0.018
	1.0323863636363637	1.0	'xf_2109_to_2099_2_2winding_transformer'	0.0175
	0.9609999999999999	1.0	'xf_2112_to_2221_3_2winding_transformer'	0.013636363636363636
	0.9609999999999999	1.0	'xf_2112_to_2221_4_2winding_transformer'	0.014318181818181818
	0.9609999999999999	1.0	'xf_2112_to_2222_5_2winding_transformer'	0.013590909090909093
	0.9374999999999997	1.0	'xf_2112_to_2300_1_2winding_transformer'	0.0038636363636363634
	0.9374999999999997	1.0	'xf_2112_to_2300_2_2winding_transformer'	0.0039545454545454545
	0.9609999999999999	1.0	'xf_2118_to_2224_1_2winding_transformer'	0.014181818181818183
	0.9609999999999999	1.0	'xf_2118_to_2224_2_2winding_transformer'	0.014090909090909091
	0.9609999999999999	1.0	'xf_2118_to_2224_3_2winding_transformer'	0.014818181818181817
	1.0363636363636364	1.0	'xf_2120_to_2190_1_2winding_transformer'	0.05181818181818182
	1.0363636363636364	1.0	'xf_2120_to_2190_2_2winding_transformer'	0.04790909090909091
	1.0363636363636364	1.0	'xf_2120_to_2190_3_2winding_transformer'	0.04454545454545455
	1.0	1.0	'xf_2121_to_2231_1_2winding_transformer'	0.01540909090909091
	1.0	1.0	'xf_2121_to_2231_2_2winding_transformer'	0.013272727272727273
	0.9804999999999999	1.0	'xf_2121_to_2232_3_2winding_transformer'	0.014499999999999999
	0.9804999999999999	1.0	'xf_2121_to_2232_4_2winding_transformer'	0.014772727272727272
	1.0227272727272725	1.0	'xf_2122_to_2015_1_2winding_transformer'	0.009681818181818182
	1.0227272727272725	1.0	'xf_2122_to_2016_2_2winding_transformer'	0.010136363636363636
	0.9804999999999999	1.0	'xf_2123_to_2233_1_2winding_transformer'	0.01390909090909091
	0.9804999999999999	1.0	'xf_2123_to_2233_3_2winding_transformer'	0.014772727272727272
	1.0	1.0	'xf_2125_to_2337_1_2winding_transformer'	0.007272727272727273
	0.9931713636363634	1.0227272727272725	'xf_2126_to_2234_1_2winding_transformer'	0.011363636363636364
	1.0105990909090903	1.0227272727272725	'xf_2127_to_2234_2_2winding_transformer'	0.013454545454545455
	1.0	1.0	'xf_2128_to_2236_1_2winding_transformer'	0.013454545454545455
	1.0	1.0	'xf_2128_to_2236_2_2winding_transformer'	0.014454545454545456
	0.9820000000000002	1.0	'xf_2128_to_2237_3_2winding_transformer'	0.012909090909090908
	0.9820000000000002	1.0	'xf_2128_to_2237_4_2winding_transformer'	0.013181818181818182
	1.0681818181818175	1.0227272727272725	'xf_2129_to_2239_1_2winding_transformer'	0.009272727272727273
	1.0681818181818175	1.0227272727272725	'xf_2129_to_2239_2_2winding_transformer'	0.008909090909090908
	0.9609999999999999	1.0	'xf_2130_to_2241_1_2winding_transformer'	0.014272727272727274
	0.9609999999999999	1.0	'xf_2130_to_2241_2_2winding_transformer'	0.013954545454545454
	0.9609999999999999	1.0	'xf_2130_to_2241_3_2winding_transformer'	0.014272727272727274
	1.0	1.0	'xf_2137_to_2067_7_2winding_transformer'	0.005636363636363636
	1.0	1.0	'xf_2137_to_2067_8_2winding_transformer'	0.0055
	1.0	1.0	'xf_2139_to_2088_1_2winding_transformer'	0.00946969696969697
	1.0	1.0	'xf_2139_to_2089_2_2winding_transformer'	0.009015151515151514
	0.9625	1.0	'xf_2140_to_2338_1_2winding_transformer'	0.009409090909090909
	0.9625	1.0	'xf_2140_to_2338_2_2winding_transformer'	0.009045454545454546
	0.9625	1.0	'xf_2141_to_2338_3_2winding_transformer'	0.009227272727272726
	1.1181136363636361	1.0	'xf_2142_to_2032_1_2winding_transformer'	0.0095
	1.1181136363636361	1.0	'xf_2142_to_2033_2_2winding_transformer'	0.00909090909090909
	1.1181136363636361	1.0	'xf_2142_to_2034_3_2winding_transformer'	0.009272727272727273
	1.1181136363636361	1.0	'xf_2142_to_2035_4_2winding_transformer'	0.009545454545454546
	1.0726363636363634	1.0	'xf_2143_to_2036_1_2winding_transformer'	0.011636363636363637
	1.0726363636363634	1.0	'xf_2143_to_2037_2_2winding_transformer'	0.011545454545454546
	1.0726363636363634	1.0	'xf_2143_to_2038_3_2winding_transformer'	0.011545454545454546
	0.9804999999999999	1.0	'xf_2146_to_2248_4_2winding_transformer'	0.013818181818181818
	0.9804999999999999	1.0	'xf_2146_to_2248_5_2winding_transformer'	0.014181818181818183
	0.9609999999999999	1.0	'xf_2146_to_2249_6_2winding_transformer'	0.013818181818181818
	0.9609999999999999	1.0	'xf_2146_to_2249_7_2winding_transformer'	0.013500000000000002
	0.9804999999999999	1.0	'xf_2146_to_2250_8_2winding_transformer'	0.014772727272727272
	1.0803099999999994	1.0227272727272725	'xf_2148_to_2251_1_2winding_transformer'	0.005772727272727273
	1.0	0.9565217391304348	'xf_2150_to_2048_1_2winding_transformer'	0.012363636363636365
	0.9625	1.0	'xf_2151_to_2343_3_2winding_transformer'	0.042272727272727274
	1.045454545454545	0.9565217391304348	'xf_2153_to_2060_1_2winding_transformer'	0.007
	1.045454545454545	0.9565217391304348	'xf_2153_to_2061_2_2winding_transformer'	0.007363636363636364
	1.0931818181818178	1.0000000000000002	'xf_2153_to_2062_3_2winding_transformer'	0.007863636363636364
	1.0017545454545456	1.0	'xf_2155_to_2261_1_2winding_transformer'	0.013045454545454546
	1.0	1.0017545454545456	'xf_2156_to_2262_2_2winding_transformer_merged_with_line_2144_to_2156_2_cp'	0.04454545454545455
	1.0017545454545456	1.0	'xf_2157_to_2261_3_2winding_transformer'	0.013227272727272728
	1.0	1.0	'xf_2158_to_2264_1_2winding_transformer'	0.018590909090909092
	1.0	1.0	'xf_2158_to_2264_2_2winding_transformer'	0.017272727272727273
	1.0614999999999997	1.0	'xf_2159_to_2073_1_2winding_transformer'	0.037454545454545456
	0.9732204545454544	1.0	'xf_2162_to_2271_2_2winding_transformer'	0.009136363636363635
	0.9732204545454544	1.0	'xf_2162_to_2271_4_2winding_transformer'	0.008954545454545455
	1.0681818181818175	1.0	'xf_2162_to_2315_1_2winding_transformer'	0.0019545454545454545
	1.0681818181818175	1.0	'xf_2162_to_2315_3_2winding_transformer'	0.002
	0.9749999999999995	1.0	'xf_2167_to_2103_8_2winding_transformer'	0.0039545454545454545
	0.9609999999999999	1.0	'xf_2167_to_2197_2_2winding_transformer'	0.014045454545454545
	0.9609999999999999	1.0	'xf_2167_to_2197_3_2winding_transformer'	0.014863636363636364
	1.0	1.0	'xf_2167_to_2197_4_2winding_transformer'	0.014
	0.9024999999999999	1.0	'xf_2167_to_2272_1_2winding_transformer'	0.013818181818181818
	0.9024999999999999	1.0	'xf_2167_to_2272_5_2winding_transformer'	0.014636363636363637
	0.9024999999999999	1.0	'xf_2167_to_2272_6_2winding_transformer'	0.013954545454545454
	0.9772727272727267	1.0	'xf_2167_to_2316_7_2winding_transformer'	0.010272727272727272
	1.0	1.0	'xf_2168_to_2273_3_2winding_transformer'	0.01540909090909091
	1.0	1.0	'xf_2168_to_2273_4_2winding_transformer'	0.014818181818181817
	0.9609999999999999	1.0	'xf_2168_to_2274_1_2winding_transformer'	0.015
	0.9609999999999999	1.0	'xf_2168_to_2274_2_2winding_transformer'	0.01531818181818182
	0.9250000000000002	1.0	'xf_2168_to_2320_6_2winding_transformer'	0.0036363636363636364
	0.9625	1.0	'xf_2168_to_2321_5_2winding_transformer'	0.003681818181818182
	1.010536363636364	1.0227272727272725	'xf_2169_to_2275_1_2winding_transformer'	0.013136363636363637
	1.010536363636364	1.0227272727272725	'xf_2169_to_2275_2_2winding_transformer'	0.013136363636363637
	1.010536363636364	1.0227272727272725	'xf_2169_to_2275_3_2winding_transformer'	0.014227272727272727
	0.9804999999999999	1.0	'xf_2170_to_2276_5_2winding_transformer'	0.016409090909090908
	0.9804999999999999	1.0	'xf_2171_to_2276_4_2winding_transformer'	0.017045454545454544
	0.9414999999999999	1.0	'xf_2172_to_2277_1_2winding_transformer'	0.013545454545454545
	0.9414999999999999	1.0	'xf_2172_to_2277_2_2winding_transformer'	0.014318181818181818
	0.9804999999999999	1.0	'xf_2172_to_2278_3_2winding_transformer'	0.014045454545454545
	0.9804999999999999	1.0	'xf_2172_to_2278_4_2winding_transformer'	0.013136363636363637
	0.9804999999999999	1.0	'xf_2174_to_2279_1_2winding_transformer'	0.014818181818181817
	0.9804999999999999	1.0	'xf_2174_to_2279_2_2winding_transformer'	0.014499999999999999
	0.9804999999999999	1.0	'xf_2174_to_2279_3_2winding_transformer'	0.013545454545454545
	0.9930772727272728	1.0227272727272725	'xf_2176_to_2280_1_2winding_transformer'	0.013772727272727272
	0.9930772727272728	1.0227272727272725	'xf_2176_to_2280_2_2winding_transformer'	0.011272727272727273
	1.045454545454545	1.0227272727272725	'xf_2177_to_2281_1_2winding_transformer'	0.014045454545454545
	1.045454545454545	1.0227272727272725	'xf_2177_to_2281_3_2winding_transformer'	0.01331818181818182
	1.0	1.0	'xf_2178_to_2284_1_2winding_transformer'	0.014
	1.0	1.0	'xf_2178_to_2284_2_2winding_transformer'	0.014454545454545456
	0.9804999999999999	1.0	'xf_2178_to_2285_3_2winding_transformer'	0.014681818181818181
	1.0628822727272726	1.0227272727272725	'xf_2179_to_2286_1_2winding_transformer'	0.0065
	1.0	1.0	'xf_2180_to_2289_1_2winding_transformer'	0.014227272727272727
	1.0	1.0	'xf_2180_to_2290_4_2winding_transformer'	0.013818181818181818
	1.0	1.0	'xf_2181_to_2290_3_2winding_transformer'	0.014363636363636365
	1.0	1.0	'xf_2182_to_2289_2_2winding_transformer'	0.013590909090909093
	1.0	1.0	'xf_2182_to_2290_5_2winding_transformer'	0.015045454545454546
	1.045454545454545	0.9565217391304348	'xf_2183_to_2091_1_2winding_transformer'	0.007272727272727273
	1.0	1.0	'xf_2184_to_2291_2_2winding_transformer'	0.014
	1.0	1.0	'xf_2184_to_2291_3_2winding_transformer'	0.013636363636363636
	1.0	1.0	'xf_2184_to_2291_4_2winding_transformer'	0.014090909090909091
	1.0	1.0	'xf_2184_to_2292_1_2winding_transformer'	0.014727272727272728
	0.9772727272727267	1.0	'xf_2184_to_2326_5_2winding_transformer'	0.01
	0.9614409090909091	1.0	'xf_2184_to_2328_6_2winding_transformer'	0.01
	1.006145454545454	0.999999999999999	'xf_2186_to_2093_2_2winding_transformer'	0.04286363636363636
	1.006145454545454	0.999999999999999	'xf_2186_to_2094_3_2winding_transformer'	0.044454545454545455
	1.006145454545454	0.999999999999999	'xf_2186_to_2095_4_2winding_transformer'	0.045454545454545456
	1.0	1.0	'xf_2186_to_2335_6_2winding_transformer'	0.003363636363636364
	1.0	1.0	'xf_2186_to_2336_7_2winding_transformer'	0.003363636363636364
	1.045454545454545	1.0	'xf_2186_to_2352_5_2winding_transformer'	0.006590909090909091
	0.9963181818181818	0.999999999999999	'xf_2187_to_2092_1_2winding_transformer'	0.04359090909090909
	1.0	1.0	'xf_2191_to_2102_8_2winding_transformer'	0.004030303030303031
	1.0	1.0	'xf_2191_to_2102_9_2winding_transformer'	0.00393939393939394
	1.0	1.0	'xf_2194_to_2170_3_2winding_transformer'	0.04090909090909091
	1.0	1.0	'xf_2194_to_2171_2_2winding_transformer'	0.039424242424242424
	1.0375000000000003	1.0	'xf_2198_to_2118_4_2winding_transformer'	0.0349
	1.0299999999999998	1.045454545454545	'xf_2199_to_2131_1_2winding_transformer'	0.0223
	1.0299999999999998	1.045454545454545	'xf_2199_to_2132_2_2winding_transformer'	0.02182
	1.0299999999999998	1.045454545454545	'xf_2199_to_2134_4_2winding_transformer_merged_with_line_2134_to_2135_4_cp'	0.02166
	0.9625	1.0	'xf_2200_to_2196_1_2winding_transformer'	0.030940000000000002
	0.9999999999999998	1.0	'xf_2201_to_2146_1_2winding_transformer'	0.02198
	0.9999999999999998	1.0	'xf_2201_to_2146_3_2winding_transformer'	0.02188
	0.9899999999999998	1.0	'xf_2201_to_2147_2_2winding_transformer'	0.02196
	1.0124999999999997	1.0	'xf_2202_to_2042_1_2winding_transformer'	0.02518
	1.0124999999999997	1.0	'xf_2202_to_2043_2_2winding_transformer'	0.02488
	1.0124999999999997	1.0	'xf_2202_to_2044_3_2winding_transformer'	0.0254
	1.0124999999999997	1.0	'xf_2202_to_2045_4_2winding_transformer'	0.02524
	1.0375000000000003	0.999999999999999	'xf_2202_to_2046_1_2winding_transformer'	0.02282
	1.0375000000000003	0.999999999999999	'xf_2202_to_2047_2_2winding_transformer'	0.0229
	1.025	1.0	'xf_2203_to_2154_1_2winding_transformer'	0.03494
	1.025	1.0	'xf_2203_to_2154_2_2winding_transformer'	0.03666
	1.05825	0.999999999999999	'xf_2204_to_2063_1_2winding_transformer'	0.01324
	1.05825	0.999999999999999	'xf_2204_to_2064_2_2winding_transformer'	0.01368
	1.05	1.0	'xf_2206_to_2166_2_2winding_transformer'	0.03516
	0.9875	1.0	'xf_2207_to_2194_1_2winding_transformer'	0.05086
	1.025	1.0	'xf_2209_to_2175_1_2winding_transformer'	0.02384
	1.0176399999999999	1.0	'xf_2213_to_2296_2_2winding_transformer'	0.014545454545454545
	0.9941200000000002	1.0	'xf_2213_to_2297_1_2winding_transformer'	0.014848484848484849
	1.0	1.0	'xf_2226_to_2302_1_2winding_transformer_merged_with_line_2009_to_2302_1_cp'	0.014848484848484849
	0.9500000000000002	1.0	'xf_2227_to_2010_1_2winding_transformer'	0.10393939393939394
	0.9500000000000002	1.0	'xf_2228_to_2011_2_2winding_transformer'	0.23333333333333334
	1.08	1.0	'xf_2229_to_2012_1_2winding_transformer'	0.00803030303030303
	1.08	1.0	'xf_2229_to_2013_2_2winding_transformer'	0.008181818181818182
	1.05	1.0	'xf_2244_to_2247_2_2winding_transformer'	0.02696969696969697
	1.05	1.0	'xf_2245_to_2246_1_2winding_transformer'	0.027424242424242424
	1.0	1.0	'xf_2260_to_2344_3_2winding_transformer'	0.006212121212121211
	1.0	1.0	'xf_2264_to_2312_3_2winding_transformer'	0.018333333333333333
	1.0	1.0	'xf_2264_to_2312_4_2winding_transformer'	0.020151515151515153
	0.9874999999999999	1.0	'xf_2265_to_2313_1_2winding_transformer'	0.011515151515151515
	0.9625	1.0	'xf_2266_to_2267_1_2winding_transformer'	0.010909090909090908
	0.9749999999999996	1.0	'xf_2266_to_2268_3_2winding_transformer'	0.010909090909090908
	1.0	1.0	'xf_2267_to_2075_4_2winding_transformer'	0.022424242424242423
	1.0	1.0	'xf_2268_to_2074_2_2winding_transformer'	0.016666666666666666
	1.0124999999999997	1.0	'xf_2269_to_2345_1_2winding_transformer'	0.028787878787878786
	0.9749999999999996	1.0	'xf_2270_to_2078_4_2winding_transformer'	0.4021212121212121
	0.9749999999999996	1.0	'xf_2270_to_2079_5_2winding_transformer'	0.02393939393939394
	0.9749999999999996	1.0	'xf_2270_to_2080_3_2winding_transformer'	0.014393939393939393
	0.9749999999999996	1.0	'xf_2270_to_2081_6_2winding_transformer'	0.014242424242424242
	1.0	1.0	'xf_2281_to_2090_2_2winding_transformer'	0.07893939393939393
	1.0375	1.0476190476190477	'xf_2287_to_2322_3_2winding_transformer'	0.011818181818181818
	1.0375	1.0476190476190477	'xf_2287_to_2323_4_2winding_transformer'	0.01196969696969697
	1.0375	1.0476190476190477	'xf_2287_to_2324_1_2winding_transformer'	0.011515151515151515
	1.0375	1.0476190476190477	'xf_2287_to_2325_2_2winding_transformer'	0.012424242424242423
	1.0227272727272725	1.0	'xf_2295_to_2189_1_2winding_transformer'	0.03515151515151515
	1.0227272727272725	1.0	'xf_2295_to_2189_2_2winding_transformer'	0.03772727272727273
	1.0	1.0	'xf_2306_to_2339_6_2winding_transformer'	0.014545454545454545
	1.0	1.0	'xf_2306_to_2340_5_2winding_transformer'	0.015000000000000001
	1.0	1.0	'xf_2306_to_2341_4_2winding_transformer'	0.015000000000000001
	1.0	1.0	'xf_2307_to_2065_4_2winding_transformer'	0.03636363636363637
	1.0	1.0	'xf_2308_to_2066_5_2winding_transformer_merged_with_line_2308_to_2311_6_cp'	0.06363636363636363
	1.0	1.0	'xf_2310_to_2344_6_2winding_transformer'	0.03409090909090909
	1.0	1.0	'xf_2313_to_2072_2_2winding_transformer'	0.05227272727272727
	1.0	1.0	'xf_2315_to_2350_6_2winding_transformer'	0.014090909090909091
	1.0227272727272725	1.0	'xf_2332_to_2333_4_2winding_transformer'	0.014545454545454545
	1.0227272727272725	1.0	'xf_2332_to_2334_3_2winding_transformer'	0.015000000000000001
	1.0	1.0	'xf_2342_to_2054_1_2winding_transformer'	0.1415151515151515
	1.0	1.0	'xf_2342_to_2055_4_2winding_transformer'	0.0890909090909091
	1.0	1.0	'xf_2342_to_2056_5_2winding_transformer'	0.04151515151515152
	1.0	1.0	'xf_2343_to_2057_6_2winding_transformer'	0.14454545454545453
	1.0	1.0	'xf_2343_to_2058_7_2winding_transformer'	0.07484848484848486
	1.0	1.0	'xf_2343_to_2059_8_2winding_transformer'	0.06060606060606061
	0.9654599999999999	1.0	'xf_2355_to_4185_1_2winding_transformer'	0.05278787878787879
	1.0375000000000003	1.0	'xf_3009_to_3011_2_2winding_transformer'	0.014924242424242423
	1.0	1.0	'xf_3009_to_3013_4_2winding_transformer'	0.003712121212121212
	1.0375000000000003	1.0	'xf_3010_to_3011_1_2winding_transformer'	0.01393939393939394
	1.0	1.0	'xf_3010_to_3012_3_2winding_transformer'	0.00393939393939394
	0.92773	1.0	'xf_3014_to_3016_1_2winding_transformer'	0.004454545454545454
	0.9659090909090908	1.0	'xf_3019_to_3020_1_2winding_transformer'	0.01109090909090909
	0.9624999999999999	1.0	'xf_3019_to_3020_2_2winding_transformer'	0.01672727272727273
	0.9624999999999999	1.0	'xf_3019_to_3020_3_2winding_transformer'	0.01672727272727273
	0.8874999999999998	1.0	'xf_3021_to_3022_1_2winding_transformer'	0.0031060606060606057
	1.05	1.0	'xf_3021_to_3022_2_2winding_transformer'	0.0031818181818181815
	1.0	1.0	'xf_3024_to_3026_3_2winding_transformer'	0.01
	0.9375	1.0	'xf_3025_to_3024_4_2winding_transformer'	0.016636363636363637
	1.0	1.0	'xf_3026_to_3025_1_2winding_transformer'	0.019393939393939394
	1.0	1.0	'xf_3026_to_3025_2_2winding_transformer'	0.018787878787878787
	1.0	1.0250000000000001	'xf_3027_to_3029_2_2winding_transformer_merged_with_line_3027_to_3072_1_cp'	0.05575757575757576
	1.0250000000000001	1.0	'xf_3028_to_3029_1_2winding_transformer'	0.015151515151515152
	0.9874999999999999	1.0	'xf_3034_to_3035_1_2winding_transformer'	0.011287878787878788
	0.9874999999999999	1.0	'xf_3034_to_3035_2_2winding_transformer'	0.010606060606060605
	0.9874999999999999	1.0	'xf_3034_to_3035_3_2winding_transformer'	0.012499999999999999
	1.0	0.9874999999999999	'xf_3036_to_3038_4_2winding_transformer_merged_with_line_3036_to_3249_1_cp'	0.06818181818181818
	0.9874999999999999	1.0	'xf_3037_to_3038_2_2winding_transformer'	0.006136363636363637
	1.0	0.983050847457627	'xf_3039_to_3040_2_2winding_transformer'	0.007121212121212121
	1.0	0.983050847457627	'xf_3039_to_3041_3_2winding_transformer'	0.006363636363636363
	1.0	0.983050847457627	'xf_3039_to_3042_4_2winding_transformer'	0.006893939393939394
	1.0	0.983050847457627	'xf_3039_to_3043_1_2winding_transformer'	0.006818181818181819
	0.9749999999999999	1.0454545454545454	'xf_3044_to_3046_1_2winding_transformer'	0.019015151515151513
	1.0454545454545454	0.9749999999999999	'xf_3045_to_3046_2_2winding_transformer_merged_with_line_3045_to_3482_1_cp'	0.027272727272727275
	1.0375	1.0	'xf_3048_to_3049_1_2winding_transformer'	0.016454545454545454
	1.0375	1.0	'xf_3048_to_3049_2_2winding_transformer'	0.01809090909090909
	1.0375000000000003	1.0454545454545454	'xf_3051_to_3053_1_2winding_transformer'	0.018636363636363635
	1.0375000000000003	1.0454545454545454	'xf_3051_to_3053_2_2winding_transformer'	0.01840909090909091
	1.015	1.0454545454545454	'xf_3054_to_3055_1_2winding_transformer'	0.018106060606060608
	1.015	1.0454545454545454	'xf_3054_to_3055_2_2winding_transformer'	0.019393939393939394
	0.975	1.0	'xf_3056_to_3057_1_2winding_transformer'	0.01672727272727273
	1.13632	1.0	'xf_3056_to_3057_2_2winding_transformer'	0.005818181818181819
	1.0456	1.0	'xf_3058_to_3059_1_2winding_transformer'	0.018363636363636363
	1.0456	1.0	'xf_3058_to_3059_2_2winding_transformer'	0.017272727272727273
	1.0238	1.0454545454545454	'xf_3061_to_3062_1_2winding_transformer'	0.014090909090909091
	1.0	1.0454545454545454	'xf_3061_to_3062_2_2winding_transformer'	0.01393939393939394
	1.0238	1.0454545454545454	'xf_3061_to_3062_3_2winding_transformer'	0.029393939393939392
	1.03	1.0454545454545454	'xf_3063_to_3064_1_2winding_transformer'	0.019393939393939394
	1.03	1.0454545454545454	'xf_3063_to_3064_2_2winding_transformer'	0.02121212121212121
	1.03	1.0454545454545454	'xf_3063_to_3064_3_2winding_transformer'	0.022196969696969698
	1.0136	1.0454545454545454	'xf_3065_to_3066_1_2winding_transformer'	0.021363636363636362
	1.0136	1.0454545454545454	'xf_3065_to_3066_2_2winding_transformer'	0.019318181818181818
	1.0	1.0	'xf_3067_to_3452_1_2winding_transformer'	0.008333333333333333
	0.9874999999999999	1.0	'xf_3069_to_3070_1_2winding_transformer'	0.013409090909090909
	0.9874999999999999	1.0	'xf_3069_to_3070_2_2winding_transformer'	0.019015151515151513
	0.9874999999999999	1.0	'xf_3069_to_3070_3_2winding_transformer'	0.013636363636363637
	0.9204545454545454	0.9181000000000001	'xf_3074_to_3075_1_2winding_transformer'	0.015909090909090907
	0.9204545454545454	0.9181000000000001	'xf_3074_to_3075_2_2winding_transformer'	0.019545454545454543
	1.03	1.0454545454545454	'xf_3077_to_3642_1_2winding_transformer'	0.022272727272727274
	1.03	1.0454545454545454	'xf_3078_to_3642_2_2winding_transformer'	0.021136363636363637
	0.925	1.0	'xf_3080_to_3081_1_2winding_transformer'	0.004090909090909091
	1.0250000000000001	1.0	'xf_3080_to_3081_2_2winding_transformer'	0.0025
	1.0	1.0000000000000002	'xf_3082_to_3457_4_2winding_transformer'	0.006363636363636364
	1.0	1.0	'xf_3083_to_3085_1_2winding_transformer'	0.008106060606060606
	1.0	1.0	'xf_3083_to_3085_2_2winding_transformer'	0.008257575757575759
	1.0	1.0	'xf_3086_to_3087_1_2winding_transformer'	0.007424242424242424
	0.9374999999999999	1.0	'xf_3088_to_3090_1_2winding_transformer'	0.007575757575757576
	0.9374999999999999	1.0	'xf_3089_to_3091_2_2winding_transformer'	0.007954545454545455
	1.0	1.0	'xf_3093_to_3449_2_2winding_transformer_merged_with_line_3089_to_3093_1_cp'	0.08090909090909092
	0.9749999999999999	1.0454545454545454	'xf_3094_to_3095_1_2winding_transformer'	0.018636363636363635
	0.9749999999999999	1.0454545454545454	'xf_3094_to_3095_2_2winding_transformer'	0.0196969696969697
	1.03	1.0454545454545454	'xf_3096_to_3097_1_2winding_transformer'	0.023257575757575755
	1.03	1.0454545454545454	'xf_3096_to_3098_2_2winding_transformer'	0.024242424242424242
	0.9813818181818181	1.0	'xf_3099_to_3100_1_2winding_transformer'	0.011545454545454546
	0.97728	1.0	'xf_3099_to_3100_2_2winding_transformer'	0.01109090909090909
	0.9874999999999999	1.0	'xf_3101_to_3103_2_2winding_transformer'	0.01734848484848485
	0.9874999999999999	1.0	'xf_3101_to_3103_3_2winding_transformer'	0.018484848484848486
	0.9874999999999999	1.0	'xf_3102_to_3103_1_2winding_transformer'	0.013030303030303031
	1.0375000000000003	1.0454545454545454	'xf_3106_to_3107_1_2winding_transformer'	0.019166666666666665
	0.9874999999999999	1.0	'xf_3108_to_3110_1_2winding_transformer'	0.01712121212121212
	0.9874999999999999	1.0	'xf_3108_to_3110_2_2winding_transformer'	0.004545454545454545
	1.0	1.0	'xf_3111_to_3112_2_2winding_transformer'	0.004015151515151515
	1.0	1.0454545454545454	'xf_3111_to_3113_1_2winding_transformer'	0.004318181818181818
	1.06	1.0454545454545454	'xf_3114_to_3115_1_2winding_transformer'	0.013181818181818182
	1.06	1.0454545454545454	'xf_3114_to_3115_2_2winding_transformer'	0.018787878787878787
	1.045	1.0454545454545454	'xf_3117_to_3118_1_2winding_transformer'	0.012424242424242423
	1.045	1.0454545454545454	'xf_3117_to_3118_2_2winding_transformer'	0.012575757575757575
	1.0815151515151518	1.0454545454545454	'xf_3120_to_3121_1_2winding_transformer'	0.005227272727272727
	1.075	1.0454545454545454	'xf_3120_to_3121_2_2winding_transformer'	0.0067424242424242425
	0.9624999999999999	1.0	'xf_3123_to_3124_1_2winding_transformer'	0.005545454545454545
	0.975	1.0	'xf_3123_to_3125_2_2winding_transformer'	0.005272727272727273
	0.952	1.0	'xf_3129_to_3130_1_2winding_transformer'	0.008454545454545454
	0.952	1.0	'xf_3129_to_3130_2_2winding_transformer'	0.008727272727272728
	1.0125	1.0	'xf_3131_to_3132_1_2winding_transformer'	0.004636363636363636
	1.0375	1.0	'xf_3131_to_3133_2_2winding_transformer'	0.0047272727272727275
	1.0250000000000001	1.0	'xf_3137_to_3138_1_2winding_transformer'	0.002575757575757576
	1.0250000000000001	1.0	'xf_3137_to_3139_2_2winding_transformer'	0.0031060606060606057
	1.0250000000000001	1.0454545454545454	'xf_3140_to_3142_1_2winding_transformer'	0.020075757575757577
	1.0250000000000001	1.0454545454545454	'xf_3141_to_3142_2_2winding_transformer'	0.019318181818181818
	1.1	1.0	'xf_3143_to_3145_1_2winding_transformer'	0.007424242424242424
	1.125	1.0	'xf_3144_to_3145_2_2winding_transformer'	0.007803030303030303
	0.925	1.0	'xf_3148_to_3004_1_2winding_transformer'	0.004393939393939394
	0.925	1.0	'xf_3148_to_3004_2_2winding_transformer'	0.004393939393939394
	1.0863578181818183	1.0	'xf_3158_to_3438_1_2winding_transformer'	0.015963636363636364
	1.0863578181818183	1.0	'xf_3158_to_3439_2_2winding_transformer'	0.01530909090909091
	1.0863578181818183	1.0	'xf_3158_to_3440_3_2winding_transformer'	0.014581818181818182
	1.062272727272727	1.0	'xf_3158_to_3525_2_2winding_transformer'	0.01781818181818182
	1.062272727272727	1.0	'xf_3158_to_3526_3_2winding_transformer'	0.018545454545454546
	1.062272727272727	1.0	'xf_3158_to_3527_1_2winding_transformer'	0.018145454545454548
	1.0	1.0	'xf_3158_to_3648_1_2winding_transformer'	0.10909090909090909
	1.0	1.0	'xf_3163_to_3271_1_2winding_transformer'	0.014363636363636365
	1.0	1.0	'xf_3163_to_3271_2_2winding_transformer'	0.016454545454545454
	1.0	1.0	'xf_3163_to_3271_3_2winding_transformer'	0.014545454545454545
	1.0	1.0	'xf_3172_to_3657_2_2winding_transformer'	0.008787878787878787
	1.0454545454545454	1.0250000000000001	'xf_3175_to_3176_1_2winding_transformer_merged_with_line_3175_to_3482_1_cp'	0.03272727272727273
	1.0	1.0	'xf_3180_to_3183_1_2winding_transformer'	0.008181818181818182
	1.0	1.0	'xf_3181_to_3183_2_2winding_transformer_merged_with_line_3181_to_3182_2_pi'	0.026818181818181817
	1.0375000000000003	1.0454545454545454	'xf_3184_to_3186_1_2winding_transformer'	0.020454545454545454
	1.0454545454545454	1.0375000000000003	'xf_3185_to_3186_2_2winding_transformer_merged_with_line_3185_to_3263_2_cp'	0.0353030303030303
	1.0375000000000003	1.0	'xf_3187_to_3188_1_2winding_transformer'	0.012196969696969697
	1.0375000000000003	1.0	'xf_3187_to_3188_2_2winding_transformer'	0.011590909090909091
	0.9874999999999999	1.0	'xf_3189_to_3191_1_2winding_transformer'	0.00393939393939394
	0.9874999999999999	1.0	'xf_3189_to_3191_2_2winding_transformer'	0.003863636363636364
	1.0165	1.0	'xf_3190_to_3461_3_2winding_transformer'	0.024166666666666666
	1.0375	1.0	'xf_3192_to_3193_1_2winding_transformer'	0.01718181818181818
	1.0375	1.0	'xf_3192_to_3193_2_2winding_transformer'	0.017454545454545455
	1.0375	1.0	'xf_3192_to_3193_3_2winding_transformer'	0.017545454545454545
	0.9883399999999999	1.0	'xf_3192_to_3605_1_2winding_transformer'	0.060636363636363634
	0.9749999999999999	1.0	'xf_3196_to_3197_1_2winding_transformer'	0.0024242424242424242
	1.05	1.0	'xf_3198_to_3200_2_2winding_transformer'	0.021515151515151515
	1.05	1.0	'xf_3199_to_3200_1_2winding_transformer'	0.020833333333333332
	1.075	1.0454545454545454	'xf_3201_to_3202_1_2winding_transformer'	0.013181818181818182
	1.075	1.0454545454545454	'xf_3201_to_3202_2_2winding_transformer'	0.0196969696969697
	1.0125	1.0	'xf_3203_to_3206_1_2winding_transformer'	0.01818181818181818
	1.0125	1.0	'xf_3204_to_3206_2_2winding_transformer'	0.01809090909090909
	1.0125	1.0	'xf_3205_to_3206_3_2winding_transformer'	0.01709090909090909
	0.9625	0.9545454545454546	'xf_3211_to_3462_1_2winding_transformer'	0.03204545454545455
	1.0	1.0585227272727273	'xf_3212_to_3465_2_2winding_transformer_merged_with_line_3212_to_3255_1_cp'	0.3952380952380953
	1.0323863636363637	1.0	'xf_3213_to_3464_1_2winding_transformer'	0.038818181818181814
	0.9749999999999999	1.0	'xf_3219_to_3221_2_2winding_transformer'	0.005606060606060606
	0.9749999999999999	1.0	'xf_3220_to_3221_1_2winding_transformer'	0.006060606060606061
	1.0	1.0	'xf_3223_to_3224_1_2winding_transformer'	0.004242424242424243
	1.0	1.0	'xf_3223_to_3224_2_2winding_transformer'	0.004393939393939394
	1.0125	1.0	'xf_3229_to_3230_1_2winding_transformer'	0.018727272727272728
	1.0125	1.0	'xf_3229_to_3230_2_2winding_transformer'	0.018636363636363635
	0.975	1.0	'xf_3234_to_3236_1_2winding_transformer'	0.004181818181818182
	1.0375	1.0	'xf_3235_to_3236_2_2winding_transformer'	0.004272727272727273
	1.03408	1.0	'xf_3237_to_3239_2_2winding_transformer'	0.02336363636363636
	1.03408	1.0	'xf_3238_to_3239_1_2winding_transformer'	0.022454545454545456
	1.05	1.0	'xf_3243_to_3659_1_2winding_transformer'	0.01446969696969697
	1.0	1.0125	'xf_3250_to_3251_1_2winding_transformer_merged_with_line_3249_to_3250_1_cp'	0.021515151515151515
	1.02272	1.0	'xf_3254_to_3257_1_2winding_transformer'	0.02081818181818182
	1.0125	1.0	'xf_3259_to_3260_1_2winding_transformer'	0.02431818181818182
	1.0125	1.0	'xf_3259_to_3260_2_2winding_transformer'	0.02515151515151515
	0.9874999999999999	1.0	'xf_3263_to_3264_1_2winding_transformer'	0.03446969696969697
	1.0625	1.0	'xf_3265_to_3156_2_2winding_transformer'	0.015303030303030303
	1.0875	1.0	'xf_3293_to_3294_1_2winding_transformer'	0.023409090909090907
	1.0	1.0000000000000002	'xf_3296_to_3008_1_2winding_transformer'	0.007727272727272728
	0.9874999999999999	1.0476190476190477	'xf_3296_to_3419_3_2winding_transformer'	0.04757575757575758
	1.025	1.0	'xf_3306_to_3308_2_2winding_transformer'	0.005090909090909091
	1.0125	1.0	'xf_3307_to_3309_1_2winding_transformer'	0.0051818181818181815
	0.9875000000000002	1.0	'xf_3315_to_3316_2_2winding_transformer'	0.017818181818181816
	1.0125	1.0	'xf_3319_to_3320_1_2winding_transformer'	0.017272727272727273
	1.0	0.975	'xf_3321_to_3323_2_2winding_transformer_merged_with_line_3321_to_3504_2_cp'	0.06151515151515151
	0.975	1.0	'xf_3322_to_3323_1_2winding_transformer'	0.01690909090909091
	1.0	1.0	'xf_3324_to_3327_4_2winding_transformer'	0.005545454545454545
	1.0251	1.0	'xf_3325_to_3328_2_2winding_transformer'	0.005454545454545454
	0.9885999999999998	1.0	'xf_3326_to_3324_3_2winding_transformer'	0.05575757575757576
	0.9885999999999998	1.0	'xf_3326_to_3325_1_2winding_transformer'	0.05848484848484848
	1.0	1.0	'xf_3330_to_3331_1_2winding_transformer_merged_with_line_3329_to_3330_1_cp'	0.03954545454545454
	1.0	1.0342	'xf_3337_to_3339_1_2winding_transformer_merged_with_line_3337_to_3471_1_cp'	0.04515151515151515
	1.03408	1.0	'xf_3338_to_3339_2_2winding_transformer'	0.021545454545454545
	0.98864	1.0	'xf_3340_to_3341_1_2winding_transformer'	0.014090909090909091
	0.98864	1.0	'xf_3340_to_3341_2_2winding_transformer'	0.014727272727272728
	1.025	1.0	'xf_3342_to_3343_1_2winding_transformer'	0.014636363636363637
	1.025	1.0	'xf_3342_to_3343_2_2winding_transformer'	0.014181818181818183
	1.0113	1.0	'xf_3344_to_3347_2_2winding_transformer'	0.007909090909090909
	1.0113	1.0	'xf_3345_to_3347_3_2winding_transformer'	0.007363636363636364
	1.0	1.0912	'xf_3349_to_3351_1_2winding_transformer_merged_with_line_3349_to_3636_1_cp'	0.041212121212121214
	1.0	1.0	'xf_3352_to_3353_1_2winding_transformer_merged_with_line_3352_to_3385_1_cp'	0.034848484848484844
	1.0	1.0	'xf_3357_to_3355_1_2winding_transformer'	0.014272727272727274
	1.0	1.0	'xf_3357_to_3355_2_2winding_transformer'	0.013727272727272727
	1.0	1.0	'xf_3357_to_3356_3_2winding_transformer'	0.013818181818181818
	1.0	1.0125	'xf_3368_to_3370_2_2winding_transformer_merged_with_line_3368_to_3382_2_cp'	0.05393939393939394
	1.0125	1.0	'xf_3369_to_3370_1_2winding_transformer'	0.01718181818181818
	0.9125	1.0	'xf_3378_to_3380_1_2winding_transformer'	0.005363636363636363
	0.8999999999999999	1.0	'xf_3378_to_3381_2_2winding_transformer'	0.005363636363636363
	0.98864	1.0	'xf_3382_to_3383_1_2winding_transformer'	0.014454545454545456
	0.98864	1.0	'xf_3382_to_3383_2_2winding_transformer'	0.017363636363636362
	1.0113599999999998	1.0	'xf_3382_to_3383_3_2winding_transformer'	0.014272727272727274
	0.9875000000000002	1.0	'xf_3382_to_3383_4_2winding_transformer'	0.017363636363636362
	1.0	1.0	'xf_3385_to_3446_1_2winding_transformer'	0.005090909090909091
	1.0	1.0	'xf_3386_to_3387_3_2winding_transformer'	0.005272727272727273
	1.0125	1.0	'xf_3386_to_3388_1_2winding_transformer'	0.005363636363636363
	1.0375	1.0	'xf_3386_to_3389_2_2winding_transformer'	0.005454545454545454
	0.975	1.0	'xf_3390_to_3392_2_2winding_transformer'	0.016
	1.0125	1.0	'xf_3393_to_3394_1_2winding_transformer'	0.01818181818181818
	1.0125	1.0	'xf_3393_to_3394_2_2winding_transformer'	0.01809090909090909
	1.0375	1.0	'xf_3395_to_3396_1_2winding_transformer'	0.016272727272727272
	1.0375	1.0	'xf_3395_to_3396_2_2winding_transformer'	0.016545454545454547
	1.03408	1.0	'xf_3395_to_3396_3_2winding_transformer'	0.009454545454545455
	1.0125	1.0	'xf_3397_to_3398_1_2winding_transformer'	0.0051818181818181815
	1.0125	1.0	'xf_3397_to_3399_2_2winding_transformer'	0.005090909090909091
	0.9624999999999999	1.0	'xf_3397_to_3400_3_2winding_transformer'	0.005090909090909091
	1.0125	1.0	'xf_3402_to_3403_1_2winding_transformer'	0.022363636363636363
	1.0125	1.0	'xf_3402_to_3403_2_2winding_transformer'	0.022454545454545456
	0.9875000000000002	1.0	'xf_3408_to_3409_1_2winding_transformer'	0.005272727272727273
	1.0	1.0	'xf_3408_to_3410_2_2winding_transformer'	0.005454545454545454
	1.0	1.0000000000000002	'xf_3432_to_3433_1_2winding_transformer'	0.0031060606060606057
	1.0	1.0	'xf_3470_to_3543_2_2winding_transformer'	0.03972727272727273
	1.0	1.0	'xf_3470_to_3543_3_2winding_transformer'	0.05672727272727273
	1.025	1.0	'xf_3471_to_3472_5_2winding_transformer'	0.017818181818181816
	1.025	1.0	'xf_3471_to_3472_6_2winding_transformer'	0.017545454545454545
	1.025	1.0	'xf_3471_to_3472_7_2winding_transformer'	0.019909090909090908
	1.0	1.0	'xf_3471_to_3545_1_2winding_transformer'	0.039090909090909086
	1.0	1.0	'xf_3471_to_3545_2_2winding_transformer'	0.039818181818181815
	1.0	1.0	'xf_3471_to_3545_3_2winding_transformer'	0.05954545454545455
	1.0	1.0	'xf_3471_to_3545_4_2winding_transformer'	0.06054545454545455
	1.0125	1.0	'xf_3473_to_3474_1_2winding_transformer'	0.018454545454545453
	1.0027272727272727	1.0	'xf_3473_to_3546_2_2winding_transformer'	0.038363636363636364
	1.0027272727272727	1.0	'xf_3473_to_3546_3_2winding_transformer'	0.03872727272727273
	1.0027272727272727	1.0	'xf_3473_to_3546_4_2winding_transformer'	0.03809090909090909
	0.9749999999999999	1.0	'xf_3475_to_3547_1_2winding_transformer'	0.06212121212121212
	0.9749999999999999	1.0	'xf_3475_to_3547_2_2winding_transformer'	0.06446969696969697
	0.9749999999999999	1.0	'xf_3476_to_3549_1_2winding_transformer'	0.04462121212121212
	0.9749999999999999	1.0	'xf_3476_to_3549_2_2winding_transformer'	0.04424242424242424
	1.0152300000000003	1.0	'xf_3477_to_3554_2_2winding_transformer'	0.07984848484848484
	0.9864899999999999	1.0	'xf_3479_to_3556_1_2winding_transformer'	0.06537878787878788
	0.9864899999999999	1.0	'xf_3479_to_3556_2_2winding_transformer'	0.06553030303030304
	1.0	1.0	'xf_3481_to_3479_4_2winding_transformer_merged_with_line_3314_to_3481_2_cp'	0.024999999999999998
	0.9874999999999999	1.0	'xf_3482_to_3557_1_2winding_transformer'	0.0353030303030303
	0.9874999999999999	1.0	'xf_3482_to_3557_2_2winding_transformer'	0.0528030303030303
	0.9625	1.0	'xf_3483_to_3558_1_2winding_transformer'	0.03659090909090909
	1.0	1.0	'xf_3490_to_3563_2_2winding_transformer'	0.10909090909090909
	0.9858999999999999	1.0	'xf_3491_to_3490_1_2winding_transformer'	0.03954545454545454
	0.985901509090909	1.0	'xf_3491_to_3490_4_2winding_transformer'	0.037909090909090906
	0.985901509090909	1.0	'xf_3491_to_3490_5_2winding_transformer'	0.039636363636363636
	1.0125	1.0454545454545454	'xf_3492_to_3493_3_2winding_transformer'	0.013333333333333334
	1.0125	1.0454545454545454	'xf_3492_to_3493_4_2winding_transformer'	0.013409090909090909
	1.0125	1.0454545454545454	'xf_3492_to_3493_5_2winding_transformer'	0.013257575757575758
	0.989240590909091	1.0	'xf_3496_to_3567_2_2winding_transformer'	0.059000000000000004
	0.95	1.0	'xf_3497_to_3568_1_2winding_transformer'	0.024166666666666666
	0.95	1.0	'xf_3498_to_3568_4_2winding_transformer'	0.023257575757575755
	0.98655	1.0	'xf_3503_to_3570_1_2winding_transformer'	0.05790909090909091
	1.04544	1.0	'xf_3504_to_3505_2_2winding_transformer'	0.017454545454545455
	1.04544	1.0	'xf_3504_to_3505_3_2winding_transformer'	0.01681818181818182
	1.04544	1.0	'xf_3504_to_3505_4_2winding_transformer'	0.017272727272727273
	0.98655	1.0	'xf_3504_to_3572_1_2winding_transformer'	0.05436363636363637
	0.98655	1.0	'xf_3504_to_3572_5_2winding_transformer'	0.05918181818181818
	1.0	1.0000000000000002	'xf_3509_to_3427_5_2winding_transformer'	0.008787878787878787
	0.9625	1.0	'xf_3516_to_3584_2_2winding_transformer'	0.03537878787878788
	0.9869399999999999	1.0	'xf_3518_to_3591_1_2winding_transformer'	0.05075757575757576
	1.025	1.0	'xf_3519_to_3520_2_2winding_transformer'	0.018818181818181817
	1.025	1.0	'xf_3519_to_3522_1_2winding_transformer'	0.019909090909090908
	1.01345	1.0	'xf_3519_to_3595_3_2winding_transformer'	0.05672727272727273
	0.9731100000000001	1.0	'xf_3523_to_3596_2_2winding_transformer'	0.0456060606060606
	0.9731100000000001	1.0	'xf_3523_to_3597_1_2winding_transformer'	0.05068181818181818
	1.0125	1.0	'xf_3530_to_3604_2_2winding_transformer'	0.042121212121212115
	0.9883399999999998	1.0	'xf_3532_to_3606_1_2winding_transformer'	0.04643939393939394
	0.9883399999999998	1.0	'xf_3532_to_3606_2_2winding_transformer'	0.04818181818181819
	1.0094699999999999	1.0	'xf_3533_to_3608_1_2winding_transformer'	0.050378787878787884
	1.0094699999999999	1.0	'xf_3533_to_3608_2_2winding_transformer'	0.05098484848484849
	0.9873	1.0	'xf_3534_to_3610_1_2winding_transformer'	0.041545454545454545
	0.9873	1.0	'xf_3534_to_3610_2_2winding_transformer'	0.03990909090909091
	0.9883399999999998	1.0	'xf_3535_to_3612_2_2winding_transformer'	0.04931818181818182
	0.9883399999999998	1.0	'xf_3535_to_3613_1_2winding_transformer'	0.050151515151515155
	1.05682	1.0	'xf_3536_to_3126_2_2winding_transformer'	0.01659090909090909
	0.9905300000000001	1.0	'xf_3536_to_3127_1_2winding_transformer'	0.019090909090909092
	1.0636363636363633	1.0476190476190477	'xf_3550_to_3418_2_2winding_transformer'	0.022763636363636364
	1.077272727272727	1.0476190476190477	'xf_3553_to_3417_1_2winding_transformer'	0.023345454545454544
	1.059318181818182	1.0454545454545454	'xf_3568_to_3501_2_2winding_transformer'	0.010690909090909091
	1.059318181818182	1.0454545454545454	'xf_3568_to_3501_3_2winding_transformer'	0.010981818181818181
	1.0375	1.0	'xf_3573_to_3507_1_2winding_transformer_merged_with_line_3039_to_3507_1_cp'	0.015636363636363636
	1.0499999999999994	1.077272727272727	'xf_3576_to_3424_2_2winding_transformer_merged_with_line_3568_to_3576_4_cp'	0.3825
	1.0413636363636365	1.0	'xf_3579_to_3428_1_2winding_transformer'	0.020872727272727272
	1.0499999999999994	1.0500000000000003	'xf_3580_to_3430_1_2winding_transformer_merged_with_line_3573_to_3580_1_cp'	0.3845
	1.0499999999999994	1.0500000000000003	'xf_3581_to_3431_2_2winding_transformer_merged_with_line_3573_to_3581_2_cp'	0.387
	1.0136	1.0	'xf_3582_to_3633_1_2winding_transformer'	0.022581818181818182
	1.0136	1.0	'xf_3583_to_3633_2_2winding_transformer'	0.0236
	1.0363636363636362	1.0	'xf_3599_to_3443_2_2winding_transformer'	0.042509090909090906
	1.0	1.0363636363636362	'xf_3600_to_3442_1_2winding_transformer_merged_with_line_3573_to_3600_1_cp'	0.5641025641025641
	1.0436363636363637	1.0	'xf_3601_to_3445_1_2winding_transformer'	0.03570909090909091
	1.0	0.9737600000000004	'xf_3602_to_3295_1_2winding_transformer_merged_with_line_3602_to_3607_1_cp'	0.509047619047619
	1.0727272727272728	1.0	'xf_3603_to_3444_1_2winding_transformer'	0.03632727272727273
	1.0388500000000003	1.0	'xf_3609_to_3434_1_2winding_transformer'	0.012472727272727272
	1.0388500000000003	1.0	'xf_3609_to_3435_2_2winding_transformer'	0.011490909090909092
	1.0388500000000003	1.0	'xf_3609_to_3436_3_2winding_transformer'	0.011454545454545453
	1.0906500000000001	1.05	'xf_3609_to_3437_4_2winding_transformer'	0.0252
	1.0	1.0	'xf_3609_to_3648_2_2winding_transformer'	0.10909090909090909
	1.0	1.0	'xf_3614_to_3536_3_2winding_transformer'	0.022763636363636364
	1.0	1.0	'xf_3614_to_3536_4_2winding_transformer'	0.023818181818181818
	1.0	1.0	'xf_3615_to_3537_2_2winding_transformer'	0.023454545454545454
	1.0	1.0	'xf_3617_to_3618_1_2winding_transformer'	0.023163636363636365
	1.0	1.0	'xf_3617_to_3618_2_2winding_transformer'	0.023927272727272728
	1.0	1.0	'xf_3619_to_3539_1_2winding_transformer_merged_with_line_3617_to_3619_2_cp'	0.03575757575757576
	1.04735	1.0	'xf_3621_to_3541_2_2winding_transformer'	0.009454545454545455
	1.04735	1.0	'xf_3622_to_3541_1_2winding_transformer'	0.00930909090909091
	1.0	1.0	'xf_3623_to_3647_1_2winding_transformer'	0.014181818181818183
	1.0	1.0	'xf_3623_to_3647_2_2winding_transformer'	0.018545454545454546
	1.0	1.0	'xf_3623_to_3647_3_2winding_transformer'	0.019363636363636364
	1.015	1.0	'xf_3625_to_3007_1_2winding_transformer'	0.011363636363636364
	1.015	1.0	'xf_3625_to_3007_2_2winding_transformer'	0.011545454545454546
	0.835	1.0	'xf_3626_to_3071_1_2winding_transformer'	0.022196969696969698
	1.09	1.0	'xf_3626_to_3071_2_2winding_transformer'	0.023333333333333334
	1.0250000000000001	1.0	'xf_3629_to_3082_3_2winding_transformer'	0.0024242424242424242
	1.0	1.0	'xf_3630_to_3331_2_2winding_transformer_merged_with_line_3523_to_3630_1_cp'	0.04
	1.0	1.0	'xf_3631_to_3087_2_2winding_transformer_merged_with_line_3523_to_3631_2_cp'	0.045909090909090906
	1.0	1.0	'xf_3632_to_3087_3_2winding_transformer'	0.007575757575757576
	1.0375	1.0	'xf_3633_to_3512_5_2winding_transformer'	0.018454545454545453
	0.9375	0.9727	'xf_3633_to_3515_3_2winding_transformer'	0.0047272727272727275
	1.0375	1.0	'xf_3633_to_3641_7_2winding_transformer'	0.018454545454545453
	0.98655	1.0	'xf_3636_to_3543_1_2winding_transformer'	0.05472727272727272
	0.98655	1.0	'xf_3636_to_3543_4_2winding_transformer'	0.05645454545454545
	0.98655	1.0	'xf_3636_to_3543_5_2winding_transformer'	0.05490909090909091
	1.0	1.0000000000000002	'xf_3637_to_3416_2_2winding_transformer'	0.008181818181818182
	1.0	1.0476190476190477	'xf_3637_to_3420_4_2winding_transformer'	0.04916666666666667
	0.9874999999999999	1.0	'xf_3638_to_3038_1_2winding_transformer'	0.005606060606060606
	0.9874999999999999	1.0	'xf_3639_to_3038_3_2winding_transformer'	0.005909090909090909
	1.077272727272727	1.0499999999999994	'xf_3640_to_3585_1_2winding_transformer'	0.029345454545454546
	1.077272727272727	1.0499999999999994	'xf_3640_to_3586_2_2winding_transformer'	0.02687272727272727
	1.077272727272727	1.0499999999999994	'xf_3640_to_3587_3_2winding_transformer'	0.027745454545454545
	1.077272727272727	1.0499999999999994	'xf_3640_to_3588_4_2winding_transformer'	0.028036363636363637
	1.0125	1.0	'xf_3643_to_3215_1_2winding_transformer'	0.003863636363636364
	1.0125	1.0	'xf_3643_to_3215_2_2winding_transformer'	0.00393939393939394
	0.9749999999999999	1.0	'xf_3646_to_3122_1_2winding_transformer'	0.020075757575757577
	0.9749999999999999	1.0	'xf_3646_to_3122_2_2winding_transformer'	0.019545454545454546
	0.9888999999999999	1.0	'xf_3651_to_3650_1_2winding_transformer'	0.01924242424242424
	1.0454545454545454	0.9894736842105267	'xf_3653_to_3655_1_2winding_transformer'	0.046696969696969695
	1.0	1.0	'xf_4003_to_4348_1_2winding_transformer'	2.014492753623189
	1.0	1.0	'xf_4004_to_4347_2_2winding_transformer'	12.749999999999998
	1.0	1.0	'xf_4007_to_4350_3_2winding_transformer'	5.56
	1.0	1.0	'xf_4008_to_4350_2_2winding_transformer'	5.5
	1.0	1.0	'xf_4022_to_4367_6_2winding_transformer'	7.246376811594205
	1.0	1.0	'xf_4023_to_4368_5_2winding_transformer'	7.463768115942031
	1.0	1.0	'xf_4024_to_4369_7_2winding_transformer'	7.333333333333335
	1.0499999999999998	1.0	'xf_4026_to_4370_2_2winding_transformer'	4.652173913043479
	1.05	1.0000000000000002	'xf_4038_to_4037_1_2winding_transformer'	0.05136363636363637
	1.0499999999999998	1.0	'xf_4047_to_4048_2_2winding_transformer'	7.2028985507246395
	1.0499999999999998	1.0	'xf_4049_to_4372_2_2winding_transformer'	7.043478260869567
	1.0499999999999998	1.0	'xf_4050_to_4373_1_2winding_transformer'	9.637681159420293
	1.0144927536231885	1.0	'xf_4051_to_4376_1_2winding_transformer'	7.101449275362321
	1.0144927536231885	1.0	'xf_4078_to_4074_2_2winding_transformer'	1.4347826086956526
	1.0144927536231885	1.0	'xf_4079_to_4074_4_2winding_transformer'	1.0434782608695654
	0.975	1.0	'xf_4080_to_4103_3_2winding_transformer'	4.666666666666668
	1.0	1.0	'xf_4081_to_4103_4_2winding_transformer'	2.37
	1.0	1.0	'xf_4082_to_4102_5_2winding_transformer'	3.57
	1.0	1.0	'xf_4083_to_4102_6_2winding_transformer'	1.53
	1.0499999999999998	1.0	'xf_4084_to_4085_2_2winding_transformer'	7.753623188405799
	1.025	1.0	'xf_4091_to_4410_6_2winding_transformer'	0.0053030303030303025
	1.025	1.0	'xf_4091_to_4411_3_2winding_transformer'	0.005606060606060606
	1.025	1.0	'xf_4091_to_4412_4_2winding_transformer'	0.005454545454545454
	1.025	1.0	'xf_4091_to_4413_5_2winding_transformer'	0.005606060606060606
	1.025	1.0	'xf_4091_to_4414_1_2winding_transformer'	0.005151515151515152
	1.025	1.0	'xf_4091_to_4415_2_2winding_transformer'	0.0053030303030303025
	1.0405000000000004	1.0	'xf_4104_to_4048_1_2winding_transformer'	0.010072727272727273
	1.0250000000000001	1.0	'xf_4109_to_4372_1_2winding_transformer'	0.00981818181818182
	1.0599999999999998	1.0	'xf_4112_to_4058_1_2winding_transformer'	0.009345454545454546
	1.0599999999999998	1.0	'xf_4112_to_4059_2_2winding_transformer'	0.008836363636363637
	1.0599999999999998	1.0	'xf_4112_to_4061_4_2winding_transformer'	0.010036363636363635
	1.0130000000000001	1.0	'xf_4113_to_4169_1_2winding_transformer'	0.010472727272727272
	1.0130000000000001	1.0	'xf_4113_to_4169_2_2winding_transformer'	0.010509090909090909
	1.0130000000000001	1.0	'xf_4113_to_4169_3_2winding_transformer'	0.011054545454545454
	1.0170000000000001	1.0	'xf_4114_to_4363_1_2winding_transformer'	0.012945454545454546
	1.0170000000000001	1.0	'xf_4114_to_4363_2_2winding_transformer'	0.012727272727272728
	1.0375	1.0	'xf_4119_to_4367_4_2winding_transformer'	0.012909090909090908
	1.0375	1.0	'xf_4120_to_4368_2_2winding_transformer'	0.012581818181818182
	1.0375	1.0	'xf_4121_to_4369_1_2winding_transformer'	0.013527272727272728
	1.0	0.9625000000000001	'xf_4122_to_4025_3_2winding_transformer_merged_with_line_4118_to_4122_4_pi'	0.10696969696969696
	1.0	1.0	'xf_4125_to_4238_1_2winding_transformer'	0.011636363636363637
	1.0	1.0	'xf_4125_to_4238_2_2winding_transformer'	0.008727272727272728
	1.0	1.0	'xf_4126_to_4127_1_2winding_transformer'	0.01
	1.0	1.0	'xf_4126_to_4127_2_2winding_transformer'	0.009772727272727273
	1.0500000000000003	1.0	'xf_4128_to_4052_1_2winding_transformer'	0.018581818181818182
	1.0500000000000003	1.0	'xf_4128_to_4053_2_2winding_transformer'	0.02010909090909091
	1.0500000000000003	1.0	'xf_4128_to_4054_3_2winding_transformer'	0.017672727272727274
	1.0450000000000002	1.0	'xf_4129_to_4062_1_2winding_transformer'	0.013236363636363636
	1.0450000000000002	1.0	'xf_4129_to_4064_3_2winding_transformer'	0.012472727272727272
	1.0450000000000002	1.0	'xf_4129_to_4065_4_2winding_transformer'	0.0132
	1.0	1.0	'xf_4133_to_4292_5_2winding_transformer'	0.011236363636363636
	1.0125	1.0	'xf_4134_to_4266_1_2winding_transformer'	0.011527272727272726
	1.0125	1.0	'xf_4134_to_4266_2_2winding_transformer'	0.010981818181818181
	1.0125	1.0	'xf_4134_to_4266_3_2winding_transformer'	0.011054545454545454
	1.0250000000000001	1.0	'xf_4135_to_4276_2_2winding_transformer'	0.011490909090909092
	1.0250000000000001	1.0	'xf_4135_to_4276_3_2winding_transformer'	0.011054545454545454
	1.0250000000000001	1.0	'xf_4135_to_4277_1_2winding_transformer'	0.012218181818181817
	0.9875000000000003	1.0	'xf_4136_to_4294_6_2winding_transformer'	0.010727272727272728
	1.0250000000000001	1.0	'xf_4137_to_4300_1_2winding_transformer'	0.008690909090909091
	1.0250000000000001	1.0	'xf_4137_to_4300_2_2winding_transformer'	0.009345454545454546
	1.0250000000000001	1.0	'xf_4137_to_4300_3_2winding_transformer'	0.008836363636363637
	1.0250000000000001	1.0	'xf_4142_to_4319_1_2winding_transformer'	0.0112
	1.0250000000000001	1.0	'xf_4142_to_4319_2_2winding_transformer'	0.011127272727272727
	1.0	1.0	'xf_4143_to_4382_1_2winding_transformer'	0.011854545454545454
	1.0	1.0	'xf_4144_to_4384_1_2winding_transformer'	0.012509090909090909
	1.0375	1.0	'xf_4145_to_4329_1_2winding_transformer'	0.011163636363636363
	0.9875000000000003	1.0	'xf_4147_to_4334_1_2winding_transformer'	0.015927272727272727
	1.0	1.0	'xf_4148_to_4335_1_2winding_transformer'	0.009054545454545456
	1.0	1.0	'xf_4148_to_4335_2_2winding_transformer'	0.008654545454545455
	1.0375	1.0	'xf_4150_to_4214_1_2winding_transformer_merged_with_line_4189_to_4214_1_cp'	0.009163636363636363
	1.0500000000000003	1.0	'xf_4154_to_4085_1_2winding_transformer'	0.006109090909090909
	0.9824999999999999	1.0	'xf_4157_to_4345_1_2winding_transformer'	0.007803030303030303
	1.0	1.0	'xf_4159_to_4346_1_2winding_transformer'	0.0048484848484848485
	1.0175	1.0	'xf_4162_to_4348_1_2winding_transformer'	0.011742424242424243
	0.9749999999999999	1.0	'xf_4163_to_4107_1_2winding_transformer'	0.03393939393939394
	0.9749999999999999	1.0	'xf_4163_to_4107_4_2winding_transformer'	0.033484848484848485
	1.0	1.0	'xf_4163_to_4349_2_2winding_transformer'	0.009015151515151514
	1.0	1.0	'xf_4163_to_4349_3_2winding_transformer'	0.009318181818181817
	1.0	1.0	'xf_4165_to_4111_1_2winding_transformer'	0.03318181818181818
	1.0	1.0	'xf_4165_to_4111_2_2winding_transformer'	0.03159090909090909
	1.011931818181818	1.0	'xf_4166_to_4005_1_2winding_transformer'	0.010227272727272727
	1.0	1.0	'xf_4166_to_4356_5_2winding_transformer'	0.00446969696969697
	0.9870000000000001	1.0	'xf_4169_to_4402_6_2winding_transformer'	0.0071969696969696965
	0.9870000000000001	1.0	'xf_4169_to_4403_4_2winding_transformer'	0.0067424242424242425
	1.0	1.0	'xf_4169_to_4404_5_2winding_transformer'	0.0071969696969696965
	1.0	1.0	'xf_4170_to_4361_1_2winding_transformer'	0.017575757575757574
	0.96843	1.0	'xf_4171_to_4115_1_2winding_transformer'	0.03318181818181818
	0.9824999999999999	1.0	'xf_4171_to_4364_2_2winding_transformer'	0.00840909090909091
	0.9824999999999999	1.0	'xf_4171_to_4364_3_2winding_transformer'	0.008106060606060606
	0.9822199999999999	1.0	'xf_4174_to_4116_2_2winding_transformer'	0.03333333333333333
	1.0	1.0	'xf_4174_to_4227_1_2winding_transformer'	0.0023484848484848484
	1.0	1.0	'xf_4174_to_4227_3_2winding_transformer'	0.0022727272727272726
	0.9824999999999999	1.0	'xf_4180_to_4228_1_2winding_transformer'	0.007045454545454546
	0.9824999999999999	1.0	'xf_4180_to_4228_2_2winding_transformer'	0.0075
	0.9824999999999999	1.0	'xf_4180_to_4228_3_2winding_transformer'	0.007954545454545455
	0.974	1.0	'xf_4181_to_4405_2_2winding_transformer'	0.0071969696969696965
	0.974	1.0	'xf_4181_to_4406_4_2winding_transformer'	0.00696969696969697
	0.974	1.0	'xf_4181_to_4407_1_2winding_transformer'	0.007121212121212121
	0.974	1.0	'xf_4181_to_4408_3_2winding_transformer'	0.006666666666666667
	0.9219999999999999	1.0	'xf_4181_to_4493_5_2winding_transformer'	0.006818181818181819
	0.9749999999999999	1.0	'xf_4184_to_4117_1_2winding_transformer'	0.033106060606060604
	0.9749999999999999	1.0	'xf_4184_to_4117_2_2winding_transformer'	0.02962121212121212
	1.0175	1.0	'xf_4185_to_4229_1_2winding_transformer'	0.015681818181818182
	1.075	1.0	'xf_4188_to_4370_1_2winding_transformer'	0.22727272727272727
	1.0	1.0	'xf_4189_to_4371_1_2winding_transformer'	0.009318181818181817
	1.0	1.0	'xf_4189_to_4371_2_2winding_transformer'	0.009393939393939394
	1.0	1.0	'xf_4189_to_4371_3_2winding_transformer'	0.00962121212121212
	0.9824999999999999	1.0	'xf_4190_to_4500_1_2winding_transformer'	0.004545454545454545
	0.9824999999999999	1.0	'xf_4190_to_4500_2_2winding_transformer'	0.00446969696969697
	1.0	1.0	'xf_4194_to_4124_1_2winding_transformer'	0.032803030303030306
	1.035	1.0	'xf_4195_to_4373_1_2winding_transformer'	0.013257575757575758
	1.0	1.0	'xf_4196_to_4242_1_2winding_transformer'	0.00446969696969697
	1.0	1.0	'xf_4196_to_4242_2_2winding_transformer'	0.004318181818181818
	1.0	1.0	'xf_4197_to_4374_1_2winding_transformer'	0.005
	1.0	1.0	'xf_4197_to_4374_2_2winding_transformer'	0.005
	1.0	1.0	'xf_4198_to_4375_1_2winding_transformer'	0.004924242424242425
	1.0	1.0	'xf_4198_to_4375_2_2winding_transformer'	0.004924242424242425
	1.0	0.96664	'xf_4199_to_4423_2A_2winding_transformer_merged_with_line_4198_to_4199_1_cp'	3.45
	1.0	1.0	'xf_4200_to_4383_1_2winding_transformer'	0.00909090909090909
	1.0	1.0	'xf_4200_to_4383_2_2winding_transformer'	0.00962121212121212
	0.9749999999999999	1.0	'xf_4201_to_4146_1_2winding_transformer'	0.03424242424242424
	1.0175	1.0	'xf_4202_to_4329_1_2winding_transformer'	0.010909090909090908
	1.0175	1.0	'xf_4202_to_4329_2_2winding_transformer'	0.011893939393939394
	1.0	1.0	'xf_4206_to_4336_1_2winding_transformer'	0.0048484848484848485
	1.0	1.0	'xf_4206_to_4336_2_2winding_transformer'	0.0046212121212121215
	1.0	1.0	'xf_4210_to_4385_1_2winding_transformer'	0.009166666666666667
	1.0	1.0	'xf_4210_to_4386_2_2winding_transformer'	0.009393939393939394
	0.9799999999999999	1.0	'xf_4213_to_4149_3_2winding_transformer'	0.03295454545454545
	1.0	1.0	'xf_4213_to_4387_2_2winding_transformer'	0.004924242424242425
	1.0	1.0	'xf_4213_to_4388_1_2winding_transformer'	0.005075757575757576
	1.035	1.0	'xf_4215_to_4389_1_2winding_transformer'	0.004924242424242425
	0.96516	1.0	'xf_4215_to_4390_2_2winding_transformer'	0.0046212121212121215
	1.0250000000000001	1.0	'xf_4216_to_4151_1_2winding_transformer'	0.03015151515151515
	1.0250000000000001	1.0	'xf_4216_to_4151_2_2winding_transformer'	0.030833333333333334
	1.0	1.0	'xf_4217_to_4391_1_2winding_transformer'	0.004393939393939394
	1.0	1.0	'xf_4217_to_4391_2_2winding_transformer'	0.004924242424242425
	1.0	1.0	'xf_4218_to_4392_2_2winding_transformer'	0.005075757575757576
	0.98258	1.0	'xf_4219_to_4393_1_2winding_transformer'	0.007803030303030303
	0.98258	1.0	'xf_4219_to_4393_2_2winding_transformer'	0.01
	1.01742	1.0	'xf_4220_to_4074_6_2winding_transformer'	0.004772727272727273
	1.0250000000000001	1.0000000000000002	'xf_4220_to_4075_7_2winding_transformer'	0.00856060606060606
	1.0625	0.9565217391304348	'xf_4220_to_4076_8_2winding_transformer'	0.00984848484848485
	1.125	1.0000000000000002	'xf_4220_to_4077_9_2winding_transformer'	0.008484848484848486
	1.0175	1.0	'xf_4221_to_4102_1_2winding_transformer'	0.017575757575757574
	1.0175	1.0	'xf_4221_to_4103_2_2winding_transformer'	0.019166666666666665
	1.02544	1.0	'xf_4222_to_4398_1_2winding_transformer'	0.013863636363636364
	1.02544	1.0	'xf_4222_to_4398_2_2winding_transformer'	0.012803030303030302
	1.0378787878787878	1.0	'xf_4224_to_4072_1_2winding_transformer'	0.012121212121212121
	1.0378787878787878	1.0	'xf_4224_to_4073_2_2winding_transformer'	0.012727272727272726
	1.035	1.0	'xf_4224_to_4340_1_2winding_transformer'	0.0048484848484848485
	1.035	1.0	'xf_4224_to_4340_2_2winding_transformer'	0.0046212121212121215
	1.0	1.0	'xf_4226_to_4112_5_2winding_transformer'	0.03787878787878788
	1.0	1.0	'xf_4226_to_4112_6_2winding_transformer'	0.036515151515151514
	1.0	1.0	'xf_4231_to_4449_1_2winding_transformer'	0.005
	1.0	1.0	'xf_4232_to_4409_1_2winding_transformer'	0.005454545454545454
	1.0	1.0	'xf_4232_to_4409_2_2winding_transformer'	0.0053030303030303025
	0.9874999999999999	1.0	'xf_4233_to_4124_2_2winding_transformer'	0.037121212121212124
	0.9874999999999999	1.0	'xf_4233_to_4124_3_2winding_transformer'	0.035454545454545454
	1.025	1.0	'xf_4234_to_4416_1_2winding_transformer'	0.004545454545454545
	1.025	1.0	'xf_4234_to_4416_2_2winding_transformer'	0.004393939393939394
	1.0124999999999997	1.0	'xf_4235_to_4417_1_2winding_transformer'	0.005151515151515152
	1.0124999999999997	1.0	'xf_4235_to_4417_2_2winding_transformer'	0.0053030303030303025
	1.0	1.0	'xf_4236_to_4418_1_2winding_transformer'	0.004696969696969697
	1.0	1.0	'xf_4236_to_4418_2_2winding_transformer'	0.005
	1.0124999999999997	1.0	'xf_4236_to_4418_3_2winding_transformer'	0.0048484848484848485
	1.0124999999999997	1.0	'xf_4236_to_4418_4_2winding_transformer'	0.005
	1.025	1.0	'xf_4237_to_4419_1_2winding_transformer'	0.005151515151515152
	1.025	1.0	'xf_4237_to_4419_2_2winding_transformer'	0.005151515151515152
	1.025	1.0	'xf_4239_to_4421_1_2winding_transformer'	0.0048484848484848485
	0.8625000000000002	1.0	'xf_4239_to_4421_2_2winding_transformer'	0.0048484848484848485
	1.0124999999999997	1.0	'xf_4240_to_4422_1_2winding_transformer'	0.005
	1.0124999999999997	1.0	'xf_4240_to_4422_2_2winding_transformer'	0.0048484848484848485
	1.0124999999999997	1.0	'xf_4240_to_4422_3_2winding_transformer'	0.005757575757575757
	1.0124999999999997	1.0	'xf_4241_to_4420_1_2winding_transformer'	0.004696969696969697
	1.0124999999999997	1.0	'xf_4241_to_4420_2_2winding_transformer'	0.005151515151515152
	1.0124999999999997	1.0031746031746032	'xf_4243_to_4066_1_2winding_transformer'	0.03878787878787879
	1.0124999999999997	1.0000000000000002	'xf_4243_to_4067_2_2winding_transformer'	0.02287878787878788
	1.025	1.0	'xf_4243_to_4482_1_2winding_transformer'	0.005
	1.0	1.0	'xf_4244_to_4424_1_2winding_transformer'	0.005
	1.0	1.0	'xf_4244_to_4424_2_2winding_transformer'	0.0053030303030303025
	0.9874999999999999	1.0	'xf_4245_to_4425_1_2winding_transformer'	0.005454545454545454
	0.9874999999999999	1.0	'xf_4245_to_4425_2_2winding_transformer'	0.005
	1.0124999999999997	1.0	'xf_4246_to_4426_1_2winding_transformer'	0.005151515151515152
	1.0124999999999997	1.0	'xf_4246_to_4426_2_2winding_transformer'	0.003787878787878788
	1.0124999999999997	1.0	'xf_4247_to_4427_1_2winding_transformer'	0.004545454545454545
	1.0124999999999997	1.0	'xf_4247_to_4427_2_2winding_transformer'	0.004696969696969697
	1.05	1.0	'xf_4249_to_4428_1_2winding_transformer'	0.00393939393939394
	1.05	1.0	'xf_4249_to_4428_2_2winding_transformer'	0.004090909090909091
	0.9874999999999999	1.0	'xf_4252_to_4429_1_2winding_transformer'	0.005151515151515152
	0.9874999999999999	1.0	'xf_4252_to_4429_2_2winding_transformer'	0.005
	0.9874999999999999	1.0	'xf_4253_to_4430_1_2winding_transformer'	0.0053030303030303025
	0.9874999999999999	1.0	'xf_4253_to_4430_2_2winding_transformer'	0.004545454545454545
	1.025	1.0	'xf_4254_to_4378_2_2winding_transformer'	0.0048484848484848485
	0.9874999999999999	1.0	'xf_4255_to_4433_1_2winding_transformer'	0.005
	0.9874999999999999	1.0	'xf_4255_to_4433_2_2winding_transformer'	0.005
	0.9749999999999996	1.0	'xf_4258_to_4435_1_2winding_transformer'	0.0048484848484848485
	0.9749999999999996	1.0	'xf_4258_to_4435_2_2winding_transformer'	0.0053030303030303025
	1.0	1.0	'xf_4259_to_4436_1_2winding_transformer'	0.005454545454545454
	1.0	1.0	'xf_4259_to_4436_2_2winding_transformer'	0.003787878787878788
	0.9749999999999996	1.0	'xf_4260_to_4437_1_2winding_transformer'	0.0048484848484848485
	0.9749999999999996	1.0	'xf_4260_to_4437_2_2winding_transformer'	0.0053030303030303025
	1.0375	1.0	'xf_4262_to_4055_1_2winding_transformer'	0.018787878787878787
	1.0	1.0375	'xf_4263_to_4056_2_2winding_transformer_merged_with_line_4263_to_4326_1_cp'	0.11272727272727273
	1.0	1.0	'xf_4264_to_4440_1_2winding_transformer'	0.005151515151515152
	1.0	1.0	'xf_4264_to_4440_2_2winding_transformer'	0.005151515151515152
	0.9874999999999999	1.0	'xf_4265_to_4441_1_2winding_transformer'	0.005151515151515152
	0.9874999999999999	1.0	'xf_4265_to_4441_2_2winding_transformer'	0.005
	0.9874999999999999	1.0	'xf_4268_to_4442_1_2winding_transformer'	0.005
	0.9874999999999999	1.0	'xf_4268_to_4442_2_2winding_transformer'	0.005151515151515152
	1.0124999999999997	1.0	'xf_4270_to_4444_1_2winding_transformer'	0.005606060606060606
	1.0124999999999997	1.0	'xf_4270_to_4444_2_2winding_transformer'	0.004696969696969697
	1.0124999999999997	1.0	'xf_4271_to_4445_1_2winding_transformer'	0.0053030303030303025
	1.0124999999999997	1.0	'xf_4271_to_4445_2_2winding_transformer'	0.005151515151515152
	0.9749999999999996	1.0	'xf_4272_to_4446_1_2winding_transformer'	0.004545454545454545
	0.9749999999999996	1.0	'xf_4272_to_4446_2_2winding_transformer'	0.004393939393939394
	0.9874999999999999	1.0	'xf_4273_to_4447_1_2winding_transformer'	0.005151515151515152
	0.9874999999999999	1.0	'xf_4273_to_4447_2_2winding_transformer'	0.005454545454545454
	1.025	1.0	'xf_4274_to_4448_1_2winding_transformer'	0.0048484848484848485
	1.025	1.0	'xf_4274_to_4448_2_2winding_transformer'	0.005151515151515152
	1.025	1.0	'xf_4274_to_4448_3_2winding_transformer'	0.005454545454545454
	0.9749999999999996	1.0	'xf_4275_to_4450_1_2winding_transformer'	0.004696969696969697
	0.9749999999999996	1.0	'xf_4275_to_4450_2_2winding_transformer'	0.005151515151515152
	0.9874999999999999	1.0	'xf_4279_to_4451_1_2winding_transformer'	0.0048484848484848485
	1.0124999999999997	1.0	'xf_4279_to_4451_2_2winding_transformer'	0.005
	1.0124999999999997	1.0	'xf_4279_to_4451_3_2winding_transformer'	0.0048484848484848485
	1.0	1.0	'xf_4280_to_4452_1_2winding_transformer'	0.005606060606060606
	1.0	1.0	'xf_4280_to_4452_2_2winding_transformer'	0.0053030303030303025
	1.0	0.9874999999999999	'xf_4282_to_4453_1_2winding_transformer_merged_with_line_4276_to_4282_1_cp'	0.02727272727272727
	1.0	1.0	'xf_4284_to_4454_2_2winding_transformer'	0.0053030303030303025
	1.0	1.0	'xf_4287_to_4455_1_2winding_transformer'	0.005
	1.0	1.0	'xf_4287_to_4455_2_2winding_transformer'	0.0048484848484848485
	1.0	1.0	'xf_4289_to_4456_1_2winding_transformer'	0.005757575757575757
	1.0	1.0	'xf_4289_to_4456_2_2winding_transformer'	0.005454545454545454
	0.9374999999999999	1.0	'xf_4292_to_4438_1_2winding_transformer'	0.0053030303030303025
	0.9374999999999999	1.0	'xf_4292_to_4438_2_2winding_transformer'	0.005
	1.025	1.0	'xf_4292_to_4438_3_2winding_transformer'	0.005454545454545454
	0.9749999999999996	1.0	'xf_4292_to_4438_6_2winding_transformer'	0.0048484848484848485
	1.0	1.0	'xf_4292_to_4439_4_2winding_transformer'	0.0030303030303030303
	1.0	1.0	'xf_4294_to_4380_1_2winding_transformer'	0.018333333333333333
	1.0124999999999997	1.0	'xf_4294_to_4380_2_2winding_transformer'	0.01803030303030303
	0.8375000000000001	1.0	'xf_4294_to_4457_3_2winding_transformer'	0.004696969696969697
	0.8375000000000001	1.0	'xf_4294_to_4457_4_2winding_transformer'	0.004696969696969697
	0.8375000000000001	1.0	'xf_4294_to_4457_5_2winding_transformer'	0.004696969696969697
	0.9874999999999999	1.0	'xf_4295_to_4458_1_2winding_transformer'	0.004242424242424243
	0.9874999999999999	1.0	'xf_4295_to_4458_2_2winding_transformer'	0.004393939393939394
	1.0124999999999997	1.0	'xf_4296_to_4381_1_2winding_transformer'	0.018333333333333333
	0.9874999999999999	1.0	'xf_4296_to_4459_2_2winding_transformer'	0.005
	0.9874999999999999	1.0	'xf_4296_to_4459_3_2winding_transformer'	0.004545454545454545
	0.9874999999999999	1.0	'xf_4296_to_4459_4_2winding_transformer'	0.004696969696969697
	1.0124999999999997	1.0	'xf_4297_to_4460_1_2winding_transformer'	0.004545454545454545
	1.0124999999999997	1.0	'xf_4297_to_4460_2_2winding_transformer'	0.004545454545454545
	1.0124999999999997	1.0	'xf_4297_to_4460_3_2winding_transformer'	0.004696969696969697
	1.0124999999999997	1.0	'xf_4299_to_4461_1_2winding_transformer'	0.006060606060606061
	1.0124999999999997	1.0	'xf_4299_to_4461_2_2winding_transformer'	0.0065151515151515155
	1.0	1.0	'xf_4301_to_4463_1_2winding_transformer'	0.005606060606060606
	1.0	1.0	'xf_4301_to_4463_2_2winding_transformer'	0.005454545454545454
	0.9874999999999999	1.0	'xf_4303_to_4464_1_2winding_transformer'	0.004696969696969697
	0.9874999999999999	1.0	'xf_4303_to_4464_2_2winding_transformer'	0.0048484848484848485
	1.0	1.0	'xf_4305_to_4465_1_2winding_transformer'	0.004545454545454545
	1.0	1.0	'xf_4305_to_4465_2_2winding_transformer'	0.004545454545454545
	1.0124999999999997	1.0	'xf_4307_to_4466_1_2winding_transformer'	0.0048484848484848485
	1.0124999999999997	1.0	'xf_4307_to_4466_2_2winding_transformer'	0.005151515151515152
	1.0	1.0	'xf_4309_to_4467_1_2winding_transformer'	0.004393939393939394
	1.0	1.0	'xf_4309_to_4467_2_2winding_transformer'	0.004696969696969697
	1.0	1.0	'xf_4310_to_4468_1_2winding_transformer_merged_with_line_4310_to_4316_1_cp'	0.028181818181818183
	1.0	1.0	'xf_4311_to_4469_1_2winding_transformer'	0.0048484848484848485
	1.0	1.0	'xf_4311_to_4469_2_2winding_transformer'	0.004393939393939394
	1.025	1.0	'xf_4312_to_4470_1_2winding_transformer'	0.0048484848484848485
	1.025	1.0	'xf_4312_to_4470_2_2winding_transformer'	0.0048484848484848485
	1.0	1.0	'xf_4313_to_4471_1_2winding_transformer'	0.0053030303030303025
	1.0	1.0	'xf_4313_to_4471_2_2winding_transformer'	0.004696969696969697
	1.0	1.0	'xf_4314_to_4472_1_2winding_transformer'	0.004393939393939394
	1.0	1.0	'xf_4314_to_4472_2_2winding_transformer'	0.004696969696969697
	0.9749999999999996	1.0	'xf_4316_to_4473_1_2winding_transformer'	0.005
	0.9749999999999996	1.0	'xf_4316_to_4473_2_2winding_transformer'	0.005151515151515152
	1.0124999999999997	1.0	'xf_4317_to_4474_1_2winding_transformer'	0.0053030303030303025
	1.0124999999999997	1.0	'xf_4317_to_4474_2_2winding_transformer'	0.0048484848484848485
	1.0124999999999997	1.0	'xf_4318_to_4475_1_2winding_transformer'	0.004696969696969697
	1.0124999999999997	1.0	'xf_4318_to_4475_2_2winding_transformer'	0.005
	1.0124999999999997	1.0	'xf_4318_to_4475_3_2winding_transformer'	0.005
	1.025	1.0	'xf_4320_to_4476_1_2winding_transformer'	0.0053030303030303025
	1.025	1.0	'xf_4320_to_4476_2_2winding_transformer'	0.0053030303030303025
	1.025	1.0	'xf_4320_to_4476_3_2winding_transformer'	0.005151515151515152
	0.9874999999999999	1.0	'xf_4321_to_4478_1_2winding_transformer'	0.005
	0.9874999999999999	1.0	'xf_4321_to_4478_2_2winding_transformer'	0.004545454545454545
	1.0	1.0	'xf_4323_to_4477_1_2winding_transformer'	0.0048484848484848485
	1.0	1.0	'xf_4323_to_4477_2_2winding_transformer'	0.004696969696969697
	1.05	1.0	'xf_4324_to_4481_1_2winding_transformer'	0.013333333333333334
	0.9625	1.0	'xf_4324_to_4481_2_2winding_transformer'	0.013181818181818182
	1.0124999999999997	1.0	'xf_4325_to_4480_1_2winding_transformer'	0.003484848484848485
	1.0124999999999997	1.0	'xf_4325_to_4480_2_2winding_transformer'	0.0036363636363636364
	1.0	1.0124999999999997	'xf_4328_to_4057_3_2winding_transformer_merged_with_line_4226_to_4328_1_cp'	0.07133333333333333
	1.0	1.0	'xf_4331_to_4431_1_2winding_transformer'	0.005
	1.025	1.0	'xf_4332_to_4483_1_2winding_transformer'	0.004545454545454545
	1.025	1.0	'xf_4332_to_4483_2_2winding_transformer'	0.004545454545454545
	1.0124999999999997	1.0	'xf_4335_to_4484_3_2winding_transformer'	0.004696969696969697
	1.0124999999999997	1.0	'xf_4335_to_4484_4_2winding_transformer'	0.004393939393939394
	0.9749999999999996	1.0	'xf_4337_to_4485_1_2winding_transformer'	0.0048484848484848485
	0.9749999999999996	1.0	'xf_4337_to_4485_2_2winding_transformer'	0.0048484848484848485
	1.025	1.0	'xf_4338_to_4479_1_2winding_transformer'	0.003787878787878788
	1.0124999999999997	1.0	'xf_4339_to_4486_1_2winding_transformer'	0.005757575757575757
	1.0124999999999997	1.0	'xf_4339_to_4486_2_2winding_transformer'	0.005909090909090909
	1.0124999999999997	1.0	'xf_4341_to_4487_1_2winding_transformer'	0.004090909090909091
	0.9874999999999999	1.0	'xf_4341_to_4487_2_2winding_transformer'	0.004090909090909091
	1.0	1.0	'xf_4342_to_4488_1_2winding_transformer'	0.0048484848484848485
	1.0	1.0	'xf_4343_to_4489_1_2winding_transformer'	0.0048484848484848485
	1.0	1.0	'xf_4343_to_4489_2_2winding_transformer'	0.0048484848484848485
	1.0	1.0	'xf_4343_to_4489_3_2winding_transformer'	0.005
	1.0	1.0	'xf_4344_to_4490_1_2winding_transformer'	0.005454545454545454
	1.0	1.0	'xf_4344_to_4490_2_2winding_transformer'	0.005151515151515152
	1.0	1.0	'xf_4350_to_4009_4_2winding_transformer'	0.1690909090909091
	1.0125	1.0	'xf_4356_to_4006_2_2winding_transformer'	0.02515151515151515
	1.0	1.0144927536231885	'xf_4357_to_4010_7_2winding_transformer'	0.03515151515151515
	1.0	1.0144927536231885	'xf_4357_to_4012_2_2winding_transformer'	0.0603030303030303
	1.0	1.0	'xf_4357_to_4014_6_2winding_transformer'	0.17606060606060606
	1.0	1.0	'xf_4357_to_4015_4_2winding_transformer'	0.17939393939393938
	1.0	1.0144927536231885	'xf_4358_to_4011_9_2winding_transformer'	0.06848484848484848
	1.0	1.0144927536231885	'xf_4358_to_4013_8_2winding_transformer'	0.044848484848484846
	1.0	1.0	'xf_4358_to_4016_5_2winding_transformer'	0.17696969696969697
	1.0	1.0	'xf_4358_to_4017_3_2winding_transformer'	0.17363636363636364
	1.0	1.0	'xf_4363_to_4018_1_2winding_transformer'	0.1006060606060606
	1.0	1.0	'xf_4363_to_4020_1_2winding_transformer'	0.21606060606060606
	1.0	1.0	'xf_4376_to_4423_2B_2winding_transformer'	0.13454545454545455
	1.0	1.0	'xf_4376_to_4423_2C_2winding_transformer'	0.13136363636363638
	1.0	1.0	'xf_4399_to_4344_3_2winding_transformer'	0.024242424242424242
	1.0124999999999997	1.0	'xf_4462_to_4461_3_2winding_transformer'	0.006212121212121211
	1.0	1.0454545454545454	'xf_5037_to_5114_1_2winding_transformer'	0.11125
	1.0144927536231885	1.0	'xf_5043_to_5219_1_2winding_transformer'	4.666666666666668
	0.95	0.99	'xf_5044_to_5045_2_2winding_transformer'	0.12181818181818183
	0.9750000000000001	1.0	'xf_5048_to_5046_3_2winding_transformer'	0.024848484848484845
	0.9750000000000001	1.0	'xf_5048_to_5047_4_2winding_transformer'	0.026060606060606062
	0.9875000000000002	1.0	'xf_5050_to_5179_1_2winding_transformer'	0.005272727272727273
	0.9875000000000002	1.0	'xf_5050_to_5179_2_2winding_transformer'	0.005363636363636363
	1.0115400000000003	1.0	'xf_5052_to_5180_1_2winding_transformer'	0.0057272727272727275
	1.0116	1.0	'xf_5052_to_5180_2_2winding_transformer'	0.005818181818181819
	1.0454	1.0	'xf_5052_to_5181_3_2winding_transformer'	0.003090909090909091
	1.0454	1.0	'xf_5052_to_5181_4_2winding_transformer'	0.003090909090909091
	1.0	1.0	'xf_5054_to_5182_1_2winding_transformer'	0.005
	0.9759999999999999	1.0	'xf_5055_to_5183_1_2winding_transformer'	0.002181818181818182
	1.0	1.0	'xf_5055_to_5184_2_2winding_transformer'	0.0025454545454545456
	1.0773000000000001	1.0	'xf_5058_to_5012_1_2winding_transformer'	0.012727272727272726
	1.0	1.0	'xf_5059_to_5185_1_2winding_transformer'	0.005909090909090909
	1.0	1.0	'xf_5059_to_5185_2_2winding_transformer'	0.006090909090909091
	0.9875000000000002	1.0	'xf_5060_to_5186_1_2winding_transformer'	0.007454545454545454
	0.975	1.0	'xf_5060_to_5186_2_2winding_transformer'	0.007090909090909091
	1.0136200000000002	1.0	'xf_5061_to_5187_2_2winding_transformer'	0.008909090909090908
	1.0136200000000002	1.0	'xf_5061_to_5187_3_2winding_transformer'	0.009272727272727273
	1.0125	1.0	'xf_5062_to_5188_1_2winding_transformer'	0.005090909090909091
	1.0125	1.0	'xf_5062_to_5188_2_2winding_transformer'	0.0047272727272727275
	0.9863600000000001	1.0	'xf_5064_to_5189_1_2winding_transformer'	0.006454545454545454
	0.9863600000000001	1.0	'xf_5064_to_5189_2_2winding_transformer'	0.005272727272727273
	0.975	1.0	'xf_5065_to_5190_1_2winding_transformer'	0.005818181818181819
	0.975	1.0	'xf_5065_to_5190_2_2winding_transformer'	0.005909090909090909
	0.975	1.0	'xf_5065_to_5190_3_2winding_transformer'	0.005454545454545454
	1.0	1.0	'xf_5066_to_5172_1_2winding_transformer'	0.004636363636363636
	0.975	1.0	'xf_5066_to_5172_2_2winding_transformer'	0.00490909090909091
	0.9624999999999999	1.0	'xf_5067_to_5191_1_2winding_transformer'	0.0057272727272727275
	0.9624999999999999	1.0	'xf_5067_to_5191_2_2winding_transformer'	0.005636363636363636
	0.9624999999999999	1.0	'xf_5068_to_5173_1_2winding_transformer'	0.007454545454545454
	0.9624999999999999	1.0	'xf_5068_to_5173_2_2winding_transformer'	0.006909090909090909
	1.02556	1.0	'xf_5070_to_5192_4_2winding_transformer'	0.0047272727272727275
	1.02556	1.0	'xf_5070_to_5192_5_2winding_transformer'	0.005636363636363636
	1.0	1.0	'xf_5074_to_5193_1_2winding_transformer'	0.010727272727272726
	1.0	1.0	'xf_5074_to_5193_2_2winding_transformer'	0.011545454545454546
	1.0495	1.0	'xf_5075_to_5194_1_2winding_transformer'	0.0031818181818181815
	1.0	1.0	'xf_5078_to_5020_1_2winding_transformer_merged_with_line_5078_to_5223_1_cp'	0.1409090909090909
	1.0	1.0	'xf_5079_to_5021_2_2winding_transformer_merged_with_line_5079_to_5223_2_pi'	0.13545454545454547
	1.04545	1.0	'xf_5083_to_5030_1_2winding_transformer'	0.014363636363636365
	0.964	1.0	'xf_5083_to_5196_2_2winding_transformer'	0.005636363636363636
	1.0	1.0	'xf_5086_to_5197_1_2winding_transformer'	0.0019090909090909091
	1.0	1.0000000000000002	'xf_5087_to_5174_1_2winding_transformer'	0.004545454545454545
	1.0	1.0000000000000002	'xf_5088_to_5174_2_2winding_transformer'	0.004454545454545454
	1.0122199999999997	1.0	'xf_5089_to_5198_1_2winding_transformer'	0.004636363636363636
	1.0122199999999997	1.0	'xf_5089_to_5199_2_2winding_transformer'	0.004363636363636364
	1.0125	1.0	'xf_5091_to_5237_1_2winding_transformer'	0.009454545454545455
	1.0125	1.0	'xf_5091_to_5237_2_2winding_transformer'	0.009636363636363637
	1.0125	1.0	'xf_5091_to_5237_3_2winding_transformer'	0.009727272727272729
	0.97724	1.0	'xf_5092_to_5177_4_2winding_transformer'	0.006818181818181818
	0.97724	1.0	'xf_5092_to_5177_5_2winding_transformer'	0.007363636363636364
	0.97724	1.0	'xf_5092_to_5177_6_2winding_transformer'	0.007454545454545454
	0.9757799999999999	1.0	'xf_5092_to_5224_1A_2winding_transformer'	0.028454545454545455
	0.9757799999999999	1.0	'xf_5092_to_5225_2A_2winding_transformer'	0.029727272727272727
	0.9757799999999999	1.0	'xf_5092_to_5226_3A_2winding_transformer'	0.028363636363636365
	1.0	1.0	'xf_5095_to_5178_1_2winding_transformer'	0.0071818181818181824
	1.0	1.0	'xf_5095_to_5178_2_2winding_transformer'	0.007454545454545454
	1.0	1.0	'xf_5097_to_5204_1_2winding_transformer'	0.004181818181818182
	1.0	1.0	'xf_5098_to_5205_2_2winding_transformer'	0.004363636363636364
	1.0	1.0	'xf_5099_to_5206_1_2winding_transformer'	0.005272727272727273
	1.0	1.0	'xf_5099_to_5207_2_2winding_transformer'	0.005636363636363636
	0.9317200000000001	1.0	'xf_5101_to_5096_3_2winding_transformer'	0.007545454545454545
	0.9317200000000001	1.0	'xf_5101_to_5096_4_2winding_transformer'	0.007545454545454545
	1.0	1.0	'xf_5101_to_5208_1_2winding_transformer'	0.004181818181818182
	0.98778	1.0	'xf_5101_to_5209_2_2winding_transformer'	0.004545454545454545
	1.0	1.0	'xf_5104_to_5210_1_2winding_transformer'	0.006
	1.0	1.0	'xf_5104_to_5210_2_2winding_transformer'	0.006090909090909091
	0.9624999999999999	1.0	'xf_5105_to_5211_1_2winding_transformer'	0.0036363636363636364
	0.975	1.0	'xf_5106_to_5211_2_2winding_transformer'	0.003363636363636364
	1.0	1.0	'xf_5109_to_5212_1_2winding_transformer'	0.0029090909090909093
	1.0	1.0	'xf_5109_to_5212_2_2winding_transformer'	0.0029090909090909093
	0.975	1.0	'xf_5111_to_5213_1_2winding_transformer'	0.004454545454545454
	1.0	1.0	'xf_5112_to_5214_1_2winding_transformer'	0.004636363636363636
	1.0	1.0	'xf_5112_to_5214_2_2winding_transformer'	0.004636363636363636
	0.98818	1.0	'xf_5113_to_5035_1_2winding_transformer'	0.015181818181818182
	0.98818	1.0	'xf_5113_to_5036_2_2winding_transformer'	0.016454545454545454
	1.0127799999999998	1.0	'xf_5113_to_5215_3_2winding_transformer'	0.0057272727272727275
	1.0127799999999998	1.0	'xf_5113_to_5215_4_2winding_transformer'	0.005818181818181819
	1.0127799999999998	1.0	'xf_5113_to_5215_5_2winding_transformer'	0.0057272727272727275
	1.02306	1.0	'xf_5118_to_5216_2_2winding_transformer'	0.005454545454545454
	1.0140000000000002	1.0	'xf_5118_to_5216_3_2winding_transformer'	0.005454545454545454
	1.0	1.0	'xf_5119_to_5120_3_2winding_transformer'	0.005818181818181819
	0.8415200000000002	1.0	'xf_5119_to_5120_4_2winding_transformer'	0.0057272727272727275
	0.9885000000000002	1.0	'xf_5121_to_5240_1_2winding_transformer'	0.006181818181818182
	0.9661	1.0	'xf_5122_to_5217_1_2winding_transformer'	0.005818181818181819
	0.9661	1.0	'xf_5122_to_5217_2_2winding_transformer'	0.005454545454545454
	1.0	1.0	'xf_5123_to_5218_1_2winding_transformer'	0.006363636363636363
	1.0	1.0	'xf_5123_to_5218_2_2winding_transformer'	0.005090909090909091
	1.0	1.0	'xf_5128_to_5044_1_2winding_transformer'	0.01690909090909091
	1.0	1.0	'xf_5128_to_5219_2_2winding_transformer'	0.012454545454545456
	0.98722	1.0	'xf_5129_to_5220_1_2winding_transformer'	0.005818181818181819
	1.0	1.0	'xf_5129_to_5220_2_2winding_transformer'	0.005818181818181819
	1.0	1.0	'xf_5130_to_5221_1_2winding_transformer'	0.0031818181818181815
	0.9886999999999999	1.0	'xf_5130_to_5221_2_2winding_transformer'	0.0032727272727272726
	1.0	1.0	'xf_5131_to_5134_1_2winding_transformer'	0.007545454545454545
	1.0	1.0	'xf_5132_to_5133_2_2winding_transformer'	0.007454545454545454
	1.0	0.952	'xf_5135_to_5222_1_2winding_transformer_merged_with_line_5135_to_5136_1_cp'	0.05090909090909091
	1.0375	1.0	'xf_5137_to_5048_1_2winding_transformer'	0.018363636363636363
	1.0375	1.0	'xf_5137_to_5048_2_2winding_transformer'	0.017727272727272727
	1.0908999999999998	1.0	'xf_5139_to_5004_1_2winding_transformer'	0.013500000000000002
	1.0908999999999998	1.0	'xf_5140_to_5005_2_2winding_transformer'	0.013772727272727272
	1.0908999999999998	1.0	'xf_5141_to_5006_1_2winding_transformer'	0.007545454545454545
	1.0135999999999994	1.0	'xf_5143_to_5053_1_2winding_transformer'	0.013590909090909093
	1.0135999999999994	1.0	'xf_5143_to_5053_2_2winding_transformer'	0.013772727272727272
	1.0	1.0	'xf_5144_to_5008_1_2winding_transformer'	0.007
	1.0	1.0681000000000003	'xf_5146_to_5010_1_2winding_transformer_merged_with_line_5146_to_5149_1_cp'	0.22028985507246376
	1.0681000000000003	1.0	'xf_5147_to_5230_1_2winding_transformer'	0.004318181818181818
	1.0224999999999997	1.0	'xf_5149_to_5063_1_2winding_transformer'	0.0175
	1.0224999999999997	1.0	'xf_5149_to_5063_2_2winding_transformer'	0.017681818181818184
	0.9884999999999996	1.0	'xf_5150_to_5017_2_2winding_transformer'	0.018136363636363638
	0.9884999999999996	1.0	'xf_5150_to_5018_1_2winding_transformer'	0.00981818181818182
	1.0	0.9565217391304348	'xf_5151_to_5013_3_2winding_transformer'	0.008
	0.9766	0.9565217391304348	'xf_5151_to_5016_6_2winding_transformer'	0.01309090909090909
	1.0	0.9565217391304348	'xf_5152_to_5014_4_2winding_transformer'	0.007363636363636364
	1.0	0.9565217391304348	'xf_5152_to_5015_5_2winding_transformer'	0.007363636363636364
	1.0	1.0	'xf_5153_to_5070_1_2winding_transformer'	0.016545454545454547
	1.0	1.0	'xf_5153_to_5070_2_2winding_transformer'	0.017454545454545455
	1.0	1.0	'xf_5153_to_5071_3_2winding_transformer'	0.018227272727272727
	1.0454499999999995	1.0	'xf_5155_to_5231_1_2winding_transformer'	0.003681818181818182
	1.0454499999999995	1.0	'xf_5155_to_5233_3_2winding_transformer'	0.0035909090909090912
	1.0434499999999998	1.0	'xf_5156_to_5234_1_2winding_transformer'	0.006909090909090909
	1.0454499999999995	1.0	'xf_5157_to_5235_1_2winding_transformer'	0.0039545454545454545
	1.0454499999999995	1.0	'xf_5157_to_5236_2_2winding_transformer'	0.0038181818181818182
	1.0	1.0454499999999995	'xf_5158_to_5028_1_2winding_transformer_merged_with_line_5158_to_5159_1_cp'	0.0990909090909091
	1.0908999999999998	1.0	'xf_5161_to_5031_1_2winding_transformer'	0.015863636363636364
	1.0908999999999998	1.0	'xf_5161_to_5032_2_2winding_transformer'	0.015545454545454545
	1.0908999999999998	1.0	'xf_5161_to_5033_3_2winding_transformer'	0.016954545454545455
	1.0	1.0	'xf_5162_to_5090_1_2winding_transformer'	0.0175
	1.0111000000000003	1.0	'xf_5162_to_5090_2_2winding_transformer'	0.01631818181818182
	1.0111000000000003	1.0	'xf_5162_to_5090_3_2winding_transformer'	0.016954545454545455
	1.0	1.0	'xf_5162_to_5090_4_2winding_transformer'	0.0165
	1.0339300000000002	1.0	'xf_5163_to_5095_3_2winding_transformer'	0.017681818181818184
	1.0339300000000002	1.0	'xf_5163_to_5095_4_2winding_transformer'	0.01818181818181818
	1.0	1.0681000000000003	'xf_5165_to_5040_4_2winding_transformer_merged_with_line_5165_to_5169_3_cp'	0.113125
	1.0113300000000003	1.0	'xf_5169_to_5118_1_2winding_transformer'	0.017
	1.0113199999999996	1.0	'xf_5170_to_5119_1_2winding_transformer'	0.01631818181818182
	1.0113199999999996	1.0	'xf_5170_to_5119_2_2winding_transformer'	0.017136363636363637
	1.0454	1.0	'xf_5223_to_5022_1_2winding_transformer'	0.008636363636363636
	1.0454	1.0	'xf_5223_to_5023_2_2winding_transformer'	0.008727272727272728
	1.0454	1.0	'xf_5223_to_5026_5_2winding_transformer'	0.008727272727272728
	1.0	1.0	'xf_5223_to_5195_6_2winding_transformer'	0.0026363636363636363
	1.0	1.0	'xf_5227_to_5008_2_2winding_transformer_merged_with_line_5227_to_5228_1_cp'	0.025454545454545455
	1.0454545454545454	1.0	'xf_5238_to_5224_1B_2winding_transformer'	0.05
	1.0454545454545454	1.0	'xf_5238_to_5224_1C_2winding_transformer'	0.04727272727272727
	1.0454545454545454	1.0	'xf_5238_to_5225_2B_2winding_transformer'	0.05272727272727273
	1.0454545454545454	1.0	'xf_5238_to_5225_2C_2winding_transformer'	0.045454545454545456
	1.0454545454545454	1.0	'xf_5238_to_5226_3B_2winding_transformer'	0.04818181818181819
	1.0454545454545454	1.0	'xf_5238_to_5226_3C_2winding_transformer'	0.05090909090909091
	1.05	1.0454545454545454	'xf_1090_1091_1523_9_3winding_transformer_br1'	0.06
	1.05	1.0454545454545454	'xf_1090_1091_1523_9_3winding_transformer_br2'	0.09090909090909091
	1.05	1.0454545454545454	'xf_1090_1091_1523_9_3winding_transformer_br3'	0.21333333333333335
	1.05	1.0454545454545454	'xf_1092_1093_1525_1_3winding_transformer_br1'	0.058159999999999996
	1.05	1.0454545454545454	'xf_1092_1093_1525_1_3winding_transformer_br2'	0.09090909090909091
	1.05	1.0454545454545454	'xf_1092_1093_1525_1_3winding_transformer_br3'	0.20727272727272728
	1.05	1.0454545454545454	'xf_1092_1093_1526_2_3winding_transformer_br1'	0.06
	1.05	1.0454545454545454	'xf_1092_1093_1526_2_3winding_transformer_br2'	0.09090909090909091
	1.05	1.0454545454545454	'xf_1092_1093_1526_2_3winding_transformer_br3'	0.23909090909090908
	1.05	1.0454545454545454	'xf_1097_1098_1161_2_3winding_transformer_br1'	0.06
	1.05	1.0454545454545454	'xf_1097_1098_1161_2_3winding_transformer_br2'	0.09090909090909091
	1.05	1.0454545454545454	'xf_1097_1098_1161_2_3winding_transformer_br3'	0.19242424242424241
	1.05	1.0454545454545454	'xf_1097_1098_1162_1_3winding_transformer_br1'	0.06
	1.05	1.0454545454545454	'xf_1097_1098_1162_1_3winding_transformer_br2'	0.09090909090909091
	1.05	1.0454545454545454	'xf_1097_1098_1162_1_3winding_transformer_br3'	0.19818181818181818
	1.05	1.0454545454545454	'xf_1099_1100_1532_10_3winding_transformer_br1'	0.06
	1.05	1.0454545454545454	'xf_1099_1100_1532_10_3winding_transformer_br2'	0.09090909090909091
	1.05	1.0454545454545454	'xf_1099_1100_1532_10_3winding_transformer_br3'	0.19272727272727275
	1.05	1.0454545454545454	'xf_1099_1100_1533_9_3winding_transformer_br1'	0.06
	1.05	1.0454545454545454	'xf_1099_1100_1533_9_3winding_transformer_br2'	0.09090909090909091
	1.05	1.0454545454545454	'xf_1099_1100_1533_9_3winding_transformer_br3'	0.20727272727272728
	1.0	0.9600000000000001	'xf_1106_1167_1536_3_3winding_transformer_br1'	0.09090909090909091
	1.0	0.9600000000000001	'xf_1106_1167_1536_3_3winding_transformer_br2'	0.028999999999999998
	1.0	0.9600000000000001	'xf_1106_1167_1536_3_3winding_transformer_br3'	0.14090909090909093
	1.0	0.9600000000000001	'xf_1106_1167_1537_4_3winding_transformer_br1'	0.09090909090909091
	1.0	0.9600000000000001	'xf_1106_1167_1537_4_3winding_transformer_br2'	0.02736363636363636
	1.0	0.9600000000000001	'xf_1106_1167_1537_4_3winding_transformer_br3'	0.1387878787878788
	1.048484848484849	1.0	'xf_1118_1038_1039_1_3winding_transformer_br1'	0.09090909090909091
	1.048484848484849	1.0	'xf_1118_1038_1039_1_3winding_transformer_br2'	0.5487012987012987
	1.048484848484849	1.0	'xf_1118_1038_1039_1_3winding_transformer_br3'	0.588961038961039
	1.048484848484849	1.0	'xf_1118_1040_1041_2_3winding_transformer_br1'	0.09090909090909091
	1.048484848484849	1.0	'xf_1118_1040_1041_2_3winding_transformer_br2'	0.5935064935064935
	1.048484848484849	1.0	'xf_1118_1040_1041_2_3winding_transformer_br3'	0.5896103896103896
	1.048484848484849	1.0	'xf_1118_1042_1043_3_3winding_transformer_br1'	0.09090909090909091
	1.048484848484849	1.0	'xf_1118_1042_1043_3_3winding_transformer_br2'	0.5649350649350648
	1.048484848484849	1.0	'xf_1118_1042_1043_3_3winding_transformer_br3'	0.5707792207792207
	1.05	1.0454545454545454	'xf_1121_1123_1634_6_3winding_transformer_br1'	0.05518
	1.05	1.0454545454545454	'xf_1121_1123_1634_6_3winding_transformer_br2'	0.09090909090909091
	1.05	1.0454545454545454	'xf_1121_1123_1634_6_3winding_transformer_br3'	0.18515151515151515
	1.05	1.0454545454545454	'xf_1121_1123_1635_7_3winding_transformer_br1'	0.06
	1.05	1.0454545454545454	'xf_1121_1123_1635_7_3winding_transformer_br2'	0.09090909090909091
	1.05	1.0454545454545454	'xf_1121_1123_1635_7_3winding_transformer_br3'	0.19787878787878788
	1.048484848484849	1.0	'xf_1148_1073_1074_1_3winding_transformer_br1'	0.09090909090909091
	1.048484848484849	1.0	'xf_1148_1073_1074_1_3winding_transformer_br2'	0.3
	1.048484848484849	1.0	'xf_1148_1073_1074_1_3winding_transformer_br3'	0.31120000000000003
	1.048484848484849	1.0	'xf_1148_1075_1076_2_3winding_transformer_br1'	0.09090909090909091
	1.048484848484849	1.0	'xf_1148_1075_1076_2_3winding_transformer_br2'	0.2784
	1.048484848484849	1.0	'xf_1148_1075_1076_2_3winding_transformer_br3'	0.2776
	1.0	1.0	'xf_1148_1077_1078_3_3winding_transformer_br1'	0.0746060606060606
	1.0	1.0	'xf_1148_1077_1078_3_3winding_transformer_br2'	0.2064
	1.0	1.0	'xf_1148_1077_1078_3_3winding_transformer_br3'	0.21280000000000002
	1.0	1.0	'xf_1148_1079_1080_4_3winding_transformer_br1'	0.08666666666666667
	1.0	1.0	'xf_1148_1079_1080_4_3winding_transformer_br2'	0.2064
	1.0	1.0	'xf_1148_1079_1080_4_3winding_transformer_br3'	0.2016
	1.0	1.0	'xf_1273_1572_1573_1_3winding_transformer_br1'	0.11113636363636363
	1.0	1.0	'xf_1273_1572_1573_1_3winding_transformer_br2'	0.025606060606060604
	1.0	1.0	'xf_1273_1572_1573_1_3winding_transformer_br3'	0.07818181818181819
	1.0	1.0	'xf_1273_1572_1573_2_3winding_transformer_br1'	0.06477272727272727
	1.0	1.0	'xf_1273_1572_1573_2_3winding_transformer_br2'	0.030606060606060605
	1.0	1.0	'xf_1273_1572_1573_2_3winding_transformer_br3'	0.08181818181818182
	1.0	1.0	'xf_1296_1504_1505_2_3winding_transformer_br1'	0.013560606060606061
	1.0	1.0	'xf_1296_1504_1505_2_3winding_transformer_br2'	0.25833333333333336
	1.0	1.0	'xf_1296_1504_1505_2_3winding_transformer_br3'	0.11727272727272728
	1.0	1.0	'xf_1296_1504_1506_1_3winding_transformer_br1'	0.014848484848484849
	1.0	1.0	'xf_1296_1504_1506_1_3winding_transformer_br2'	0.14575757575757575
	1.0	1.0	'xf_1296_1504_1506_1_3winding_transformer_br3'	0.12454545454545456
	1.0	1.0	'xf_1428_1501_1539_1_3winding_transformer_br1'	0.014318181818181817
	1.0	1.0	'xf_1428_1501_1539_1_3winding_transformer_br2'	0.2536363636363636
	1.0	1.0	'xf_1428_1501_1539_1_3winding_transformer_br3'	0.11272727272727273
	1.0	1.0	'xf_1428_1501_1540_2_3winding_transformer_br1'	0.014393939393939393
	1.0	1.0	'xf_1428_1501_1540_2_3winding_transformer_br2'	0.11136363636363636
	1.0	1.0	'xf_1428_1501_1540_2_3winding_transformer_br3'	0.10727272727272727
	1.0	1.0	'xf_1430_1502_1542_1_3winding_transformer_br1'	0.02090909090909091
	1.0	1.0	'xf_1430_1502_1542_1_3winding_transformer_br2'	0.45454545454545453
	1.0	1.0	'xf_1430_1502_1542_1_3winding_transformer_br3'	0.24000000000000002
	1.0	1.0	'xf_1430_1502_1543_2_3winding_transformer_br1'	0.020454545454545454
	1.0	1.0	'xf_1430_1502_1543_2_3winding_transformer_br2'	0.4484848484848485
	1.0	1.0	'xf_1430_1502_1543_2_3winding_transformer_br3'	0.25727272727272726
	1.15	1.0	'xf_1587_1328_1067_1_3winding_transformer_br1'	0.024999999999999998
	1.15	1.0	'xf_1587_1328_1067_1_3winding_transformer_br2'	0.01143939393939394
	1.15	1.0	'xf_1587_1328_1067_1_3winding_transformer_br3'	2.727272727272727
	1.0	1.0	'xf_1588_1327_1068_2_3winding_transformer_br1'	0.024393939393939395
	1.0	1.0	'xf_1588_1327_1068_2_3winding_transformer_br3'	2.727272727272727
	0.9900000000000003	1.0	'xf_1616_1027_1618_1_3winding_transformer_br1'	0.0503030303030303
	0.9900000000000003	1.0	'xf_1616_1027_1618_1_3winding_transformer_br2'	0.01143939393939394
	0.9900000000000003	1.0	'xf_1616_1027_1618_1_3winding_transformer_br3'	0.21818181818181817
	1.0	1.0	'xf_1617_1027_1619_2_3winding_transformer_br1'	0.05666666666666667
	1.0	1.0	'xf_1617_1027_1619_2_3winding_transformer_br2'	0.010833333333333334
	1.0	1.0	'xf_1617_1027_1619_2_3winding_transformer_br3'	0.2
	1.0149999999999995	0.9999999999999998	'xf_2077_2205_2346_2_3winding_transformer_br1'	0.13636363636363635
	1.0149999999999995	0.9999999999999998	'xf_2077_2205_2346_2_3winding_transformer_br2'	0.02282
	1.0149999999999995	0.9999999999999998	'xf_2077_2205_2346_2_3winding_transformer_br3'	0.2287878787878788
	1.0149999999999995	0.9999999999999998	'xf_2077_2205_2347_1_3winding_transformer_br1'	0.13636363636363635
	1.0149999999999995	0.9999999999999998	'xf_2077_2205_2347_1_3winding_transformer_br2'	0.02214
	1.0149999999999995	0.9999999999999998	'xf_2077_2205_2347_1_3winding_transformer_br3'	0.22484848484848485
	1.0149999999999995	0.9999999999999998	'xf_2077_2205_2349_3_3winding_transformer_br1'	0.13636363636363635
	1.0149999999999995	0.9999999999999998	'xf_2077_2205_2349_3_3winding_transformer_br2'	0.02138
	1.0149999999999995	0.9999999999999998	'xf_2077_2205_2349_3_3winding_transformer_br3'	0.23181818181818184
	1.0817477272727272	1.0	'xf_2145_2243_2306_1_3winding_transformer_br1'	0.0037727272727272726
	1.0817477272727272	1.0	'xf_2145_2243_2306_1_3winding_transformer_br2'	0.38363636363636366
	1.0817477272727272	1.0	'xf_2145_2243_2306_1_3winding_transformer_br3'	0.04727272727272727
	1.0817477272727272	1.0	'xf_2145_2243_2306_2_3winding_transformer_br1'	0.004863636363636364
	1.0817477272727272	1.0	'xf_2145_2243_2306_2_3winding_transformer_br2'	0.18000000000000002
	1.0817477272727272	1.0	'xf_2145_2243_2306_2_3winding_transformer_br3'	0.05090909090909091
	1.0817477272727272	1.0	'xf_2145_2243_2306_3_3winding_transformer_br1'	0.004363636363636364
	1.0817477272727272	1.0	'xf_2145_2243_2306_3_3winding_transformer_br2'	0.14303030303030304
	1.0817477272727272	1.0	'xf_2145_2243_2306_3_3winding_transformer_br3'	0.03772727272727273
	0.9673454545454544	1.0	'xf_2162_2271_2315_5_3winding_transformer_br1'	0.020181818181818183
	0.9673454545454544	1.0	'xf_2162_2271_2315_5_3winding_transformer_br2'	0.45454545454545453
	0.9673454545454544	1.0	'xf_2162_2271_2315_5_3winding_transformer_br3'	0.1918181818181818
	1.048484848484849	1.0	'xf_2191_2018_2019_6_3winding_transformer_br1'	0.09090909090909091
	1.048484848484849	1.0	'xf_2191_2018_2019_6_3winding_transformer_br2'	0.2817647058823529
	1.048484848484849	1.0	'xf_2191_2018_2019_6_3winding_transformer_br3'	0.27294117647058824
	1.048484848484849	1.0	'xf_2191_2020_2021_7_3winding_transformer_br1'	0.07115151515151515
	1.048484848484849	1.0	'xf_2191_2020_2021_7_3winding_transformer_br2'	0.31764705882352945
	1.048484848484849	1.0	'xf_2191_2020_2021_7_3winding_transformer_br3'	0.3129411764705883
	1.048484848484849	1.0	'xf_2191_2023_2024_1_3winding_transformer_br1'	0.09090909090909091
	1.048484848484849	1.0	'xf_2191_2023_2024_1_3winding_transformer_br2'	0.23399999999999999
	1.048484848484849	1.0	'xf_2191_2023_2024_1_3winding_transformer_br3'	0.2326666666666667
	1.048484848484849	1.0	'xf_2191_2025_2026_2_3winding_transformer_br1'	0.09090909090909091
	1.048484848484849	1.0	'xf_2191_2025_2026_2_3winding_transformer_br2'	0.2326666666666667
	1.048484848484849	1.0	'xf_2191_2025_2026_2_3winding_transformer_br3'	0.21666666666666667
	1.048484848484849	1.0	'xf_2191_2027_2028_3_3winding_transformer_br1'	0.09090909090909091
	1.048484848484849	1.0	'xf_2191_2027_2028_3_3winding_transformer_br2'	0.232
	1.048484848484849	1.0	'xf_2191_2027_2028_3_3winding_transformer_br3'	0.226
	1.048484848484849	1.0	'xf_2191_2029_2030_4_3winding_transformer_br1'	0.09090909090909091
	1.048484848484849	1.0	'xf_2191_2029_2030_4_3winding_transformer_br2'	0.224
	1.048484848484849	1.0	'xf_2191_2029_2030_4_3winding_transformer_br3'	0.242
	1.048484848484849	1.0	'xf_2191_2031_2022_5_3winding_transformer_br1'	0.09090909090909091
	1.048484848484849	1.0	'xf_2191_2031_2022_5_3winding_transformer_br2'	0.222
	1.048484848484849	1.0	'xf_2191_2031_2022_5_3winding_transformer_br3'	0.22733333333333333
	1.0140909090909087	1.0	'xf_2195_2293_2332_1_3winding_transformer_br1'	0.004212121212121212
	1.0140909090909087	1.0	'xf_2195_2293_2332_1_3winding_transformer_br2'	0.3245454545454546
	1.0140909090909087	1.0	'xf_2195_2293_2332_1_3winding_transformer_br3'	0.07409090909090908
	1.0140909090909087	1.0	'xf_2195_2293_2332_2_3winding_transformer_br1'	0.004
	1.0140909090909087	1.0	'xf_2195_2293_2332_2_3winding_transformer_br2'	0.45454545454545453
	1.0140909090909087	1.0	'xf_2195_2293_2332_2_3winding_transformer_br3'	0.06772727272727273
	0.9625	1.0	'xf_2200_2196_2304_3_3winding_transformer_br1'	0.03424
	0.9625	1.0	'xf_2200_2196_2304_3_3winding_transformer_br2'	0.10909090909090909
	0.9625	1.0	'xf_2200_2196_2304_3_3winding_transformer_br3'	0.37000000000000005
	0.9625	1.0	'xf_2200_2196_2305_2_3winding_transformer_br1'	0.03204
	0.9625	1.0	'xf_2200_2196_2305_2_3winding_transformer_br2'	0.10909090909090909
	0.9625	1.0	'xf_2200_2196_2305_2_3winding_transformer_br3'	0.3518181818181818
	0.9774599999999999	1.0	'xf_3134_3135_3136_1_3winding_transformer_br1'	0.011636363636363637
	0.9774599999999999	1.0	'xf_3134_3135_3136_1_3winding_transformer_br2'	0.026363636363636363
	0.9774599999999999	1.0	'xf_3134_3135_3136_1_3winding_transformer_br3'	0.028181818181818183
	0.9774599999999999	1.0	'xf_3134_3135_3136_2_3winding_transformer_br1'	0.012818181818181817
	0.9774599999999999	1.0	'xf_3134_3135_3136_2_3winding_transformer_br2'	0.028181818181818183
	0.9774599999999999	1.0	'xf_3134_3135_3136_2_3winding_transformer_br3'	0.02727272727272727
	1.0	1.0	'xf_3177_3179_3178_1_3winding_transformer_br1'	0.012727272727272726
	1.0	1.0	'xf_3177_3179_3178_1_3winding_transformer_br2'	0.028181818181818183
	1.0	1.0	'xf_3177_3179_3178_1_3winding_transformer_br3'	0.02909090909090909
	1.0	1.0	'xf_3177_3179_3178_2_3winding_transformer_br1'	0.018
	1.0	1.0	'xf_3177_3179_3178_2_3winding_transformer_br2'	0.026363636363636363
	1.0	1.0	'xf_3177_3179_3178_2_3winding_transformer_br3'	0.028181818181818183
	1.025	1.0	'xf_3226_3227_3228_1_3winding_transformer_br1'	0.010272727272727272
	1.025	1.0	'xf_3226_3227_3228_1_3winding_transformer_br2'	0.028181818181818183
	1.025	1.0	'xf_3226_3227_3228_1_3winding_transformer_br3'	0.028181818181818183
	1.025	1.0	'xf_3226_3227_3228_2_3winding_transformer_br1'	0.012454545454545456
	1.025	1.0	'xf_3226_3227_3228_2_3winding_transformer_br2'	0.02727272727272727
	1.025	1.0	'xf_3226_3227_3228_2_3winding_transformer_br3'	0.026363636363636363
	1.0	1.0	'xf_3231_3644_3645_1_3winding_transformer_br1'	0.014363636363636365
	1.0	1.0	'xf_3231_3644_3645_1_3winding_transformer_br2'	0.02727272727272727
	1.0	1.0	'xf_3231_3644_3645_1_3winding_transformer_br3'	0.026363636363636363
	1.0	1.0	'xf_3231_3644_3645_2_3winding_transformer_br1'	0.010909090909090908
	1.0	1.0	'xf_3231_3644_3645_2_3winding_transformer_br2'	0.02909090909090909
	1.0	1.0	'xf_3231_3644_3645_2_3winding_transformer_br3'	0.02727272727272727
	1.0250000000000001	1.0	'xf_3266_3154_3155_1_3winding_transformer_br1'	0.13401515151515153
	1.0250000000000001	1.0	'xf_3266_3154_3155_1_3winding_transformer_br2'	0.09090909090909091
	1.0250000000000001	1.0	'xf_3266_3154_3155_1_3winding_transformer_br3'	0.08727272727272727
	1.01255	1.0	'xf_3302_3304_3303_1_3winding_transformer_br1'	0.015545454545454545
	1.01255	1.0	'xf_3302_3304_3303_1_3winding_transformer_br2'	0.028181818181818183
	1.01255	1.0	'xf_3302_3304_3303_1_3winding_transformer_br3'	0.02727272727272727
	1.01255	1.0	'xf_3302_3304_3303_2_3winding_transformer_br1'	0.012636363636363635
	1.01255	1.0	'xf_3302_3304_3303_2_3winding_transformer_br2'	0.030000000000000002
	1.01255	1.0	'xf_3302_3304_3303_2_3winding_transformer_br3'	0.028181818181818183
	1.01255	1.0	'xf_3302_3304_3303_3_3winding_transformer_br1'	0.011818181818181818
	1.01255	1.0	'xf_3302_3304_3303_3_3winding_transformer_br2'	0.030000000000000002
	1.01255	1.0	'xf_3302_3304_3303_3_3winding_transformer_br3'	0.028181818181818183
	0.98745	1.0	'xf_3333_3335_3336_2_3winding_transformer_br1'	0.023090909090909092
	0.98745	1.0	'xf_3333_3335_3336_2_3winding_transformer_br2'	0.02727272727272727
	0.98745	1.0	'xf_3333_3335_3336_2_3winding_transformer_br3'	0.026363636363636363
	0.98745	1.0	'xf_3333_3336_3335_1_3winding_transformer_br1'	0.019363636363636364
	0.98745	1.0	'xf_3333_3336_3335_1_3winding_transformer_br2'	0.02727272727272727
	0.98745	1.0	'xf_3333_3336_3335_1_3winding_transformer_br3'	0.02727272727272727
	0.98745	1.0	'xf_3333_3336_3335_3_3winding_transformer_br1'	0.015454545454545453
	0.98745	1.0	'xf_3333_3336_3335_3_3winding_transformer_br2'	0.02727272727272727
	0.98745	1.0	'xf_3333_3336_3335_3_3winding_transformer_br3'	0.02909090909090909
	1.025	1.0	'xf_3358_3360_3361_1_3winding_transformer_br1'	0.013181818181818182
	1.025	1.0	'xf_3358_3360_3361_1_3winding_transformer_br2'	0.025454545454545455
	1.025	1.0	'xf_3358_3360_3361_1_3winding_transformer_br3'	0.025454545454545455
	1.025	1.0	'xf_3359_3360_3361_2_3winding_transformer_br1'	0.012181818181818183
	1.025	1.0	'xf_3359_3360_3361_2_3winding_transformer_br2'	0.02727272727272727
	1.025	1.0	'xf_3359_3360_3361_2_3winding_transformer_br3'	0.024545454545454547
	0.9875000000000002	1.0	'xf_3359_3360_3361_3_3winding_transformer_br1'	0.016363636363636365
	0.9875000000000002	1.0	'xf_3359_3360_3361_3_3winding_transformer_br2'	0.024545454545454547
	0.9875000000000002	1.0	'xf_3359_3360_3361_3_3winding_transformer_br3'	0.023636363636363636
	0.98745	1.0	'xf_3362_3364_3363_1_3winding_transformer_br1'	0.019181818181818182
	0.98745	1.0	'xf_3362_3364_3363_1_3winding_transformer_br2'	0.02727272727272727
	0.98745	1.0	'xf_3362_3364_3363_1_3winding_transformer_br3'	0.025454545454545455
	0.98745	1.0	'xf_3362_3364_3363_2_3winding_transformer_br1'	0.014090909090909091
	0.98745	1.0	'xf_3362_3364_3363_2_3winding_transformer_br2'	0.02727272727272727
	0.98745	1.0	'xf_3362_3364_3363_2_3winding_transformer_br3'	0.028181818181818183
	1.01255	1.0	'xf_3371_3372_3373_1_3winding_transformer_br1'	0.010909090909090908
	1.01255	1.0	'xf_3371_3372_3373_1_3winding_transformer_br2'	0.02727272727272727
	1.01255	1.0	'xf_3371_3372_3373_1_3winding_transformer_br3'	0.028181818181818183
	1.01255	1.0	'xf_3371_3372_3373_2_3winding_transformer_br1'	0.009727272727272729
	1.01255	1.0	'xf_3371_3372_3373_2_3winding_transformer_br2'	0.02727272727272727
	1.01255	1.0	'xf_3371_3372_3373_2_3winding_transformer_br3'	0.028181818181818183
	1.0	0.98745	'xf_3379_3380_3381_3_3winding_transformer_br1_merged_with_line_3379_to_3504_1_cp'	0.016363636363636365
	0.98745	1.0	'xf_3379_3380_3381_3_3winding_transformer_br2'	0.026363636363636363
	0.98745	1.0	'xf_3379_3380_3381_3_3winding_transformer_br3'	0.028181818181818183
	0.9749	1.0	'xf_3413_3415_3414_1_3winding_transformer_br1'	0.013454545454545455
	0.9749	1.0	'xf_3413_3415_3414_1_3winding_transformer_br2'	0.026363636363636363
	0.9749	1.0	'xf_3413_3415_3414_1_3winding_transformer_br3'	0.028181818181818183
	0.9749	1.0	'xf_3413_3415_3414_2_3winding_transformer_br1'	0.011727272727272727
	0.9749	1.0	'xf_3413_3415_3414_2_3winding_transformer_br2'	0.02727272727272727
	0.9749	1.0	'xf_3413_3415_3414_2_3winding_transformer_br3'	0.02909090909090909
	0.9625	1.0	'xf_3483_3558_3484_3_3winding_transformer_br1'	0.22727272727272727
	0.9625	1.0	'xf_3483_3558_3484_3_3winding_transformer_br2'	0.0252
	0.9625	1.0	'xf_3483_3558_3484_3_3winding_transformer_br3'	0.11937172774869108
	0.9625	1.0	'xf_3483_3558_3485_2_3winding_transformer_br1'	0.22727272727272727
	0.9625	1.0	'xf_3483_3558_3485_2_3winding_transformer_br2'	0.02687272727272727
	0.9625	1.0	'xf_3483_3558_3485_2_3winding_transformer_br3'	0.11413612565445026
	1.0323863636363637	1.0472727272727271	'xf_3486_3561_3487_1_3winding_transformer_br1'	0.22727272727272727
	1.0323863636363637	1.0472727272727271	'xf_3486_3561_3487_1_3winding_transformer_br2'	0.015199999999999998
	1.0323863636363637	1.0472727272727271	'xf_3486_3561_3487_1_3winding_transformer_br3'	0.05549738219895288
	1.0323863636363637	1.0472727272727271	'xf_3486_3561_3488_2_3winding_transformer_br1'	0.03606060606060606
	1.0323863636363637	1.0472727272727271	'xf_3486_3561_3488_2_3winding_transformer_br2'	0.10909090909090909
	1.0323863636363637	1.0472727272727271	'xf_3486_3561_3488_2_3winding_transformer_br3'	0.05602094240837696
	1.0323863636363637	1.0472727272727271	'xf_3486_3561_3489_3_3winding_transformer_br1'	0.037954545454545456
	1.0323863636363637	1.0472727272727271	'xf_3486_3561_3489_3_3winding_transformer_br2'	0.10334545454545455
	1.0323863636363637	1.0472727272727271	'xf_3486_3561_3489_3_3winding_transformer_br3'	0.06701570680628272
	0.9625	1.0	'xf_3492_3565_3494_2_3winding_transformer_br1'	0.22727272727272727
	0.9625	1.0	'xf_3492_3565_3494_2_3winding_transformer_br2'	0.029890909090909093
	0.9625	1.0	'xf_3492_3565_3494_2_3winding_transformer_br3'	0.11421052631578947
	0.9625	1.0	'xf_3492_3565_3495_1_3winding_transformer_br1'	0.22727272727272727
	0.9625	1.0	'xf_3492_3565_3495_1_3winding_transformer_br2'	0.026109090909090908
	0.9625	1.0	'xf_3492_3565_3495_1_3winding_transformer_br3'	0.10684210526315789
	0.9625	1.0	'xf_3516_3584_3517_1_3winding_transformer_br1'	0.22727272727272727
	0.9625	1.0	'xf_3516_3584_3517_1_3winding_transformer_br2'	0.017854545454545456
	0.9625	1.0	'xf_3516_3584_3517_1_3winding_transformer_br3'	0.0643979057591623
	1.0875	1.0	'xf_3628_3455_3453_1_3winding_transformer_br1'	0.0275
	1.0875	1.0	'xf_3628_3455_3453_1_3winding_transformer_br2'	0.11
	1.0875	1.0	'xf_3628_3455_3453_1_3winding_transformer_br3'	0.1109090909090909
	1.0875	1.0	'xf_3629_3454_3456_2_3winding_transformer_br1'	0.03696969696969697
	1.0875	1.0	'xf_3629_3454_3456_2_3winding_transformer_br2'	0.09818181818181819
	1.0875	1.0	'xf_3629_3454_3456_2_3winding_transformer_br3'	0.09818181818181819
	0.9749	1.0	'xf_3633_3514_3513_4_3winding_transformer_br1'	0.011727272727272727
	1.0	0.9749	'xf_3633_3514_3513_4_3winding_transformer_br2_merged_with_line_3367_to_3514_1_pi'	0.0025454545454545456
	1.05	1.0000000000000002	'xf_4031_4028_4027_2_3winding_transformer_br1'	0.12893939393939394
	1.05	1.0000000000000002	'xf_4031_4028_4027_2_3winding_transformer_br2'	0.1565217391304348
	1.05	1.0000000000000002	'xf_4031_4028_4027_2_3winding_transformer_br3'	0.15478260869565216
	1.05	1.0000000000000002	'xf_4031_4030_4029_1_3winding_transformer_br1'	0.1659090909090909
	1.05	1.0000000000000002	'xf_4031_4030_4029_1_3winding_transformer_br2'	0.1565217391304348
	1.05	1.0000000000000002	'xf_4031_4030_4029_1_3winding_transformer_br3'	0.14869565217391303
	1.05	1.0000000000000002	'xf_4038_4034_4033_3_3winding_transformer_br1'	0.14515151515151514
	1.05	1.0000000000000002	'xf_4038_4034_4033_3_3winding_transformer_br2'	0.15739130434782608
	1.05	1.0000000000000002	'xf_4038_4034_4033_3_3winding_transformer_br3'	0.14521739130434783
	1.05	1.0000000000000002	'xf_4038_4035_4036_2_3winding_transformer_br1'	0.20257575757575758
	1.05	1.0000000000000002	'xf_4038_4035_4036_2_3winding_transformer_br2'	0.14521739130434783
	1.05	1.0000000000000002	'xf_4038_4035_4036_2_3winding_transformer_br3'	0.14956521739130435
	1.0625000000000002	1.0	'xf_4104_4039_4040_1_3winding_transformer_br1'	0.032145454545454547
	1.0625000000000002	1.0	'xf_4104_4039_4040_1_3winding_transformer_br2'	0.08712121212121211
	1.0625000000000002	1.0	'xf_4104_4039_4040_1_3winding_transformer_br3'	0.0893939393939394
	1.0625000000000002	1.0	'xf_4104_4041_4042_2_3winding_transformer_br1'	0.10909090909090909
	1.0625000000000002	1.0	'xf_4104_4041_4042_2_3winding_transformer_br2'	0.10380952380952382
	1.0625000000000002	1.0	'xf_4104_4041_4042_2_3winding_transformer_br3'	0.10095238095238096
	1.0625000000000002	1.0	'xf_4104_4043_4044_3_3winding_transformer_br1'	0.029818181818181817
	1.0625000000000002	1.0	'xf_4104_4043_4044_3_3winding_transformer_br2'	0.12
	1.0625000000000002	1.0	'xf_4104_4043_4044_3_3winding_transformer_br3'	0.12210526315789473
	1.0625000000000002	1.0	'xf_4104_4045_4046_4_3winding_transformer_br1'	0.051781818181818186
	1.0625000000000002	1.0	'xf_4104_4045_4046_4_3winding_transformer_br2'	0.10666666666666667
	1.0625000000000002	1.0	'xf_4104_4045_4046_4_3winding_transformer_br3'	0.10476190476190476
	1.0250000000000001	1.0	'xf_4109_4357_4358_1_3winding_transformer_br1'	0.10909090909090909
	1.0250000000000001	1.0	'xf_4109_4357_4358_1_3winding_transformer_br2'	0.052121212121212124
	1.0250000000000001	1.0	'xf_4109_4357_4358_1_3winding_transformer_br3'	0.050909090909090904
	1.0	1.0	'xf_4160_4097_4400_2_3winding_transformer_br1'	0.00946969696969697
	1.0	1.0	'xf_4160_4097_4400_2_3winding_transformer_br2'	0.06848484848484848
	1.0	1.0	'xf_4160_4097_4400_2_3winding_transformer_br3'	0.053636363636363635
	1.0	1.0	'xf_4160_4097_4401_1_3winding_transformer_br1'	0.009772727272727273
	1.0	1.0	'xf_4160_4097_4401_1_3winding_transformer_br2'	0.07818181818181819
	1.0	1.0	'xf_4160_4097_4401_1_3winding_transformer_br3'	0.053636363636363635
	1.0	1.0	'xf_4166_4356_4491_3_3winding_transformer_br1'	0.004772727272727273
	1.0	1.0	'xf_4166_4356_4491_3_3winding_transformer_br2'	0.21515151515151515
	1.0	1.0	'xf_4166_4356_4491_3_3winding_transformer_br3'	0.11545454545454546
	1.0	1.0	'xf_4166_4356_4492_4_3winding_transformer_br1'	0.004924242424242425
	1.0	1.0	'xf_4166_4356_4492_4_3winding_transformer_br2'	0.32939393939393935
	1.0	1.0	'xf_4166_4356_4492_4_3winding_transformer_br3'	0.10636363636363635
	1.0	1.0175	'xf_4186_4230_4494_1_3winding_transformer_br1_merged_with_line_4185_to_4186_1_cp'	0.016742424242424243
	1.0175	1.0	'xf_4186_4230_4494_1_3winding_transformer_br2'	0.45454545454545453
	1.0175	1.0	'xf_4186_4230_4494_1_3winding_transformer_br3'	0.10090909090909092
	1.0175	1.0	'xf_4187_4230_4495_2_3winding_transformer_br2'	0.22666666666666668
	1.0175	1.0	'xf_4187_4230_4495_2_3winding_transformer_br3'	0.10545454545454545
	1.0	1.0	'xf_4218_4392_4496_1_3winding_transformer_br1'	0.00856060606060606
	1.0	1.0	'xf_4218_4392_4496_1_3winding_transformer_br2'	0.43393939393939396
	1.0	1.0	'xf_4218_4392_4496_1_3winding_transformer_br3'	0.18818181818181817
	1.01742	1.0	'xf_4220_4074_4498_3_3winding_transformer_br1'	0.007348484848484848
	1.01742	1.0	'xf_4220_4074_4498_3_3winding_transformer_br2'	0.10787878787878788
	1.01742	1.0	'xf_4220_4074_4498_3_3winding_transformer_br3'	0.16272727272727272
	1.01742	1.0	'xf_4220_4074_4499_5_3winding_transformer_br1'	0.007575757575757576
	1.01742	1.0	'xf_4220_4074_4499_5_3winding_transformer_br2'	0.15424242424242424
	1.01742	1.0	'xf_4220_4074_4499_5_3winding_transformer_br3'	0.14636363636363636
	1.0	1.0	'xf_4220_4394_4497_1_3winding_transformer_br1'	0.006439393939393939
	1.0	1.0	'xf_4220_4394_4497_1_3winding_transformer_br2'	0.11303030303030304
	1.0	1.0	'xf_4220_4394_4497_1_3winding_transformer_br3'	0.16272727272727272
	1.025	1.0	'xf_4254_4377_4432_1_3winding_transformer_br1'	0.023636363636363636
	1.025	1.0	'xf_4254_4377_4432_1_3winding_transformer_br2'	0.16151515151515153
	1.025	1.0	'xf_4254_4377_4432_1_3winding_transformer_br3'	0.0736842105263158
	1.0124999999999997	1.0	'xf_4257_4379_4434_1_3winding_transformer_br1'	0.02196969696969697
	1.0124999999999997	1.0	'xf_4257_4379_4434_1_3winding_transformer_br2'	0.2012121212121212
	1.0124999999999997	1.0	'xf_4257_4379_4434_1_3winding_transformer_br3'	0.06710526315789474
	1.0124999999999997	1.0	'xf_4257_4379_4434_2_3winding_transformer_br1'	0.019848484848484848
	1.0124999999999997	1.0	'xf_4257_4379_4434_2_3winding_transformer_br2'	0.4315151515151515
	1.0124999999999997	1.0	'xf_4257_4379_4434_2_3winding_transformer_br3'	0.06315789473684211
	1.0124999999999997	1.0	'xf_4257_4379_4434_3_3winding_transformer_br1'	0.020303030303030305
	1.0124999999999997	1.0	'xf_4257_4379_4434_3_3winding_transformer_br2'	0.3042424242424242
	1.0124999999999997	1.0	'xf_4257_4379_4434_3_3winding_transformer_br3'	0.06710526315789474
	1.0105	1.0000000000000002	'xf_5087_5175_5176_3_3winding_transformer_br1'	0.044
	1.0105	1.0000000000000002	'xf_5087_5175_5176_3_3winding_transformer_br2'	0.1606060606060606
	1.0105	1.0000000000000002	'xf_5087_5175_5176_3_3winding_transformer_br3'	0.16666666666666669
	1.0105	1.0000000000000002	'xf_5088_5175_5241_4_3winding_transformer_br1'	0.05236363636363636
	1.0105	1.0000000000000002	'xf_5088_5175_5241_4_3winding_transformer_br2'	0.15606060606060607
	1.0105	1.0000000000000002	'xf_5088_5175_5241_4_3winding_transformer_br3'	0.15454545454545457
	0.98778	1.0	'xf_5090_5200_5201_5_3winding_transformer_br1'	0.03581818181818182
	0.98778	1.0	'xf_5090_5200_5201_5_3winding_transformer_br2'	0.049090909090909095
	0.98778	1.0	'xf_5090_5200_5201_5_3winding_transformer_br3'	0.05090909090909091
	0.9755600000000001	1.0	'xf_5090_5200_5201_6_3winding_transformer_br1'	0.029727272727272727
	0.9755600000000001	1.0	'xf_5090_5200_5201_6_3winding_transformer_br2'	0.05272727272727273
	0.9755600000000001	1.0	'xf_5090_5200_5201_6_3winding_transformer_br3'	0.05272727272727273
	0.9877000000000001	1.0	'xf_5093_5202_5203_1_3winding_transformer_br2'	0.07181818181818182
	0.9877000000000001	1.0	'xf_5093_5202_5203_1_3winding_transformer_br3'	0.06454545454545454
	1.0	0.9877000000000001	'xf_5094_5202_5203_2_3winding_transformer_br1_merged_with_line_5091_to_5094_2_cp'	0.005545454545454545
	0.9877000000000001	1.0	'xf_5094_5202_5203_2_3winding_transformer_br2'	0.07181818181818182
	0.9877000000000001	1.0	'xf_5094_5202_5203_2_3winding_transformer_br3'	0.06909090909090909
};

%column_names% name mBase 
mpc.load_data = {
	'load_P_1002_1'	100.0
	'load_P_1003_2'	100.0
	'load_P_1004_3'	100.0
	'load_P_1005_4'	100.0
	'load_P_1015_1G'	100.0
	'load_P_1016_1G'	100.0
	'load_P_1017_1'	100.0
	'load_P_1018_2'	100.0
	'load_P_1019_3'	100.0
	'load_P_1020_4'	100.0
	'load_P_1021_1G'	100.0
	'load_P_1022_1'	100.0
	'load_P_1025_1'	100.0
	'load_P_1030_4'	100.0
	'load_P_1032_1'	100.0
	'load_P_1033_3G'	100.0
	'load_P_1033_4G'	100.0
	'load_P_1033_5G'	100.0
	'load_P_1034_1'	100.0
	'load_P_1036_3'	100.0
	'load_P_1037_4'	100.0
	'load_P_1038_1'	100.0
	'load_P_1039_2'	100.0
	'load_P_1040_3'	100.0
	'load_P_1041_4'	100.0
	'load_P_1042_5'	100.0
	'load_P_1043_6'	100.0
	'load_P_1044_1'	100.0
	'load_P_1048_1G'	100.0
	'load_P_1049_1'	100.0
	'load_P_1050_2'	100.0
	'load_P_1051_3'	100.0
	'load_P_1052_4'	100.0
	'load_P_1053_3G'	100.0
	'load_P_1054_1G'	100.0
	'load_P_1055_1G'	100.0
	'load_P_1056_1'	100.0
	'load_P_1058_1'	100.0
	'load_P_1062_1G'	100.0
	'load_P_1074_2'	100.0
	'load_P_1075_3'	100.0
	'load_P_1078_6'	100.0
	'load_P_1079_7'	100.0
	'load_P_1080_8'	100.0
	'load_P_1081_5'	100.0
	'load_P_1082_6'	100.0
	'load_P_1083_1'	100.0
	'load_P_1083_1G'	100.0
	'load_P_1083_2'	100.0
	'load_P_1083_3'	100.0
	'load_P_1083_4'	100.0
	'load_P_1094_1'	100.0
	'load_P_1094_2'	100.0
	'load_P_1127_1'	100.0
	'load_P_1128_2'	100.0
	'load_P_1129_4'	100.0
	'load_P_1130_3'	100.0
	'load_P_1139_1'	100.0
	'load_P_1146_1'	100.0
	'load_P_1146_1C'	100.0
	'load_P_1146_2'	100.0
	'load_P_1146_2C'	100.0
	'load_P_1146_3'	100.0
	'load_P_1146_3C'	100.0
	'load_P_1146_4'	100.0
	'load_P_1146_4C'	100.0
	'load_P_1166_1'	100.0
	'load_P_1166_2'	100.0
	'load_P_1166_3'	100.0
	'load_P_1166_4'	100.0
	'load_P_1168_1'	100.0
	'load_P_1168_2'	100.0
	'load_P_1169_1'	100.0
	'load_P_1169_2'	100.0
	'load_P_1169_3'	100.0
	'load_P_1169_4'	100.0
	'load_P_1169_5'	100.0
	'load_P_1169_6'	100.0
	'load_P_1169_7'	100.0
	'load_P_1169_8'	100.0
	'load_P_1184_1'	100.0
	'load_P_1184_2'	100.0
	'load_P_1184_3'	100.0
	'load_P_1185_1'	100.0
	'load_P_1185_10'	100.0
	'load_P_1185_11'	100.0
	'load_P_1185_12'	100.0
	'load_P_1185_2'	100.0
	'load_P_1185_3'	100.0
	'load_P_1185_4'	100.0
	'load_P_1185_5'	100.0
	'load_P_1185_6'	100.0
	'load_P_1185_7'	100.0
	'load_P_1185_8'	100.0
	'load_P_1185_9'	100.0
	'load_P_1186_1'	100.0
	'load_P_1186_2'	100.0
	'load_P_1186_3'	100.0
	'load_P_1186_4'	100.0
	'load_P_1186_5'	100.0
	'load_P_1189_1'	100.0
	'load_P_1189_2'	100.0
	'load_P_1190_1'	100.0
	'load_P_1191_2'	100.0
	'load_P_1192_1'	100.0
	'load_P_1192_2'	100.0
	'load_P_1195_1'	100.0
	'load_P_1195_2'	100.0
	'load_P_1196_7'	100.0
	'load_P_1200_1'	100.0
	'load_P_1201_2'	100.0
	'load_P_1201_3'	100.0
	'load_P_1203_1'	100.0
	'load_P_1209_1'	100.0
	'load_P_1209_2'	100.0
	'load_P_1209_3'	100.0
	'load_P_1209_4'	100.0
	'load_P_1210_1'	100.0
	'load_P_1210_2'	100.0
	'load_P_1214_1'	100.0
	'load_P_1214_2'	100.0
	'load_P_1214_3'	100.0
	'load_P_1216_1'	100.0
	'load_P_1217_1'	100.0
	'load_P_1220_1'	100.0
	'load_P_1220_2'	100.0
	'load_P_1220_3'	100.0
	'load_P_1223_1'	100.0
	'load_P_1226_1'	100.0
	'load_P_1226_2'	100.0
	'load_P_1228_1'	100.0
	'load_P_1229_1'	100.0
	'load_P_1230_1'	100.0
	'load_P_1232_1'	100.0
	'load_P_1232_2'	100.0
	'load_P_1236_1'	100.0
	'load_P_1237_1'	100.0
	'load_P_1240_1'	100.0
	'load_P_1240_2'	100.0
	'load_P_1240_3'	100.0
	'load_P_1240_4'	100.0
	'load_P_1240_5'	100.0
	'load_P_1243_4'	100.0
	'load_P_1244_1'	100.0
	'load_P_1246_2'	100.0
	'load_P_1247_1'	100.0
	'load_P_1247_2'	100.0
	'load_P_1247_4'	100.0
	'load_P_1247_5'	100.0
	'load_P_1248_1'	100.0
	'load_P_1248_2'	100.0
	'load_P_1249_1'	100.0
	'load_P_1250_1'	100.0
	'load_P_1251_2'	100.0
	'load_P_1252_1'	100.0
	'load_P_1252_2'	100.0
	'load_P_1254_1'	100.0
	'load_P_1254_2'	100.0
	'load_P_1254_3'	100.0
	'load_P_1255_1'	100.0
	'load_P_1255_2'	100.0
	'load_P_1256_1'	100.0
	'load_P_1256_2'	100.0
	'load_P_1257_2'	100.0
	'load_P_1257_3'	100.0
	'load_P_1258_1'	100.0
	'load_P_1258_2'	100.0
	'load_P_1259_3'	100.0
	'load_P_1259_4'	100.0
	'load_P_1260_1'	100.0
	'load_P_1260_2'	100.0
	'load_P_1260_3'	100.0
	'load_P_1260_6'	100.0
	'load_P_1261_1'	100.0
	'load_P_1261_2'	100.0
	'load_P_1261_3'	100.0
	'load_P_1264_1'	100.0
	'load_P_1266_1'	100.0
	'load_P_1266_2'	100.0
	'load_P_1266_4'	100.0
	'load_P_1275_1'	100.0
	'load_P_1275_2'	100.0
	'load_P_1284_1'	100.0
	'load_P_1284_2'	100.0
	'load_P_1284_3'	100.0
	'load_P_1284_4'	100.0
	'load_P_1288_1'	100.0
	'load_P_1288_2'	100.0
	'load_P_1288_3'	100.0
	'load_P_1292_1'	100.0
	'load_P_1293_1'	100.0
	'load_P_1294_1'	100.0
	'load_P_1294_2'	100.0
	'load_P_1294_3'	100.0
	'load_P_1295_1'	100.0
	'load_P_1295_2'	100.0
	'load_P_1295_3'	100.0
	'load_P_1299_1'	100.0
	'load_P_1301_1'	100.0
	'load_P_1301_2'	100.0
	'load_P_1301_3'	100.0
	'load_P_1305_1'	100.0
	'load_P_1305_2'	100.0
	'load_P_1306_1'	100.0
	'load_P_1306_2'	100.0
	'load_P_1307_1'	100.0
	'load_P_1307_2'	100.0
	'load_P_1309_1'	100.0
	'load_P_1309_2'	100.0
	'load_P_1309_3'	100.0
	'load_P_1309_4'	100.0
	'load_P_1314_1'	100.0
	'load_P_1314_2'	100.0
	'load_P_1314_3'	100.0
	'load_P_1314_4'	100.0
	'load_P_1320_1'	100.0
	'load_P_1320_2'	100.0
	'load_P_1321_1'	100.0
	'load_P_1321_2'	100.0
	'load_P_1323_1'	100.0
	'load_P_1323_2'	100.0
	'load_P_1323_3'	100.0
	'load_P_1325_2'	100.0
	'load_P_1330_1'	100.0
	'load_P_1338_1'	100.0
	'load_P_1338_2'	100.0
	'load_P_1339_1'	100.0
	'load_P_1339_2'	100.0
	'load_P_1339_3'	100.0
	'load_P_1340_1'	100.0
	'load_P_1341_1'	100.0
	'load_P_1343_3'	100.0
	'load_P_1343_4'	100.0
	'load_P_1344_1'	100.0
	'load_P_1344_2'	100.0
	'load_P_1345_1'	100.0
	'load_P_1345_2'	100.0
	'load_P_1349_1'	100.0
	'load_P_1349_2'	100.0
	'load_P_1350_3'	100.0
	'load_P_1350_4'	100.0
	'load_P_1352_1'	100.0
	'load_P_1352_2'	100.0
	'load_P_1352_3'	100.0
	'load_P_1352_4'	100.0
	'load_P_1355_1'	100.0
	'load_P_1355_2'	100.0
	'load_P_1356_1'	100.0
	'load_P_1356_2'	100.0
	'load_P_1357_1'	100.0
	'load_P_1357_2'	100.0
	'load_P_1358_1'	100.0
	'load_P_1360_1'	100.0
	'load_P_1361_2'	100.0
	'load_P_1364_1'	100.0
	'load_P_1364_2'	100.0
	'load_P_1369_2'	100.0
	'load_P_1369_3'	100.0
	'load_P_1369_4'	100.0
	'load_P_1369_5'	100.0
	'load_P_1371_1'	100.0
	'load_P_1371_2'	100.0
	'load_P_1372_3'	100.0
	'load_P_1372_4'	100.0
	'load_P_1373_1'	100.0
	'load_P_1373_2'	100.0
	'load_P_1376_1'	100.0
	'load_P_1378_2'	100.0
	'load_P_1379_1'	100.0
	'load_P_1379_2'	100.0
	'load_P_1379_3'	100.0
	'load_P_1380_1'	100.0
	'load_P_1380_2'	100.0
	'load_P_1382_1'	100.0
	'load_P_1382_2'	100.0
	'load_P_1382_3'	100.0
	'load_P_1387_4'	100.0
	'load_P_1388_1'	100.0
	'load_P_1388_2'	100.0
	'load_P_1391_1'	100.0
	'load_P_1391_10'	100.0
	'load_P_1391_2'	100.0
	'load_P_1391_3'	100.0
	'load_P_1391_4'	100.0
	'load_P_1391_5'	100.0
	'load_P_1391_6'	100.0
	'load_P_1391_8'	100.0
	'load_P_1391_9'	100.0
	'load_P_1394_1'	100.0
	'load_P_1394_2'	100.0
	'load_P_1395_1'	100.0
	'load_P_1396_1'	100.0
	'load_P_1396_2'	100.0
	'load_P_1397_1'	100.0
	'load_P_1397_2'	100.0
	'load_P_1397_3'	100.0
	'load_P_1397_4'	100.0
	'load_P_1397_5'	100.0
	'load_P_1398_3'	100.0
	'load_P_1399_1'	100.0
	'load_P_1399_2'	100.0
	'load_P_1400_1'	100.0
	'load_P_1403_1'	100.0
	'load_P_1406_1'	100.0
	'load_P_1406_2'	100.0
	'load_P_1406_3'	100.0
	'load_P_1415_1'	100.0
	'load_P_1416_1'	100.0
	'load_P_1416_2'	100.0
	'load_P_1416_3'	100.0
	'load_P_1422_1'	100.0
	'load_P_1422_2'	100.0
	'load_P_1424_1'	100.0
	'load_P_1424_2'	100.0
	'load_P_1425_1'	100.0
	'load_P_1425_2'	100.0
	'load_P_1425_3'	100.0
	'load_P_1425_4'	100.0
	'load_P_1429_1'	100.0
	'load_P_1429_2'	100.0
	'load_P_1430_3'	100.0
	'load_P_1430_4'	100.0
	'load_P_1433_1'	100.0
	'load_P_1435_1'	100.0
	'load_P_1435_2'	100.0
	'load_P_1436_1G'	100.0
	'load_P_1437_1'	100.0
	'load_P_1438_1'	100.0
	'load_P_1438_2'	100.0
	'load_P_1438_3'	100.0
	'load_P_1443_2'	100.0
	'load_P_1443_3'	100.0
	'load_P_1443_4'	100.0
	'load_P_1443_5'	100.0
	'load_P_1445_1'	100.0
	'load_P_1445_2'	100.0
	'load_P_1451_2'	100.0
	'load_P_1452_1'	100.0
	'load_P_1453_1'	100.0
	'load_P_1455_1'	100.0
	'load_P_1455_2'	100.0
	'load_P_1456_1'	100.0
	'load_P_1456_2'	100.0
	'load_P_1457_2'	100.0
	'load_P_1459_1'	100.0
	'load_P_1459_10'	100.0
	'load_P_1459_11'	100.0
	'load_P_1459_12'	100.0
	'load_P_1459_2'	100.0
	'load_P_1459_3'	100.0
	'load_P_1459_5'	100.0
	'load_P_1459_6'	100.0
	'load_P_1459_7'	100.0
	'load_P_1459_8'	100.0
	'load_P_1459_9'	100.0
	'load_P_1463_1'	100.0
	'load_P_1463_2'	100.0
	'load_P_1464_1'	100.0
	'load_P_1464_2'	100.0
	'load_P_1467_1'	100.0
	'load_P_1467_2'	100.0
	'load_P_1474_1'	100.0
	'load_P_1474_2'	100.0
	'load_P_1475_1'	100.0
	'load_P_1475_2'	100.0
	'load_P_1476_1'	100.0
	'load_P_1476_2'	100.0
	'load_P_1476_3'	100.0
	'load_P_1477_1'	100.0
	'load_P_1477_2'	100.0
	'load_P_1477_3'	100.0
	'load_P_1479_1'	100.0
	'load_P_1482_1'	100.0
	'load_P_1482_2'	100.0
	'load_P_1482_3'	100.0
	'load_P_1482_5'	100.0
	'load_P_1482_6'	100.0
	'load_P_1482_7'	100.0
	'load_P_1482_8'	100.0
	'load_P_1484_1'	100.0
	'load_P_1484_2'	100.0
	'load_P_1486_1'	100.0
	'load_P_1486_2'	100.0
	'load_P_1488_1'	100.0
	'load_P_1488_2'	100.0
	'load_P_1490_1'	100.0
	'load_P_1490_2'	100.0
	'load_P_1491_1'	100.0
	'load_P_1491_2'	100.0
	'load_P_1491_3'	100.0
	'load_P_1491_4'	100.0
	'load_P_1491_5'	100.0
	'load_P_1492_1'	100.0
	'load_P_1492_2'	100.0
	'load_P_1492_3'	100.0
	'load_P_1498_2'	100.0
	'load_P_1499_1'	100.0
	'load_P_1499_2'	100.0
	'load_P_1501_2'	100.0
	'load_P_1501_3'	100.0
	'load_P_1501_4'	100.0
	'load_P_1502_1'	100.0
	'load_P_1502_2'	100.0
	'load_P_1504_1'	100.0
	'load_P_1504_2'	100.0
	'load_P_1504_3'	100.0
	'load_P_1507_1'	100.0
	'load_P_1507_2'	100.0
	'load_P_1508_1'	100.0
	'load_P_1508_2'	100.0
	'load_P_1509_1'	100.0
	'load_P_1509_2'	100.0
	'load_P_1509_3'	100.0
	'load_P_1510_2'	100.0
	'load_P_1510_4'	100.0
	'load_P_1512_1'	100.0
	'load_P_1513_1'	100.0
	'load_P_1513_2'	100.0
	'load_P_1515_5'	100.0
	'load_P_1517_1'	100.0
	'load_P_1518_1'	100.0
	'load_P_1518_2'	100.0
	'load_P_1519_1'	100.0
	'load_P_1519_2'	100.0
	'load_P_1522_5'	100.0
	'load_P_1524_6'	100.0
	'load_P_1527_1'	100.0
	'load_P_1527_2'	100.0
	'load_P_1528_3'	100.0
	'load_P_1529_2'	100.0
	'load_P_1530_1'	100.0
	'load_P_1531_5'	100.0
	'load_P_1534_1'	100.0
	'load_P_1534_2'	100.0
	'load_P_1534_3'	100.0
	'load_P_1535_1'	100.0
	'load_P_1538_1'	100.0
	'load_P_1544_5'	100.0
	'load_P_1546_6'	100.0
	'load_P_1547_1'	100.0
	'load_P_1547_2'	100.0
	'load_P_1548_1'	100.0
	'load_P_1548_2'	100.0
	'load_P_1548_3'	100.0
	'load_P_1548_4'	100.0
	'load_P_1548_5'	100.0
	'load_P_1548_6'	100.0
	'load_P_1549_4'	100.0
	'load_P_1550_3'	100.0
	'load_P_1553_3'	100.0
	'load_P_1553_4'	100.0
	'load_P_1554_1'	100.0
	'load_P_1555_1'	100.0
	'load_P_1556_1'	100.0
	'load_P_1557_1'	100.0
	'load_P_1557_2'	100.0
	'load_P_1558_1'	100.0
	'load_P_1558_2'	100.0
	'load_P_1559_1'	100.0
	'load_P_1560_2'	100.0
	'load_P_1560_3'	100.0
	'load_P_1561_1'	100.0
	'load_P_1563_1'	100.0
	'load_P_1563_2'	100.0
	'load_P_1567_1'	100.0
	'load_P_1568_1'	100.0
	'load_P_1568_2'	100.0
	'load_P_1572_1'	100.0
	'load_P_1573_2'	100.0
	'load_P_1573_3'	100.0
	'load_P_1574_1'	100.0
	'load_P_1574_2'	100.0
	'load_P_1574_3'	100.0
	'load_P_1575_1'	100.0
	'load_P_1575_2'	100.0
	'load_P_1575_3'	100.0
	'load_P_1576_3'	100.0
	'load_P_1576_4'	100.0
	'load_P_1577_1'	100.0
	'load_P_1577_2'	100.0
	'load_P_1578_1'	100.0
	'load_P_1578_3'	100.0
	'load_P_1578_4'	100.0
	'load_P_1581_1'	100.0
	'load_P_1581_2'	100.0
	'load_P_1583_1'	100.0
	'load_P_1583_2'	100.0
	'load_P_1583_3'	100.0
	'load_P_1584_1'	100.0
	'load_P_1584_2'	100.0
	'load_P_1585_4'	100.0
	'load_P_1586_1'	100.0
	'load_P_1586_2'	100.0
	'load_P_1586_3'	100.0
	'load_P_1589_1'	100.0
	'load_P_1589_2'	100.0
	'load_P_1590_1'	100.0
	'load_P_1591_1'	100.0
	'load_P_1591_2'	100.0
	'load_P_1591_3'	100.0
	'load_P_1592_1'	100.0
	'load_P_1592_2'	100.0
	'load_P_1592_3'	100.0
	'load_P_1593_1'	100.0
	'load_P_1594_1'	100.0
	'load_P_1594_2'	100.0
	'load_P_1595_1'	100.0
	'load_P_1596_1'	100.0
	'load_P_1596_2'	100.0
	'load_P_1598_2'	100.0
	'load_P_1599_1'	100.0
	'load_P_1600_1'	100.0
	'load_P_1600_2'	100.0
	'load_P_1601_1'	100.0
	'load_P_1603_1'	100.0
	'load_P_1603_2'	100.0
	'load_P_1604_1'	100.0
	'load_P_1604_2'	100.0
	'load_P_1606_2'	100.0
	'load_P_1610_4'	100.0
	'load_P_1610_6'	100.0
	'load_P_1611_1'	100.0
	'load_P_1611_2'	100.0
	'load_P_1613_1'	100.0
	'load_P_1613_2'	100.0
	'load_P_1614_2'	100.0
	'load_P_1615_1'	100.0
	'load_P_1618_1'	100.0
	'load_P_1620_1'	100.0
	'load_P_1620_2'	100.0
	'load_P_1621_1'	100.0
	'load_P_1621_2'	100.0
	'load_P_1621_3'	100.0
	'load_P_1621_4'	100.0
	'load_P_1622_1'	100.0
	'load_P_1623_1'	100.0
	'load_P_1623_2'	100.0
	'load_P_1623_3'	100.0
	'load_P_1624_1'	100.0
	'load_P_1624_2'	100.0
	'load_P_1624_3'	100.0
	'load_P_1624_4'	100.0
	'load_P_1625_1'	100.0
	'load_P_1625_2'	100.0
	'load_P_1626_2'	100.0
	'load_P_1626_3'	100.0
	'load_P_1626_4'	100.0
	'load_P_1629_1'	100.0
	'load_P_1629_2'	100.0
	'load_P_1629_3'	100.0
	'load_P_1629_4'	100.0
	'load_P_1629_5'	100.0
	'load_P_1629_6'	100.0
	'load_P_1629_7'	100.0
	'load_P_1630_1'	100.0
	'load_P_1630_2'	100.0
	'load_P_1631_1'	100.0
	'load_P_1631_2'	100.0
	'load_P_1633_1'	100.0
	'load_P_1633_2'	100.0
	'load_P_1633_5'	100.0
	'load_P_1633_6'	100.0
	'load_P_1633_7'	100.0
	'load_P_1633_8'	100.0
	'load_P_1636_1'	100.0
	'load_P_1638_1'	100.0
	'load_P_1638_2'	100.0
	'load_P_1638_3'	100.0
	'load_P_1638_4'	100.0
	'load_P_1638_5'	100.0
	'load_P_1639_6'	100.0
	'load_P_1639_7'	100.0
	'load_P_1639_8'	100.0
	'load_P_1639_9'	100.0
	'load_P_1640_1'	100.0
	'load_P_1640_2'	100.0
	'load_P_1645_3'	100.0
	'load_P_1645_4'	100.0
	'load_P_1645_5'	100.0
	'load_P_1647_1'	100.0
	'load_P_1647_2'	100.0
	'load_P_1647_3'	100.0
	'load_P_1647_4'	100.0
	'load_P_1648_1'	100.0
	'load_P_1649_1'	100.0
	'load_P_1649_2'	100.0
	'load_P_1650_1'	100.0
	'load_P_1650_2'	100.0
	'load_P_1650_3'	100.0
	'load_P_1651_1'	100.0
	'load_P_1652_1'	100.0
	'load_P_1653_2'	100.0
	'load_P_1653_3'	100.0
	'load_P_1658_2'	100.0
	'load_P_1658_3'	100.0
	'load_P_2001_1G'	100.0
	'load_P_2002_2G'	100.0
	'load_P_2014_1'	100.0
	'load_P_2021_14'	100.0
	'load_P_2024_2'	100.0
	'load_P_2028_6'	100.0
	'load_P_2030_8'	100.0
	'load_P_2035_2'	100.0
	'load_P_2036_1'	100.0
	'load_P_2037_2'	100.0
	'load_P_2038_3'	100.0
	'load_P_2043_2'	100.0
	'load_P_2044_3'	100.0
	'load_P_2045_4'	100.0
	'load_P_2046_1'	100.0
	'load_P_2047_2'	100.0
	'load_P_2060_1'	100.0
	'load_P_2061_4'	100.0
	'load_P_2063_11'	100.0
	'load_P_2064_12'	100.0
	'load_P_2065_1'	100.0
	'load_P_2065_1C'	100.0
	'load_P_2066_2'	100.0
	'load_P_2066_2C'	100.0
	'load_P_2072_1G'	100.0
	'load_P_2073_1'	100.0
	'load_P_2074_2G'	100.0
	'load_P_2075_2G'	100.0
	'load_P_2078_1G'	100.0
	'load_P_2079_1G'	100.0
	'load_P_2080_1G'	100.0
	'load_P_2081_1G'	100.0
	'load_P_2091_1'	100.0
	'load_P_2092_1'	100.0
	'load_P_2093_2'	100.0
	'load_P_2094_3'	100.0
	'load_P_2095_4'	100.0
	'load_P_2096_1G'	100.0
	'load_P_2097_2'	100.0
	'load_P_2103_5'	100.0
	'load_P_2103_6'	100.0
	'load_P_2140_1'	100.0
	'load_P_2140_1C'	100.0
	'load_P_2141_2'	100.0
	'load_P_2141_2C'	100.0
	'load_P_2197_3'	100.0
	'load_P_2197_4'	100.0
	'load_P_2210_1'	100.0
	'load_P_2210_1C'	100.0
	'load_P_2210_3'	100.0
	'load_P_2211_1'	100.0
	'load_P_2213_1'	100.0
	'load_P_2213_2'	100.0
	'load_P_2214_1'	100.0
	'load_P_2214_2'	100.0
	'load_P_2215_1'	100.0
	'load_P_2216_1'	100.0
	'load_P_2217_1'	100.0
	'load_P_2218_1'	100.0
	'load_P_2218_2'	100.0
	'load_P_2219_1'	100.0
	'load_P_2220_1'	100.0
	'load_P_2220_2'	100.0
	'load_P_2221_10'	100.0
	'load_P_2221_11'	100.0
	'load_P_2221_12'	100.0
	'load_P_2221_13'	100.0
	'load_P_2221_4'	100.0
	'load_P_2221_5'	100.0
	'load_P_2221_6'	100.0
	'load_P_2221_8'	100.0
	'load_P_2221_9'	100.0
	'load_P_2222_7'	100.0
	'load_P_2222_7C'	100.0
	'load_P_2224_1'	100.0
	'load_P_2224_2'	100.0
	'load_P_2224_3'	100.0
	'load_P_2225_1'	100.0
	'load_P_2231_1'	100.0
	'load_P_2231_2'	100.0
	'load_P_2232_3'	100.0
	'load_P_2232_4'	100.0
	'load_P_2233_1'	100.0
	'load_P_2233_2'	100.0
	'load_P_2233_3'	100.0
	'load_P_2234_1'	100.0
	'load_P_2234_2'	100.0
	'load_P_2235_1'	100.0
	'load_P_2235_2'	100.0
	'load_P_2236_1'	100.0
	'load_P_2236_2'	100.0
	'load_P_2237_3'	100.0
	'load_P_2237_4'	100.0
	'load_P_2238_1'	100.0
	'load_P_2239_1'	100.0
	'load_P_2239_2'	100.0
	'load_P_2240_1'	100.0
	'load_P_2241_1'	100.0
	'load_P_2241_2'	100.0
	'load_P_2241_3'	100.0
	'load_P_2243_4'	100.0
	'load_P_2243_5'	100.0
	'load_P_2248_1'	100.0
	'load_P_2248_2'	100.0
	'load_P_2249_3'	100.0
	'load_P_2249_4'	100.0
	'load_P_2251_1'	100.0
	'load_P_2252_1'	100.0
	'load_P_2255_1'	100.0
	'load_P_2255_2'	100.0
	'load_P_2256_1'	100.0
	'load_P_2256_2'	100.0
	'load_P_2257_1'	100.0
	'load_P_2257_2'	100.0
	'load_P_2261_1'	100.0
	'load_P_2261_3'	100.0
	'load_P_2261_4'	100.0
	'load_P_2262_2'	100.0
	'load_P_2262_5'	100.0
	'load_P_2264_4'	100.0
	'load_P_2264_5'	100.0
	'load_P_2266_1'	100.0
	'load_P_2271_1'	100.0
	'load_P_2271_2'	100.0
	'load_P_2271_3'	100.0
	'load_P_2271_4'	100.0
	'load_P_2271_5'	100.0
	'load_P_2271_6'	100.0
	'load_P_2271_7'	100.0
	'load_P_2272_1'	100.0
	'load_P_2272_2'	100.0
	'load_P_2273_2'	100.0
	'load_P_2273_4'	100.0
	'load_P_2274_1'	100.0
	'load_P_2274_3'	100.0
	'load_P_2275_1'	100.0
	'load_P_2275_2'	100.0
	'load_P_2276_1'	100.0
	'load_P_2276_2'	100.0
	'load_P_2276_3'	100.0
	'load_P_2277_1'	100.0
	'load_P_2277_2'	100.0
	'load_P_2278_3'	100.0
	'load_P_2279_1'	100.0
	'load_P_2279_2'	100.0
	'load_P_2280_1'	100.0
	'load_P_2280_2'	100.0
	'load_P_2284_1'	100.0
	'load_P_2284_2'	100.0
	'load_P_2285_3'	100.0
	'load_P_2286_1'	100.0
	'load_P_2288_1'	100.0
	'load_P_2289_1'	100.0
	'load_P_2289_2'	100.0
	'load_P_2290_3'	100.0
	'load_P_2290_4'	100.0
	'load_P_2291_1'	100.0
	'load_P_2291_2'	100.0
	'load_P_2291_3'	100.0
	'load_P_2291_4'	100.0
	'load_P_2293_3'	100.0
	'load_P_2293_4'	100.0
	'load_P_2294_1'	100.0
	'load_P_2295_2'	100.0
	'load_P_2295_3'	100.0
	'load_P_2295_4'	100.0
	'load_P_2295_5'	100.0
	'load_P_2298_3'	100.0
	'load_P_2299_4'	100.0
	'load_P_2300_1'	100.0
	'load_P_2300_2'	100.0
	'load_P_2300_3'	100.0
	'load_P_2303_1'	100.0
	'load_P_2306_6'	100.0
	'load_P_2306_7'	100.0
	'load_P_2311_6'	100.0
	'load_P_2311_7'	100.0
	'load_P_2311_8'	100.0
	'load_P_2312_1'	100.0
	'load_P_2312_2'	100.0
	'load_P_2312_3'	100.0
	'load_P_2314_1'	100.0
	'load_P_2314_1C'	100.0
	'load_P_2314_2'	100.0
	'load_P_2314_2C'	100.0
	'load_P_2315_8'	100.0
	'load_P_2315_9'	100.0
	'load_P_2320_5'	100.0
	'load_P_2320_6'	100.0
	'load_P_2320_7'	100.0
	'load_P_2322_3'	100.0
	'load_P_2323_4'	100.0
	'load_P_2324_1'	100.0
	'load_P_2325_2'	100.0
	'load_P_2327_5'	100.0
	'load_P_2327_6'	100.0
	'load_P_2331_7'	100.0
	'load_P_2332_5'	100.0
	'load_P_2332_6'	100.0
	'load_P_2333_2'	100.0
	'load_P_2334_1'	100.0
	'load_P_2335_6'	100.0
	'load_P_2335_6C'	100.0
	'load_P_2336_7'	100.0
	'load_P_2336_7C'	100.0
	'load_P_2337_1'	100.0
	'load_P_2344_3'	100.0
	'load_P_2344_3C'	100.0
	'load_P_2348_3'	100.0
	'load_P_2348_3C'	100.0
	'load_P_2348_4'	100.0
	'load_P_2348_4C'	100.0
	'load_P_2352_5'	100.0
	'load_P_3004_1'	100.0
	'load_P_3005_1'	100.0
	'load_P_3005_2'	100.0
	'load_P_3006_1'	100.0
	'load_P_3007_1'	100.0
	'load_P_3007_2'	100.0
	'load_P_3011_1'	100.0
	'load_P_3011_2'	100.0
	'load_P_3012_3'	100.0
	'load_P_3013_4'	100.0
	'load_P_3016_1'	100.0
	'load_P_3019_1'	100.0
	'load_P_3020_2'	100.0
	'load_P_3020_3'	100.0
	'load_P_3020_4'	100.0
	'load_P_3022_1'	100.0
	'load_P_3023_1'	100.0
	'load_P_3023_2'	100.0
	'load_P_3026_1'	100.0
	'load_P_3029_1'	100.0
	'load_P_3029_2'	100.0
	'load_P_3032_1'	100.0
	'load_P_3033_8'	100.0
	'load_P_3034_1'	100.0
	'load_P_3035_2'	100.0
	'load_P_3038_1'	100.0
	'load_P_3039_5'	100.0
	'load_P_3046_1'	100.0
	'load_P_3049_1'	100.0
	'load_P_3049_2'	100.0
	'load_P_3053_1'	100.0
	'load_P_3055_1'	100.0
	'load_P_3057_1'	100.0
	'load_P_3059_1'	100.0
	'load_P_3061_1'	100.0
	'load_P_3062_2'	100.0
	'load_P_3064_1'	100.0
	'load_P_3066_1'	100.0
	'load_P_3070_2'	100.0
	'load_P_3070_3'	100.0
	'load_P_3070_4'	100.0
	'load_P_3071_1'	100.0
	'load_P_3071_2'	100.0
	'load_P_3074_1'	100.0
	'load_P_3074_2'	100.0
	'load_P_3075_3'	100.0
	'load_P_3076_1'	100.0
	'load_P_3076_2'	100.0
	'load_P_3076_3'	100.0
	'load_P_3081_1'	100.0
	'load_P_3082_5'	100.0
	'load_P_3085_1'	100.0
	'load_P_3087_1'	100.0
	'load_P_3090_1'	100.0
	'load_P_3091_2'	100.0
	'load_P_3095_1'	100.0
	'load_P_3097_1'	100.0
	'load_P_3100_1'	100.0
	'load_P_3100_2'	100.0
	'load_P_3103_1'	100.0
	'load_P_3107_1'	100.0
	'load_P_3110_1'	100.0
	'load_P_3112_1'	100.0
	'load_P_3113_2'	100.0
	'load_P_3115_1'	100.0
	'load_P_3116_1'	100.0
	'load_P_3116_2'	100.0
	'load_P_3118_1'	100.0
	'load_P_3121_1'	100.0
	'load_P_3122_1'	100.0
	'load_P_3124_1'	100.0
	'load_P_3124_3'	100.0
	'load_P_3125_2'	100.0
	'load_P_3125_4'	100.0
	'load_P_3126_1'	100.0
	'load_P_3128_1'	100.0
	'load_P_3128_2'	100.0
	'load_P_3128_3'	100.0
	'load_P_3130_1'	100.0
	'load_P_3130_2'	100.0
	'load_P_3132_1'	100.0
	'load_P_3133_2'	100.0
	'load_P_3135_3'	100.0
	'load_P_3135_4'	100.0
	'load_P_3136_1'	100.0
	'load_P_3136_2'	100.0
	'load_P_3137_10'	100.0
	'load_P_3137_9'	100.0
	'load_P_3142_1'	100.0
	'load_P_3142_2'	100.0
	'load_P_3145_1'	100.0
	'load_P_3149_1'	100.0
	'load_P_3152_1'	100.0
	'load_P_3154_3'	100.0
	'load_P_3155_1'	100.0
	'load_P_3156_2'	100.0
	'load_P_3157_1'	100.0
	'load_P_3157_2'	100.0
	'load_P_3159_1'	100.0
	'load_P_3160_1'	100.0
	'load_P_3160_2'	100.0
	'load_P_3162_1'	100.0
	'load_P_3163_1'	100.0
	'load_P_3163_2'	100.0
	'load_P_3163_3'	100.0
	'load_P_3166_1'	100.0
	'load_P_3168_1'	100.0
	'load_P_3169_1'	100.0
	'load_P_3170_1'	100.0
	'load_P_3171_2'	100.0
	'load_P_3173_1'	100.0
	'load_P_3173_2'	100.0
	'load_P_3174_1'	100.0
	'load_P_3174_2'	100.0
	'load_P_3176_1'	100.0
	'load_P_3177_1'	100.0
	'load_P_3178_2'	100.0
	'load_P_3178_3'	100.0
	'load_P_3179_4'	100.0
	'load_P_3179_5'	100.0
	'load_P_3183_1'	100.0
	'load_P_3183_2'	100.0
	'load_P_3186_1'	100.0
	'load_P_3186_2'	100.0
	'load_P_3188_1'	100.0
	'load_P_3191_1'	100.0
	'load_P_3191_2'	100.0
	'load_P_3193_1'	100.0
	'load_P_3193_2'	100.0
	'load_P_3193_3'	100.0
	'load_P_3194_1'	100.0
	'load_P_3200_1'	100.0
	'load_P_3200_2'	100.0
	'load_P_3202_1'	100.0
	'load_P_3202_2'	100.0
	'load_P_3203_1'	100.0
	'load_P_3205_2'	100.0
	'load_P_3206_3'	100.0
	'load_P_3206_4'	100.0
	'load_P_3206_5'	100.0
	'load_P_3211_1'	100.0
	'load_P_3215_1'	100.0
	'load_P_3221_1'	100.0
	'load_P_3224_1'	100.0
	'load_P_3225_1'	100.0
	'load_P_3227_1'	100.0
	'load_P_3228_2'	100.0
	'load_P_3230_1'	100.0
	'load_P_3230_2'	100.0
	'load_P_3232_1'	100.0
	'load_P_3233_1'	100.0
	'load_P_3236_1'	100.0
	'load_P_3236_2'	100.0
	'load_P_3236_3'	100.0
	'load_P_3239_1'	100.0
	'load_P_3239_2'	100.0
	'load_P_3240_1'	100.0
	'load_P_3240_2'	100.0
	'load_P_3241_1'	100.0
	'load_P_3241_2'	100.0
	'load_P_3242_2'	100.0
	'load_P_3245_1'	100.0
	'load_P_3247_1'	100.0
	'load_P_3247_2'	100.0
	'load_P_3248_1'	100.0
	'load_P_3251_1'	100.0
	'load_P_3257_1'	100.0
	'load_P_3258_1'	100.0
	'load_P_3260_1'	100.0
	'load_P_3261_1'	100.0
	'load_P_3262_1'	100.0
	'load_P_3262_2'	100.0
	'load_P_3263_2'	100.0
	'load_P_3263_3'	100.0
	'load_P_3263_4'	100.0
	'load_P_3264_1'	100.0
	'load_P_3267_1'	100.0
	'load_P_3270_1'	100.0
	'load_P_3270_2'	100.0
	'load_P_3271_4'	100.0
	'load_P_3271_5'	100.0
	'load_P_3271_6'	100.0
	'load_P_3272_1'	100.0
	'load_P_3273_1'	100.0
	'load_P_3275_1'	100.0
	'load_P_3276_1'	100.0
	'load_P_3276_2'	100.0
	'load_P_3277_2'	100.0
	'load_P_3278_1'	100.0
	'load_P_3278_2'	100.0
	'load_P_3279_1'	100.0
	'load_P_3279_2'	100.0
	'load_P_3280_1'	100.0
	'load_P_3280_2'	100.0
	'load_P_3280_3'	100.0
	'load_P_3280_4'	100.0
	'load_P_3281_3'	100.0
	'load_P_3282_1'	100.0
	'load_P_3282_2'	100.0
	'load_P_3283_1'	100.0
	'load_P_3283_2'	100.0
	'load_P_3284_1'	100.0
	'load_P_3284_2'	100.0
	'load_P_3285_1'	100.0
	'load_P_3285_2'	100.0
	'load_P_3287_1'	100.0
	'load_P_3287_2'	100.0
	'load_P_3287_3'	100.0
	'load_P_3288_1'	100.0
	'load_P_3288_2'	100.0
	'load_P_3289_1'	100.0
	'load_P_3289_2'	100.0
	'load_P_3290_1'	100.0
	'load_P_3292_1G'	100.0
	'load_P_3295_1'	100.0
	'load_P_3298_1'	100.0
	'load_P_3298_2'	100.0
	'load_P_3300_1'	100.0
	'load_P_3300_2'	100.0
	'load_P_3301_1'	100.0
	'load_P_3303_4'	100.0
	'load_P_3303_5'	100.0
	'load_P_3303_6'	100.0
	'load_P_3304_1'	100.0
	'load_P_3304_2'	100.0
	'load_P_3304_3'	100.0
	'load_P_3305_1'	100.0
	'load_P_3305_2'	100.0
	'load_P_3308_1'	100.0
	'load_P_3308_4'	100.0
	'load_P_3309_2'	100.0
	'load_P_3309_3'	100.0
	'load_P_3311_1'	100.0
	'load_P_3311_2'	100.0
	'load_P_3316_1'	100.0
	'load_P_3316_2'	100.0
	'load_P_3320_1'	100.0
	'load_P_3323_1'	100.0
	'load_P_3323_2'	100.0
	'load_P_3326_3'	100.0
	'load_P_3327_2'	100.0
	'load_P_3328_1'	100.0
	'load_P_3331_1'	100.0
	'load_P_3332_1'	100.0
	'load_P_3335_1'	100.0
	'load_P_3335_2'	100.0
	'load_P_3335_3'	100.0
	'load_P_3336_4'	100.0
	'load_P_3336_5'	100.0
	'load_P_3336_6'	100.0
	'load_P_3339_1'	100.0
	'load_P_3339_2'	100.0
	'load_P_3339_3'	100.0
	'load_P_3341_1'	100.0
	'load_P_3341_2'	100.0
	'load_P_3343_1'	100.0
	'load_P_3343_2'	100.0
	'load_P_3347_1'	100.0
	'load_P_3351_1'	100.0
	'load_P_3351_2'	100.0
	'load_P_3351_3'	100.0
	'load_P_3353_1'	100.0
	'load_P_3354_1'	100.0
	'load_P_3354_2'	100.0
	'load_P_3355_3'	100.0
	'load_P_3355_4'	100.0
	'load_P_3356_5'	100.0
	'load_P_3360_1'	100.0
	'load_P_3361_2'	100.0
	'load_P_3363_1'	100.0
	'load_P_3363_2'	100.0
	'load_P_3364_3'	100.0
	'load_P_3364_4'	100.0
	'load_P_3365_1'	100.0
	'load_P_3365_2'	100.0
	'load_P_3365_3'	100.0
	'load_P_3367_4'	100.0
	'load_P_3367_5'	100.0
	'load_P_3367_6'	100.0
	'load_P_3367_7'	100.0
	'load_P_3370_1'	100.0
	'load_P_3372_1'	100.0
	'load_P_3373_2'	100.0
	'load_P_3374_1'	100.0
	'load_P_3374_2'	100.0
	'load_P_3375_2'	100.0
	'load_P_3376_1'	100.0
	'load_P_3380_1'	100.0
	'load_P_3380_2'	100.0
	'load_P_3381_3'	100.0
	'load_P_3381_4'	100.0
	'load_P_3383_1'	100.0
	'load_P_3384_1'	100.0
	'load_P_3384_2'	100.0
	'load_P_3387_2'	100.0
	'load_P_3387_6'	100.0
	'load_P_3388_1'	100.0
	'load_P_3388_4'	100.0
	'load_P_3389_3'	100.0
	'load_P_3389_5'	100.0
	'load_P_3392_1'	100.0
	'load_P_3394_1'	100.0
	'load_P_3394_2'	100.0
	'load_P_3396_1'	100.0
	'load_P_3398_1'	100.0
	'load_P_3398_3'	100.0
	'load_P_3399_2'	100.0
	'load_P_3399_5'	100.0
	'load_P_3400_4'	100.0
	'load_P_3400_6'	100.0
	'load_P_3401_1'	100.0
	'load_P_3401_2'	100.0
	'load_P_3402_1'	100.0
	'load_P_3402_2'	100.0
	'load_P_3403_3'	100.0
	'load_P_3403_4'	100.0
	'load_P_3403_5'	100.0
	'load_P_3403_6'	100.0
	'load_P_3404_2'	100.0
	'load_P_3405_1'	100.0
	'load_P_3406_1'	100.0
	'load_P_3407_1'	100.0
	'load_P_3407_2'	100.0
	'load_P_3409_2'	100.0
	'load_P_3409_3'	100.0
	'load_P_3410_1'	100.0
	'load_P_3410_4'	100.0
	'load_P_3414_3'	100.0
	'load_P_3414_4'	100.0
	'load_P_3415_1'	100.0
	'load_P_3415_2'	100.0
	'load_P_3417_1'	100.0
	'load_P_3418_2'	100.0
	'load_P_3419_3'	100.0
	'load_P_3420_4'	100.0
	'load_P_3421_5'	100.0
	'load_P_3422_6'	100.0
	'load_P_3423_1'	100.0
	'load_P_3424_2'	100.0
	'load_P_3425_3'	100.0
	'load_P_3426_4'	100.0
	'load_P_3427_12'	100.0
	'load_P_3430_1'	100.0
	'load_P_3431_2'	100.0
	'load_P_3433_1'	100.0
	'load_P_3434_1'	100.0
	'load_P_3435_2'	100.0
	'load_P_3436_3'	100.0
	'load_P_3437_4'	100.0
	'load_P_3438_1'	100.0
	'load_P_3439_2'	100.0
	'load_P_3441_1'	100.0
	'load_P_3441_2'	100.0
	'load_P_3442_1'	100.0
	'load_P_3443_2'	100.0
	'load_P_3444_1'	100.0
	'load_P_3444_2'	100.0
	'load_P_3446_1'	100.0
	'load_P_3446_1G'	100.0
	'load_P_3449_2'	100.0
	'load_P_3450_7'	100.0
	'load_P_3452_2'	100.0
	'load_P_3453_3'	100.0
	'load_P_3454_2'	100.0
	'load_P_3462_1'	100.0
	'load_P_3463_1'	100.0
	'load_P_3464_1'	100.0
	'load_P_3472_1'	100.0
	'load_P_3474_1'	100.0
	'load_P_3477_1'	100.0
	'load_P_3477_1C'	100.0
	'load_P_3477_2'	100.0
	'load_P_3477_2C'	100.0
	'load_P_3477_3'	100.0
	'load_P_3477_3C'	100.0
	'load_P_3477_4'	100.0
	'load_P_3477_4C'	100.0
	'load_P_3477_5'	100.0
	'load_P_3477_5C'	100.0
	'load_P_3477_6'	100.0
	'load_P_3477_6C'	100.0
	'load_P_3478_1'	100.0
	'load_P_3493_1'	100.0
	'load_P_3496_1'	100.0
	'load_P_3496_2'	100.0
	'load_P_3499_4'	100.0
	'load_P_3500_1'	100.0
	'load_P_3501_2'	100.0
	'load_P_3502_1'	100.0
	'load_P_3502_2'	100.0
	'load_P_3504_1'	100.0
	'load_P_3504_2'	100.0
	'load_P_3505_3'	100.0
	'load_P_3505_4'	100.0
	'load_P_3521_1'	100.0
	'load_P_3521_2'	100.0
	'load_P_3525_2'	100.0
	'load_P_3526_3'	100.0
	'load_P_3527_1'	100.0
	'load_P_3535_1'	100.0
	'load_P_3535_2'	100.0
	'load_P_3535_3'	100.0
	'load_P_3535_4'	100.0
	'load_P_3539_1'	100.0
	'load_P_3539_2'	100.0
	'load_P_3540_1'	100.0
	'load_P_3540_2'	100.0
	'load_P_3541_1'	100.0
	'load_P_3541_2'	100.0
	'load_P_3542_1'	100.0
	'load_P_3585_1'	100.0
	'load_P_3586_2'	100.0
	'load_P_3587_3'	100.0
	'load_P_3588_4'	100.0
	'load_P_3611_1'	100.0
	'load_P_3611_2'	100.0
	'load_P_3624_1'	100.0
	'load_P_3624_2'	100.0
	'load_P_3635_1'	100.0
	'load_P_3642_1'	100.0
	'load_P_3642_2'	100.0
	'load_P_3644_3'	100.0
	'load_P_3644_4'	100.0
	'load_P_3645_1'	100.0
	'load_P_3645_2'	100.0
	'load_P_3647_1'	100.0
	'load_P_3647_2'	100.0
	'load_P_3647_3'	100.0
	'load_P_3651_1'	100.0
	'load_P_3655_1'	100.0
	'load_P_3656_2'	100.0
	'load_P_3659_1'	100.0
	'load_P_3659_2'	100.0
	'load_P_4004_1G'	100.0
	'load_P_4010_1'	100.0
	'load_P_4011_22'	100.0
	'load_P_4012_21'	100.0
	'load_P_4025_4G'	100.0
	'load_P_4032_1'	100.0
	'load_P_4032_2'	100.0
	'load_P_4051_1'	100.0
	'load_P_4052_11'	100.0
	'load_P_4053_12'	100.0
	'load_P_4058_1'	100.0
	'load_P_4059_2'	100.0
	'load_P_4061_4'	100.0
	'load_P_4062_1'	100.0
	'load_P_4064_3'	100.0
	'load_P_4065_4'	100.0
	'load_P_4066_1'	100.0
	'load_P_4067_2'	100.0
	'load_P_4071_1'	100.0
	'load_P_4071_1G'	100.0
	'load_P_4071_2'	100.0
	'load_P_4071_3'	100.0
	'load_P_4071_4'	100.0
	'load_P_4074_1'	100.0
	'load_P_4074_2'	100.0
	'load_P_4074_3'	100.0
	'load_P_4080_1G'	100.0
	'load_P_4091_1'	100.0
	'load_P_4091_2'	100.0
	'load_P_4097_2'	100.0
	'load_P_4097_3'	100.0
	'load_P_4123_1'	100.0
	'load_P_4123_2'	100.0
	'load_P_4127_1'	100.0
	'load_P_4127_2'	100.0
	'load_P_4132_1'	100.0
	'load_P_4156_1'	100.0
	'load_P_4156_2'	100.0
	'load_P_4159_1'	100.0
	'load_P_4160_1'	100.0
	'load_P_4163_1'	100.0
	'load_P_4168_1'	100.0
	'load_P_4169_1'	100.0
	'load_P_4172_1'	100.0
	'load_P_4176_1'	100.0
	'load_P_4177_1'	100.0
	'load_P_4178_1'	100.0
	'load_P_4179_1'	100.0
	'load_P_4192_1'	100.0
	'load_P_4192_2'	100.0
	'load_P_4193_1'	100.0
	'load_P_4193_2'	100.0
	'load_P_4205_1'	100.0
	'load_P_4207_1'	100.0
	'load_P_4208_1'	100.0
	'load_P_4209_1'	100.0
	'load_P_4209_2'	100.0
	'load_P_4209_3'	100.0
	'load_P_4210_3'	100.0
	'load_P_4211_1'	100.0
	'load_P_4212_1'	100.0
	'load_P_4212_2'	100.0
	'load_P_4226_5'	100.0
	'load_P_4226_6'	100.0
	'load_P_4226_7'	100.0
	'load_P_4227_1'	100.0
	'load_P_4227_2'	100.0
	'load_P_4228_1'	100.0
	'load_P_4228_2'	100.0
	'load_P_4230_1'	100.0
	'load_P_4230_2'	100.0
	'load_P_4230_3'	100.0
	'load_P_4230_4'	100.0
	'load_P_4230_5'	100.0
	'load_P_4230_6'	100.0
	'load_P_4233_1'	100.0
	'load_P_4233_2'	100.0
	'load_P_4238_1'	100.0
	'load_P_4242_1'	100.0
	'load_P_4242_2'	100.0
	'load_P_4248_1'	100.0
	'load_P_4248_2'	100.0
	'load_P_4248_3'	100.0
	'load_P_4250_1'	100.0
	'load_P_4250_2'	100.0
	'load_P_4251_1'	100.0
	'load_P_4251_2'	100.0
	'load_P_4266_1'	100.0
	'load_P_4296_1'	100.0
	'load_P_4297_1'	100.0
	'load_P_4300_1'	100.0
	'load_P_4300_2'	100.0
	'load_P_4302_1'	100.0
	'load_P_4302_2'	100.0
	'load_P_4319_1'	100.0
	'load_P_4319_2'	100.0
	'load_P_4322_1'	100.0
	'load_P_4329_1'	100.0
	'load_P_4329_2'	100.0
	'load_P_4329_3'	100.0
	'load_P_4329_4'	100.0
	'load_P_4329_5'	100.0
	'load_P_4329_6'	100.0
	'load_P_4336_1'	100.0
	'load_P_4336_2'	100.0
	'load_P_4337_1'	100.0
	'load_P_4340_1'	100.0
	'load_P_4345_4'	100.0
	'load_P_4346_2'	100.0
	'load_P_4349_2'	100.0
	'load_P_4349_3'	100.0
	'load_P_4356_1'	100.0
	'load_P_4361_1'	100.0
	'load_P_4364_1'	100.0
	'load_P_4365_1'	100.0
	'load_P_4366_1'	100.0
	'load_P_4366_2'	100.0
	'load_P_4366_3'	100.0
	'load_P_4366_4'	100.0
	'load_P_4366_5'	100.0
	'load_P_4371_1'	100.0
	'load_P_4371_2'	100.0
	'load_P_4371_3'	100.0
	'load_P_4371_4'	100.0
	'load_P_4374_1'	100.0
	'load_P_4375_1'	100.0
	'load_P_4377_1'	100.0
	'load_P_4378_3'	100.0
	'load_P_4379_1'	100.0
	'load_P_4379_2'	100.0
	'load_P_4380_1'	100.0
	'load_P_4380_2'	100.0
	'load_P_4380_3'	100.0
	'load_P_4381_2'	100.0
	'load_P_4382_1'	100.0
	'load_P_4383_1'	100.0
	'load_P_4383_2'	100.0
	'load_P_4385_1'	100.0
	'load_P_4386_2'	100.0
	'load_P_4387_2'	100.0
	'load_P_4388_1'	100.0
	'load_P_4389_1'	100.0
	'load_P_4390_2'	100.0
	'load_P_4391_1'	100.0
	'load_P_4391_2'	100.0
	'load_P_4392_1'	100.0
	'load_P_4392_2'	100.0
	'load_P_4393_1'	100.0
	'load_P_4394_5'	100.0
	'load_P_4398_1'	100.0
	'load_P_4402_4'	100.0
	'load_P_4402_4C'	100.0
	'load_P_4403_3'	100.0
	'load_P_4403_3C'	100.0
	'load_P_4404_2'	100.0
	'load_P_4404_2C'	100.0
	'load_P_4405_2'	100.0
	'load_P_4405_2C'	100.0
	'load_P_4406_4'	100.0
	'load_P_4406_4C'	100.0
	'load_P_4407_1'	100.0
	'load_P_4407_1C'	100.0
	'load_P_4408_3'	100.0
	'load_P_4408_3C'	100.0
	'load_P_4409_1'	100.0
	'load_P_4409_2'	100.0
	'load_P_4410_8'	100.0
	'load_P_4410_8C'	100.0
	'load_P_4411_5'	100.0
	'load_P_4411_5C'	100.0
	'load_P_4412_6'	100.0
	'load_P_4412_6C'	100.0
	'load_P_4413_7'	100.0
	'load_P_4413_7C'	100.0
	'load_P_4414_3'	100.0
	'load_P_4414_3C'	100.0
	'load_P_4415_4'	100.0
	'load_P_4415_4C'	100.0
	'load_P_4416_1'	100.0
	'load_P_4416_2'	100.0
	'load_P_4417_1'	100.0
	'load_P_4417_2'	100.0
	'load_P_4418_1'	100.0
	'load_P_4418_2'	100.0
	'load_P_4418_3'	100.0
	'load_P_4418_4'	100.0
	'load_P_4419_1'	100.0
	'load_P_4420_1'	100.0
	'load_P_4421_1'	100.0
	'load_P_4421_2'	100.0
	'load_P_4422_1'	100.0
	'load_P_4422_2'	100.0
	'load_P_4422_3'	100.0
	'load_P_4424_1'	100.0
	'load_P_4424_2'	100.0
	'load_P_4425_1'	100.0
	'load_P_4426_1'	100.0
	'load_P_4427_1'	100.0
	'load_P_4427_2'	100.0
	'load_P_4428_1'	100.0
	'load_P_4428_2'	100.0
	'load_P_4429_1'	100.0
	'load_P_4429_2'	100.0
	'load_P_4430_1'	100.0
	'load_P_4431_1'	100.0
	'load_P_4432_2'	100.0
	'load_P_4433_1'	100.0
	'load_P_4435_1'	100.0
	'load_P_4435_2'	100.0
	'load_P_4436_1'	100.0
	'load_P_4437_1'	100.0
	'load_P_4437_2'	100.0
	'load_P_4438_1'	100.0
	'load_P_4438_2'	100.0
	'load_P_4438_3'	100.0
	'load_P_4438_4'	100.0
	'load_P_4438_5'	100.0
	'load_P_4438_6'	100.0
	'load_P_4438_7'	100.0
	'load_P_4439_8'	100.0
	'load_P_4440_1'	100.0
	'load_P_4440_2'	100.0
	'load_P_4441_1'	100.0
	'load_P_4441_2'	100.0
	'load_P_4442_1'	100.0
	'load_P_4442_2'	100.0
	'load_P_4443_1'	100.0
	'load_P_4444_1'	100.0
	'load_P_4445_1'	100.0
	'load_P_4446_1'	100.0
	'load_P_4446_2'	100.0
	'load_P_4447_1'	100.0
	'load_P_4447_2'	100.0
	'load_P_4448_1'	100.0
	'load_P_4448_2'	100.0
	'load_P_4448_3'	100.0
	'load_P_4449_1'	100.0
	'load_P_4450_1'	100.0
	'load_P_4450_2'	100.0
	'load_P_4451_1'	100.0
	'load_P_4451_2'	100.0
	'load_P_4452_1'	100.0
	'load_P_4452_2'	100.0
	'load_P_4453_1'	100.0
	'load_P_4454_1'	100.0
	'load_P_4454_2'	100.0
	'load_P_4455_1'	100.0
	'load_P_4455_2'	100.0
	'load_P_4456_1'	100.0
	'load_P_4456_2'	100.0
	'load_P_4457_4'	100.0
	'load_P_4457_5'	100.0
	'load_P_4457_6'	100.0
	'load_P_4458_1'	100.0
	'load_P_4458_2'	100.0
	'load_P_4459_3'	100.0
	'load_P_4459_4'	100.0
	'load_P_4459_5'	100.0
	'load_P_4460_2'	100.0
	'load_P_4460_3'	100.0
	'load_P_4460_4'	100.0
	'load_P_4461_1'	100.0
	'load_P_4461_2'	100.0
	'load_P_4461_3'	100.0
	'load_P_4463_1'	100.0
	'load_P_4463_2'	100.0
	'load_P_4464_1'	100.0
	'load_P_4464_2'	100.0
	'load_P_4465_1'	100.0
	'load_P_4466_1'	100.0
	'load_P_4466_2'	100.0
	'load_P_4467_1'	100.0
	'load_P_4468_1'	100.0
	'load_P_4469_1'	100.0
	'load_P_4469_2'	100.0
	'load_P_4470_1'	100.0
	'load_P_4471_1'	100.0
	'load_P_4471_2'	100.0
	'load_P_4472_1'	100.0
	'load_P_4473_1'	100.0
	'load_P_4473_2'	100.0
	'load_P_4474_1'	100.0
	'load_P_4474_2'	100.0
	'load_P_4475_1'	100.0
	'load_P_4475_2'	100.0
	'load_P_4475_3'	100.0
	'load_P_4476_1G'	100.0
	'load_P_4476_2'	100.0
	'load_P_4476_2G'	100.0
	'load_P_4476_3'	100.0
	'load_P_4476_4'	100.0
	'load_P_4477_1'	100.0
	'load_P_4478_1'	100.0
	'load_P_4478_2'	100.0
	'load_P_4479_1'	100.0
	'load_P_4480_1'	100.0
	'load_P_4480_2'	100.0
	'load_P_4481_1'	100.0
	'load_P_4482_1'	100.0
	'load_P_4483_1'	100.0
	'load_P_4484_1'	100.0
	'load_P_4484_2'	100.0
	'load_P_4485_2'	100.0
	'load_P_4485_3'	100.0
	'load_P_4486_1'	100.0
	'load_P_4486_2'	100.0
	'load_P_4487_1'	100.0
	'load_P_4487_2'	100.0
	'load_P_4488_1'	100.0
	'load_P_4489_1'	100.0
	'load_P_4489_2'	100.0
	'load_P_4490_2'	100.0
	'load_P_4490_3'	100.0
	'load_P_4493_5'	100.0
	'load_P_4493_5C'	100.0
	'load_P_4500_1'	100.0
	'load_P_4500_2'	100.0
	'load_P_5017_1'	100.0
	'load_P_5043_1G'	100.0
	'load_P_5048_1G'	100.0
	'load_P_5048_2G'	100.0
	'load_P_5072_1'	100.0
	'load_P_5072_1C'	100.0
	'load_P_5072_2'	100.0
	'load_P_5072_2C'	100.0
	'load_P_5072_3'	100.0
	'load_P_5072_3C'	100.0
	'load_P_5072_4'	100.0
	'load_P_5072_4C'	100.0
	'load_P_5096_1'	100.0
	'load_P_5096_2'	100.0
	'load_P_5120_1'	100.0
	'load_P_5120_2'	100.0
	'load_P_5125_1'	100.0
	'load_P_5127_1'	100.0
	'load_P_5133_2'	100.0
	'load_P_5134_1'	100.0
	'load_P_5154_1'	100.0
	'load_P_5154_1C'	100.0
	'load_P_5154_2'	100.0
	'load_P_5154_2C'	100.0
	'load_P_5154_3'	100.0
	'load_P_5154_3C'	100.0
	'load_P_5154_4'	100.0
	'load_P_5154_4C'	100.0
	'load_P_5154_5'	100.0
	'load_P_5154_5C'	100.0
	'load_P_5172_1'	100.0
	'load_P_5172_2'	100.0
	'load_P_5173_1'	100.0
	'load_P_5173_2'	100.0
	'load_P_5174_1'	100.0
	'load_P_5174_1C'	100.0
	'load_P_5174_2'	100.0
	'load_P_5174_2C'	100.0
	'load_P_5174_3'	100.0
	'load_P_5174_3C'	100.0
	'load_P_5175_4'	100.0
	'load_P_5175_4C'	100.0
	'load_P_5175_5'	100.0
	'load_P_5175_5C'	100.0
	'load_P_5176_6'	100.0
	'load_P_5176_6C'	100.0
	'load_P_5177_1'	100.0
	'load_P_5177_2'	100.0
	'load_P_5177_3'	100.0
	'load_P_5178_1'	100.0
	'load_P_5178_2'	100.0
	'load_P_5179_1'	100.0
	'load_P_5179_2'	100.0
	'load_P_5180_1'	100.0
	'load_P_5180_2'	100.0
	'load_P_5181_3'	100.0
	'load_P_5181_4'	100.0
	'load_P_5182_1'	100.0
	'load_P_5183_1'	100.0
	'load_P_5184_2'	100.0
	'load_P_5185_1'	100.0
	'load_P_5185_2'	100.0
	'load_P_5186_1'	100.0
	'load_P_5186_2'	100.0
	'load_P_5187_1'	100.0
	'load_P_5187_2'	100.0
	'load_P_5188_1'	100.0
	'load_P_5188_2'	100.0
	'load_P_5188_3'	100.0
	'load_P_5189_1'	100.0
	'load_P_5189_2'	100.0
	'load_P_5190_1'	100.0
	'load_P_5190_2'	100.0
	'load_P_5190_3'	100.0
	'load_P_5191_1'	100.0
	'load_P_5191_2'	100.0
	'load_P_5192_1'	100.0
	'load_P_5192_2'	100.0
	'load_P_5193_1'	100.0
	'load_P_5193_2'	100.0
	'load_P_5195_1'	100.0
	'load_P_5196_1'	100.0
	'load_P_5197_1'	100.0
	'load_P_5198_1'	100.0
	'load_P_5199_2'	100.0
	'load_P_5200_1'	100.0
	'load_P_5200_2'	100.0
	'load_P_5201_3'	100.0
	'load_P_5201_4'	100.0
	'load_P_5202_1'	100.0
	'load_P_5202_2'	100.0
	'load_P_5203_3'	100.0
	'load_P_5203_4'	100.0
	'load_P_5204_1'	100.0
	'load_P_5205_2'	100.0
	'load_P_5206_1'	100.0
	'load_P_5207_2'	100.0
	'load_P_5208_3'	100.0
	'load_P_5209_4'	100.0
	'load_P_5210_1'	100.0
	'load_P_5210_2'	100.0
	'load_P_5211_1'	100.0
	'load_P_5211_2'	100.0
	'load_P_5212_1'	100.0
	'load_P_5212_2'	100.0
	'load_P_5213_1'	100.0
	'load_P_5213_2'	100.0
	'load_P_5214_1'	100.0
	'load_P_5214_2'	100.0
	'load_P_5215_1'	100.0
	'load_P_5215_2'	100.0
	'load_P_5215_3'	100.0
	'load_P_5215_4'	100.0
	'load_P_5216_1'	100.0
	'load_P_5216_2'	100.0
	'load_P_5217_1'	100.0
	'load_P_5217_2'	100.0
	'load_P_5218_1'	100.0
	'load_P_5218_2'	100.0
	'load_P_5220_1'	100.0
	'load_P_5220_2'	100.0
	'load_P_5221_1'	100.0
	'load_P_5221_2'	100.0
	'load_P_5222_1'	100.0
	'load_P_5237_1'	100.0
	'load_P_5237_2'	100.0
	'load_P_5237_3'	100.0
	'load_P_5238_4'	100.0
	'load_P_5238_4C'	100.0
	'load_P_5238_7'	100.0
	'load_P_5238_7C'	100.0
	'load_P_5238_8'	100.0
	'load_P_5238_8C'	100.0
	'load_P_5238_9'	100.0
	'load_P_5238_9C'	100.0
	'load_P_5240_1'	100.0
	'load_P_5241_7'	100.0
	'load_P_5241_7C'	100.0
	'load_P_1002_1'	100.0
	'load_P_1002_1'	100.0
	'load_P_1002_1'	100.0
	'load_P_1002_1'	100.0
	'load_P_1002_1'	100.0
	'load_P_1002_1'	100.0
};

%column_names% name 
mpc.shunt_data = {
	'fSH_1217_R1'
	'fSH_2000_R1'
	'fSH_2000_R2'
	'fSH_2000_R3'
	'fSH_2203_R1'
	'fSH_2203_R2'
	'fSH_2205_R1'
	'fSH_2205_R2'
	'fSH_2246_R1'
	'fSH_2247_R2'
	'fSH_3558_R3'
	'fSH_3561_R3'
	'fSH_3573_R1'
	'fSH_3573_R2'
	'fSH_3591_R1'
	'fSH_4356_R1'
	'fSH_4356_R2'
	'fSH_4359_R2'
	'fSH_4360_R1'
	'fSH_4372_R1'
	'fSH_4373_R1'
	'fSH_4400_R1'
	'fSH_4401_R2'
	'fSH_1209_C1'
	'fSH_1606_C1'
	'fSH_1606_C2'
	'fSH_1628_C2'
	'fSH_2000_C2'
	'fSH_2000_C3'
	'fSH_2005_C1'
	'fSH_2006_C2'
	'fSH_2082_C1'
	'fSH_2082_C2'
	'fSH_2082_C3'
	'fSH_2112_C1'
	'fSH_2168_C1'
	'fSH_2246_C1'
	'fSH_2247_C2'
	'fSH_2248_C1'
	'fSH_2348_C3'
	'fSH_2355_C1'
	'fSH_2355_C2'
	'fSH_2355_C3'
	'fSH_3007_C1'
	'fSH_3020_C1'
	'fSH_3029_C2'
	'fSH_3049_C2'
	'fSH_3193_C1'
	'fSH_3228_C2'
	'fSH_3303_C2'
	'fSH_3304_C1'
	'fSH_3320_C1'
	'fSH_3331_C2'
	'fSH_3331_C7'
	'fSH_3335_C6'
	'fSH_3336_14'
	'fSH_3339_C1'
	'fSH_3347_C2'
	'fSH_3351_C1'
	'fSH_3355_C2'
	'fSH_3361_C6'
	'fSH_3361_C7'
	'fSH_3365_C1'
	'fSH_3367_C3'
	'fSH_3388_C2'
	'fSH_3389_C5'
	'fSH_3396_C1'
	'fSH_3409_C3'
	'fSH_3410_C1'
	'fSH_3505_C1'
	'fSH_3521_C2'
	'fSH_3642_C2'
	'fSH_4001_C1'
	'fSH_4096_C4'
	'fSH_4131_C1'
	'fSH_4185_C1'
	'fSH_4260_C1'
	'fSH_4351_C1'
	'fSH_4363_C5'
	'fSH_4367_C3'
	'fSH_4367_C6'
	'fSH_4368_C2'
	'fSH_4368_C5'
	'fSH_4369_C1'
	'fSH_4369_C4'
	'fSH_4373_C1'
	'fSH_4395_C1'
	'fSH_4396_C2'
	'fSH_4397_C3'
	'fSH_4440_C1'
	'fSH_4498_C2'
	'fSH_4499_C3'
	'swSH_1015'
	'swSH_1016'
	'swSH_1021'
	'swSH_1054'
	'swSH_1055'
	'swSH_1056'
	'swSH_1062'
	'swSH_1083'
	'swSH_1107'
	'swSH_1109'
	'swSH_1116'
	'swSH_1141'
	'swSH_1155'
	'swSH_1161'
	'swSH_1167'
	'swSH_1169'
	'swSH_1222'
	'swSH_1411'
	'swSH_1436'
	'swSH_1511'
	'swSH_1525'
	'swSH_1541'
	'swSH_2072'
	'swSH_2074'
	'swSH_2075'
	'swSH_2078'
	'swSH_2079'
	'swSH_2080'
	'swSH_2081'
	'swSH_2191'
	'swSH_2313'
	'swSH_3061'
	'swSH_3063'
	'swSH_3065'
	'swSH_3162'
	'swSH_3169'
	'swSH_3292'
	'swSH_3427'
	'swSH_3446'
	'swSH_3517'
	'swSH_3558'
	'swSH_3561'
	'swSH_3569'
	'swSH_3584'
	'swSH_3596'
	'swSH_3597'
	'swSH_3650'
	'swSH_4004'
	'swSH_4107'
	'swSH_4124'
	'swSH_4147'
	'swSH_4149'
	'swSH_4151'
	'swSH_4476'
	'swSH_5046'
	'swSH_5047'
	'swSH_1033'
	'swSH_1048'
	'swSH_1093'
	'swSH_1144'
	'swSH_1146'
	'swSH_1149'
	'swSH_1159'
	'swSH_1164'
	'swSH_1165'
	'swSH_1166'
	'swSH_1168'
	'swSH_1184'
	'swSH_1185'
	'swSH_1186'
	'swSH_1189'
	'swSH_1190'
	'swSH_1191'
	'swSH_1198'
	'swSH_1199'
	'swSH_1205'
	'swSH_1214'
	'swSH_1221'
	'swSH_1565'
	'swSH_1568'
	'swSH_1586'
	'swSH_1591'
	'swSH_1606'
	'swSH_1622'
	'swSH_1623'
	'swSH_1625'
	'swSH_1626'
	'swSH_1633'
	'swSH_1651'
	'swSH_2123'
	'swSH_2146'
	'swSH_2154'
	'swSH_2163'
	'swSH_2164'
	'swSH_2182'
	'swSH_2220'
	'swSH_2231'
	'swSH_2232'
	'swSH_2241'
	'swSH_2243'
	'swSH_2273'
	'swSH_2279'
	'swSH_2280'
	'swSH_2284'
	'swSH_2289'
	'swSH_2290'
	'swSH_2291'
	'swSH_2315'
	'swSH_2345'
	'swSH_3054'
	'swSH_3070'
	'swSH_3075'
	'swSH_3087'
	'swSH_3096'
	'swSH_3098'
	'swSH_3149'
	'swSH_3150'
	'swSH_3152'
	'swSH_3159'
	'swSH_3172'
	'swSH_3216'
	'swSH_3259'
	'swSH_3271'
	'swSH_3471'
	'swSH_3473'
	'swSH_3477'
	'swSH_3479'
	'swSH_3491'
	'swSH_3496'
	'swSH_3503'
	'swSH_3504'
	'swSH_3519'
	'swSH_3543'
	'swSH_3545'
	'swSH_3549'
	'swSH_3560'
	'swSH_3589'
	'swSH_3598'
	'swSH_3633'
	'swSH_3636'
	'swSH_4014'
	'swSH_4015'
	'swSH_4016'
	'swSH_4017'
	'swSH_4025'
	'swSH_4217'
	'swSH_5000'
	'swSH_5001'
	'swSH_5048'
	'swSH_5061'
	'swSH_5063'
	'swSH_5070'
	'swSH_5092'
	'swSH_5153'
	'swSH_5171'
	'Dec11_L1_line_4129_to_4148_1'
	'Dec11_L2_line_4129_to_4148_1'
	'Dec14_L1_line_4123_to_4292_1'
	'Dec14_L2_line_4123_to_4292_1'
	'Dec15_L1_line_4226_to_4243_1'
	'Dec15_L2_line_4226_to_4243_1'
	'Dec16_L1_line_4226_to_4243_2'
	'Dec16_L2_line_4226_to_4243_2'
	'Dec17_L1_line_4226_to_4292_2'
	'Dec17_L2_line_4226_to_4292_2'
	'Dec18_L1_line_4226_to_4326_2'
	'Dec18_L2_line_4226_to_4326_2'
	'Dec19_L1_line_4226_to_4327_1'
	'Dec19_L2_line_4226_to_4327_1'
	'Dec20_L1_line_4233_to_4234_1'
	'Dec20_L2_line_4233_to_4234_1'
	'Dec21_L1_line_4233_to_4236_1'
	'Dec21_L2_line_4233_to_4236_1'
	'Dec22_L1_line_4275_to_4289_1'
	'Dec22_L2_line_4275_to_4289_1'
	'Dec23_L1_line_4276_to_4279_1'
	'Dec23_L2_line_4276_to_4279_1'
	'Dec24_L1_line_4276_to_4281_1'
	'Dec24_L2_line_4276_to_4281_1'
	'Dec25_L1_line_4277_to_4285_1'
	'Dec25_L2_line_4277_to_4285_1'
	'Dec26_L1_line_4285_to_4286_1'
	'Dec26_L2_line_4285_to_4286_1'
	'Dec27_L1_line_4297_to_4334_1'
	'Dec27_L2_line_4297_to_4334_1'
	'Dec2_L1_line_4112_to_4133_1'
	'Dec2_L2_line_4112_to_4133_1'
	'Dec3_L1_line_4112_to_4134_1'
	'Dec3_L2_line_4112_to_4134_1'
	'Dec5_L1_line_4124_to_4125_1'
	'Dec5_L2_line_4124_to_4125_1'
	'Dec6_L1_line_4124_to_4143_1'
	'Dec6_L2_line_4124_to_4143_1'
	'Dec7_L1_line_4125_to_4128_1'
	'Dec7_L2_line_4125_to_4128_1'
	'Dec8_L1_line_4128_to_4148_1'
	'Dec8_L2_line_4128_to_4148_1'
	'Dec10_C1_line_4129_to_4147_1'
	'Dec10_C2_line_4129_to_4147_1'
	'Dec12_C1_line_4135_to_4136_1'
	'Dec12_C2_line_4135_to_4136_1'
	'Dec13_C1_line_4135_to_4137_1'
	'Dec13_C2_line_4135_to_4137_1'
	'Dec1_C1_line_4112_to_4124_1'
	'Dec1_C2_line_4112_to_4124_1'
	'Dec4_C1_line_4112_to_4135_1'
	'Dec4_C2_line_4112_to_4135_1'
	'Dec9_C1_line_4129_to_4146_1'
	'Dec9_C2_line_4129_to_4146_1'
};


%% dc grid topology
%colunm_names% dcpoles
mpc.dcpol=2;
% numbers of poles (1=monopolar grid, 2=bipolar grid)
%% bus data
%column_names%   busdc_i grid    Pdc     Vdc     basekVdc    Vdcmax  Vdcmin  Cdc
mpc.busdc = {
    1              1       0       1       400         1.1     0.9     0;
    2              1       0       1       400         1.1     0.9     0;
	3              1       0       1        80         1.1     0.9     0;
	4              1       0       1        80         1.1     0.9     0;
	5              1       0       1       150         1.1     0.9     0;
	6              1       0       1       150         1.1     0.9     0;
};

%% converters
%column_names%   busdc_i busac_i type_dc type_ac  	P_g     			Q_g  				islcc  Vtar    rtf xtf  transformer tm   bf filter    rc      xc  reactor   basekVac    Vmmax   Vmmin   Imax    status   LossA LossB  LossCrec LossCinv  droop      Pdcset    Vdcset  dVdcset Pacmax Pacmin Qacmax Qacmin
mpc.convdc = {
					1       838   1       1      306.9329717183617    -26.945331173370217     0 1     0.00086  0.03   1 1 		0.01 0 0.0005   0.015 	 1  500         1.1     0.9      500.0     1       0.5517 3.031 0.0175    0.0      0.0050    -58.6274   1.0079   0 500 -500 500 -500;
					2      2250   2       1     -312.72784494029287   -34.65382633932923      0 1     0.00086  0.03   1 1 		0.01 0 0.0005   0.015 	 1  500         1.1     0.9      500.0     1       0.5517 3.031 0.0175 	  0.0      0.0070     21.9013   1.0000   0 500 -500 500 -500;
					3       211   1       1      78.78567579901096    -23.068019066753926     0 1     0.00238  0.0833 1 1 		0.01 0 0.00139  0.0416   1  110         1.1     0.9      180.0     1       0.1986 0.800 0.0034    0.0      0.0050    -58.6274   1.0079   0 180 -180 180 -180;
					4     	297   2       1     -80.30449311345579     25.585663148466196     0 1     0.00238  0.0833 1 1 		0.01 0 0.00139  0.0416   1  132         1.1     0.9      180.0     1       0.1986 0.800 0.0034    0.0      0.0050    -58.6274   1.0079   0 180 -180 180 -180;
					5       798   2       1      189.85812278904058   -0.012268930947322076   0 1     0.00194  0.0682 1 1 		0.01 0 0.00113  0.0341   1  220         1.1     0.9      220.0     1       0.1986 0.800 0.0034    0.0      0.0050    -58.6274   1.0079   0 220 -220 220 -220;
					6      	986   1       1     -194.81260090392405    134.00141272410838     0 1     0.00194  0.0682 1 1 		0.01 0 0.00113  0.0341   1  220         1.1     0.9      220.0     1       0.1986 0.800 0.0034    0.0      0.0050    -58.6274   1.0079   0 220 -220 220 -220;
};

%% branches
%column_names%   fbusdc  tbusdc  r      l        c   rateA   rateB   rateC   status
mpc.branchdc = {
    1       2       0.001   0   0    510     500     500    1;
	3       4       0.0061  0   0     60      60      60    1;
	3       4       0.0061  0   0     60      60      60    1;
	3       4       0.0061  0   0     60      60      60    1;
	5       6       0.005   0   0    220     220     220    1;
 };