%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   This is a synthetic power system network model that covers the geographic
%   footprint of three midwest states (Michigan, Ohio and Indiana). The case is
%   designed with a 765, 345, 138 and 69 kV transmission network to serve a
%   load that roughly mimics the actual population of its geographic footprint.
%   The synthetic transmission system was designed by algorithms described in
%   [1] to be statistically similar to actual transmission system models but
%   without modeling any actual lines.
%
%   One-line diagrams and other data formats available at:
%   https://github.com/WISPO-POP/SyntheticElectricNetworkModels
%   https://electricgrids.engr.tamu.edu
%
%   This synthetic dateset was developed as part of the ARPA-E GRID DATA
%   program as part of the EPIGRIDS project.
%
%   When publishing results based on this data, please cite:
%
%   [1] J. M. Snodgrass, "Tractable Algorithms for Constructing Electric Power Network Models,"
%      Ph.D. Thesis, The University of Wisconsin - Madison, 2021.
%
%   Copyright (c) 2022 by J. Snodgrass, S. Greene, B. Lesieutre, C. DeMarco
%   Licensed under the Creative Commons Attribution 4.0
%   International license, http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case10192_epigrids
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	20401	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20402	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20403	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20404	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20405	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20406	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20407	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20408	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20409	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20410	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20411	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20412	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20413	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20414	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20415	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20416	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20417	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20418	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20419	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20420	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20421	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20422	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20423	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20424	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20425	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20426	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20427	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20428	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20429	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20430	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20431	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20432	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20433	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20434	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20435	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20436	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20437	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20438	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20439	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20440	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20441	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20442	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20443	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20444	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20445	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20446	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20447	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20448	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20449	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20450	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20451	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20452	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20453	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20454	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20455	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20456	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20457	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20458	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20459	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20460	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20461	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20462	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20463	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20464	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20465	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20466	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20467	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20468	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20469	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20470	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20471	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20472	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20473	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20474	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20475	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20476	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20477	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20478	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20479	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20480	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20481	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20482	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20483	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20484	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20485	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20486	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20487	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20488	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20489	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20490	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20491	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20492	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20493	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20494	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20495	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20496	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20497	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20498	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20499	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20500	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20501	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20502	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20503	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20504	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20505	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20506	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20507	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20508	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20509	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20510	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20511	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20512	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20513	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20514	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20515	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20516	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20517	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20518	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20519	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20520	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20521	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20522	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20523	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20524	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20525	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20526	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20527	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20528	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20529	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20530	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20531	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20532	 3	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20533	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20534	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20535	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20536	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20537	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20538	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20539	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20540	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20541	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20542	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20543	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20544	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20545	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20546	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20547	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20548	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20549	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20550	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20551	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20552	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20553	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20554	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20555	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20556	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20557	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20558	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20559	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20560	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20561	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20562	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20563	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20564	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20565	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20566	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20567	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20568	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20569	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20570	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20571	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20572	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20573	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20574	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20575	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20576	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20577	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20578	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20579	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20580	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20581	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20582	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20583	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20584	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20585	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20586	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20587	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20588	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20589	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20590	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20591	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20592	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20593	 1	 17.18	 4.25	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20594	 1	 84.89	 19.91	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20595	 1	 19.98	 4.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20596	 1	 5.39	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20597	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20598	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20599	 1	 19.49	 5.38	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20600	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20601	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20602	 1	 4.89	 1.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20603	 1	 5.09	 1.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20604	 1	 3.57	 0.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20605	 1	 7.14	 1.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20606	 1	 15.48	 3.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20607	 1	 19.62	 4.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20608	 1	 7.68	 1.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20609	 1	 8.59	 1.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20610	 1	 2.79	 0.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20611	 1	 9.27	 2.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20612	 1	 5.97	 1.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20613	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20614	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20615	 1	 6.11	 1.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20616	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20617	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20618	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20619	 1	 3.98	 0.89	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20620	 1	 4.78	 1.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20621	 1	 2.61	 0.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20622	 1	 2.99	 0.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20623	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20624	 1	 13.06	 2.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20625	 1	 8.16	 1.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20626	 1	 3.53	 0.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20627	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20628	 1	 5.5	 1.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20629	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20630	 1	 11.56	 2.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20631	 1	 12.48	 2.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20632	 1	 32.68	 7.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20633	 1	 6.7	 1.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20634	 1	 3.09	 0.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20635	 1	 3.93	 0.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20636	 1	 3.67	 0.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20637	 1	 6.78	 1.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20638	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20639	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20640	 1	 9.07	 2.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20641	 1	 8.81	 1.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20642	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20643	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20644	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20645	 1	 10.64	 2.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20646	 1	 6.7	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20647	 1	 8.39	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20648	 1	 5.91	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20649	 1	 3.46	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20650	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20651	 1	 19.07	 4.32	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20652	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20653	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20654	 1	 6.62	 1.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20655	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20656	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20657	 1	 10.16	 2.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20658	 1	 6.87	 1.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20659	 1	 5.83	 1.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20660	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20661	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20662	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20663	 1	 5.24	 1.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20664	 1	 11.57	 2.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20665	 1	 5.67	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20666	 1	 6.77	 1.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20667	 1	 5.94	 1.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20668	 1	 6.37	 1.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20669	 1	 9.89	 2.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20670	 1	 28.34	 8.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20671	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20672	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20673	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20674	 1	 7.18	 1.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20675	 1	 3.91	 0.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20676	 1	 4.17	 0.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20677	 1	 8.23	 1.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20678	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20679	 1	 6.97	 1.61	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20680	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20681	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20682	 1	 7.83	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20683	 1	 5.99	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20684	 1	 7.21	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20685	 1	 7.77	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20686	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20687	 1	 8.5	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20688	 1	 10.41	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20689	 1	 24.73	 5.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20690	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20691	 1	 7.2	 1.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20692	 1	 2.87	 1.25	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20693	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20694	 1	 3.03	 0.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20695	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20696	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20697	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20698	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20699	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20700	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20701	 1	 6.63	 2.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20702	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20703	 1	 31.28	 9.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20704	 1	 11.03	 4.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20705	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20706	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20707	 1	 9.32	 3.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20708	 1	 13.24	 5.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20709	 1	 5.27	 2.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20710	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20711	 1	 7.78	 3.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20712	 1	 12.91	 4.31	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20713	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20714	 1	 23.36	 7.42	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20715	 1	 10.48	 2.92	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20716	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20717	 1	 35.21	 7.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20718	 1	 5.54	 2.18	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20719	 1	 12.29	 3.46	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20720	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20721	 1	 17.13	 3.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20722	 1	 24.23	 5.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20723	 1	 19.21	 6.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20724	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20725	 1	 6.3	 2.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20726	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20727	 1	 15.58	 4.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20728	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20729	 1	 4.54	 1.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20730	 1	 6.91	 3.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20731	 1	 9.62	 3.69	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20732	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20733	 1	 3.55	 1.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20734	 1	 5.26	 2.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20735	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20736	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20737	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20738	 1	 4.21	 1.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20739	 1	 7.24	 2.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20740	 1	 16.02	 4.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20741	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20742	 1	 15.16	 3.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20743	 1	 13.7	 3.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20744	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20745	 1	 6.53	 2.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20746	 1	 11.58	 4.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20747	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20748	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20749	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20750	 1	 21.73	 4.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20751	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20752	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20753	 1	 6.46	 2.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20754	 1	 3.55	 1.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20755	 1	 27.76	 7.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20756	 1	 22.79	 6.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20757	 1	 5.05	 1.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20758	 1	 6.13	 2.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20759	 1	 2.07	 0.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20760	 1	 10.44	 4.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20761	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20762	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20763	 1	 7.59	 3.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20764	 1	 9.94	 3.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20765	 1	 9.53	 2.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20766	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20767	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20768	 1	 14.82	 4.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20769	 1	 34.09	 12.17	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20770	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20771	 1	 5.62	 2.69	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20772	 1	 10.44	 3.36	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20773	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20774	 1	 7.26	 3.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20775	 1	 7.08	 3.12	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20776	 1	 27.17	 6.35	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20777	 1	 22.6	 8.19	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20778	 1	 15.92	 5.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20779	 1	 6.36	 3.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20780	 1	 10.0	 3.51	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20781	 1	 7.63	 2.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20782	 1	 6.91	 2.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20783	 1	 17.9	 7.44	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20784	 1	 9.16	 3.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20785	 1	 73.08	 16.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20786	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20787	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20788	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20789	 1	 14.84	 3.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20790	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20791	 1	 6.74	 2.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20792	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20793	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20794	 1	 3.73	 1.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20795	 1	 19.88	 7.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20796	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20797	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20798	 1	 7.19	 2.6	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20799	 1	 5.7	 2.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20800	 1	 3.69	 1.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20801	 1	 9.51	 3.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20802	 1	 5.59	 2.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20803	 1	 2.96	 1.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20804	 1	 14.16	 4.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20805	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20806	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20807	 1	 19.06	 4.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20808	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20809	 1	 8.0	 3.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20810	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20811	 1	 5.05	 2.05	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20812	 1	 79.27	 18.43	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20813	 1	 4.08	 1.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20814	 1	 18.18	 6.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20815	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20816	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20817	 1	 21.27	 4.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20818	 1	 77.71	 17.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20819	 1	 11.72	 2.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20820	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20821	 1	 8.32	 1.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20822	 1	 65.2	 14.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20823	 1	 12.93	 2.86	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20824	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20825	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20826	 1	 8.93	 2.46	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20827	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20828	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20829	 1	 4.77	 2.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20830	 1	 9.43	 3.8	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20831	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20832	 1	 8.38	 2.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20833	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20834	 1	 7.9	 2.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20835	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20836	 1	 4.38	 1.96	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20837	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20838	 1	 6.58	 1.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20839	 1	 16.81	 3.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20840	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20841	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20842	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20843	 1	 6.77	 1.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20844	 1	 11.17	 3.93	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20845	 1	 8.6	 1.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20846	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20847	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20848	 1	 13.48	 4.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20849	 1	 7.65	 2.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20850	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20851	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20852	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20853	 1	 10.46	 3.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20854	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20855	 1	 37.12	 7.51	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20856	 1	 45.1	 10.51	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20857	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20858	 1	 22.88	 6.61	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20859	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20860	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20861	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20862	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20863	 1	 19.97	 4.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20864	 1	 43.69	 10.17	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20865	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20866	 1	 13.64	 3.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20867	 1	 9.78	 2.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20868	 1	 10.31	 2.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20869	 1	 30.15	 6.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20870	 1	 65.4	 14.78	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20871	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20872	 1	 106.12	 23.8	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20873	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20874	 1	 48.65	 10.96	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20875	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20876	 1	 29.17	 6.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20877	 1	 38.17	 11.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20878	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20879	 1	 66.53	 16.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20880	 1	 31.08	 8.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20881	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20882	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20883	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20884	 1	 26.01	 7.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20885	 1	 50.63	 13.76	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20886	 1	 32.54	 7.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20887	 1	 86.56	 20.12	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20888	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20889	 1	 15.18	 5.63	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20890	 1	 7.27	 1.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20891	 1	 7.12	 3.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20892	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20893	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20894	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20895	 1	 6.81	 1.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20896	 1	 13.55	 3.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20897	 1	 22.8	 7.36	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20898	 1	 4.85	 2.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20899	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20900	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20901	 1	 5.71	 2.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20902	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20903	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20904	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20905	 1	 16.61	 4.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20906	 1	 4.22	 1.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20907	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20908	 1	 7.32	 3.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20909	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20910	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20911	 1	 11.19	 3.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20912	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20913	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20914	 1	 14.78	 5.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20915	 1	 17.25	 4.44	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20916	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20917	 1	 5.54	 2.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20918	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20919	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20920	 1	 71.15	 16.95	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20921	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20922	 1	 6.32	 2.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20923	 1	 5.86	 2.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20924	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20925	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20926	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20927	 1	 5.76	 2.81	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20928	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20929	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20930	 1	 8.06	 1.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20931	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20932	 1	 6.39	 2.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20933	 1	 14.21	 3.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20934	 1	 6.18	 2.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20935	 1	 18.82	 4.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20936	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20937	 1	 20.3	 4.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20938	 1	 8.86	 2.88	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20939	 1	 8.8	 3.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20940	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20941	 1	 8.92	 3.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20942	 1	 17.28	 7.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20943	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20944	 1	 5.99	 2.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20945	 1	 13.8	 4.62	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20946	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20947	 1	 15.69	 4.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20948	 1	 21.09	 4.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20949	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20950	 1	 13.04	 3.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20951	 1	 8.05	 1.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20952	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20953	 1	 12.55	 2.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20954	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20955	 1	 13.29	 3.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20956	 1	 32.41	 7.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20957	 1	 12.71	 2.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20958	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20959	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20960	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20961	 1	 15.6	 4.88	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20962	 1	 15.7	 3.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20963	 1	 16.01	 3.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20964	 1	 8.76	 3.17	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20965	 1	 8.61	 3.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20966	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20967	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20968	 1	 7.67	 3.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20969	 1	 5.45	 2.34	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20970	 1	 2.8	 1.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20971	 1	 23.05	 6.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20972	 1	 7.64	 2.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20973	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20974	 1	 14.61	 6.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20975	 1	 10.87	 4.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20976	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20977	 1	 7.39	 3.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20978	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20979	 1	 6.46	 2.54	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20980	 1	 8.7	 4.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20981	 1	 33.57	 11.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20982	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20983	 1	 26.74	 10.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20984	 1	 7.66	 3.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20985	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20986	 1	 6.38	 2.89	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20987	 1	 11.63	 4.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20988	 1	 37.79	 11.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20989	 1	 19.35	 7.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20990	 1	 11.76	 4.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20991	 1	 18.75	 6.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20992	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20993	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20994	 1	 25.81	 9.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20995	 1	 17.5	 7.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20996	 1	 7.09	 3.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	20997	 1	 9.0	 3.89	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20998	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20999	 1	 7.11	 2.58	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21000	 1	 7.42	 2.94	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21001	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21002	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21003	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21004	 1	 17.85	 7.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21005	 1	 6.5	 3.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21006	 1	 3.7	 1.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21007	 1	 5.91	 2.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21008	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21009	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21010	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21011	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21012	 1	 7.8	 3.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21013	 1	 27.31	 8.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21014	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21015	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21016	 1	 7.61	 1.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21017	 1	 12.37	 4.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21018	 1	 19.57	 4.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21019	 1	 15.23	 6.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21020	 1	 19.0	 4.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21021	 1	 8.55	 1.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21022	 1	 9.12	 4.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21023	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21024	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21025	 1	 31.32	 8.25	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21026	 1	 8.53	 4.1	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21027	 1	 10.89	 4.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21028	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21029	 1	 19.11	 6.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21030	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	21031	 1	 11.3	 4.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21032	 1	 16.56	 6.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21033	 1	 27.1	 8.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21034	 1	 8.68	 3.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21035	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21036	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21037	 1	 16.84	 7.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21038	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21039	 1	 12.49	 4.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21040	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21041	 1	 86.66	 22.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21042	 1	 15.34	 5.34	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21043	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21044	 1	 4.09	 1.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21045	 1	 12.08	 4.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21046	 1	 13.97	 5.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21047	 1	 11.4	 4.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21048	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21049	 1	 7.82	 1.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21050	 1	 7.69	 1.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21051	 1	 13.58	 4.53	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21052	 1	 9.75	 3.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21053	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21054	 1	 8.61	 1.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21055	 1	 11.07	 2.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21056	 1	 3.21	 0.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21057	 1	 7.42	 1.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21058	 1	 11.29	 2.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21059	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21060	 1	 7.9	 1.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21061	 1	 10.58	 3.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21062	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21063	 1	 10.27	 3.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21064	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21065	 1	 6.57	 2.77	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21066	 1	 3.8	 1.53	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21067	 1	 11.45	 4.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21068	 1	 31.19	 5.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21069	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21070	 1	 3.47	 1.21	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21071	 1	 11.5	 4.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21072	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21073	 1	 7.28	 3.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21074	 1	 22.81	 5.23	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21075	 1	 4.78	 2.05	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21076	 1	 9.85	 4.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21077	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21078	 1	 11.12	 4.03	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21079	 1	 4.8	 2.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21080	 1	 6.69	 2.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21081	 1	 9.32	 4.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21082	 1	 7.75	 1.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21083	 1	 24.37	 5.63	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21084	 1	 14.49	 3.34	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21085	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21086	 1	 87.79	 20.23	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21087	 1	 16.63	 3.85	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21088	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21089	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21090	 1	 10.52	 2.46	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21091	 1	 76.11	 21.48	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21092	 1	 59.56	 14.63	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21093	 1	 5.94	 2.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21094	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21095	 1	 19.91	 5.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21096	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21097	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21098	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21099	 1	 14.78	 5.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21100	 1	 17.4	 5.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21101	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21102	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21103	 1	 5.72	 2.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21104	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21105	 1	 9.63	 3.86	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21106	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21107	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21108	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21109	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21110	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21111	 1	 4.16	 0.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21112	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21113	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21114	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21115	 1	 26.93	 6.88	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21116	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21117	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21118	 1	 11.41	 4.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21119	 1	 10.93	 4.17	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21120	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21121	 1	 26.94	 7.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21122	 1	 3.97	 1.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21123	 1	 23.84	 8.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21124	 1	 4.96	 2.21	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21125	 1	 14.86	 3.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21126	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21127	 1	 12.41	 4.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21128	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21129	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21130	 1	 15.39	 4.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21131	 1	 12.9	 6.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21132	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21133	 1	 10.33	 4.29	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21134	 1	 7.08	 2.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21135	 1	 6.02	 2.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21136	 1	 12.84	 5.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21137	 1	 8.35	 3.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21138	 1	 13.91	 5.53	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21139	 1	 12.91	 4.91	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21140	 1	 9.05	 3.6	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21141	 1	 14.99	 5.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21142	 1	 12.83	 4.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21143	 1	 12.39	 4.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21144	 1	 68.34	 13.19	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21145	 1	 9.85	 4.03	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21146	 1	 17.74	 6.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21147	 1	 8.3	 2.26	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21148	 1	 20.69	 5.97	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21149	 1	 18.3	 5.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21150	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21151	 1	 4.2	 2.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21152	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21153	 1	 12.89	 5.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21154	 1	 17.2	 4.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21155	 1	 5.25	 2.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21156	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21157	 1	 7.81	 3.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21158	 1	 8.53	 3.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21159	 1	 7.65	 2.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21160	 1	 28.36	 8.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21161	 1	 4.3	 0.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21162	 1	 69.13	 15.58	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21163	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21164	 1	 30.79	 -4.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21165	 1	 15.7	 -4.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21166	 1	 9.04	 2.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21167	 1	 3.25	 0.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21168	 1	 1.97	 0.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21169	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21170	 1	 105.66	 24.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21171	 1	 11.76	 2.69	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21172	 1	 0.0	 0.0	 0.0	 60.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21173	 1	 64.88	 14.78	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21174	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21175	 1	 6.79	 1.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21176	 1	 12.54	 2.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21177	 1	 21.91	 5.11	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21178	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21179	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21180	 1	 19.19	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21181	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21182	 1	 18.9	 4.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21183	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21184	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21185	 1	 7.29	 1.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21186	 1	 8.26	 1.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21187	 1	 4.68	 1.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21188	 1	 5.72	 2.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21189	 1	 12.67	 4.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21190	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21191	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21192	 1	 23.75	 9.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21193	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21194	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21195	 1	 1.21	 0.51	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21196	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21197	 1	 4.2	 1.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21198	 1	 2.95	 1.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21199	 1	 5.81	 2.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21200	 1	 7.19	 2.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21201	 1	 2.64	 1.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21202	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21203	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21204	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21205	 1	 2.68	 1.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21206	 1	 1.88	 0.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21207	 1	 3.44	 1.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21208	 1	 1.33	 0.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21209	 1	 1.19	 0.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21210	 1	 2.39	 1.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21211	 1	 5.75	 2.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21212	 1	 6.89	 2.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21213	 1	 7.06	 2.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21214	 1	 4.52	 1.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21215	 1	 4.44	 1.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21216	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21217	 1	 6.0	 2.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21218	 1	 67.56	 13.26	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21219	 1	 162.63	 42.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21220	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21221	 1	 5.04	 2.24	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21222	 1	 4.22	 1.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21223	 1	 10.33	 4.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21224	 1	 57.1	 15.6	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21225	 1	 79.58	 24.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21226	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21227	 1	 8.94	 3.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21228	 1	 4.86	 2.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21229	 1	 12.83	 5.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21230	 1	 2.89	 1.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21231	 1	 4.88	 1.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21232	 1	 6.76	 2.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21233	 1	 6.31	 2.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21234	 1	 7.1	 2.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21235	 1	 7.79	 3.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21236	 1	 1.84	 0.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21237	 1	 2.36	 0.88	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21238	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21239	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21240	 1	 20.08	 6.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21241	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21242	 1	 64.51	 19.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21243	 1	 10.32	 3.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21244	 1	 18.33	 6.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21245	 1	 2.25	 1.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21246	 1	 45.72	 8.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21247	 1	 5.55	 2.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21248	 1	 25.55	 8.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21249	 1	 22.45	 7.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21250	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21251	 1	 7.54	 3.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21252	 1	 6.22	 2.64	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21253	 1	 10.63	 4.28	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21254	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21255	 1	 6.36	 2.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21256	 1	 12.03	 5.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21257	 1	 6.31	 2.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21258	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21259	 1	 20.12	 6.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21260	 1	 5.9	 2.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21261	 1	 7.4	 2.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21262	 1	 7.78	 2.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21263	 1	 7.06	 2.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21264	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21265	 1	 2.09	 0.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21266	 1	 8.05	 3.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21267	 1	 5.85	 2.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21268	 1	 15.68	 6.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21269	 1	 12.18	 4.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21270	 1	 17.6	 6.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21271	 1	 10.29	 3.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21272	 1	 9.7	 3.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21273	 1	 44.46	 10.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21274	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21275	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21276	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21277	 1	 9.5	 4.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21278	 1	 8.05	 3.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21279	 1	 12.57	 4.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21280	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21281	 1	 12.5	 4.52	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21282	 1	 10.13	 3.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21283	 1	 4.24	 1.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21284	 1	 9.23	 4.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21285	 1	 6.95	 2.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21286	 1	 12.86	 5.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21287	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21288	 1	 12.2	 4.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21289	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21290	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21291	 1	 13.88	 4.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21292	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21293	 1	 22.47	 7.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21294	 1	 10.95	 4.36	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21295	 1	 19.68	 7.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21296	 1	 3.63	 1.77	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21297	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21298	 1	 4.33	 2.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21299	 1	 10.72	 4.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21300	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21301	 1	 20.14	 5.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21302	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21303	 1	 3.2	 1.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21304	 1	 19.9	 4.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21305	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21306	 1	 8.51	 2.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21307	 1	 10.43	 4.61	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21308	 1	 4.34	 1.71	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21309	 1	 21.43	 6.51	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21310	 1	 1.94	 0.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21311	 1	 3.78	 1.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21312	 1	 29.97	 7.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21313	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21314	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21315	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21316	 1	 16.18	 5.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21317	 1	 17.82	 6.16	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21318	 1	 12.44	 4.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21319	 1	 9.75	 4.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21320	 1	 17.94	 7.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21321	 1	 16.41	 6.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21322	 1	 37.3	 8.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21323	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21324	 1	 4.06	 1.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21325	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21326	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21327	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21328	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21329	 1	 56.8	 13.86	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21330	 1	 10.97	 4.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21331	 1	 10.61	 3.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21332	 1	 55.03	 12.78	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21333	 1	 5.06	 2.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21334	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21335	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21336	 1	 8.97	 3.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21337	 1	 6.68	 2.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21338	 1	 12.83	 3.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21339	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21340	 1	 9.61	 3.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21341	 1	 23.57	 7.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21342	 1	 12.22	 4.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21343	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21344	 1	 2.86	 1.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21345	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21346	 1	 3.66	 1.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21347	 1	 3.48	 1.41	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21348	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21349	 1	 9.83	 4.01	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21350	 1	 3.7	 1.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21351	 1	 8.16	 3.35	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21352	 1	 14.57	 5.1	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21353	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21354	 1	 3.33	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21355	 1	 7.65	 3.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21356	 1	 15.96	 5.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21357	 1	 9.38	 4.34	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21358	 1	 14.26	 3.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21359	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21360	 1	 14.59	 4.93	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21361	 1	 9.25	 2.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21362	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21363	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21364	 1	 14.9	 5.29	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21365	 1	 4.08	 1.52	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21366	 1	 8.51	 2.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21367	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21368	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21369	 1	 23.61	 6.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21370	 1	 8.44	 3.94	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21371	 1	 3.62	 1.57	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21372	 1	 6.98	 2.76	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21373	 1	 22.98	 7.59	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21374	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21375	 1	 15.54	 5.32	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21376	 1	 5.72	 2.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21377	 1	 10.25	 4.53	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21378	 1	 4.44	 1.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21379	 1	 10.14	 2.96	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21380	 1	 11.78	 5.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21381	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	21382	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21383	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21384	 1	 4.11	 1.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21385	 1	 3.64	 1.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21386	 1	 6.13	 2.35	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21387	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21388	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21389	 1	 59.99	 14.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21390	 1	 12.94	 5.41	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21391	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21392	 1	 22.61	 6.63	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21393	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21394	 1	 5.61	 2.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21395	 1	 8.67	 3.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21396	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21397	 1	 6.29	 2.58	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21398	 1	 4.37	 1.76	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21399	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21400	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21401	 1	 6.44	 2.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21402	 1	 5.47	 2.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21403	 1	 3.8	 1.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21404	 1	 13.63	 5.64	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21405	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21406	 1	 4.76	 1.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21407	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21408	 1	 17.15	 4.93	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21409	 1	 6.24	 2.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21410	 1	 3.27	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21411	 1	 4.13	 1.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21412	 1	 3.73	 1.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21413	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21414	 1	 5.52	 2.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21415	 1	 6.18	 2.91	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21416	 1	 6.91	 2.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21417	 1	 5.58	 2.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21418	 1	 5.13	 2.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21419	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21420	 1	 2.97	 1.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21421	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21422	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21423	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21424	 1	 5.31	 2.31	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21425	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21426	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21427	 1	 3.26	 1.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21428	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21429	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21430	 1	 4.56	 1.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21431	 1	 1.96	 0.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21432	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21433	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21434	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21435	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21436	 1	 9.53	 3.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21437	 1	 8.16	 3.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21438	 1	 6.26	 2.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21439	 1	 11.34	 3.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21440	 1	 16.46	 5.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21441	 1	 7.08	 3.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21442	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21443	 1	 6.37	 2.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21444	 1	 5.05	 2.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21445	 1	 15.25	 5.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21446	 1	 8.94	 3.19	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21447	 1	 9.32	 3.86	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21448	 1	 8.28	 3.41	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21449	 1	 11.66	 4.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21450	 1	 5.12	 2.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21451	 1	 4.43	 1.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21452	 1	 10.43	 4.26	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21453	 1	 5.06	 1.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21454	 1	 7.59	 3.03	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21455	 1	 6.18	 2.52	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21456	 1	 12.3	 3.95	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21457	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21458	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21459	 1	 1.74	 0.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21460	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21461	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21462	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21463	 1	 7.54	 3.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21464	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21465	 1	 4.55	 2.2	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21466	 1	 5.99	 2.35	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21467	 1	 4.84	 1.93	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21468	 1	 6.21	 2.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21469	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21470	 1	 10.83	 4.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21471	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21472	 1	 3.03	 1.16	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21473	 1	 6.4	 2.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21474	 1	 8.37	 3.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21475	 1	 110.0	 30.35	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21476	 1	 6.19	 2.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21477	 1	 2.72	 1.17	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21478	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21479	 1	 14.88	 5.63	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21480	 1	 7.31	 2.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21481	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21482	 1	 4.62	 1.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21483	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	21484	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21485	 1	 64.17	 18.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21486	 1	 20.68	 7.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21487	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	21488	 1	 11.99	 3.91	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21489	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21490	 1	 5.27	 2.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21491	 1	 3.84	 1.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21492	 1	 4.63	 1.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21493	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21494	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21495	 1	 1.88	 0.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21496	 1	 3.24	 1.12	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21497	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21498	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21499	 1	 4.55	 1.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21500	 1	 2.36	 1.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21501	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21502	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21503	 1	 4.87	 1.61	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21504	 1	 5.03	 1.86	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21505	 1	 16.34	 4.64	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21506	 1	 4.25	 1.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21507	 1	 5.42	 1.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21508	 1	 9.78	 2.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21509	 1	 22.27	 4.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21510	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21511	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21512	 1	 10.91	 3.04	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21513	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21514	 1	 9.58	 3.78	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21515	 1	 6.29	 2.27	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21516	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21517	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21518	 1	 2.03	 0.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21519	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21520	 1	 3.6	 1.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21521	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21522	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21523	 1	 3.68	 1.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21524	 1	 19.83	 4.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21525	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21526	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21527	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21528	 1	 13.15	 3.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21529	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21530	 1	 3.57	 1.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21531	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21532	 1	 9.57	 3.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21533	 1	 11.44	 3.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21534	 1	 9.77	 2.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21535	 1	 13.52	 3.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21536	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21537	 1	 8.93	 4.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21538	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21539	 1	 13.35	 4.31	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21540	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21541	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21542	 1	 17.47	 4.51	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21543	 1	 15.39	 5.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21544	 1	 22.21	 6.46	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21545	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21546	 1	 25.66	 7.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21547	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21548	 1	 9.52	 3.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21549	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21550	 1	 9.49	 3.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21551	 1	 7.52	 3.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21552	 1	 12.5	 4.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21553	 1	 10.79	 4.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21554	 1	 12.83	 4.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21555	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21556	 1	 3.71	 1.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21557	 1	 15.21	 3.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21558	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21559	 1	 2.65	 1.24	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21560	 1	 7.62	 2.82	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21561	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21562	 1	 23.01	 7.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21563	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21564	 1	 13.64	 4.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21565	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21566	 1	 23.31	 7.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21567	 1	 12.95	 5.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21568	 1	 10.99	 4.38	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21569	 1	 57.77	 20.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21570	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21571	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21572	 1	 8.01	 3.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21573	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21574	 1	 7.18	 3.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21575	 1	 3.18	 1.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21576	 1	 5.35	 2.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21577	 1	 13.74	 5.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21578	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21579	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21580	 1	 6.32	 2.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21581	 1	 13.43	 4.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21582	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21583	 1	 5.18	 1.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21584	 1	 6.74	 3.21	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21585	 1	 9.89	 3.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21586	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21587	 1	 5.88	 2.04	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21588	 1	 10.49	 3.52	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21589	 1	 9.62	 4.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21590	 1	 12.27	 4.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21591	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21592	 1	 7.73	 3.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21593	 1	 7.6	 3.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21594	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21595	 1	 12.43	 4.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21596	 1	 9.64	 3.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21597	 1	 22.01	 8.19	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21598	 1	 3.06	 1.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21599	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21600	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21601	 1	 55.12	 15.2	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21602	 1	 3.88	 1.62	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21603	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21604	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21605	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21606	 1	 12.16	 2.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21607	 1	 3.84	 1.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21608	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21609	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21610	 1	 5.55	 1.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21611	 1	 117.14	 27.75	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21612	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21613	 1	 6.81	 1.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21614	 1	 18.61	 -7.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21615	 1	 14.26	 3.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21616	 1	 55.91	 18.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21617	 1	 7.62	 2.79	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21618	 1	 22.15	 5.11	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21619	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21620	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21621	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21622	 1	 12.17	 4.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21623	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21624	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21625	 1	 10.0	 3.95	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21626	 1	 19.33	 5.71	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21627	 1	 3.82	 1.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21628	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21629	 1	 8.57	 3.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21630	 1	 8.75	 3.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21631	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21632	 1	 9.72	 3.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21633	 1	 9.45	 3.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21634	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21635	 1	 10.5	 3.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21636	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21637	 1	 4.0	 1.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21638	 1	 7.71	 2.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21639	 1	 5.5	 1.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21640	 1	 5.49	 1.88	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21641	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21642	 1	 5.91	 2.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21643	 1	 9.37	 3.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21644	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21645	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21646	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21647	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21648	 1	 6.27	 2.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21649	 1	 5.34	 1.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21650	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21651	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21652	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21653	 1	 5.26	 2.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21654	 1	 4.2	 1.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21655	 1	 6.94	 2.27	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21656	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21657	 1	 8.16	 3.51	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21658	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21659	 1	 8.92	 3.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21660	 1	 4.22	 1.96	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21661	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21662	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21663	 1	 36.87	 10.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21664	 1	 72.05	 14.99	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21665	 1	 8.02	 3.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21666	 1	 6.87	 3.25	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21667	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21668	 1	 18.57	 4.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21669	 1	 13.54	 5.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21670	 1	 5.66	 2.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21671	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21672	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21673	 1	 7.71	 3.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21674	 1	 6.98	 3.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21675	 1	 7.59	 2.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21676	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21677	 1	 7.68	 2.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21678	 1	 11.76	 4.11	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21679	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21680	 1	 6.85	 3.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21681	 1	 12.83	 5.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21682	 1	 8.92	 4.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21683	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21684	 1	 7.94	 3.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21685	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21686	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21687	 1	 7.88	 1.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21688	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21689	 1	 9.8	 2.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21690	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21691	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21692	 1	 9.72	 2.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21693	 1	 29.93	 6.77	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21694	 1	 23.44	 5.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21695	 1	 6.61	 1.49	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21696	 1	 3.81	 1.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21697	 1	 4.76	 1.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21698	 1	 16.26	 5.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21699	 1	 8.3	 3.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21700	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21701	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21702	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21703	 1	 4.91	 2.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21704	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21705	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21706	 1	 8.66	 3.26	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21707	 1	 12.5	 4.54	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21708	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21709	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21710	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21711	 1	 9.46	 3.93	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21712	 1	 10.06	 4.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21713	 1	 9.97	 3.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21714	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21715	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21716	 1	 18.5	 6.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21717	 1	 14.76	 2.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21718	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21719	 1	 6.24	 2.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21720	 1	 10.66	 4.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21721	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21722	 1	 16.43	 7.52	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21723	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21724	 1	 8.16	 3.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21725	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21726	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21727	 1	 11.9	 4.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21728	 1	 1.4	 0.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21729	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21730	 1	 9.96	 3.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21731	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21732	 1	 3.12	 1.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21733	 1	 14.52	 6.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21734	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21735	 1	 8.77	 3.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21736	 1	 10.17	 4.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21737	 1	 5.61	 2.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21738	 1	 5.13	 2.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21739	 1	 17.15	 7.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21740	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21741	 1	 4.31	 1.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21742	 1	 6.1	 2.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21743	 1	 21.91	 5.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21744	 1	 11.59	 3.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21745	 1	 96.06	 18.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21746	 1	 5.87	 1.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21747	 1	 18.99	 4.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21748	 1	 10.41	 3.99	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21749	 1	 3.34	 1.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21750	 1	 9.7	 4.31	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21751	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21752	 1	 148.69	 41.62	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21753	 1	 77.73	 11.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21754	 1	 16.91	 6.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21755	 1	 4.33	 1.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21756	 1	 3.41	 1.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21757	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21758	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21759	 1	 66.79	 22.11	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21760	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21761	 1	 4.35	 1.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21762	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21763	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21764	 1	 6.32	 2.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21765	 1	 13.04	 5.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21766	 1	 4.15	 1.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21767	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21768	 1	 32.41	 10.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21769	 1	 14.27	 5.8	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21770	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21771	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21772	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21773	 1	 6.76	 1.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21774	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21775	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21776	 1	 8.89	 2.04	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21777	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21778	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21779	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21780	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21781	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21782	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21783	 1	 11.34	 3.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21784	 1	 10.06	 3.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21785	 1	 7.84	 3.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21786	 1	 7.89	 2.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21787	 1	 21.37	 4.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21788	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21789	 1	 21.34	 5.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21790	 1	 9.45	 3.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21791	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21792	 1	 7.41	 1.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21793	 1	 6.64	 1.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21794	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21795	 1	 3.39	 0.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21796	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21797	 1	 3.17	 0.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21798	 1	 11.02	 2.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21799	 1	 2.12	 0.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21800	 1	 6.86	 1.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21801	 1	 4.5	 1.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21802	 1	 7.42	 1.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21803	 1	 2.76	 0.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21804	 1	 3.11	 0.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21805	 1	 4.78	 1.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21806	 1	 7.46	 1.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21807	 1	 3.76	 0.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21808	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21809	 1	 1.41	 0.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21810	 1	 4.5	 1.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21811	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21812	 1	 23.36	 7.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21813	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21814	 1	 6.74	 2.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21815	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21816	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21817	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21818	 1	 32.04	 9.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21819	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21820	 1	 2.68	 0.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21821	 1	 5.45	 1.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21822	 1	 8.15	 1.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21823	 1	 3.75	 0.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21824	 1	 60.4	 18.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21825	 1	 4.92	 1.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21826	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21827	 1	 19.2	 6.81	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21828	 1	 40.6	 11.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21829	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21830	 1	 4.79	 1.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21831	 1	 5.78	 1.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21832	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21833	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21834	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21835	 1	 79.53	 25.78	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21836	 1	 10.35	 3.38	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21837	 1	 1.84	 0.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21838	 1	 25.77	 5.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21839	 1	 12.28	 2.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21840	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21841	 1	 10.17	 2.35	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21842	 1	 3.07	 0.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21843	 1	 5.55	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21844	 1	 6.37	 1.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21845	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21846	 1	 8.98	 3.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21847	 1	 5.83	 2.23	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21848	 1	 35.43	 10.1	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21849	 1	 13.12	 2.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21850	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21851	 1	 16.96	 3.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21852	 1	 13.1	 2.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21853	 1	 11.53	 2.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21854	 1	 10.82	 2.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21855	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21856	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21857	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21858	 1	 2.39	 1.05	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21859	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21860	 1	 5.49	 2.29	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21861	 1	 23.22	 6.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21862	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21863	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21864	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21865	 1	 11.12	 3.64	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21866	 1	 5.81	 2.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21867	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21868	 1	 14.29	 5.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21869	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21870	 1	 18.79	 6.16	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21871	 1	 59.9	 12.46	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21872	 1	 9.62	 3.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21873	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21874	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21875	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21876	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21877	 1	 9.68	 3.36	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21878	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21879	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21880	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21881	 1	 20.32	 7.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21882	 1	 13.38	 4.35	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21883	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21884	 1	 6.19	 2.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21885	 1	 5.98	 2.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21886	 1	 3.49	 1.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21887	 1	 9.12	 3.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21888	 1	 16.3	 3.85	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21889	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21890	 1	 14.36	 4.62	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21891	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21892	 1	 9.37	 4.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21893	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21894	 1	 5.83	 1.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21895	 1	 6.17	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21896	 1	 4.31	 0.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21897	 1	 6.46	 1.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21898	 1	 67.79	 15.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21899	 1	 8.99	 1.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21900	 1	 4.54	 1.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21901	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21902	 1	 19.14	 7.52	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21903	 1	 8.69	 3.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21904	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21905	 1	 3.1	 1.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21906	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21907	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21908	 1	 6.23	 2.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21909	 1	 6.42	 2.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21910	 1	 7.2	 2.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21911	 1	 2.43	 1.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21912	 1	 7.59	 2.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21913	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21914	 1	 24.82	 6.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21915	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21916	 1	 1.79	 0.74	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21917	 1	 3.93	 1.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21918	 1	 7.45	 3.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21919	 1	 17.35	 4.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21920	 1	 5.17	 2.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21921	 1	 8.57	 3.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21922	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21923	 1	 16.64	 7.49	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21924	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21925	 1	 54.92	 13.11	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21926	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21927	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21928	 1	 7.87	 3.53	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21929	 1	 5.71	 2.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21930	 1	 3.78	 1.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21931	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21932	 1	 5.67	 2.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21933	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21934	 1	 8.37	 3.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21935	 1	 11.95	 5.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21936	 1	 20.22	 8.8	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21937	 1	 4.53	 1.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21938	 1	 8.59	 4.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21939	 1	 2.55	 1.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21940	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21941	 1	 24.12	 7.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21942	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21943	 1	 11.79	 5.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21944	 1	 21.78	 6.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21945	 1	 16.31	 5.62	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21946	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21947	 1	 7.27	 2.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21948	 1	 4.84	 2.22	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21949	 1	 13.89	 3.76	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21950	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21951	 1	 21.33	 7.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21952	 1	 6.16	 2.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21953	 1	 14.03	 3.21	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21954	 1	 12.5	 5.01	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21955	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21956	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21957	 1	 2.98	 1.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21958	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21959	 1	 2.49	 1.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21960	 1	 3.87	 1.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21961	 1	 8.33	 3.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21962	 1	 9.18	 3.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21963	 1	 4.21	 1.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21964	 1	 2.39	 0.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21965	 1	 2.58	 1.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21966	 1	 5.6	 2.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21967	 1	 2.61	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21968	 1	 8.45	 3.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21969	 1	 9.57	 2.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21970	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21971	 1	 11.13	 3.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21972	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21973	 1	 36.41	 9.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21974	 1	 5.79	 2.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21975	 1	 10.08	 3.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21976	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21977	 1	 36.81	 7.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21978	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21979	 1	 6.65	 3.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21980	 1	 4.65	 2.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21981	 1	 9.07	 3.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21982	 1	 11.91	 4.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21983	 1	 3.64	 1.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21984	 1	 4.17	 1.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21985	 1	 6.11	 2.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21986	 1	 6.74	 2.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21987	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21988	 1	 9.17	 3.27	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21989	 1	 8.14	 3.3	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21990	 1	 13.18	 5.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21991	 1	 7.98	 2.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21992	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21993	 1	 21.65	 8.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21994	 1	 69.71	 20.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21995	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21996	 1	 13.39	 6.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21997	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21998	 1	 12.37	 5.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	21999	 1	 2.84	 1.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22000	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22001	 1	 2.47	 0.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22002	 1	 8.49	 3.1	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22003	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22004	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22005	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22006	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22007	 1	 10.09	 3.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22008	 1	 5.15	 2.04	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22009	 1	 2.25	 0.9	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22010	 1	 4.66	 1.73	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22011	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22012	 1	 13.5	 5.42	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22013	 1	 5.56	 2.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22014	 1	 4.91	 2.32	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22015	 1	 7.21	 2.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22016	 1	 70.53	 16.23	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22017	 1	 7.65	 3.28	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22018	 1	 4.4	 2.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22019	 1	 6.47	 3.37	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22020	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22021	 1	 16.39	 4.53	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22022	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22023	 1	 9.41	 3.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22024	 1	 14.58	 5.16	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22025	 1	 25.33	 7.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22026	 1	 17.03	 5.23	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22027	 1	 5.4	 2.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22028	 1	 3.59	 1.49	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22029	 1	 24.8	 9.51	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22030	 1	 10.89	 4.12	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22031	 1	 16.56	 7.2	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22032	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22033	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22034	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22035	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22036	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22037	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22038	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22039	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22040	 1	 14.55	 4.02	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22041	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22042	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22043	 1	 8.59	 3.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22044	 1	 30.98	 9.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22045	 1	 4.45	 2.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22046	 1	 5.89	 2.58	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22047	 1	 16.03	 5.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22048	 1	 5.88	 2.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22049	 1	 76.3	 23.61	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22050	 1	 16.72	 5.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22051	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22052	 1	 7.93	 3.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22053	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22054	 1	 12.09	 5.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22055	 1	 9.62	 4.73	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22056	 1	 8.06	 3.19	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22057	 1	 6.29	 2.89	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22058	 1	 13.8	 4.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22059	 1	 12.57	 4.77	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22060	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22061	 1	 10.59	 4.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22062	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22063	 1	 13.22	 5.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22064	 1	 13.46	 4.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22065	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22066	 1	 11.51	 4.48	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22067	 1	 9.73	 4.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22068	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22069	 1	 6.66	 3.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22070	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22071	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22072	 1	 4.24	 1.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22073	 1	 7.67	 1.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22074	 1	 10.24	 2.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22075	 1	 8.17	 2.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22076	 1	 13.15	 3.8	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22077	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22078	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22079	 1	 17.47	 3.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22080	 1	 21.54	 5.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22081	 1	 19.58	 4.89	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22082	 1	 6.8	 2.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22083	 1	 25.28	 7.14	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22084	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22085	 1	 9.58	 3.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22086	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22087	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22088	 1	 15.63	 4.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22089	 1	 11.25	 4.32	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22090	 1	 14.99	 4.96	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22091	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22092	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22093	 1	 10.56	 4.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22094	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22095	 1	 7.08	 1.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22096	 1	 12.83	 2.94	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22097	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22098	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22099	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22100	 1	 10.36	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22101	 1	 1.27	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22102	 1	 2.25	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22103	 1	 2.27	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22104	 1	 3.65	 2.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22105	 1	 0.86	 0.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22106	 1	 0.0	 0.0	 0.0	 -289.26	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	22107	 1	 1.99	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22108	 1	 4.61	 2.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22109	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22110	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22111	 1	 4.85	 3.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22112	 1	 5.28	 2.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22113	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22114	 1	 4.01	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22115	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22116	 1	 1.43	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22117	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22118	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22119	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22120	 1	 2.34	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22121	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22122	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22123	 1	 9.52	 4.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22124	 1	 10.37	 6.67	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22125	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22126	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22127	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22128	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22129	 1	 4.14	 2.94	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22130	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22131	 1	 3.47	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22132	 1	 0.71	 0.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22133	 1	 3.56	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22134	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22135	 1	 8.28	 5.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22136	 1	 20.57	 9.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22137	 1	 3.84	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22138	 1	 1.45	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22139	 1	 4.32	 3.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22140	 1	 2.37	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22141	 1	 4.23	 2.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22142	 1	 2.45	 0.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22143	 1	 2.61	 1.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22144	 1	 2.0	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22145	 1	 6.87	 3.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22146	 1	 2.07	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22147	 1	 2.76	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22148	 1	 5.91	 3.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22149	 1	 1.65	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22150	 1	 2.25	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22151	 1	 2.78	 1.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22152	 1	 2.12	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22153	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22154	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22155	 1	 7.66	 3.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22156	 1	 5.51	 3.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22157	 1	 4.1	 2.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22158	 1	 10.68	 5.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22159	 1	 4.71	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22160	 1	 2.53	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22161	 1	 5.53	 3.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22162	 1	 7.21	 5.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22163	 1	 2.8	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22164	 1	 1.75	 0.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22165	 1	 10.58	 6.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22166	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22167	 1	 1.52	 0.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22168	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22169	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22170	 1	 2.02	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22171	 1	 4.31	 2.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22172	 1	 2.06	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22173	 1	 5.1	 2.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22174	 1	 4.61	 2.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22175	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22176	 1	 5.73	 3.19	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22177	 1	 4.96	 3.53	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22178	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22179	 1	 6.29	 4.06	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22180	 1	 5.16	 2.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22181	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22182	 1	 16.26	 9.12	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22183	 1	 7.38	 4.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22184	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22185	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22186	 1	 1.67	 1.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22187	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22188	 1	 3.82	 2.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22189	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22190	 1	 1.62	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22191	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22192	 1	 3.79	 2.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22193	 1	 4.69	 3.17	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22194	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22195	 1	 1.29	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22196	 1	 3.56	 2.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22197	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22198	 1	 8.15	 3.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22199	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22200	 1	 1.36	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22201	 1	 4.74	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22202	 1	 1.49	 1.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22203	 1	 9.99	 5.57	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22204	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22205	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22206	 1	 2.37	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22207	 1	 4.82	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22208	 1	 9.5	 5.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22209	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22210	 1	 1.58	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22211	 1	 5.04	 3.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22212	 1	 3.37	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22213	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22214	 1	 4.95	 3.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22215	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22216	 1	 2.03	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22217	 1	 1.55	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22218	 1	 9.16	 3.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22219	 1	 8.41	 3.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22220	 1	 5.72	 3.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22221	 1	 5.58	 3.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22222	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22223	 1	 2.43	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22224	 1	 2.14	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22225	 1	 2.86	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22226	 1	 1.84	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22227	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22228	 1	 2.28	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22229	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22230	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22231	 1	 1.3	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22232	 1	 8.74	 5.64	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22233	 1	 2.74	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22234	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22235	 1	 8.27	 5.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22236	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22237	 1	 7.71	 3.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22238	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22239	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22240	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22241	 1	 7.21	 4.27	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22242	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22243	 1	 0.71	 0.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22244	 1	 3.82	 2.76	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22245	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22246	 1	 5.67	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22247	 1	 8.21	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22248	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22249	 1	 5.25	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22250	 1	 4.54	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22251	 1	 1.94	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22252	 1	 2.79	 0.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22253	 1	 8.75	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22254	 1	 12.65	 2.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22255	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22256	 1	 2.0	 0.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22257	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22258	 1	 3.04	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22259	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22260	 1	 2.87	 0.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22261	 1	 4.01	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22262	 1	 15.39	 3.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22263	 1	 2.5	 0.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22264	 1	 4.25	 0.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22265	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22266	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22267	 1	 1.62	 0.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22268	 1	 9.38	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22269	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22270	 1	 7.24	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22271	 1	 3.16	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22272	 1	 2.68	 0.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22273	 1	 7.19	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22274	 1	 6.09	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22275	 1	 4.06	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22276	 1	 4.11	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22277	 1	 3.3	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22278	 1	 3.07	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22279	 1	 2.01	 0.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22280	 1	 2.49	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22281	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22282	 1	 3.68	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22283	 1	 7.74	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22284	 1	 7.65	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22285	 1	 1.93	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22286	 1	 7.03	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22287	 1	 4.56	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22288	 1	 1.11	 0.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22289	 1	 2.6	 0.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22290	 1	 10.07	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22291	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22292	 1	 7.98	 1.84	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22293	 1	 8.6	 1.98	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22294	 1	 3.57	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22295	 1	 34.42	 7.94	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22296	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22297	 1	 3.92	 0.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22298	 1	 4.79	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22299	 1	 2.07	 0.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22300	 1	 3.24	 2.08	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22301	 1	 4.79	 2.49	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22302	 1	 4.96	 2.61	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22303	 1	 13.88	 5.86	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22304	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22305	 1	 7.84	 4.54	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22306	 1	 13.1	 6.28	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22307	 1	 6.95	 4.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22308	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22309	 1	 0.96	 0.67	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22310	 1	 5.89	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22311	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22312	 1	 1.2	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22313	 1	 3.01	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22314	 1	 5.64	 2.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22315	 1	 2.01	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22316	 1	 7.65	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22317	 1	 4.32	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22318	 1	 5.61	 2.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22319	 1	 3.42	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22320	 1	 2.52	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22321	 1	 2.82	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22322	 1	 8.89	 4.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22323	 1	 9.08	 4.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22324	 1	 2.77	 1.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22325	 1	 3.01	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22326	 1	 1.48	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22327	 1	 2.16	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22328	 1	 2.84	 2.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22329	 1	 1.66	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22330	 1	 4.54	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22331	 1	 4.1	 2.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22332	 1	 1.93	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22333	 1	 6.57	 4.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22334	 1	 4.59	 3.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22335	 1	 0.77	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22336	 1	 10.17	 5.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22337	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22338	 1	 1.81	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22339	 1	 1.12	 0.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22340	 1	 0.98	 0.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22341	 1	 0.85	 0.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22342	 1	 1.53	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22343	 1	 7.97	 4.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22344	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22345	 1	 1.16	 0.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22346	 1	 6.53	 4.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22347	 1	 3.13	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22348	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22349	 1	 2.05	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22350	 1	 1.5	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22351	 1	 7.56	 3.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22352	 1	 4.07	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22353	 1	 2.16	 1.7	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22354	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22355	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22356	 1	 1.92	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22357	 1	 5.6	 3.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22358	 1	 4.09	 2.64	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22359	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22360	 1	 4.47	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22361	 1	 5.37	 2.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22362	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22363	 1	 1.7	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22364	 1	 2.48	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22365	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22366	 1	 3.89	 2.37	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22367	 1	 4.61	 2.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22368	 1	 2.8	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22369	 1	 6.85	 3.43	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22370	 1	 2.05	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22371	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22372	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22373	 1	 1.73	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22374	 1	 7.04	 4.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22375	 1	 4.72	 2.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22376	 1	 8.7	 5.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22377	 1	 1.47	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22378	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22379	 1	 0.85	 0.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22380	 1	 6.34	 4.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22381	 1	 3.2	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22382	 1	 4.91	 3.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22383	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22384	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22385	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22386	 1	 11.68	 8.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22387	 1	 3.22	 2.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22388	 1	 1.85	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22389	 1	 2.91	 1.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22390	 1	 3.58	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22391	 1	 7.48	 3.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22392	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22393	 1	 6.51	 3.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22394	 1	 11.12	 5.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22395	 1	 7.56	 3.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22396	 1	 3.32	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22397	 1	 1.25	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22398	 1	 3.6	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22399	 1	 2.18	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22400	 1	 3.7	 2.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22401	 1	 1.47	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22402	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22403	 1	 11.4	 6.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22404	 1	 9.05	 5.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22405	 1	 2.91	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22406	 1	 12.24	 6.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22407	 1	 1.91	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22408	 1	 4.55	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22409	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22410	 1	 3.37	 2.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22411	 1	 4.66	 3.02	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22412	 1	 19.05	 7.08	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22413	 1	 3.38	 0.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22414	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22415	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22416	 1	 6.23	 3.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22417	 1	 2.65	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22418	 1	 4.64	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22419	 1	 1.66	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22420	 1	 5.4	 3.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22421	 1	 2.51	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22422	 1	 6.81	 3.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22423	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22424	 1	 2.56	 1.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22425	 1	 1.89	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22426	 1	 5.39	 3.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22427	 1	 2.67	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22428	 1	 4.27	 2.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22429	 1	 9.13	 4.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22430	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22431	 1	 5.28	 3.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22432	 1	 11.25	 6.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22433	 1	 1.5	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22434	 1	 1.08	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22435	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22436	 1	 1.08	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22437	 1	 1.71	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22438	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22439	 1	 2.1	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22440	 1	 0.58	 0.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22441	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22442	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22443	 1	 1.76	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22444	 1	 1.61	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22445	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22446	 1	 1.26	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22447	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22448	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22449	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22450	 1	 2.27	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22451	 1	 2.15	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22452	 1	 2.25	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22453	 1	 2.72	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22454	 1	 5.35	 3.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22455	 1	 1.75	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22456	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22457	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22458	 1	 7.59	 4.31	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22459	 1	 1.55	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22460	 1	 4.49	 2.79	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22461	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22462	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22463	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22464	 1	 1.37	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22465	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22466	 1	 3.41	 2.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22467	 1	 3.96	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22468	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22469	 1	 3.63	 2.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22470	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22471	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22472	 1	 2.29	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22473	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22474	 1	 2.19	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22475	 1	 0.69	 0.49	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22476	 1	 1.04	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22477	 1	 1.12	 0.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22478	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22479	 1	 3.42	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22480	 1	 3.88	 2.04	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22481	 1	 6.48	 4.07	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22482	 1	 1.6	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22483	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22484	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22485	 1	 1.48	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22486	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22487	 1	 2.39	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22488	 1	 2.4	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22489	 1	 1.55	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22490	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22491	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22492	 1	 4.77	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22493	 1	 2.15	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22494	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22495	 1	 5.58	 3.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22496	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22497	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22498	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22499	 1	 4.84	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22500	 1	 6.28	 3.97	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22501	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22502	 1	 2.75	 2.27	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22503	 1	 2.64	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22504	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22505	 1	 2.78	 2.08	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22506	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22507	 1	 2.07	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22508	 1	 3.8	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22509	 1	 2.96	 2.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22510	 1	 5.23	 3.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22511	 1	 2.36	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22512	 1	 1.35	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22513	 1	 3.49	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22514	 1	 3.17	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22515	 1	 3.65	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22516	 1	 1.83	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22517	 1	 2.99	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22518	 1	 1.8	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22519	 1	 1.79	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22520	 1	 4.36	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22521	 1	 1.61	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22522	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22523	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22524	 1	 0.85	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22525	 1	 2.39	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22526	 1	 1.15	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22527	 1	 2.49	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22528	 1	 7.17	 4.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22529	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22530	 1	 2.82	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22531	 1	 0.89	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22532	 1	 4.22	 2.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22533	 1	 2.23	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22534	 1	 1.16	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22535	 1	 1.93	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22536	 1	 1.05	 0.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22537	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22538	 1	 1.12	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22539	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22540	 1	 7.87	 4.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22541	 1	 2.28	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22542	 1	 2.27	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22543	 1	 2.37	 1.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22544	 1	 2.07	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22545	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22546	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22547	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22548	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22549	 1	 1.29	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22550	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22551	 1	 1.08	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22552	 1	 2.16	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22553	 1	 2.23	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22554	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22555	 1	 5.32	 3.55	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22556	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22557	 1	 7.44	 3.68	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22558	 1	 3.55	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22559	 1	 1.66	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22560	 1	 2.93	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22561	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22562	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22563	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22564	 1	 2.22	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22565	 1	 0.72	 0.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22566	 1	 1.37	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22567	 1	 1.63	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22568	 1	 4.01	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22569	 1	 1.26	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22570	 1	 4.82	 3.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22571	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22572	 1	 1.23	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22573	 1	 1.84	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22574	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22575	 1	 5.22	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22576	 1	 0.59	 0.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22577	 1	 5.51	 3.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22578	 1	 3.23	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22579	 1	 2.57	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22580	 1	 3.79	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22581	 1	 4.5	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22582	 1	 2.96	 2.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22583	 1	 3.96	 3.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22584	 1	 2.98	 0.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22585	 1	 4.36	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22586	 1	 13.54	 7.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22587	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22588	 1	 3.27	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22589	 1	 2.39	 0.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22590	 1	 2.98	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22591	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22592	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22593	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22594	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22595	 1	 2.78	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22596	 1	 2.31	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22597	 1	 14.14	 8.47	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22598	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22599	 1	 1.33	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22600	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22601	 1	 4.87	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22602	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22603	 1	 3.59	 2.67	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22604	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22605	 1	 6.15	 3.53	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22606	 1	 2.26	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22607	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22608	 1	 14.48	 3.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22609	 1	 10.36	 2.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22610	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22611	 1	 3.53	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22612	 1	 11.41	 2.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22613	 1	 2.31	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22614	 1	 4.92	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22615	 1	 3.61	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22616	 1	 3.12	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22617	 1	 3.17	 -4.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22618	 1	 2.07	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22619	 1	 3.55	 2.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22620	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22621	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22622	 1	 6.82	 4.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22623	 1	 5.19	 2.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22624	 1	 1.82	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22625	 1	 7.82	 4.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22626	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22627	 1	 6.48	 4.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22628	 1	 1.39	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22629	 1	 1.33	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22630	 1	 1.3	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22631	 1	 0.57	 0.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22632	 1	 1.58	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22633	 1	 6.98	 3.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22634	 1	 7.21	 3.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22635	 1	 11.53	 5.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22636	 1	 4.58	 2.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22637	 1	 7.68	 4.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22638	 1	 4.25	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22639	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22640	 1	 15.42	 6.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22641	 1	 1.37	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22642	 1	 1.77	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22643	 1	 1.58	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22644	 1	 3.38	 2.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22645	 1	 2.14	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22646	 1	 1.7	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22647	 1	 2.35	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22648	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22649	 1	 1.69	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22650	 1	 0.92	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22651	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22652	 1	 4.34	 2.76	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22653	 1	 2.5	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22654	 1	 2.2	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22655	 1	 1.75	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22656	 1	 3.79	 2.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22657	 1	 7.31	 3.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22658	 1	 3.65	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22659	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22660	 1	 1.07	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22661	 1	 3.26	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22662	 1	 5.24	 3.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22663	 1	 2.36	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22664	 1	 1.54	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22665	 1	 4.66	 2.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22666	 1	 2.19	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22667	 1	 3.31	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22668	 1	 1.26	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22669	 1	 2.59	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22670	 1	 5.01	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22671	 1	 3.28	 2.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22672	 1	 2.76	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22673	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22674	 1	 1.16	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22675	 1	 2.26	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22676	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22677	 1	 0.54	 0.42	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22678	 1	 1.6	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22679	 1	 0.69	 0.49	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22680	 1	 1.36	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22681	 1	 2.28	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22682	 1	 2.07	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22683	 1	 1.52	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22684	 1	 2.66	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22685	 1	 1.59	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22686	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22687	 1	 2.82	 1.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22688	 1	 5.55	 4.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22689	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22690	 1	 3.17	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22691	 1	 2.44	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22692	 1	 2.07	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22693	 1	 4.35	 2.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22694	 1	 5.04	 3.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22695	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22696	 1	 2.84	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22697	 1	 6.31	 3.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22698	 1	 2.48	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22699	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22700	 1	 6.75	 3.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22701	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22702	 1	 4.97	 2.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22703	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22704	 1	 3.31	 1.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22705	 1	 3.28	 2.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22706	 1	 5.48	 3.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22707	 1	 4.0	 2.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22708	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22709	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22710	 1	 2.29	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22711	 1	 2.69	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22712	 1	 4.89	 2.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22713	 1	 8.59	 5.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22714	 1	 5.65	 3.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22715	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22716	 1	 7.62	 4.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22717	 1	 8.15	 5.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22718	 1	 2.09	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22719	 1	 14.35	 5.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22720	 1	 0.13	 0.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22721	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22722	 1	 8.96	 4.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22723	 1	 3.32	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22724	 1	 11.25	 5.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22725	 1	 8.67	 4.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22726	 1	 13.92	 6.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22727	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22728	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22729	 1	 2.69	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22730	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22731	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22732	 1	 4.15	 2.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22733	 1	 1.79	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22734	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22735	 1	 5.99	 3.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22736	 1	 1.37	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22737	 1	 3.26	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22738	 1	 9.0	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22739	 1	 3.62	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22740	 1	 4.51	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22741	 1	 0.94	 0.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22742	 1	 1.25	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22743	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22744	 1	 0.7	 0.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22745	 1	 5.64	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22746	 1	 2.05	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22747	 1	 2.13	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22748	 1	 4.56	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22749	 1	 3.97	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22750	 1	 3.73	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22751	 1	 4.76	 2.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22752	 1	 2.39	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22753	 1	 2.6	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22754	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22755	 1	 2.83	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22756	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22757	 1	 4.06	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22758	 1	 3.96	 2.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22759	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22760	 1	 5.24	 3.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22761	 1	 1.3	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22762	 1	 3.07	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22763	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22764	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22765	 1	 3.84	 2.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22766	 1	 2.58	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22767	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22768	 1	 2.6	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22769	 1	 1.56	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22770	 1	 1.22	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22771	 1	 1.82	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22772	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22773	 1	 2.34	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22774	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22775	 1	 3.42	 2.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22776	 1	 3.94	 3.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22777	 1	 2.83	 2.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22778	 1	 1.73	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22779	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22780	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22781	 1	 14.41	 8.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22782	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22783	 1	 3.26	 2.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22784	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22785	 1	 11.37	 7.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22786	 1	 14.24	 6.14	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22787	 1	 15.03	 8.58	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22788	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22789	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22790	 1	 2.84	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22791	 1	 2.28	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22792	 1	 6.52	 4.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22793	 1	 6.21	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22794	 1	 5.69	 3.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22795	 1	 3.56	 2.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22796	 1	 2.95	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22797	 1	 2.29	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22798	 1	 1.24	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22799	 1	 3.82	 2.74	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22800	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22801	 1	 4.57	 2.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22802	 1	 9.04	 4.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22803	 1	 13.1	 5.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22804	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22805	 1	 4.41	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22806	 1	 4.26	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22807	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22808	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22809	 1	 6.4	 3.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22810	 1	 1.57	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22811	 1	 6.96	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22812	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22813	 1	 6.65	 3.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22814	 1	 3.01	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22815	 1	 6.33	 3.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22816	 1	 3.99	 2.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22817	 1	 5.15	 3.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22818	 1	 1.67	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22819	 1	 0.93	 0.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22820	 1	 8.22	 3.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22821	 1	 2.88	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22822	 1	 4.28	 2.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22823	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22824	 1	 16.55	 8.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22825	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22826	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22827	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22828	 1	 3.99	 2.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22829	 1	 6.47	 3.79	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22830	 1	 2.77	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22831	 1	 2.38	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22832	 1	 2.35	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22833	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22834	 1	 2.06	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22835	 1	 7.41	 3.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22836	 1	 9.78	 5.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22837	 1	 6.01	 3.84	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22838	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22839	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22840	 1	 6.98	 3.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22841	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22842	 1	 7.56	 4.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22843	 1	 7.4	 4.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22844	 1	 10.85	 6.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22845	 1	 1.25	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22846	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22847	 1	 4.32	 3.33	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22848	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22849	 1	 4.0	 2.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22850	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22851	 1	 4.73	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22852	 1	 6.6	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22853	 1	 11.38	 6.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22854	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22855	 1	 5.77	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22856	 1	 5.06	 2.54	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22857	 1	 21.62	 10.7	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22858	 1	 14.22	 7.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22859	 1	 9.59	 5.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22860	 1	 2.07	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22861	 1	 5.57	 3.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22862	 1	 2.08	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22863	 1	 2.43	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22864	 1	 1.49	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22865	 1	 2.44	 1.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22866	 1	 1.71	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22867	 1	 1.85	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22868	 1	 1.95	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22869	 1	 3.62	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22870	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22871	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22872	 1	 2.34	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22873	 1	 3.76	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22874	 1	 1.84	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22875	 1	 3.05	 2.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22876	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22877	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22878	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22879	 1	 2.84	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22880	 1	 2.62	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22881	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22882	 1	 4.25	 2.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22883	 1	 9.04	 4.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22884	 1	 3.72	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22885	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22886	 1	 24.29	 10.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22887	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22888	 1	 3.35	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22889	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22890	 1	 14.0	 7.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22891	 1	 5.91	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22892	 1	 0.96	 0.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22893	 1	 0.8	 0.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22894	 1	 1.91	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22895	 1	 2.09	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22896	 1	 1.77	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22897	 1	 3.23	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22898	 1	 10.41	 5.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22899	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22900	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22901	 1	 6.88	 4.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22902	 1	 7.32	 3.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22903	 1	 1.99	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22904	 1	 8.57	 4.29	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22905	 1	 5.26	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22906	 1	 2.12	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22907	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22908	 1	 6.17	 3.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22909	 1	 9.67	 4.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22910	 1	 3.88	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22911	 1	 1.07	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22912	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22913	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22914	 1	 3.18	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22915	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22916	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22917	 1	 7.57	 4.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22918	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22919	 1	 4.06	 3.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22920	 1	 3.56	 2.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22921	 1	 1.88	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22922	 1	 3.1	 2.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22923	 1	 3.17	 2.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22924	 1	 1.72	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22925	 1	 3.46	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22926	 1	 5.6	 2.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22927	 1	 11.23	 4.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22928	 1	 2.51	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22929	 1	 4.22	 2.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22930	 1	 6.84	 4.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22931	 1	 4.16	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22932	 1	 2.92	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22933	 1	 2.12	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22934	 1	 2.88	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22935	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22936	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22937	 1	 3.23	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22938	 1	 4.41	 2.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22939	 1	 6.27	 4.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22940	 1	 6.28	 3.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22941	 1	 4.78	 2.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22942	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22943	 1	 4.24	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22944	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22945	 1	 4.05	 2.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22946	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22947	 1	 9.99	 5.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22948	 1	 3.06	 2.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22949	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22950	 1	 1.77	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22951	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22952	 1	 2.0	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22953	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22954	 1	 2.24	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22955	 1	 6.75	 2.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22956	 1	 11.0	 5.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22957	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	22958	 1	 3.82	 2.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22959	 1	 2.0	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22960	 1	 2.68	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22961	 1	 2.63	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22962	 1	 4.07	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22963	 1	 2.59	 1.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22964	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22965	 1	 4.17	 2.7	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22966	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22967	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22968	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22969	 1	 4.98	 3.26	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22970	 1	 26.45	 11.85	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22971	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22972	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22973	 1	 4.04	 3.06	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22974	 1	 4.15	 2.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22975	 1	 4.34	 3.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22976	 1	 7.09	 4.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22977	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22978	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22979	 1	 8.2	 5.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22980	 1	 12.82	 7.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22981	 1	 6.79	 4.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22982	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22983	 1	 4.13	 2.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22984	 1	 2.03	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22985	 1	 2.05	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22986	 1	 1.61	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22987	 1	 10.57	 5.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22988	 1	 3.48	 2.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22989	 1	 2.63	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22990	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22991	 1	 1.6	 0.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22992	 1	 0.13	 0.08	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22993	 1	 1.28	 0.8	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22994	 1	 2.54	 1.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22995	 1	 3.18	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22996	 1	 3.83	 2.63	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	22997	 1	 2.56	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22998	 1	 1.89	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	22999	 1	 1.45	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23000	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23001	 1	 3.25	 2.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23002	 1	 5.68	 3.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23003	 1	 2.55	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23004	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23005	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23006	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23007	 1	 3.26	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23008	 1	 0.63	 0.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23009	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23010	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23011	 1	 3.18	 2.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23012	 1	 3.69	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23013	 1	 2.7	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23014	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23015	 1	 3.37	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23016	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23017	 1	 3.99	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23018	 1	 3.8	 2.66	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23019	 1	 2.13	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23020	 1	 1.7	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23021	 1	 1.55	 0.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23022	 1	 3.08	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23023	 1	 2.01	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23024	 1	 1.77	 0.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23025	 1	 6.69	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23026	 1	 7.18	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23027	 1	 3.54	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23028	 1	 4.58	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23029	 1	 3.13	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23030	 1	 2.71	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23031	 1	 2.05	 0.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23032	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23033	 1	 2.77	 0.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23034	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23035	 1	 4.53	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23036	 1	 6.77	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23037	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23038	 1	 4.46	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23039	 1	 5.67	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23040	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23041	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23042	 1	 16.81	 3.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23043	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23044	 1	 6.7	 4.2	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23045	 1	 8.52	 4.3	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23046	 1	 14.12	 3.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23047	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23048	 1	 4.93	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23049	 1	 8.56	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23050	 1	 1.23	 0.88	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23051	 1	 2.71	 0.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23052	 1	 1.07	 0.77	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23053	 1	 1.02	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23054	 1	 2.88	 0.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23055	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23056	 1	 1.12	 0.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23057	 1	 2.23	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23058	 1	 2.14	 0.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23059	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23060	 1	 2.42	 0.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23061	 1	 2.81	 0.66	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23062	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23063	 1	 2.35	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23064	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23065	 1	 2.28	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23066	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23067	 1	 3.65	 1.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23068	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23069	 1	 5.13	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23070	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23071	 1	 8.31	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23072	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23073	 1	 1.19	 0.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23074	 1	 2.12	 0.5	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23075	 1	 1.76	 0.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23076	 1	 2.02	 0.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23077	 1	 2.01	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23078	 1	 0.89	 0.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23079	 1	 1.43	 0.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23080	 1	 2.74	 0.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23081	 1	 2.76	 0.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23082	 1	 0.81	 0.19	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23083	 1	 2.66	 0.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23084	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23085	 1	 1.19	 0.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23086	 1	 1.57	 0.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23087	 1	 3.4	 0.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23088	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23089	 1	 6.56	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23090	 1	 4.37	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23091	 1	 7.44	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23092	 1	 1.41	 0.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23093	 1	 6.92	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23094	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23095	 1	 1.74	 0.41	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23096	 1	 1.87	 0.44	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23097	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23098	 1	 1.2	 0.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23099	 1	 2.02	 0.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23100	 1	 0.83	 0.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23101	 1	 1.71	 0.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23102	 1	 6.11	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23103	 1	 1.82	 0.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23104	 1	 1.61	 0.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23105	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23106	 1	 3.91	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23107	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23108	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23109	 1	 4.26	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23110	 1	 1.12	 0.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23111	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23112	 1	 1.47	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23113	 1	 1.74	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23114	 1	 6.5	 3.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23115	 1	 1.67	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23116	 1	 2.48	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23117	 1	 3.15	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23118	 1	 9.66	 4.79	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23119	 1	 4.28	 2.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23120	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23121	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23122	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23123	 1	 2.24	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23124	 1	 11.18	 6.36	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23125	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23126	 1	 3.95	 2.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23127	 1	 4.91	 2.92	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23128	 1	 3.55	 2.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23129	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23130	 1	 9.64	 5.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23131	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23132	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23133	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23134	 1	 3.01	 2.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23135	 1	 1.87	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23136	 1	 4.06	 2.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23137	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23138	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23139	 1	 2.8	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23140	 1	 1.68	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23141	 1	 6.81	 5.17	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23142	 1	 0.82	 0.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23143	 1	 6.64	 4.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23144	 1	 10.59	 6.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23145	 1	 9.69	 5.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23146	 1	 4.83	 3.3	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23147	 1	 5.78	 4.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23148	 1	 2.42	 1.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23149	 1	 2.44	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23150	 1	 2.77	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23151	 1	 4.67	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23152	 1	 3.11	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23153	 1	 6.65	 3.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23154	 1	 3.28	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23155	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23156	 1	 3.12	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23157	 1	 4.14	 2.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23158	 1	 2.8	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23159	 1	 1.76	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23160	 1	 8.92	 5.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23161	 1	 4.44	 2.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23162	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23163	 1	 9.06	 4.99	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23164	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23165	 1	 3.22	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23166	 1	 4.86	 3.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23167	 1	 3.52	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23168	 1	 2.29	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23169	 1	 4.41	 2.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23170	 1	 2.53	 2.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23171	 1	 3.26	 2.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23172	 1	 1.88	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23173	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23174	 1	 4.68	 3.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23175	 1	 4.51	 3.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23176	 1	 2.44	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23177	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23178	 1	 4.48	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23179	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23180	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23181	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23182	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23183	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23184	 1	 2.37	 1.7	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23185	 1	 3.53	 2.23	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23186	 1	 2.27	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23187	 1	 3.94	 2.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23188	 1	 1.13	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23189	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23190	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23191	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23192	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23193	 1	 2.33	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23194	 1	 2.78	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23195	 1	 17.67	 7.51	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23196	 1	 2.62	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23197	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23198	 1	 1.67	 1.06	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23199	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23200	 1	 2.7	 2.07	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23201	 1	 2.73	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23202	 1	 1.99	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23203	 1	 5.26	 3.29	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23204	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23205	 1	 2.77	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23206	 1	 3.23	 2.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23207	 1	 2.76	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23208	 1	 2.58	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23209	 1	 2.94	 1.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23210	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23211	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23212	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23213	 1	 3.06	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23214	 1	 4.74	 2.87	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23215	 1	 2.94	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23216	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23217	 1	 0.87	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23218	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23219	 1	 4.63	 2.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23220	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23221	 1	 8.04	 4.28	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23222	 1	 1.87	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23223	 1	 7.2	 3.7	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23224	 1	 3.98	 3.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23225	 1	 6.01	 3.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23226	 1	 1.5	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23227	 1	 2.16	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23228	 1	 1.09	 0.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23229	 1	 2.18	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23230	 1	 1.04	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23231	 1	 1.49	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23232	 1	 1.6	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23233	 1	 4.9	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23234	 1	 1.14	 0.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23235	 1	 1.25	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23236	 1	 1.26	 0.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23237	 1	 1.88	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23238	 1	 1.91	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23239	 1	 1.64	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23240	 1	 1.66	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23241	 1	 1.39	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23242	 1	 2.4	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23243	 1	 1.68	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23244	 1	 2.11	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23245	 1	 1.58	 0.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23246	 1	 3.18	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23247	 1	 6.48	 3.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23248	 1	 3.55	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23249	 1	 2.28	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23250	 1	 1.95	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23251	 1	 1.13	 0.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23252	 1	 1.55	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23253	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23254	 1	 3.51	 2.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23255	 1	 3.69	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23256	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23257	 1	 6.08	 4.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23258	 1	 3.77	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23259	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23260	 1	 4.89	 3.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23261	 1	 16.12	 8.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23262	 1	 6.54	 2.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23263	 1	 1.84	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23264	 1	 2.21	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23265	 1	 4.13	 2.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23266	 1	 0.8	 0.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23267	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23268	 1	 1.18	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23269	 1	 1.31	 0.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23270	 1	 1.75	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23271	 1	 0.62	 0.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23272	 1	 0.67	 0.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23273	 1	 5.13	 3.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23274	 1	 1.15	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23275	 1	 0.77	 0.58	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23276	 1	 1.84	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23277	 1	 5.38	 3.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23278	 1	 2.82	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23279	 1	 1.74	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23280	 1	 4.69	 2.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23281	 1	 1.38	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23282	 1	 5.1	 3.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23283	 1	 2.51	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23284	 1	 2.55	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23285	 1	 1.88	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23286	 1	 1.58	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23287	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23288	 1	 1.81	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23289	 1	 1.22	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23290	 1	 4.02	 2.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23291	 1	 2.32	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23292	 1	 2.92	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23293	 1	 3.56	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23294	 1	 3.92	 2.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23295	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23296	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23297	 1	 1.62	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23298	 1	 1.97	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23299	 1	 1.18	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23300	 1	 1.89	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23301	 1	 1.12	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23302	 1	 1.44	 0.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23303	 1	 1.45	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23304	 1	 2.0	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23305	 1	 2.87	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23306	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23307	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23308	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23309	 1	 9.76	 5.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23310	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23311	 1	 1.59	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23312	 1	 3.34	 2.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23313	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23314	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23315	 1	 14.24	 4.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23316	 1	 5.15	 2.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23317	 1	 4.08	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23318	 1	 4.85	 3.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23319	 1	 4.21	 2.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23320	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23321	 1	 3.02	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23322	 1	 12.18	 3.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23323	 1	 3.44	 2.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23324	 1	 4.63	 2.6	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23325	 1	 3.41	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23326	 1	 7.28	 4.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23327	 1	 3.99	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23328	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23329	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23330	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23331	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23332	 1	 17.83	 8.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23333	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23334	 1	 4.89	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23335	 1	 2.28	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23336	 1	 1.85	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23337	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23338	 1	 3.98	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23339	 1	 1.25	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23340	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23341	 1	 2.45	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23342	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23343	 1	 1.75	 1.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23344	 1	 1.34	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23345	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23346	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23347	 1	 1.52	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23348	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23349	 1	 3.37	 2.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23350	 1	 1.47	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23351	 1	 4.7	 3.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23352	 1	 5.8	 3.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23353	 1	 4.98	 3.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23354	 1	 1.53	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23355	 1	 1.33	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23356	 1	 3.25	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23357	 1	 2.18	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23358	 1	 5.81	 3.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23359	 1	 2.39	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23360	 1	 2.8	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23361	 1	 1.62	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23362	 1	 6.37	 3.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23363	 1	 2.09	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23364	 1	 1.32	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23365	 1	 4.7	 3.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23366	 1	 9.24	 6.57	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23367	 1	 1.55	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23368	 1	 5.44	 3.36	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23369	 1	 1.78	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23370	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23371	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23372	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23373	 1	 2.12	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23374	 1	 2.44	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23375	 1	 1.49	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23376	 1	 2.67	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23377	 1	 1.4	 0.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23378	 1	 5.65	 3.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23379	 1	 11.22	 4.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23380	 1	 3.64	 2.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23381	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23382	 1	 6.01	 3.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23383	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23384	 1	 4.77	 3.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23385	 1	 2.15	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23386	 1	 2.67	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23387	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23388	 1	 1.88	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23389	 1	 1.78	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23390	 1	 9.51	 5.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23391	 1	 7.44	 4.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23392	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23393	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23394	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23395	 1	 2.14	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23396	 1	 2.76	 1.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23397	 1	 1.92	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23398	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23399	 1	 2.9	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23400	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23401	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23402	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23403	 1	 2.27	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23404	 1	 12.23	 8.17	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23405	 1	 3.02	 2.19	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23406	 1	 2.53	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23407	 1	 2.25	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23408	 1	 2.51	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23409	 1	 1.47	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23410	 1	 4.46	 3.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23411	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23412	 1	 5.38	 3.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23413	 1	 3.58	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23414	 1	 5.04	 3.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23415	 1	 3.73	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23416	 1	 4.37	 2.88	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23417	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23418	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23419	 1	 3.24	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23420	 1	 1.89	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23421	 1	 4.47	 1.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23422	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23423	 1	 14.85	 3.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23424	 1	 1.35	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23425	 1	 3.82	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23426	 1	 3.59	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23427	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23428	 1	 7.67	 4.37	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23429	 1	 8.93	 6.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23430	 1	 3.62	 2.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23431	 1	 4.85	 3.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23432	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23433	 1	 13.8	 5.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23434	 1	 1.44	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23435	 1	 2.87	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23436	 1	 2.87	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23437	 1	 1.86	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23438	 1	 2.33	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23439	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23440	 1	 4.55	 2.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23441	 1	 1.62	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23442	 1	 1.19	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23443	 1	 3.7	 2.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23444	 1	 3.43	 0.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23445	 1	 9.2	 2.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23446	 1	 2.93	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23447	 1	 4.4	 2.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23448	 1	 4.3	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23449	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23450	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23451	 1	 1.97	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23452	 1	 6.05	 3.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23453	 1	 2.22	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23454	 1	 2.44	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23455	 1	 6.41	 3.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23456	 1	 3.66	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23457	 1	 3.13	 1.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23458	 1	 8.95	 4.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23459	 1	 8.5	 4.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23460	 1	 3.58	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23461	 1	 5.08	 3.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23462	 1	 2.2	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23463	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23464	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23465	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23466	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23467	 1	 5.02	 3.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23468	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23469	 1	 1.71	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23470	 1	 2.12	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23471	 1	 2.09	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23472	 1	 2.71	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23473	 1	 3.92	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23474	 1	 2.9	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23475	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23476	 1	 2.75	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23477	 1	 6.76	 3.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23478	 1	 10.42	 5.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23479	 1	 2.16	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23480	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23481	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23482	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23483	 1	 2.78	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23484	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23485	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23486	 1	 3.6	 2.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23487	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23488	 1	 8.44	 4.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23489	 1	 6.11	 3.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23490	 1	 3.29	 2.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23491	 1	 5.57	 3.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23492	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23493	 1	 12.15	 4.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23494	 1	 5.55	 3.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23495	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23496	 1	 6.98	 3.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23497	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23498	 1	 5.49	 4.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23499	 1	 6.69	 4.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23500	 1	 9.74	 5.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23501	 1	 6.3	 3.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23502	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23503	 1	 4.01	 2.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23504	 1	 4.72	 3.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23505	 1	 4.49	 2.5	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23506	 1	 2.15	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23507	 1	 3.95	 3.05	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23508	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23509	 1	 12.41	 6.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23510	 1	 0.85	 0.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23511	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23512	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23513	 1	 15.05	 8.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23514	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23515	 1	 2.39	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23516	 1	 2.97	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23517	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23518	 1	 2.04	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23519	 1	 6.51	 3.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23520	 1	 2.3	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23521	 1	 5.18	 3.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23522	 1	 2.63	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23523	 1	 3.49	 2.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23524	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23525	 1	 2.11	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23526	 1	 2.8	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23527	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23528	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23529	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23530	 1	 3.08	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23531	 1	 2.12	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23532	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23533	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23534	 1	 2.25	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23535	 1	 1.69	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23536	 1	 2.59	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23537	 1	 5.85	 2.65	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23538	 1	 3.51	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23539	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23540	 1	 1.53	 1.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23541	 1	 1.75	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23542	 1	 1.43	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23543	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23544	 1	 3.01	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23545	 1	 1.64	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23546	 1	 3.06	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23547	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23548	 1	 2.42	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23549	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23550	 1	 1.14	 0.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23551	 1	 4.06	 2.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23552	 1	 2.17	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23553	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23554	 1	 1.84	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23555	 1	 1.69	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23556	 1	 1.55	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23557	 1	 2.98	 2.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23558	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23559	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23560	 1	 1.95	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23561	 1	 0.97	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23562	 1	 2.22	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23563	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23564	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23565	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23566	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23567	 1	 2.32	 1.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23568	 1	 2.14	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23569	 1	 3.62	 2.26	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23570	 1	 2.35	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23571	 1	 1.64	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23572	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23573	 1	 2.81	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23574	 1	 7.49	 4.67	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23575	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23576	 1	 1.83	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23577	 1	 1.15	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23578	 1	 3.42	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23579	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23580	 1	 2.24	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23581	 1	 9.87	 2.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23582	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23583	 1	 6.08	 2.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23584	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23585	 1	 1.87	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23586	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23587	 1	 2.9	 2.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23588	 1	 3.17	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23589	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23590	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23591	 1	 1.8	 0.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23592	 1	 11.62	 5.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23593	 1	 5.91	 3.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23594	 1	 3.4	 2.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23595	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23596	 1	 4.31	 2.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23597	 1	 4.56	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23598	 1	 2.23	 0.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23599	 1	 5.92	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23600	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23601	 1	 2.64	 0.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23602	 1	 8.16	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23603	 1	 2.29	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23604	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23605	 1	 4.21	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23606	 1	 2.59	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23607	 1	 8.79	 2.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23608	 1	 3.18	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23609	 1	 2.38	 0.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23610	 1	 1.82	 0.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23611	 1	 3.08	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23612	 1	 2.27	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23613	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23614	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23615	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23616	 1	 6.49	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23617	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23618	 1	 1.69	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23619	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23620	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23621	 1	 3.58	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23622	 1	 4.17	 2.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23623	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23624	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23625	 1	 10.14	 6.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23626	 1	 2.68	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23627	 1	 1.89	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23628	 1	 3.76	 2.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23629	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23630	 1	 5.3	 3.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23631	 1	 3.49	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23632	 1	 4.07	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23633	 1	 1.29	 0.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23634	 1	 0.85	 0.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23635	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23636	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23637	 1	 4.36	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23638	 1	 0.97	 0.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23639	 1	 3.01	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23640	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23641	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23642	 1	 10.73	 6.86	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23643	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23644	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23645	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23646	 1	 4.48	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23647	 1	 1.85	 0.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23648	 1	 3.53	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23649	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23650	 1	 5.42	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23651	 1	 1.13	 0.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23652	 1	 1.8	 0.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23653	 1	 2.88	 0.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23654	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23655	 1	 2.1	 0.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23656	 1	 2.49	 0.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23657	 1	 3.16	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23658	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23659	 1	 3.47	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23660	 1	 2.49	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23661	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23662	 1	 1.19	 0.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23663	 1	 3.67	 2.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23664	 1	 1.6	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23665	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23666	 1	 1.47	 0.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23667	 1	 2.03	 0.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23668	 1	 3.66	 0.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23669	 1	 2.71	 0.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23670	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23671	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23672	 1	 2.31	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23673	 1	 1.55	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23674	 1	 8.31	 4.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23675	 1	 1.04	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23676	 1	 2.42	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23677	 1	 2.0	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23678	 1	 2.46	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23679	 1	 1.75	 0.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23680	 1	 2.3	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23681	 1	 1.96	 0.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23682	 1	 2.48	 0.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23683	 1	 1.83	 0.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23684	 1	 1.54	 0.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23685	 1	 2.44	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23686	 1	 3.44	 2.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23687	 1	 1.87	 0.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23688	 1	 1.68	 0.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23689	 1	 2.75	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23690	 1	 2.06	 0.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23691	 1	 1.92	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23692	 1	 0.95	 0.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23693	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23694	 1	 2.29	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23695	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23696	 1	 1.89	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23697	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23698	 1	 1.34	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23699	 1	 6.18	 3.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23700	 1	 2.25	 0.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23701	 1	 1.9	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23702	 1	 2.18	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23703	 1	 1.76	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23704	 1	 3.71	 0.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23705	 1	 2.06	 0.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23706	 1	 5.6	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23707	 1	 2.78	 0.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23708	 1	 3.49	 2.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23709	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23710	 1	 0.94	 0.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23711	 1	 4.84	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23712	 1	 5.36	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23713	 1	 3.44	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23714	 1	 2.48	 0.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23715	 1	 3.11	 0.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23716	 1	 2.25	 0.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23717	 1	 2.27	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23718	 1	 2.54	 0.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23719	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23720	 1	 5.53	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23721	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23722	 1	 2.27	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23723	 1	 2.56	 0.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23724	 1	 2.1	 1.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23725	 1	 5.11	 2.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23726	 1	 4.54	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23727	 1	 2.36	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23728	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23729	 1	 3.46	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23730	 1	 4.38	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23731	 1	 3.96	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23732	 1	 4.9	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23733	 1	 3.02	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23734	 1	 1.5	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23735	 1	 1.65	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23736	 1	 2.78	 0.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23737	 1	 3.55	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23738	 1	 2.23	 0.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23739	 1	 1.89	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23740	 1	 2.19	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23741	 1	 8.79	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23742	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23743	 1	 5.69	 3.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23744	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23745	 1	 2.39	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23746	 1	 1.2	 0.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23747	 1	 1.28	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23748	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23749	 1	 1.25	 0.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23750	 1	 3.57	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23751	 1	 12.76	 8.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23752	 1	 1.71	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23753	 1	 2.53	 0.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23754	 1	 1.73	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23755	 1	 1.47	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23756	 1	 2.25	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23757	 1	 2.41	 0.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23758	 1	 2.52	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23759	 1	 5.84	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23760	 1	 1.72	 1.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23761	 1	 1.26	 0.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23762	 1	 1.76	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23763	 1	 4.37	 2.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23764	 1	 4.12	 2.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23765	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23766	 1	 0.93	 0.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23767	 1	 3.1	 2.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23768	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23769	 1	 1.69	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23770	 1	 1.95	 1.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23771	 1	 4.71	 2.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23772	 1	 4.58	 3.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23773	 1	 2.99	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23774	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23775	 1	 2.62	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23776	 1	 5.46	 3.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23777	 1	 5.68	 2.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23778	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23779	 1	 5.31	 2.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23780	 1	 2.66	 1.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23781	 1	 3.18	 2.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23782	 1	 2.43	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23783	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23784	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23785	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23786	 1	 4.72	 2.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23787	 1	 2.41	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23788	 1	 7.26	 3.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23789	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23790	 1	 7.23	 4.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23791	 1	 2.35	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23792	 1	 1.45	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23793	 1	 6.0	 3.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23794	 1	 2.23	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23795	 1	 8.08	 4.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23796	 1	 3.19	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23797	 1	 2.83	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23798	 1	 3.23	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23799	 1	 2.95	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23800	 1	 1.89	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23801	 1	 2.79	 1.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23802	 1	 2.81	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23803	 1	 1.39	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23804	 1	 2.44	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23805	 1	 3.68	 1.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23806	 1	 3.84	 2.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23807	 1	 0.73	 0.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23808	 1	 1.86	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23809	 1	 2.09	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23810	 1	 1.84	 0.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23811	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23812	 1	 1.86	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23813	 1	 1.44	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23814	 1	 2.76	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23815	 1	 1.43	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23816	 1	 1.27	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23817	 1	 1.91	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23818	 1	 17.23	 6.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23819	 1	 1.93	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23820	 1	 6.68	 4.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23821	 1	 2.74	 2.19	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23822	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23823	 1	 1.48	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23824	 1	 1.97	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23825	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23826	 1	 1.49	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23827	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23828	 1	 3.5	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23829	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23830	 1	 1.75	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23831	 1	 1.82	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23832	 1	 2.84	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23833	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23834	 1	 2.38	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23835	 1	 7.23	 4.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23836	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23837	 1	 2.88	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23838	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23839	 1	 5.27	 3.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23840	 1	 2.94	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23841	 1	 3.27	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23842	 1	 3.05	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23843	 1	 2.42	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23844	 1	 1.78	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23845	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23846	 1	 1.0	 0.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23847	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23848	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23849	 1	 3.65	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23850	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23851	 1	 1.99	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23852	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23853	 1	 2.98	 2.19	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23854	 1	 39.54	 16.41	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23855	 1	 3.04	 2.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23856	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23857	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23858	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23859	 1	 1.92	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23860	 1	 2.12	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23861	 1	 9.0	 4.17	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23862	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23863	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23864	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23865	 1	 3.63	 2.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23866	 1	 3.85	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23867	 1	 1.5	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23868	 1	 1.42	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23869	 1	 3.21	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23870	 1	 3.47	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23871	 1	 1.25	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23872	 1	 1.89	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23873	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23874	 1	 2.8	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23875	 1	 2.64	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23876	 1	 1.97	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23877	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23878	 1	 3.46	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23879	 1	 3.22	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23880	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23881	 1	 5.35	 3.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23882	 1	 6.29	 3.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23883	 1	 3.05	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23884	 1	 12.42	 7.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23885	 1	 1.11	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23886	 1	 5.87	 3.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23887	 1	 3.2	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23888	 1	 2.06	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23889	 1	 1.84	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23890	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23891	 1	 8.4	 4.25	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23892	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23893	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23894	 1	 6.78	 3.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23895	 1	 3.06	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23896	 1	 7.26	 4.98	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23897	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23898	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23899	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23900	 1	 2.64	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23901	 1	 8.52	 3.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23902	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23903	 1	 11.92	 5.1	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23904	 1	 12.08	 5.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23905	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23906	 1	 2.57	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23907	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23908	 1	 1.7	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23909	 1	 2.63	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23910	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23911	 1	 4.63	 2.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23912	 1	 4.58	 3.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23913	 1	 3.43	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23914	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23915	 1	 1.88	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23916	 1	 3.81	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23917	 1	 2.02	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23918	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23919	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23920	 1	 2.42	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23921	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23922	 1	 9.73	 4.64	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23923	 1	 4.54	 3.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23924	 1	 0.66	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23925	 1	 2.59	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23926	 1	 1.94	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23927	 1	 0.68	 0.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23928	 1	 2.78	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23929	 1	 6.41	 4.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23930	 1	 13.06	 5.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23931	 1	 0.93	 0.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23932	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23933	 1	 3.75	 2.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23934	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23935	 1	 24.17	 14.28	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23936	 1	 7.96	 5.23	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23937	 1	 1.98	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23938	 1	 1.44	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23939	 1	 1.94	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23940	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23941	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23942	 1	 2.15	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23943	 1	 12.35	 8.04	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23944	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23945	 1	 4.44	 2.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23946	 1	 1.71	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23947	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23948	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23949	 1	 1.13	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23950	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23951	 1	 1.38	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23952	 1	 6.95	 4.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23953	 1	 1.91	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23954	 1	 1.13	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23955	 1	 1.32	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23956	 1	 0.93	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23957	 1	 6.37	 3.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23958	 1	 1.16	 0.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23959	 1	 0.76	 0.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23960	 1	 1.08	 0.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23961	 1	 3.03	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23962	 1	 4.39	 2.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23963	 1	 2.01	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23964	 1	 2.91	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23965	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23966	 1	 0.92	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23967	 1	 2.43	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23968	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23969	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23970	 1	 1.44	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23971	 1	 7.42	 3.58	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23972	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23973	 1	 3.69	 2.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23974	 1	 2.8	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23975	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23976	 1	 1.14	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23977	 1	 1.57	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23978	 1	 2.66	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23979	 1	 2.76	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23980	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23981	 1	 1.08	 0.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23982	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23983	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23984	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23985	 1	 9.99	 5.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23986	 1	 4.18	 3.28	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23987	 1	 1.68	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23988	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23989	 1	 2.37	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23990	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23991	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23992	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23993	 1	 6.25	 3.67	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23994	 1	 1.23	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23995	 1	 11.39	 5.4	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23996	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23997	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23998	 1	 3.8	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	23999	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24000	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24001	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24002	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24003	 1	 1.79	 1.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24004	 1	 1.42	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24005	 1	 3.76	 2.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24006	 1	 1.28	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24007	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24008	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24009	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24010	 1	 3.58	 2.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24011	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24012	 1	 1.68	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24013	 1	 1.64	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24014	 1	 1.02	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24015	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24016	 1	 2.87	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24017	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24018	 1	 2.86	 2.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24019	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24020	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24021	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24022	 1	 3.12	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24023	 1	 2.97	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24024	 1	 4.61	 2.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24025	 1	 6.1	 3.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24026	 1	 2.67	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24027	 1	 13.98	 4.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24028	 1	 1.49	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24029	 1	 8.24	 4.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24030	 1	 2.7	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24031	 1	 2.14	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24032	 1	 3.09	 2.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24033	 1	 1.1	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24034	 1	 4.43	 2.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24035	 1	 2.29	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24036	 1	 1.26	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24037	 1	 1.95	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24038	 1	 7.89	 4.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24039	 1	 6.0	 3.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24040	 1	 3.67	 2.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24041	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24042	 1	 3.96	 2.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24043	 1	 5.28	 3.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24044	 1	 45.16	 20.4	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24045	 1	 3.57	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24046	 1	 1.87	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24047	 1	 4.63	 2.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24048	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24049	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24050	 1	 4.55	 3.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24051	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24052	 1	 2.63	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24053	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24054	 1	 1.62	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24055	 1	 1.58	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24056	 1	 4.36	 2.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24057	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24058	 1	 0.63	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24059	 1	 3.3	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24060	 1	 1.09	 0.86	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24061	 1	 6.6	 4.72	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24062	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24063	 1	 1.96	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24064	 1	 3.55	 2.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24065	 1	 1.78	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24066	 1	 1.63	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24067	 1	 5.67	 3.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24068	 1	 1.17	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24069	 1	 2.61	 1.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24070	 1	 7.96	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24071	 1	 7.49	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24072	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24073	 1	 3.45	 0.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24074	 1	 2.53	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24075	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24076	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24077	 1	 2.9	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24078	 1	 3.32	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24079	 1	 6.59	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24080	 1	 10.8	 2.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24081	 1	 9.09	 2.07	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24082	 4	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24083	 1	 8.96	 2.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24084	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24085	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24086	 1	 5.62	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24087	 1	 1.08	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24088	 1	 6.47	 2.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24089	 1	 2.03	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24090	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24091	 1	 2.19	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24092	 1	 2.19	 1.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24093	 1	 1.28	 0.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24094	 1	 12.38	 7.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24095	 1	 13.34	 8.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24096	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24097	 1	 5.16	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24098	 1	 5.49	 2.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24099	 1	 5.38	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24100	 1	 3.08	 2.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24101	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24102	 1	 14.71	 9.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24103	 1	 1.96	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24104	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24105	 1	 4.9	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24106	 1	 1.76	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24107	 1	 8.1	 3.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24108	 1	 1.4	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24109	 1	 4.72	 2.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24110	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24111	 1	 2.75	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24112	 1	 3.43	 2.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24113	 1	 2.33	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24114	 1	 4.44	 3.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24115	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24116	 1	 5.72	 3.65	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24117	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24118	 1	 4.15	 2.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24119	 1	 6.14	 3.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24120	 1	 2.08	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24121	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24122	 1	 1.92	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24123	 1	 3.47	 2.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24124	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24125	 1	 10.03	 4.52	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24126	 1	 2.18	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24127	 1	 18.92	 7.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24128	 1	 5.2	 3.4	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24129	 1	 1.79	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24130	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24131	 1	 2.63	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24132	 1	 6.43	 3.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24133	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24134	 1	 1.66	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24135	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24136	 1	 4.98	 2.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24137	 1	 1.8	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24138	 1	 6.45	 3.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24139	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24140	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24141	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24142	 1	 3.18	 2.18	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24143	 1	 10.51	 6.82	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24144	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24145	 1	 6.26	 3.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24146	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24147	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24148	 1	 5.22	 3.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24149	 1	 2.88	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24150	 1	 1.35	 0.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24151	 1	 3.47	 2.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24152	 1	 11.79	 2.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24153	 1	 2.6	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24154	 1	 1.37	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24155	 1	 2.38	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24156	 1	 2.1	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24157	 1	 3.91	 2.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24158	 1	 1.47	 0.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24159	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24160	 1	 3.92	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24161	 1	 0.69	 0.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24162	 1	 4.14	 0.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24163	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24164	 1	 1.62	 0.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24165	 1	 4.02	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24166	 1	 3.57	 2.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24167	 1	 1.46	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24168	 1	 2.54	 0.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24169	 1	 1.67	 0.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24170	 1	 1.17	 0.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24171	 1	 1.11	 0.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24172	 1	 7.86	 1.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24173	 1	 7.64	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24174	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24175	 1	 2.66	 0.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24176	 1	 4.41	 3.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24177	 1	 2.97	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24178	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24179	 1	 10.36	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24180	 1	 7.16	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24181	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24182	 1	 2.68	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24183	 1	 1.32	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24184	 1	 2.11	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24185	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24186	 1	 2.98	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24187	 1	 3.28	 2.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24188	 1	 2.41	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24189	 1	 1.52	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24190	 1	 2.82	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24191	 1	 9.16	 4.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24192	 1	 0.76	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24193	 1	 2.11	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24194	 1	 2.23	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24195	 1	 2.0	 1.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24196	 1	 1.01	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24197	 1	 6.55	 3.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24198	 1	 8.29	 5.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24199	 1	 2.33	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24200	 1	 1.3	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24201	 1	 1.12	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24202	 1	 3.19	 1.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24203	 1	 2.88	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24204	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24205	 1	 1.97	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24206	 1	 2.36	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24207	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24208	 1	 1.98	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24209	 1	 2.58	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24210	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24211	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24212	 1	 3.66	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24213	 1	 2.19	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24214	 1	 1.63	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24215	 1	 10.6	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24216	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24217	 1	 1.57	 0.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24218	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24219	 1	 2.33	 0.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24220	 1	 2.28	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24221	 1	 2.21	 0.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24222	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24223	 1	 0.79	 0.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24224	 1	 6.57	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24225	 1	 1.13	 0.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24226	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24227	 1	 3.4	 0.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24228	 1	 2.53	 0.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24229	 1	 3.7	 0.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24230	 1	 7.2	 4.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24231	 1	 8.01	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24232	 1	 3.44	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24233	 1	 2.11	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24234	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24235	 1	 4.12	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24236	 1	 6.25	 3.46	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24237	 1	 6.14	 3.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24238	 1	 4.58	 1.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24239	 1	 17.95	 4.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24240	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24241	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24242	 1	 5.2	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24243	 1	 6.64	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24244	 1	 11.29	 2.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24245	 1	 1.16	 0.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24246	 1	 13.94	 7.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24247	 1	 1.91	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24248	 1	 2.2	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24249	 1	 3.59	 2.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24250	 1	 0.87	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24251	 1	 1.32	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24252	 1	 3.01	 2.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24253	 1	 2.72	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24254	 1	 1.23	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24255	 1	 2.43	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24256	 1	 1.68	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24257	 1	 2.31	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24258	 1	 1.34	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24259	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24260	 1	 2.71	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24261	 1	 2.46	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24262	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24263	 1	 2.86	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24264	 1	 2.75	 2.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24265	 1	 1.61	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24266	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24267	 1	 2.27	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24268	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24269	 1	 2.42	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24270	 1	 1.21	 0.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24271	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24272	 1	 1.12	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24273	 1	 1.51	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24274	 1	 0.66	 0.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24275	 1	 1.68	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24276	 1	 1.59	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24277	 1	 1.71	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24278	 1	 1.4	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24279	 1	 3.49	 2.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24280	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24281	 1	 2.07	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24282	 1	 3.79	 2.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24283	 1	 5.95	 2.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24284	 1	 2.0	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24285	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24286	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24287	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24288	 1	 4.72	 2.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24289	 1	 12.82	 6.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24290	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24291	 1	 1.39	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24292	 1	 3.12	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24293	 1	 4.68	 2.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24294	 1	 2.49	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24295	 1	 2.08	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24296	 1	 2.21	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24297	 1	 1.76	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24298	 1	 3.26	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24299	 1	 1.63	 1.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24300	 1	 2.43	 1.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24301	 1	 1.75	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24302	 1	 3.94	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24303	 1	 1.75	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24304	 1	 2.28	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24305	 1	 3.09	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24306	 1	 1.93	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24307	 1	 2.81	 2.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24308	 1	 3.01	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24309	 1	 1.92	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24310	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24311	 1	 4.02	 2.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24312	 1	 2.05	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24313	 1	 2.7	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24314	 1	 3.3	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24315	 1	 1.69	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24316	 1	 1.1	 0.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24317	 1	 0.87	 0.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24318	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24319	 1	 2.03	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24320	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24321	 1	 1.21	 0.77	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24322	 1	 1.41	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24323	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24324	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24325	 1	 1.38	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24326	 1	 2.32	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24327	 1	 1.6	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24328	 1	 4.26	 2.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24329	 1	 0.63	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24330	 1	 1.55	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24331	 1	 2.03	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24332	 1	 0.85	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24333	 1	 1.0	 0.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24334	 1	 2.76	 2.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24335	 1	 2.02	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24336	 1	 2.78	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24337	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24338	 1	 0.73	 0.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24339	 1	 2.02	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24340	 1	 5.26	 2.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24341	 1	 6.68	 4.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24342	 1	 2.03	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24343	 1	 1.97	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24344	 1	 2.42	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24345	 1	 1.14	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24346	 1	 2.33	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24347	 1	 0.6	 0.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24348	 1	 10.34	 5.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24349	 1	 2.29	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24350	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24351	 1	 2.43	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24352	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24353	 1	 0.79	 0.49	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24354	 1	 0.56	 0.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24355	 1	 3.73	 2.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24356	 1	 2.44	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24357	 1	 4.77	 2.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24358	 1	 3.5	 2.26	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24359	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24360	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24361	 1	 9.8	 5.17	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24362	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24363	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24364	 1	 3.47	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24365	 1	 2.53	 1.39	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24366	 1	 0.93	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24367	 1	 4.95	 3.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24368	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24369	 1	 0.94	 0.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24370	 1	 0.42	 0.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24371	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24372	 1	 3.15	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24373	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24374	 1	 9.58	 5.5	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24375	 1	 2.74	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24376	 1	 1.86	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24377	 1	 1.72	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24378	 1	 2.55	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24379	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24380	 1	 6.28	 3.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24381	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24382	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24383	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24384	 1	 4.95	 3.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24385	 1	 1.63	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24386	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24387	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24388	 1	 1.18	 0.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24389	 1	 1.73	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24390	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24391	 1	 2.73	 2.23	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24392	 1	 2.09	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24393	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24394	 1	 2.49	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24395	 1	 1.66	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24396	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24397	 1	 2.27	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24398	 1	 1.83	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24399	 1	 0.92	 0.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24400	 1	 0.9	 0.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24401	 1	 5.47	 2.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24402	 1	 3.15	 2.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24403	 1	 7.17	 3.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24404	 1	 1.4	 0.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24405	 1	 1.4	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24406	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24407	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24408	 1	 1.49	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24409	 1	 1.12	 0.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24410	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24411	 1	 0.86	 0.56	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24412	 1	 1.98	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24413	 1	 1.61	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24414	 1	 1.56	 0.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24415	 1	 1.34	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24416	 1	 1.28	 0.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24417	 1	 1.4	 0.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24418	 1	 0.56	 0.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24419	 1	 1.24	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24420	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24421	 1	 0.81	 0.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24422	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24423	 1	 1.33	 0.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24424	 1	 1.12	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24425	 1	 0.92	 0.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24426	 1	 2.14	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24427	 1	 0.71	 0.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24428	 1	 1.34	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24429	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24430	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24431	 1	 1.31	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24432	 1	 5.81	 3.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24433	 1	 0.67	 0.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24434	 1	 1.08	 0.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24435	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24436	 1	 1.23	 0.87	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24437	 1	 1.48	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24438	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24439	 1	 1.91	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24440	 1	 6.55	 4.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24441	 1	 7.03	 4.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24442	 1	 6.86	 3.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24443	 1	 2.48	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24444	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24445	 1	 1.05	 0.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24446	 1	 2.35	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24447	 1	 2.06	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24448	 1	 2.29	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24449	 1	 2.66	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24450	 1	 5.32	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24451	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24452	 1	 1.04	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24453	 1	 1.38	 0.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24454	 1	 2.54	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24455	 1	 2.78	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24456	 1	 7.48	 4.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24457	 1	 5.95	 2.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24458	 1	 2.25	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24459	 1	 1.83	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24460	 1	 1.82	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24461	 1	 1.67	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24462	 1	 1.8	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24463	 1	 1.18	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24464	 1	 1.1	 0.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24465	 1	 1.59	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24466	 1	 2.26	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24467	 1	 2.96	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24468	 1	 2.4	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24469	 1	 2.76	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24470	 1	 1.4	 0.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24471	 1	 2.34	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24472	 1	 2.06	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24473	 1	 1.31	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24474	 1	 2.86	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24475	 1	 2.15	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24476	 1	 1.93	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24477	 1	 3.78	 2.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24478	 1	 1.98	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24479	 1	 1.49	 0.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24480	 1	 1.59	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24481	 1	 2.32	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24482	 1	 2.6	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24483	 1	 2.04	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24484	 1	 2.11	 1.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24485	 1	 2.37	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24486	 1	 2.13	 1.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24487	 1	 2.0	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24488	 1	 2.39	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24489	 1	 2.13	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24490	 1	 1.74	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24491	 1	 1.98	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24492	 1	 2.5	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24493	 1	 2.33	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24494	 1	 2.06	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24495	 1	 1.98	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24496	 1	 1.49	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24497	 1	 2.31	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24498	 1	 1.93	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24499	 1	 2.8	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24500	 1	 1.55	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24501	 1	 1.1	 0.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24502	 1	 2.61	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24503	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24504	 1	 1.25	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24505	 1	 1.88	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24506	 1	 2.36	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24507	 1	 1.58	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24508	 1	 2.67	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24509	 1	 1.54	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24510	 1	 0.97	 0.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24511	 1	 1.0	 0.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24512	 1	 1.43	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24513	 1	 0.87	 0.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24514	 1	 1.3	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24515	 1	 1.22	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24516	 1	 1.19	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24517	 1	 1.43	 0.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24518	 1	 2.62	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24519	 1	 1.59	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24520	 1	 2.1	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24521	 1	 1.99	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24522	 1	 1.06	 0.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24523	 1	 2.92	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24524	 1	 2.66	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24525	 1	 1.44	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24526	 1	 2.99	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24527	 1	 2.18	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24528	 1	 2.01	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24529	 1	 2.58	 1.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24530	 1	 1.4	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24531	 1	 6.75	 3.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24532	 1	 2.91	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24533	 1	 1.04	 0.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24534	 1	 1.23	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24535	 1	 2.56	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24536	 1	 3.37	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24537	 1	 1.9	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24538	 1	 2.4	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24539	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24540	 1	 1.78	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24541	 1	 2.28	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24542	 1	 1.94	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24543	 1	 2.79	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24544	 1	 3.58	 2.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24545	 1	 1.2	 0.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24546	 1	 1.69	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24547	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24548	 1	 2.84	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24549	 1	 2.74	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24550	 1	 3.65	 2.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24551	 1	 1.33	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24552	 1	 2.34	 1.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24553	 1	 1.67	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24554	 1	 2.29	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24555	 1	 1.77	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24556	 1	 6.62	 3.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24557	 1	 1.97	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24558	 1	 2.21	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24559	 1	 4.3	 3.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24560	 1	 9.62	 5.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24561	 1	 3.03	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24562	 1	 0.75	 0.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24563	 1	 5.34	 2.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24564	 1	 0.99	 0.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24565	 1	 1.43	 0.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24566	 1	 3.11	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24567	 1	 1.64	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24568	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24569	 1	 2.84	 2.03	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24570	 1	 2.64	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24571	 1	 1.91	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24572	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24573	 1	 1.97	 1.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24574	 1	 1.58	 1.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24575	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24576	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24577	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24578	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24579	 1	 2.56	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24580	 1	 2.47	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24581	 1	 1.71	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24582	 1	 2.72	 2.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24583	 1	 2.11	 1.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24584	 1	 7.31	 4.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24585	 1	 2.57	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24586	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24587	 1	 1.78	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24588	 1	 1.3	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24589	 1	 1.18	 0.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24590	 1	 2.32	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24591	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24592	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24593	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24594	 1	 1.22	 0.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24595	 1	 1.64	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24596	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24597	 1	 2.58	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24598	 1	 1.97	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24599	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24600	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24601	 1	 1.91	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24602	 1	 3.08	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24603	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	24604	 1	 3.25	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24605	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24606	 1	 1.58	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24607	 1	 1.6	 1.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24608	 1	 1.37	 1.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24609	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24610	 1	 1.2	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24611	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24612	 1	 1.22	 0.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24613	 1	 4.37	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24614	 1	 4.68	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24615	 1	 2.93	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24616	 1	 3.84	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24617	 1	 3.01	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24618	 1	 8.86	 2.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24619	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24620	 1	 33.44	 15.03	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24621	 1	 3.53	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24622	 1	 1.04	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24623	 1	 3.32	 2.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24624	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24625	 1	 3.36	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24626	 1	 6.22	 4.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24627	 1	 5.38	 3.51	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24628	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24629	 1	 1.98	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24630	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24631	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24632	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24633	 1	 1.71	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24634	 1	 2.3	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24635	 1	 1.45	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24636	 1	 2.5	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24637	 1	 2.05	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24638	 1	 2.44	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24639	 1	 2.86	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24640	 1	 1.82	 1.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24641	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24642	 1	 2.2	 1.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24643	 1	 2.22	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24644	 1	 2.29	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24645	 1	 4.24	 2.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24646	 1	 2.8	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24647	 1	 3.21	 2.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24648	 1	 3.13	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24649	 1	 4.9	 3.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24650	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24651	 1	 3.53	 2.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24652	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24653	 1	 2.9	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24654	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24655	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24656	 1	 2.09	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24657	 1	 2.76	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24658	 1	 1.66	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24659	 1	 3.2	 2.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24660	 1	 2.43	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24661	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24662	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24663	 1	 8.56	 3.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24664	 1	 7.05	 4.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24665	 1	 1.98	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24666	 1	 3.24	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24667	 1	 1.81	 1.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24668	 1	 1.72	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24669	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24670	 1	 1.6	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24671	 1	 5.21	 3.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24672	 1	 2.33	 1.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24673	 1	 2.37	 1.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24674	 1	 7.53	 4.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24675	 1	 2.3	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24676	 1	 2.88	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24677	 1	 2.92	 1.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24678	 1	 4.21	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24679	 1	 2.42	 1.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24680	 1	 2.66	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24681	 1	 1.24	 0.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24682	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24683	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24684	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24685	 1	 1.83	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24686	 1	 1.69	 1.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24687	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24688	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24689	 1	 1.47	 0.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24690	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24691	 1	 5.67	 2.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24692	 1	 4.72	 2.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24693	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24694	 1	 1.41	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24695	 1	 1.47	 1.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24696	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24697	 1	 1.51	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24698	 1	 2.37	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24699	 1	 1.52	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24700	 1	 2.1	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24701	 1	 2.42	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24702	 1	 1.78	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24703	 1	 1.23	 0.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24704	 1	 3.9	 2.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24705	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24706	 1	 4.14	 2.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24707	 1	 3.89	 2.37	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24708	 1	 4.11	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24709	 1	 2.82	 1.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24710	 1	 3.41	 2.53	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24711	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24712	 1	 1.84	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24713	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24714	 1	 2.97	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24715	 1	 2.29	 1.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24716	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24717	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24718	 1	 1.01	 0.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24719	 1	 3.44	 2.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24720	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24721	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24722	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24723	 1	 4.75	 2.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24724	 1	 6.4	 3.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24725	 1	 11.28	 7.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24726	 1	 3.6	 2.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24727	 1	 2.72	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24728	 1	 1.87	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24729	 1	 7.48	 4.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24730	 1	 2.94	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24731	 1	 2.47	 1.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24732	 1	 2.5	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24733	 1	 2.37	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24734	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24735	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24736	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24737	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24738	 1	 9.44	 5.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24739	 1	 2.01	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24740	 1	 1.07	 0.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24741	 1	 2.54	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24742	 1	 2.37	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24743	 1	 2.75	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24744	 1	 2.09	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24745	 1	 3.42	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24746	 1	 3.94	 2.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24747	 1	 5.39	 3.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24748	 1	 3.26	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24749	 1	 3.24	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24750	 1	 1.85	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24751	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24752	 1	 1.05	 0.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24753	 1	 3.87	 2.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24754	 1	 2.06	 1.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24755	 1	 1.42	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24756	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24757	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24758	 1	 4.69	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24759	 1	 4.93	 3.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24760	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24761	 1	 9.07	 4.91	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24762	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24763	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24764	 1	 4.11	 2.65	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24765	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24766	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24767	 1	 2.31	 1.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24768	 1	 1.4	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24769	 1	 1.82	 1.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24770	 1	 2.94	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24771	 1	 1.59	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24772	 1	 4.68	 3.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24773	 1	 3.12	 2.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24774	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24775	 1	 3.47	 2.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24776	 1	 2.42	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24777	 1	 1.77	 1.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24778	 1	 4.9	 2.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24779	 1	 2.76	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24780	 1	 3.78	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24781	 1	 3.56	 2.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24782	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24783	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24784	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24785	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24786	 1	 3.98	 2.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24787	 1	 3.09	 1.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24788	 1	 1.23	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24789	 1	 2.09	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24790	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24791	 1	 4.08	 2.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24792	 1	 2.33	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24793	 1	 3.41	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24794	 1	 3.35	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24795	 1	 2.28	 1.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24796	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24797	 1	 7.7	 4.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24798	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24799	 1	 6.35	 4.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24800	 1	 1.65	 1.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24801	 1	 3.25	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24802	 1	 22.02	 12.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24803	 1	 2.09	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24804	 1	 1.26	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24805	 1	 19.83	 10.79	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24806	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24807	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24808	 1	 26.43	 13.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24809	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24810	 1	 35.34	 19.32	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24811	 1	 3.48	 2.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24812	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24813	 1	 1.72	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24814	 1	 2.93	 2.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24815	 1	 10.17	 5.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24816	 1	 7.74	 4.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24817	 1	 9.59	 5.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24818	 1	 5.27	 3.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24819	 1	 8.26	 3.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24820	 1	 1.47	 1.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24821	 1	 3.03	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24822	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24823	 1	 6.3	 4.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24824	 1	 3.32	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24825	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24826	 1	 2.68	 2.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24827	 1	 2.57	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24828	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24829	 1	 2.26	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24830	 1	 2.99	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24831	 1	 13.27	 6.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24832	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24833	 1	 1.89	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24834	 1	 2.36	 1.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24835	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24836	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24837	 1	 32.86	 15.83	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24838	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24839	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24840	 1	 3.95	 2.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24841	 1	 2.21	 1.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24842	 1	 1.28	 0.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24843	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24844	 1	 6.13	 3.9	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24845	 1	 20.67	 10.25	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24846	 1	 2.07	 1.37	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24847	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24848	 1	 12.8	 3.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24849	 1	 10.96	 4.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24850	 1	 2.19	 1.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24851	 1	 13.34	 8.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24852	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24853	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24854	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24855	 1	 5.85	 3.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24856	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24857	 1	 3.97	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24858	 1	 2.88	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24859	 1	 2.42	 1.58	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24860	 1	 19.24	 10.23	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24861	 1	 3.14	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24862	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24863	 1	 7.0	 4.22	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24864	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24865	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24866	 1	 7.49	 3.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24867	 1	 6.12	 2.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24868	 1	 3.34	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24869	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24870	 1	 19.16	 6.8	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24871	 1	 14.39	 4.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24872	 1	 2.36	 1.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24873	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24874	 1	 8.98	 4.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24875	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24876	 1	 9.92	 3.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24877	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24878	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24879	 1	 2.97	 1.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24880	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24881	 1	 6.12	 2.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24882	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	24883	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24884	 1	 2.83	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24885	 1	 3.84	 1.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24886	 1	 3.93	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24887	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24888	 1	 8.58	 3.09	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24889	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24890	 1	 2.33	 0.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24891	 1	 2.42	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24892	 1	 6.93	 2.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24893	 1	 2.25	 0.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24894	 1	 1.72	 0.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24895	 1	 1.5	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24896	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24897	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24898	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24899	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24900	 1	 9.13	 3.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24901	 1	 5.7	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24902	 1	 12.68	 4.79	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24903	 1	 12.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24904	 1	 7.76	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24905	 1	 10.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24906	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24907	 1	 2.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24908	 1	 6.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24909	 1	 7.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24910	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24911	 1	 5.49	 2.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24912	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24913	 1	 9.85	 3.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24914	 1	 17.19	 4.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24915	 1	 8.23	 3.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24916	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24917	 1	 10.14	 3.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24918	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24919	 1	 5.35	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24920	 1	 12.53	 5.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24921	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24922	 1	 7.72	 3.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24923	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24924	 1	 55.3	 22.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24925	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24926	 1	 12.91	 4.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24927	 1	 8.55	 4.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24928	 1	 3.15	 1.56	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24929	 1	 18.99	 7.05	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24930	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24931	 1	 12.67	 4.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24932	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24933	 1	 2.89	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24934	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24935	 1	 9.21	 4.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24936	 1	 7.76	 1.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24937	 1	 8.59	 3.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24938	 1	 16.21	 3.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24939	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24940	 1	 5.31	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24941	 1	 11.93	 5.2	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24942	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24943	 1	 4.24	 2.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24944	 1	 4.64	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24945	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24946	 1	 4.1	 2.14	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24947	 1	 6.87	 2.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24948	 1	 3.33	 1.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24949	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24950	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24951	 1	 14.84	 6.41	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24952	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24953	 1	 9.49	 4.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24954	 1	 5.1	 2.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24955	 1	 7.61	 3.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24956	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24957	 1	 6.76	 1.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24958	 1	 8.11	 3.36	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24959	 1	 22.37	 5.23	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24960	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24961	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24962	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24963	 1	 2.32	 0.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24964	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24965	 1	 17.58	 6.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24966	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24967	 1	 3.57	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24968	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24969	 1	 4.16	 1.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24970	 1	 2.26	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24971	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24972	 1	 5.11	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24973	 1	 5.81	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24974	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24975	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24976	 1	 3.3	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24977	 1	 1.7	 0.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24978	 1	 1.37	 0.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24979	 1	 7.98	 3.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24980	 1	 2.56	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24981	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24982	 1	 7.93	 3.62	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24983	 1	 5.69	 2.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24984	 1	 6.64	 2.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24985	 1	 8.2	 3.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24986	 1	 5.14	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24987	 1	 18.47	 7.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24988	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24989	 1	 8.78	 3.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24990	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24991	 1	 5.97	 2.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24992	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	24993	 1	 9.95	 3.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24994	 1	 5.23	 2.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24995	 1	 4.1	 1.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24996	 1	 3.98	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24997	 1	 16.13	 6.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24998	 1	 4.93	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	24999	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25000	 1	 5.3	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25001	 1	 13.47	 5.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25002	 1	 6.79	 3.25	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25003	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25004	 1	 9.79	 3.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25005	 1	 12.45	 4.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25006	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25007	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25008	 1	 4.82	 2.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25009	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25010	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25011	 1	 4.56	 2.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25012	 1	 3.93	 1.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25013	 1	 4.63	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25014	 1	 7.71	 3.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25015	 1	 10.44	 4.34	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25016	 1	 7.61	 2.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25017	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25018	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25019	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25020	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25021	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25022	 1	 52.26	 19.17	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25023	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25024	 1	 4.1	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25025	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25026	 1	 6.23	 2.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25027	 1	 49.23	 16.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25028	 1	 7.19	 2.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25029	 1	 5.1	 2.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25030	 1	 7.26	 3.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25031	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25032	 1	 8.28	 4.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25033	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25034	 1	 2.93	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25035	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25036	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25037	 1	 7.05	 2.81	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25038	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25039	 1	 4.98	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25040	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25041	 1	 4.47	 1.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25042	 1	 9.1	 3.81	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25043	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25044	 1	 5.75	 2.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25045	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25046	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25047	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25048	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25049	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25050	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25051	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25052	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25053	 1	 4.67	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25054	 1	 2.64	 1.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25055	 1	 5.82	 2.6	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25056	 1	 3.05	 1.36	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25057	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25058	 1	 3.23	 1.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25059	 1	 3.78	 1.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25060	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25061	 1	 3.71	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25062	 1	 8.57	 4.03	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25063	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25064	 1	 6.8	 2.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25065	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25066	 1	 4.91	 2.45	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25067	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25068	 1	 8.12	 2.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25069	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25070	 1	 7.06	 3.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25071	 1	 6.26	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25072	 1	 11.06	 5.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25073	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25074	 1	 16.32	 6.79	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25075	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25076	 1	 9.65	 4.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25077	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25078	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25079	 1	 8.71	 4.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25080	 1	 3.16	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25081	 1	 1.76	 0.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25082	 1	 12.46	 2.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25083	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25084	 1	 6.88	 1.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25085	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25086	 1	 2.87	 0.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25087	 1	 9.69	 2.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25088	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25089	 1	 8.09	 1.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25090	 1	 6.5	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25091	 1	 1.86	 0.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25092	 1	 3.65	 0.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25093	 1	 2.41	 0.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25094	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25095	 1	 5.86	 1.36	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25096	 1	 6.4	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25097	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25098	 1	 1.21	 0.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25099	 1	 1.46	 0.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25100	 1	 1.41	 0.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25101	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25102	 1	 10.7	 2.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25103	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25104	 1	 9.07	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25105	 1	 10.08	 2.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25106	 1	 9.08	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25107	 1	 8.19	 1.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25108	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25109	 1	 5.43	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25110	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25111	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25112	 1	 5.58	 1.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25113	 1	 7.05	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25114	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25115	 1	 2.71	 0.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25116	 1	 10.87	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25117	 1	 3.95	 0.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25118	 1	 9.58	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25119	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25120	 1	 14.08	 3.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25121	 1	 5.88	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25122	 1	 11.02	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25123	 1	 7.71	 1.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25124	 1	 10.16	 2.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25125	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25126	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25127	 1	 4.68	 1.1	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25128	 1	 4.07	 0.96	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25129	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25130	 1	 15.31	 3.6	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25131	 1	 15.42	 3.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25132	 1	 8.06	 1.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25133	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25134	 1	 11.81	 2.76	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25135	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25136	 1	 2.86	 1.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25137	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25138	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25139	 1	 9.91	 3.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25140	 1	 3.73	 1.84	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25141	 1	 4.82	 1.86	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25142	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25143	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25144	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25145	 1	 3.65	 1.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25146	 1	 2.51	 1.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25147	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25148	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25149	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25150	 1	 4.63	 1.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25151	 1	 8.89	 4.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25152	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25153	 1	 17.7	 6.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25154	 1	 8.48	 2.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25155	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25156	 1	 11.85	 5.83	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25157	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25158	 1	 4.88	 2.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25159	 1	 0.04	 0.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25160	 1	 6.29	 2.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25161	 1	 8.23	 3.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25162	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25163	 1	 5.43	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25164	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25165	 1	 6.02	 2.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25166	 1	 5.69	 2.66	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25167	 1	 7.55	 3.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25168	 1	 15.73	 7.34	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25169	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25170	 1	 5.67	 2.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25171	 1	 3.21	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25172	 1	 5.29	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25173	 1	 13.01	 4.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25174	 1	 6.75	 2.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25175	 1	 10.99	 3.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25176	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25177	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25178	 1	 7.81	 2.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25179	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25180	 1	 5.04	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25181	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25182	 1	 5.74	 2.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25183	 1	 8.83	 3.06	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25184	 1	 7.53	 2.89	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25185	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25186	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25187	 1	 10.19	 4.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25188	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25189	 1	 7.0	 2.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25190	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25191	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25192	 1	 4.57	 1.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25193	 1	 7.29	 2.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25194	 1	 13.24	 5.64	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25195	 1	 5.01	 2.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25196	 1	 4.22	 2.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25197	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25198	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25199	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25200	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25201	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25202	 1	 5.26	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25203	 1	 3.48	 1.58	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25204	 1	 3.37	 1.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25205	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25206	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25207	 1	 4.46	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25208	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25209	 1	 6.41	 2.81	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25210	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25211	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25212	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25213	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25214	 1	 8.85	 2.52	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25215	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25216	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25217	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25218	 1	 5.73	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25219	 1	 4.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25220	 1	 14.53	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25221	 1	 21.14	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25222	 1	 5.69	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25223	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25224	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25225	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25226	 1	 5.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25227	 1	 14.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25228	 1	 9.58	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25229	 1	 4.7	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25230	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25231	 1	 1.73	 0.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25232	 1	 9.9	 4.54	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25233	 1	 10.64	 4.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25234	 1	 9.06	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25235	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25236	 1	 11.02	 2.96	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25237	 1	 5.81	 2.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25238	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25239	 1	 3.83	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25240	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25241	 1	 4.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25242	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25243	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25244	 1	 2.22	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25245	 1	 2.74	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25246	 1	 3.15	 1.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25247	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25248	 1	 2.96	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25249	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25250	 1	 9.95	 3.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25251	 1	 6.71	 2.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25252	 1	 2.69	 1.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25253	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25254	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25255	 1	 3.4	 1.29	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25256	 1	 7.13	 3.09	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25257	 1	 7.87	 2.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25258	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25259	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25260	 1	 7.15	 2.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25261	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25262	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25263	 1	 3.64	 1.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25264	 1	 17.17	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25265	 1	 5.04	 2.05	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25266	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25267	 1	 2.29	 1.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25268	 1	 7.5	 3.02	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25269	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25270	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25271	 1	 4.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25272	 1	 6.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25273	 1	 4.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25274	 1	 1.08	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25275	 1	 3.18	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25276	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25277	 1	 7.73	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25278	 1	 5.35	 2.38	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25279	 1	 26.62	 10.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25280	 1	 13.56	 5.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25281	 1	 22.13	 7.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25282	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25283	 1	 59.43	 17.04	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25284	 1	 17.03	 6.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25285	 1	 10.72	 3.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25286	 1	 11.18	 4.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25287	 1	 9.62	 3.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25288	 1	 3.61	 1.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25289	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25290	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25291	 1	 4.9	 1.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25292	 1	 43.73	 11.73	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25293	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25294	 1	 1.81	 0.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25295	 1	 1.15	 0.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25296	 1	 1.1	 0.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25297	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25298	 1	 1.1	 0.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25299	 1	 0.81	 0.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25300	 1	 1.71	 0.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25301	 1	 6.18	 2.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25302	 1	 6.18	 1.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25303	 1	 1.15	 0.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25304	 1	 1.24	 0.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25305	 1	 1.02	 0.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25306	 1	 2.69	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25307	 1	 20.46	 5.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25308	 1	 1.19	 0.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25309	 1	 2.88	 1.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25310	 1	 9.74	 2.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25311	 1	 5.59	 1.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25312	 1	 4.76	 1.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25313	 1	 52.2	 11.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25314	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25315	 1	 0.23	 0.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25316	 1	 5.61	 2.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25317	 1	 1.29	 0.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25318	 1	 1.41	 0.66	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25319	 1	 14.77	 5.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25320	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25321	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25322	 1	 11.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25323	 1	 3.56	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25324	 1	 2.59	 0.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25325	 1	 2.09	 0.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25326	 1	 4.81	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25327	 1	 3.39	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25328	 1	 2.76	 1.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25329	 1	 4.99	 2.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25330	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25331	 1	 3.7	 1.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25332	 1	 3.17	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25333	 1	 3.32	 1.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25334	 1	 2.5	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25335	 1	 9.84	 3.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25336	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25337	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25338	 1	 5.43	 1.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25339	 1	 16.53	 5.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25340	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25341	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25342	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25343	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25344	 1	 2.27	 1.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25345	 1	 3.5	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25346	 1	 2.41	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25347	 1	 5.62	 2.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25348	 1	 0.97	 0.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25349	 1	 1.96	 0.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25350	 1	 20.39	 7.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25351	 1	 4.7	 1.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25352	 1	 11.08	 3.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25353	 1	 20.27	 6.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25354	 1	 1.22	 0.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25355	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25356	 1	 2.8	 1.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25357	 1	 6.11	 2.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25358	 1	 6.12	 2.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25359	 1	 6.6	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25360	 1	 5.08	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25361	 1	 1.97	 0.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25362	 1	 2.16	 1.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25363	 1	 5.26	 2.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25364	 1	 3.18	 1.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25365	 1	 2.57	 1.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25366	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25367	 1	 2.31	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25368	 1	 5.49	 2.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25369	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25370	 1	 3.92	 1.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25371	 1	 2.22	 1.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25372	 1	 5.06	 1.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25373	 1	 2.22	 1.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25374	 1	 2.2	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25375	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25376	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25377	 1	 5.5	 2.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25378	 1	 3.11	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25379	 1	 6.34	 2.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25380	 1	 1.65	 0.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25381	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25382	 1	 10.18	 3.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25383	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25384	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25385	 1	 2.4	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25386	 1	 6.8	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25387	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25388	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25389	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25390	 1	 3.75	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25391	 1	 4.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25392	 1	 13.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25393	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25394	 1	 9.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25395	 1	 6.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25396	 1	 4.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25397	 1	 5.75	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25398	 1	 6.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25399	 1	 3.92	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25400	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25401	 1	 35.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25402	 1	 3.88	 1.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25403	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25404	 1	 4.39	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25405	 1	 4.31	 1.88	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25406	 1	 4.14	 1.79	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25407	 1	 5.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25408	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25409	 1	 4.2	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25410	 1	 4.42	 2.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25411	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25412	 1	 8.74	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25413	 1	 8.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25414	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25415	 1	 11.02	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25416	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25417	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25418	 1	 5.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25419	 1	 7.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25420	 1	 2.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25421	 1	 4.34	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25422	 1	 6.92	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25423	 1	 4.11	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25424	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25425	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25426	 1	 31.42	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25427	 1	 6.64	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25428	 1	 15.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25429	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25430	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25431	 1	 6.76	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25432	 1	 10.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25433	 1	 12.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25434	 1	 7.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25435	 1	 12.09	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25436	 1	 5.34	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25437	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25438	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25439	 1	 3.44	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25440	 1	 2.21	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25441	 1	 3.02	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25442	 1	 6.59	 2.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25443	 1	 6.63	 3.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25444	 1	 3.4	 1.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25445	 1	 3.28	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25446	 1	 4.43	 1.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25447	 1	 4.42	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25448	 1	 3.08	 1.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25449	 1	 7.71	 3.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25450	 1	 6.96	 3.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25451	 1	 3.07	 1.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25452	 1	 5.02	 2.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25453	 1	 2.65	 1.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25454	 1	 2.14	 0.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25455	 1	 1.67	 0.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25456	 1	 3.72	 1.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25457	 1	 1.97	 0.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25458	 1	 6.84	 3.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25459	 1	 2.33	 0.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25460	 1	 1.59	 0.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25461	 1	 10.74	 3.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25462	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25463	 1	 2.08	 0.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25464	 1	 4.89	 1.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25465	 1	 1.74	 0.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25466	 1	 1.36	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25467	 1	 4.52	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25468	 1	 4.66	 1.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25469	 1	 4.57	 2.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25470	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25471	 1	 4.21	 1.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25472	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25473	 1	 2.64	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25474	 1	 4.11	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25475	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25476	 1	 7.03	 3.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25477	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25478	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25479	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25480	 1	 4.51	 2.33	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25481	 1	 7.4	 2.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25482	 1	 2.65	 1.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25483	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25484	 1	 7.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25485	 1	 6.18	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25486	 1	 5.68	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25487	 1	 6.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25488	 1	 3.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25489	 1	 4.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25490	 1	 7.81	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25491	 1	 1.98	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25492	 1	 6.98	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25493	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25494	 1	 6.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25495	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25496	 1	 6.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25497	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25498	 1	 20.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25499	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25500	 1	 5.92	 2.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25501	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25502	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25503	 1	 1.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25504	 1	 3.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25505	 1	 1.96	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25506	 1	 6.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25507	 1	 7.06	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25508	 1	 5.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25509	 1	 5.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25510	 1	 2.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25511	 1	 4.61	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25512	 1	 3.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25513	 1	 1.76	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25514	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25515	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25516	 1	 10.2	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25517	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25518	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25519	 1	 4.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25520	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25521	 1	 3.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25522	 1	 2.8	 1.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25523	 1	 12.13	 5.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25524	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25525	 1	 5.49	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25526	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25527	 1	 5.66	 2.59	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25528	 1	 10.54	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25529	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25530	 1	 9.21	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25531	 1	 5.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25532	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25533	 1	 5.91	 2.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25534	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25535	 1	 10.13	 3.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25536	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25537	 1	 11.18	 4.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25538	 1	 9.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25539	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25540	 1	 2.61	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25541	 1	 9.04	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25542	 1	 14.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25543	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25544	 1	 2.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25545	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25546	 1	 11.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25547	 1	 5.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25548	 1	 3.94	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25549	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25550	 1	 6.12	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25551	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25552	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25553	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25554	 1	 8.78	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25555	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25556	 1	 3.08	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25557	 1	 15.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25558	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25559	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25560	 1	 7.75	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25561	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25562	 1	 4.46	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25563	 1	 5.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25564	 1	 3.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25565	 1	 6.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25566	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25567	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25568	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25569	 1	 3.04	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25570	 1	 3.03	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25571	 1	 6.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25572	 1	 6.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25573	 1	 4.1	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25574	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25575	 1	 3.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25576	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25577	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25578	 1	 2.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25579	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25580	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25581	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25582	 1	 2.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25583	 1	 4.84	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25584	 1	 4.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25585	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25586	 1	 4.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25587	 1	 4.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25588	 1	 8.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25589	 1	 5.21	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25590	 1	 3.03	 1.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25591	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25592	 1	 10.09	 4.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25593	 1	 6.74	 2.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25594	 1	 10.63	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25595	 1	 7.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25596	 1	 10.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25597	 1	 12.84	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25598	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25599	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25600	 1	 3.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25601	 1	 10.2	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25602	 1	 4.87	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25603	 1	 2.4	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25604	 1	 4.82	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25605	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25606	 1	 3.39	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25607	 1	 7.27	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25608	 1	 4.53	 2.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25609	 1	 2.29	 0.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25610	 1	 5.34	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25611	 1	 6.36	 2.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25612	 1	 1.56	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25613	 1	 4.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25614	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25615	 1	 4.57	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25616	 1	 12.46	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25617	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25618	 1	 10.48	 2.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25619	 1	 2.62	 1.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25620	 1	 4.69	 2.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25621	 1	 5.74	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25622	 1	 2.69	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25623	 1	 5.25	 2.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25624	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25625	 1	 26.25	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25626	 1	 4.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25627	 1	 3.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25628	 1	 9.45	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25629	 1	 10.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25630	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25631	 1	 4.74	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25632	 1	 7.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25633	 1	 9.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25634	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25635	 1	 6.17	 2.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25636	 1	 3.22	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25637	 1	 6.26	 2.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25638	 1	 10.9	 5.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25639	 1	 7.07	 3.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25640	 1	 26.99	 10.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25641	 1	 5.58	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25642	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25643	 1	 11.8	 4.62	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25644	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25645	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25646	 1	 6.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25647	 1	 3.58	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25648	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25649	 1	 9.78	 4.8	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25650	 1	 4.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25651	 1	 2.54	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25652	 1	 1.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25653	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25654	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25655	 1	 1.39	 0.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25656	 1	 22.42	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25657	 1	 6.36	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25658	 1	 1.94	 0.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25659	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25660	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25661	 1	 2.94	 1.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25662	 1	 2.81	 1.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25663	 1	 6.64	 2.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25664	 1	 4.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25665	 1	 34.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25666	 1	 3.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25667	 1	 11.02	 4.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25668	 1	 5.51	 2.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25669	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	25670	 1	 6.21	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25671	 1	 5.5	 2.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25672	 1	 7.64	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25673	 1	 3.74	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25674	 1	 59.34	 18.66	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25675	 1	 18.53	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25676	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25677	 1	 4.23	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25678	 1	 6.64	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25679	 1	 6.46	 2.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25680	 1	 9.01	 2.71	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25681	 1	 12.57	 4.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25682	 1	 6.1	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25683	 1	 12.9	 4.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25684	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25685	 1	 49.64	 15.73	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25686	 1	 15.26	 5.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25687	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25688	 1	 8.19	 3.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25689	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25690	 1	 6.14	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25691	 1	 8.65	 2.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25692	 1	 7.73	 3.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25693	 1	 16.65	 5.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25694	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25695	 1	 4.98	 2.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25696	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25697	 1	 5.45	 2.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25698	 1	 8.85	 2.07	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25699	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25700	 1	 3.33	 0.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25701	 1	 3.34	 0.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25702	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25703	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25704	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25705	 1	 3.06	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25706	 1	 5.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25707	 1	 4.4	 1.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25708	 1	 3.3	 0.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25709	 1	 4.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25710	 1	 6.38	 1.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25711	 1	 7.56	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25712	 1	 6.64	 1.56	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25713	 1	 3.94	 0.93	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25714	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25715	 1	 3.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25716	 1	 5.63	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25717	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25718	 1	 8.8	 2.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25719	 1	 7.22	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25720	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25721	 1	 7.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25722	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25723	 1	 4.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25724	 1	 6.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25725	 1	 5.09	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25726	 1	 5.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25727	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25728	 1	 7.21	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25729	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25730	 1	 9.34	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25731	 1	 5.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25732	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25733	 1	 9.39	 4.34	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25734	 1	 4.16	 1.87	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25735	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25736	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25737	 1	 18.0	 5.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25738	 1	 6.88	 3.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25739	 1	 20.35	 7.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25740	 1	 17.47	 6.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25741	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25742	 1	 3.0	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25743	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25744	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25745	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25746	 1	 17.08	 5.29	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25747	 1	 10.93	 5.39	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25748	 1	 36.3	 12.95	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25749	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25750	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25751	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25752	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25753	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25754	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25755	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25756	 1	 2.94	 1.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25757	 1	 6.01	 2.33	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25758	 1	 22.25	 7.42	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25759	 1	 6.97	 2.73	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25760	 1	 13.24	 4.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25761	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25762	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25763	 1	 6.82	 3.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25764	 1	 4.85	 2.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25765	 1	 6.43	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25766	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25767	 1	 12.97	 5.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25768	 1	 3.31	 1.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25769	 1	 7.85	 3.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25770	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25771	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25772	 1	 8.21	 3.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25773	 1	 4.85	 1.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25774	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25775	 1	 5.63	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25776	 1	 10.28	 4.9	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25777	 1	 6.2	 2.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25778	 1	 8.93	 4.34	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25779	 1	 18.02	 4.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25780	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25781	 1	 11.28	 4.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25782	 1	 5.36	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25783	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25784	 1	 9.03	 3.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25785	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25786	 1	 3.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25787	 1	 3.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25788	 1	 2.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25789	 1	 5.57	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25790	 1	 3.06	 0.71	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25791	 1	 2.32	 0.54	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25792	 1	 2.25	 0.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25793	 1	 2.59	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25794	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25795	 1	 3.94	 0.91	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25796	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25797	 1	 3.5	 0.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25798	 1	 4.51	 1.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25799	 1	 3.0	 0.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25800	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25801	 1	 5.22	 1.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25802	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25803	 1	 2.74	 0.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25804	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25805	 1	 4.07	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25806	 1	 14.89	 3.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25807	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25808	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25809	 1	 6.39	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25810	 1	 3.76	 0.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25811	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25812	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25813	 1	 2.87	 0.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25814	 1	 4.3	 1.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25815	 1	 9.17	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25816	 1	 8.73	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25817	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25818	 1	 3.4	 0.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25819	 1	 2.0	 0.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25820	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25821	 1	 6.58	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25822	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25823	 1	 3.78	 0.88	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25824	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25825	 1	 1.8	 0.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25826	 1	 4.72	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25827	 1	 2.98	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25828	 1	 3.01	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25829	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25830	 1	 4.37	 1.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25831	 1	 2.6	 0.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25832	 1	 3.77	 0.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25833	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25834	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25835	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25836	 1	 1.4	 0.33	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25837	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25838	 1	 1.84	 0.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25839	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25840	 1	 1.44	 0.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25841	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25842	 1	 6.95	 1.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25843	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25844	 1	 3.07	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25845	 1	 5.07	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25846	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25847	 1	 2.51	 0.59	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25848	 1	 5.97	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25849	 1	 7.23	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25850	 1	 9.95	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25851	 1	 3.44	 0.81	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25852	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25853	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25854	 1	 2.68	 0.63	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25855	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25856	 1	 1.73	 0.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25857	 1	 2.47	 0.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25858	 1	 3.77	 0.88	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25859	 1	 3.2	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25860	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25861	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25862	 1	 7.15	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25863	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25864	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25865	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25866	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25867	 1	 4.31	 1.02	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25868	 1	 4.21	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25869	 1	 3.22	 0.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25870	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25871	 1	 3.01	 0.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25872	 1	 4.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25873	 1	 4.53	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25874	 1	 7.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25875	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25876	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25877	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25878	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25879	 1	 6.52	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25880	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25881	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25882	 1	 4.5	 1.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25883	 1	 5.09	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25884	 1	 2.67	 0.63	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25885	 1	 4.3	 1.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25886	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25887	 1	 2.59	 0.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25888	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25889	 1	 3.54	 0.83	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25890	 1	 4.28	 1.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25891	 1	 4.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25892	 1	 4.75	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25893	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25894	 1	 2.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25895	 1	 5.42	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25896	 1	 1.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25897	 1	 1.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25898	 1	 6.04	 1.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25899	 1	 3.18	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25900	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25901	 1	 7.04	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25902	 1	 5.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25903	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25904	 1	 1.13	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25905	 1	 4.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25906	 1	 3.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25907	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25908	 1	 2.67	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25909	 1	 7.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25910	 1	 4.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25911	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25912	 1	 2.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25913	 1	 4.42	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25914	 1	 5.45	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25915	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25916	 1	 10.67	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25917	 1	 5.27	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25918	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25919	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25920	 1	 5.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25921	 1	 7.96	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25922	 1	 8.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25923	 1	 8.08	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25924	 1	 6.47	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25925	 1	 2.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25926	 1	 7.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25927	 1	 0.59	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25928	 1	 4.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25929	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25930	 1	 3.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25931	 1	 4.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25932	 1	 6.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25933	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25934	 1	 9.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25935	 1	 3.21	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25936	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25937	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25938	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25939	 1	 3.27	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25940	 1	 4.14	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25941	 1	 12.81	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25942	 1	 5.81	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25943	 1	 4.21	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25944	 1	 10.91	 2.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25945	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25946	 1	 3.47	 0.81	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25947	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25948	 1	 2.02	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25949	 1	 1.52	 0.35	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25950	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25951	 1	 3.86	 0.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25952	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25953	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25954	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25955	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25956	 1	 3.57	 0.83	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25957	 1	 1.6	 0.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25958	 1	 5.37	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25959	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25960	 1	 5.04	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25961	 1	 10.74	 2.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25962	 1	 8.47	 1.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25963	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25964	 1	 7.67	 1.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25965	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25966	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25967	 1	 8.14	 1.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25968	 1	 10.38	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25969	 1	 6.38	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25970	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25971	 1	 5.5	 1.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25972	 1	 4.34	 1.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25973	 1	 5.63	 1.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25974	 1	 7.89	 1.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25975	 1	 8.33	 1.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25976	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25977	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25978	 1	 10.32	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25979	 1	 3.42	 0.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25980	 1	 3.89	 0.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25981	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25982	 1	 5.64	 1.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25983	 1	 7.4	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25984	 1	 6.84	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25985	 1	 7.18	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25986	 1	 5.15	 1.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25987	 1	 2.23	 0.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25988	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25989	 1	 3.99	 0.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25990	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25991	 1	 7.46	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	25992	 1	 7.4	 1.74	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25993	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25994	 1	 26.37	 6.18	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25995	 1	 3.82	 0.9	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25996	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25997	 1	 3.34	 0.79	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25998	 1	 8.96	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25999	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26000	 1	 25.85	 6.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26001	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26002	 1	 6.36	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26003	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26004	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26005	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26006	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26007	 1	 5.36	 1.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26008	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26009	 1	 17.01	 3.96	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26010	 1	 3.52	 0.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26011	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26012	 1	 1.86	 0.44	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26013	 1	 3.78	 0.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26014	 1	 2.79	 0.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26015	 1	 3.15	 0.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26016	 1	 2.1	 0.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26017	 1	 3.11	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26018	 1	 3.14	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26019	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26020	 1	 1.7	 0.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26021	 1	 2.0	 0.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26022	 1	 3.01	 0.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26023	 1	 2.48	 0.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26024	 1	 2.73	 0.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26025	 1	 3.13	 0.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26026	 1	 4.48	 1.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26027	 1	 3.71	 0.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26028	 1	 2.86	 0.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26029	 1	 4.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26030	 1	 7.47	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26031	 1	 6.83	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26032	 1	 4.18	 0.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26033	 1	 5.6	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26034	 1	 14.85	 3.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26035	 1	 7.5	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26036	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26037	 1	 3.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26038	 1	 3.01	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26039	 1	 4.07	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26040	 1	 2.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26041	 1	 5.49	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26042	 1	 3.77	 0.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26043	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26044	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26045	 1	 5.48	 1.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26046	 1	 9.58	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26047	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26048	 1	 18.37	 4.31	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26049	 1	 5.99	 1.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26050	 1	 23.55	 9.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26051	 1	 9.55	 2.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26052	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26053	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26054	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26055	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26056	 1	 13.25	 4.84	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26057	 1	 5.94	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26058	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26059	 1	 11.21	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26060	 1	 5.23	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26061	 1	 5.62	 1.31	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26062	 1	 18.87	 4.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26063	 1	 27.94	 6.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26064	 1	 7.52	 1.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26065	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26066	 1	 4.51	 1.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26067	 1	 6.3	 1.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26068	 1	 1.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26069	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26070	 1	 4.57	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26071	 1	 6.57	 2.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26072	 1	 5.51	 2.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26073	 1	 11.27	 4.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26074	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26075	 1	 6.46	 3.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26076	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26077	 1	 8.87	 3.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26078	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26079	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26080	 1	 4.44	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26081	 1	 5.26	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26082	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26083	 1	 14.94	 7.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26084	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26085	 1	 16.57	 4.54	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26086	 1	 3.63	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26087	 1	 2.42	 1.14	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26088	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26089	 1	 5.94	 2.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26090	 1	 17.19	 5.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26091	 1	 12.84	 4.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26092	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26093	 1	 11.23	 3.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26094	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26095	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26096	 1	 4.67	 2.18	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26097	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26098	 1	 17.33	 4.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26099	 1	 26.61	 6.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26100	 1	 6.54	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26101	 1	 4.01	 0.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26102	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26103	 1	 5.17	 2.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26104	 1	 5.5	 2.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26105	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26106	 1	 3.64	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26107	 1	 5.33	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26108	 1	 4.34	 1.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26109	 1	 6.42	 3.05	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26110	 1	 14.71	 5.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26111	 1	 13.28	 3.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26112	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26113	 1	 7.6	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26114	 1	 4.39	 1.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26115	 1	 12.56	 5.44	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26116	 1	 18.99	 8.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26117	 1	 8.87	 4.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26118	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26119	 1	 7.86	 3.54	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26120	 1	 7.91	 3.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26121	 1	 18.04	 5.54	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26122	 1	 12.82	 5.96	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26123	 1	 15.07	 6.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26124	 1	 13.58	 4.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26125	 1	 10.15	 4.62	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26126	 1	 14.16	 6.11	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26127	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26128	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26129	 1	 11.33	 4.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26130	 1	 14.03	 5.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26131	 1	 17.26	 6.45	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26132	 1	 4.33	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26133	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26134	 1	 12.12	 3.98	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26135	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26136	 1	 8.21	 1.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26137	 1	 8.48	 2.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26138	 1	 2.49	 0.98	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26139	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26140	 1	 5.67	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26141	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26142	 1	 4.96	 2.42	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26143	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26144	 1	 10.69	 4.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26145	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26146	 1	 3.34	 1.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26147	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26148	 1	 5.96	 2.93	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26149	 1	 4.35	 1.92	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26150	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26151	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26152	 1	 1.28	 0.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26153	 1	 7.54	 3.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26154	 1	 1.6	 0.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26155	 1	 1.88	 0.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26156	 1	 1.1	 0.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26157	 1	 2.37	 1.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26158	 1	 2.28	 0.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26159	 1	 1.43	 0.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26160	 1	 1.4	 0.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26161	 1	 3.99	 1.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26162	 1	 2.22	 1.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26163	 1	 4.77	 2.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26164	 1	 2.36	 1.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26165	 1	 3.35	 1.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26166	 1	 1.47	 0.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26167	 1	 48.84	 16.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26168	 1	 11.94	 5.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26169	 1	 11.26	 4.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26170	 1	 19.62	 8.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26171	 1	 2.88	 1.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26172	 1	 1.41	 0.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26173	 1	 2.6	 1.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26174	 1	 4.36	 1.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26175	 1	 1.88	 0.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26176	 1	 2.05	 0.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26177	 1	 5.16	 1.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26178	 1	 1.77	 0.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26179	 1	 1.03	 0.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26180	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26181	 1	 2.89	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26182	 1	 3.41	 1.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26183	 1	 2.63	 1.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26184	 1	 2.81	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26185	 1	 13.49	 3.48	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26186	 1	 3.13	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26187	 1	 8.29	 4.01	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26188	 1	 8.52	 3.18	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26189	 1	 5.18	 2.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26190	 1	 5.22	 2.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26191	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26192	 1	 3.8	 1.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26193	 1	 34.67	 8.34	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26194	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26195	 1	 8.7	 3.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26196	 1	 5.05	 2.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26197	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26198	 1	 5.23	 2.23	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26199	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26200	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26201	 1	 29.39	 11.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26202	 1	 3.86	 1.9	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26203	 1	 31.22	 12.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26204	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26205	 1	 2.43	 1.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26206	 1	 3.76	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26207	 1	 3.71	 1.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26208	 1	 2.89	 1.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26209	 1	 3.46	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26210	 1	 2.69	 1.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26211	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26212	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26213	 1	 2.52	 0.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26214	 1	 5.66	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26215	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26216	 1	 1.33	 0.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26217	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26218	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26219	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26220	 1	 3.34	 1.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26221	 1	 9.21	 4.09	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26222	 1	 1.94	 0.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26223	 1	 3.47	 1.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26224	 1	 1.86	 0.8	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26225	 1	 2.15	 0.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26226	 1	 3.07	 1.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26227	 1	 5.93	 2.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26228	 1	 2.77	 1.41	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26229	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26230	 1	 2.57	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26231	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26232	 1	 7.49	 3.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26233	 1	 1.95	 0.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26234	 1	 4.82	 1.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26235	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26236	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26237	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26238	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26239	 1	 1.7	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26240	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26241	 1	 5.62	 2.62	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26242	 1	 4.39	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26243	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26244	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26245	 1	 1.41	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26246	 1	 1.28	 0.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26247	 1	 3.72	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26248	 1	 2.98	 1.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26249	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26250	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26251	 1	 3.35	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26252	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26253	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26254	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26255	 1	 2.33	 1.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26256	 1	 6.57	 3.26	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26257	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26258	 1	 4.83	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26259	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26260	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26261	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26262	 1	 4.57	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26263	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26264	 1	 3.88	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26265	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26266	 1	 8.71	 4.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26267	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26268	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26269	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26270	 1	 5.11	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26271	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26272	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26273	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26274	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26275	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26276	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26277	 1	 3.53	 1.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26278	 1	 2.04	 1.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26279	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26280	 1	 5.67	 2.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26281	 1	 5.17	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26282	 1	 9.16	 3.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26283	 1	 7.2	 3.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26284	 1	 4.7	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26285	 1	 2.92	 1.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26286	 1	 5.67	 2.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26287	 1	 25.78	 9.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26288	 1	 2.96	 1.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26289	 1	 4.56	 2.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26290	 1	 11.57	 5.56	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26291	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26292	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26293	 1	 6.28	 2.67	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26294	 1	 3.04	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26295	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26296	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26297	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26298	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26299	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26300	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26301	 1	 1.38	 0.73	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26302	 1	 3.98	 2.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26303	 1	 4.33	 2.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26304	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26305	 1	 9.4	 3.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26306	 1	 52.33	 17.12	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26307	 1	 10.08	 4.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26308	 1	 2.09	 0.91	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26309	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26310	 1	 8.46	 3.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26311	 1	 6.74	 2.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26312	 1	 9.04	 4.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26313	 1	 81.02	 26.05	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26314	 1	 5.95	 2.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26315	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26316	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26317	 1	 10.35	 3.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26318	 1	 9.15	 2.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26319	 1	 6.64	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26320	 1	 12.73	 4.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26321	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26322	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26323	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26324	 1	 4.77	 1.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26325	 1	 6.07	 2.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26326	 1	 6.22	 2.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26327	 1	 5.48	 2.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26328	 1	 9.8	 3.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26329	 1	 7.78	 3.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26330	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26331	 1	 4.27	 1.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26332	 1	 9.94	 4.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26333	 1	 2.28	 0.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26334	 1	 8.61	 4.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26335	 1	 12.87	 5.9	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26336	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26337	 1	 10.14	 4.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26338	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26339	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26340	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26341	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26342	 1	 11.09	 4.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26343	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26344	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26345	 1	 4.53	 2.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26346	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26347	 1	 8.71	 3.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26348	 1	 3.25	 1.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26349	 1	 9.08	 4.07	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26350	 1	 61.97	 23.91	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26351	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26352	 1	 3.9	 1.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26353	 1	 5.1	 2.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26354	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26355	 1	 2.59	 1.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26356	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26357	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26358	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26359	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26360	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26361	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26362	 1	 30.53	 9.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26363	 1	 3.37	 1.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26364	 1	 6.02	 2.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26365	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26366	 1	 3.38	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26367	 1	 1.44	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26368	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26369	 1	 9.83	 3.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26370	 1	 10.03	 4.03	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26371	 1	 4.47	 2.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26372	 1	 3.52	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26373	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26374	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26375	 1	 17.18	 3.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26376	 1	 28.33	 7.74	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26377	 1	 9.56	 2.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26378	 1	 12.51	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26379	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26380	 1	 7.18	 1.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26381	 1	 10.35	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26382	 1	 13.69	 3.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26383	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26384	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26385	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26386	 1	 12.18	 5.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26387	 1	 9.12	 2.14	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26388	 1	 9.63	 2.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26389	 1	 6.54	 1.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26390	 1	 10.93	 2.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26391	 1	 4.49	 2.01	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26392	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26393	 1	 24.62	 5.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26394	 1	 8.06	 3.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26395	 1	 10.24	 4.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26396	 1	 2.87	 1.31	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26397	 1	 2.57	 1.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26398	 1	 5.62	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26399	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26400	 1	 10.92	 3.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26401	 1	 6.28	 3.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26402	 1	 18.19	 5.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26403	 1	 9.54	 3.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26404	 1	 10.08	 4.12	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26405	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26406	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26407	 1	 3.87	 1.67	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26408	 1	 9.08	 4.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26409	 1	 13.3	 4.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26410	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26411	 1	 7.51	 2.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26412	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26413	 1	 6.6	 3.4	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26414	 1	 5.07	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26415	 1	 4.85	 2.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26416	 1	 4.01	 2.04	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26417	 1	 6.36	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26418	 1	 6.96	 2.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26419	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26420	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26421	 1	 4.74	 2.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26422	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26423	 1	 19.71	 6.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26424	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26425	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26426	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26427	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26428	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26429	 1	 5.43	 2.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26430	 1	 6.47	 2.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26431	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26432	 1	 9.81	 3.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26433	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26434	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26435	 1	 4.55	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26436	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26437	 1	 4.01	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26438	 1	 10.73	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26439	 1	 13.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26440	 1	 6.61	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26441	 1	 6.96	 2.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26442	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26443	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26444	 1	 6.11	 2.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26445	 1	 7.59	 2.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26446	 1	 16.31	 5.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26447	 1	 15.35	 3.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26448	 1	 16.5	 5.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26449	 1	 8.1	 3.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26450	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26451	 1	 3.27	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26452	 1	 3.96	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26453	 1	 3.25	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26454	 1	 6.54	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26455	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26456	 1	 1.46	 0.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26457	 1	 4.17	 1.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26458	 1	 1.9	 0.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26459	 1	 1.74	 0.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26460	 1	 7.39	 3.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26461	 1	 6.09	 2.92	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26462	 1	 3.72	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26463	 1	 30.11	 9.29	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26464	 1	 9.79	 3.97	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26465	 1	 5.88	 3.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26466	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26467	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26468	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26469	 1	 4.75	 2.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26470	 1	 3.0	 1.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26471	 1	 2.11	 0.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26472	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26473	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26474	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26475	 1	 5.3	 2.59	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26476	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26477	 1	 4.4	 1.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26478	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26479	 1	 6.52	 3.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26480	 1	 13.43	 5.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26481	 1	 7.27	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26482	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26483	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26484	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26485	 1	 2.99	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26486	 1	 4.08	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26487	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26488	 1	 4.46	 2.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26489	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26490	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26491	 1	 4.6	 2.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26492	 1	 5.3	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26493	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26494	 1	 13.95	 4.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26495	 1	 5.76	 2.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26496	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26497	 1	 9.7	 3.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26498	 1	 6.83	 2.59	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26499	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26500	 1	 3.91	 1.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26501	 1	 6.79	 3.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26502	 1	 3.6	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26503	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26504	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26505	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26506	 1	 4.49	 2.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26507	 1	 5.66	 2.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26508	 1	 4.73	 2.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26509	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26510	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26511	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26512	 1	 6.41	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26513	 1	 9.68	 4.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26514	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26515	 1	 16.26	 7.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26516	 1	 5.98	 2.33	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26517	 1	 10.21	 4.42	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26518	 1	 16.18	 6.12	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26519	 1	 1.57	 0.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26520	 1	 12.07	 3.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26521	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26522	 1	 17.6	 6.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26523	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26524	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26525	 1	 8.94	 3.9	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26526	 1	 10.35	 5.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26527	 1	 5.97	 2.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26528	 1	 20.3	 7.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26529	 1	 8.61	 3.85	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26530	 1	 8.66	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26531	 1	 1.61	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26532	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26533	 1	 4.28	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26534	 1	 1.26	 0.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26535	 1	 3.53	 1.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26536	 1	 5.83	 2.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26537	 1	 8.32	 2.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26538	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26539	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26540	 1	 9.27	 3.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26541	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26542	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26543	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26544	 1	 3.59	 1.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26545	 1	 6.75	 3.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26546	 1	 3.31	 1.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26547	 1	 6.52	 3.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26548	 1	 2.08	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26549	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26550	 1	 4.32	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26551	 1	 3.48	 1.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26552	 1	 5.67	 2.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26553	 1	 7.35	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26554	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26555	 1	 6.49	 2.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26556	 1	 5.26	 2.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26557	 1	 5.22	 2.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26558	 1	 4.46	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26559	 1	 7.11	 1.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26560	 1	 3.35	 0.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26561	 1	 3.72	 0.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26562	 1	 6.81	 1.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26563	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26564	 1	 6.99	 2.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26565	 1	 5.56	 2.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26566	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26567	 1	 75.05	 17.64	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26568	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26569	 1	 1.98	 0.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26570	 1	 5.75	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26571	 1	 9.64	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26572	 1	 2.22	 0.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26573	 1	 6.99	 1.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26574	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26575	 1	 12.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26576	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26577	 1	 7.64	 1.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26578	 1	 8.09	 1.88	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26579	 1	 4.08	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26580	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26581	 1	 6.96	 1.62	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26582	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26583	 1	 3.74	 0.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26584	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26585	 1	 9.91	 2.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26586	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26587	 1	 10.05	 4.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26588	 1	 15.62	 5.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26589	 1	 6.81	 1.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26590	 1	 55.35	 13.04	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26591	 1	 17.63	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26592	 1	 7.81	 1.8	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26593	 1	 2.46	 0.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26594	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26595	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26596	 1	 11.6	 2.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26597	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26598	 1	 9.56	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26599	 1	 5.42	 1.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26600	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26601	 1	 6.72	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26602	 1	 4.14	 1.85	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26603	 1	 5.59	 3.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26604	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26605	 1	 58.0	 24.79	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26606	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26607	 1	 3.24	 1.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26608	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26609	 1	 2.85	 1.35	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26610	 1	 5.26	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26611	 1	 6.8	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26612	 1	 1.56	 0.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26613	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26614	 1	 7.04	 3.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26615	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26616	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26617	 1	 5.91	 2.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26618	 1	 2.44	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26619	 1	 3.0	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26620	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26621	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26622	 1	 5.05	 2.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26623	 1	 9.11	 3.23	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26624	 1	 3.49	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26625	 1	 2.2	 1.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26626	 1	 7.21	 3.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26627	 1	 5.48	 2.36	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26628	 1	 22.08	 7.6	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26629	 1	 7.57	 3.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26630	 1	 4.44	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26631	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26632	 1	 9.7	 4.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26633	 1	 8.34	 3.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26634	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26635	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26636	 1	 15.48	 5.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26637	 1	 3.49	 1.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26638	 1	 6.71	 3.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26639	 1	 3.04	 1.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26640	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26641	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26642	 1	 15.79	 6.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26643	 1	 4.36	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26644	 1	 31.74	 10.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26645	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26646	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26647	 1	 5.03	 2.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26648	 1	 4.17	 1.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26649	 1	 5.04	 2.44	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26650	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26651	 1	 10.24	 4.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26652	 1	 4.67	 2.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26653	 1	 7.1	 3.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26654	 1	 2.73	 1.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26655	 1	 4.68	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26656	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26657	 1	 9.02	 4.11	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26658	 1	 6.9	 3.06	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26659	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26660	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26661	 1	 9.78	 3.93	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26662	 1	 3.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26663	 1	 9.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26664	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26665	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26666	 1	 2.41	 1.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26667	 1	 3.88	 1.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26668	 1	 15.08	 6.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26669	 1	 11.9	 4.34	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26670	 1	 29.33	 11.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26671	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26672	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26673	 1	 5.16	 2.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26674	 1	 10.42	 4.27	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26675	 1	 6.77	 2.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26676	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26677	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26678	 1	 4.76	 2.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26679	 1	 7.19	 2.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26680	 1	 12.45	 4.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26681	 1	 32.66	 9.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26682	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26683	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26684	 1	 2.42	 1.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26685	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26686	 1	 5.05	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26687	 1	 11.43	 4.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26688	 1	 10.38	 4.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26689	 1	 8.17	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26690	 1	 6.0	 1.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26691	 1	 3.41	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26692	 1	 1.99	 0.88	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26693	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26694	 1	 1.68	 0.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26695	 1	 4.62	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26696	 1	 3.31	 1.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26697	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26698	 1	 1.46	 0.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26699	 1	 8.11	 3.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26700	 1	 3.71	 1.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26701	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26702	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26703	 1	 7.59	 2.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26704	 1	 6.68	 2.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26705	 1	 9.32	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26706	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26707	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26708	 1	 1.86	 0.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26709	 1	 1.65	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26710	 1	 1.0	 0.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26711	 1	 6.56	 2.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26712	 1	 1.85	 0.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26713	 1	 5.1	 1.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26714	 1	 5.88	 2.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26715	 1	 4.07	 1.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26716	 1	 3.55	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26717	 1	 5.58	 2.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26718	 1	 2.62	 1.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26719	 1	 3.0	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26720	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26721	 1	 22.03	 9.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26722	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26723	 1	 3.72	 1.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26724	 1	 5.06	 1.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26725	 1	 3.07	 1.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26726	 1	 1.82	 0.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26727	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26728	 1	 13.52	 4.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26729	 1	 5.23	 1.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26730	 1	 6.67	 2.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26731	 1	 3.9	 1.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26732	 4	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26733	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26734	 1	 65.88	 17.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26735	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26736	 1	 79.71	 24.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26737	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26738	 1	 3.85	 1.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26739	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26740	 1	 2.99	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26741	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26742	 1	 2.84	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26743	 1	 5.77	 2.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26744	 1	 12.04	 4.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26745	 1	 2.91	 1.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26746	 1	 7.71	 3.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26747	 1	 5.11	 1.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26748	 1	 14.68	 5.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26749	 1	 8.04	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26750	 1	 26.26	 9.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26751	 1	 2.5	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26752	 1	 4.01	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26753	 1	 1.92	 0.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26754	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26755	 1	 10.01	 3.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26756	 1	 3.59	 1.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26757	 1	 4.68	 1.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26758	 1	 5.77	 2.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26759	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26760	 1	 7.36	 3.23	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26761	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26762	 1	 7.43	 3.31	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26763	 1	 5.56	 2.29	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26764	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26765	 1	 4.44	 1.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26766	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26767	 1	 6.86	 2.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26768	 1	 2.3	 0.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26769	 1	 6.11	 1.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26770	 1	 5.61	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26771	 1	 4.77	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26772	 1	 5.51	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26773	 1	 12.53	 2.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26774	 1	 13.14	 3.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26775	 1	 13.89	 3.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26776	 1	 1.59	 0.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26777	 1	 10.34	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26778	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26779	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26780	 1	 8.14	 3.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26781	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26782	 1	 13.79	 5.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26783	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26784	 1	 35.19	 10.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26785	 1	 4.33	 2.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26786	 1	 12.38	 4.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26787	 1	 18.47	 4.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26788	 1	 10.11	 2.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26789	 1	 2.52	 0.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26790	 1	 11.33	 3.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26791	 1	 6.23	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26792	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26793	 1	 3.01	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26794	 1	 13.43	 4.96	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26795	 1	 143.37	 44.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26796	 1	 3.99	 1.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26797	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26798	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26799	 1	 4.06	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26800	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26801	 1	 5.29	 1.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26802	 1	 2.33	 1.06	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26803	 1	 6.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26804	 1	 7.31	 1.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26805	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26806	 1	 9.07	 2.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26807	 1	 8.24	 1.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26808	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26809	 1	 3.58	 1.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26810	 1	 4.8	 1.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26811	 1	 10.46	 2.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26812	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26813	 1	 4.7	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26814	 1	 1.23	 0.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26815	 1	 0.92	 0.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26816	 1	 4.72	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26817	 1	 1.36	 0.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26818	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26819	 1	 3.42	 1.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26820	 1	 1.57	 0.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26821	 1	 3.11	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26822	 1	 3.5	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26823	 1	 1.84	 0.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26824	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26825	 1	 1.71	 0.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26826	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26827	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26828	 1	 3.78	 0.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26829	 1	 1.7	 0.41	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26830	 1	 1.75	 0.79	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26831	 1	 14.27	 3.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26832	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26833	 1	 2.88	 0.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26834	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26835	 1	 1.91	 0.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26836	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26837	 1	 5.31	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26838	 1	 3.84	 0.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26839	 1	 6.25	 1.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26840	 1	 4.42	 2.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26841	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26842	 1	 1.7	 0.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26843	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26844	 1	 5.68	 2.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26845	 1	 4.15	 1.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26846	 1	 4.13	 0.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26847	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26848	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26849	 1	 1.24	 0.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26850	 1	 4.61	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26851	 1	 14.31	 6.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26852	 1	 4.26	 1.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26853	 1	 7.54	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26854	 1	 5.49	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26855	 1	 2.53	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26856	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26857	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26858	 1	 19.52	 5.54	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26859	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26860	 1	 4.47	 1.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26861	 1	 14.05	 6.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26862	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26863	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26864	 1	 7.26	 1.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26865	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26866	 1	 11.9	 2.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26867	 1	 4.37	 1.86	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26868	 1	 6.59	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26869	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26870	 1	 15.3	 3.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26871	 1	 4.14	 1.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26872	 1	 8.44	 3.25	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26873	 1	 28.36	 8.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26874	 1	 4.99	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26875	 1	 3.75	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26876	 1	 7.27	 3.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26877	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26878	 1	 24.17	 11.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26879	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26880	 1	 4.68	 2.11	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26881	 1	 4.63	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26882	 1	 20.63	 4.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26883	 1	 15.13	 3.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26884	 1	 1.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26885	 1	 13.84	 3.26	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26886	 1	 3.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26887	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26888	 1	 13.6	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26889	 1	 3.59	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26890	 1	 6.23	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26891	 1	 2.94	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26892	 1	 4.3	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26893	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26894	 1	 6.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26895	 1	 6.65	 1.56	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26896	 1	 16.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26897	 1	 61.98	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26898	 1	 9.01	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26899	 1	 10.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26900	 1	 5.78	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26901	 1	 9.57	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26902	 1	 9.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26903	 1	 24.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26904	 1	 4.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26905	 1	 6.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26906	 1	 6.54	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26907	 1	 7.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26908	 1	 12.84	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26909	 1	 8.27	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26910	 1	 3.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26911	 1	 3.21	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26912	 1	 3.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26913	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26914	 1	 68.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26915	 1	 6.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26916	 1	 11.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26917	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26918	 1	 2.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26919	 1	 8.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26920	 1	 11.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26921	 1	 8.04	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26922	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26923	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26924	 1	 14.67	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26925	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26926	 1	 6.09	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26927	 1	 6.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26928	 1	 4.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26929	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26930	 1	 19.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26931	 1	 5.7	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26932	 1	 9.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26933	 1	 2.53	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26934	 1	 3.29	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26935	 1	 23.13	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26936	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26937	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26938	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26939	 1	 4.33	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26940	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26941	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26942	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26943	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26944	 1	 3.23	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26945	 1	 5.71	 1.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26946	 1	 11.86	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26947	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26948	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26949	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26950	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26951	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26952	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26953	 1	 18.14	 4.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26954	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26955	 1	 8.06	 1.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26956	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26957	 1	 18.2	 4.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26958	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26959	 1	 8.75	 3.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26960	 1	 13.97	 3.26	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26961	 1	 6.96	 1.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26962	 1	 5.42	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26963	 1	 9.3	 2.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26964	 1	 13.11	 2.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26965	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26966	 1	 16.58	 3.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26967	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26968	 1	 8.51	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26969	 1	 9.83	 2.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26970	 1	 24.91	 5.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26971	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26972	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26973	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26974	 1	 5.58	 1.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26975	 1	 19.36	 7.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26976	 1	 10.73	 4.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26977	 1	 5.0	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26978	 1	 4.68	 1.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26979	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26980	 1	 2.36	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26981	 1	 2.39	 1.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26982	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26983	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26984	 1	 1.79	 0.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26985	 1	 2.54	 1.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26986	 1	 4.09	 2.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26987	 1	 4.02	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26988	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26989	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26990	 1	 4.12	 1.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26991	 1	 1.53	 0.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26992	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26993	 1	 10.72	 3.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26994	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26995	 1	 107.33	 40.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26996	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26997	 1	 12.67	 4.31	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26998	 1	 5.01	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	26999	 1	 9.3	 2.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27000	 1	 4.69	 1.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27001	 1	 7.58	 3.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27002	 1	 7.3	 2.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27003	 1	 6.81	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27004	 1	 3.8	 1.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27005	 1	 6.64	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27006	 1	 2.88	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27007	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27008	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27009	 1	 6.85	 2.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27010	 1	 10.86	 3.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27011	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27012	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27013	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27014	 1	 8.22	 3.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27015	 1	 4.99	 2.36	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27016	 1	 4.39	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27017	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27018	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27019	 1	 2.92	 1.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27020	 1	 3.52	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27021	 1	 2.55	 1.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27022	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27023	 1	 4.49	 1.92	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27024	 1	 10.37	 3.76	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27025	 1	 9.86	 3.74	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27026	 1	 6.62	 3.18	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27027	 1	 2.6	 1.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27028	 1	 8.37	 3.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27029	 1	 1.56	 0.62	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27030	 1	 3.29	 1.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27031	 1	 5.48	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27032	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27033	 1	 3.38	 1.41	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27034	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27035	 1	 5.4	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27036	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27037	 1	 2.44	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27038	 1	 2.77	 1.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27039	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27040	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27041	 1	 2.23	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27042	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27043	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27044	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27045	 1	 2.01	 0.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27046	 1	 79.79	 24.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27047	 1	 4.62	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27048	 1	 1.82	 0.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27049	 1	 2.03	 0.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27050	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27051	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27052	 1	 8.75	 3.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27053	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27054	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27055	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27056	 1	 2.86	 1.34	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27057	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27058	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27059	 1	 22.55	 8.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27060	 1	 7.74	 3.25	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27061	 1	 8.16	 3.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27062	 1	 5.93	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27063	 1	 16.35	 7.39	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27064	 1	 6.35	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27065	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27066	 1	 58.85	 21.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27067	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27068	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27069	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27070	 1	 8.01	 3.07	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27071	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27072	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27073	 1	 21.06	 7.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27074	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27075	 1	 15.13	 5.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27076	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27077	 1	 7.3	 3.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27078	 1	 4.54	 2.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27079	 1	 10.05	 3.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27080	 1	 3.72	 1.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27081	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27082	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27083	 1	 2.71	 1.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27084	 1	 10.33	 4.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27085	 1	 1.89	 0.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27086	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27087	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27088	 1	 6.1	 2.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27089	 1	 5.78	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27090	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27091	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27092	 1	 8.2	 2.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27093	 1	 74.79	 23.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27094	 1	 23.37	 7.59	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27095	 1	 4.07	 0.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27096	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27097	 1	 23.72	 8.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27098	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27099	 1	 1.3	 0.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27100	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27101	 1	 9.55	 4.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27102	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27103	 1	 22.66	 5.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27104	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27105	 1	 5.92	 1.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27106	 1	 2.5	 0.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27107	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27108	 1	 10.39	 4.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27109	 1	 4.12	 1.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27110	 1	 18.83	 7.36	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27111	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27112	 1	 6.67	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27113	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27114	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27115	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27116	 1	 6.54	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27117	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27118	 1	 6.06	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27119	 1	 4.63	 1.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27120	 1	 6.61	 1.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27121	 1	 15.03	 3.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27122	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27123	 1	 5.15	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27124	 1	 20.53	 4.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27125	 1	 14.79	 6.84	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27126	 1	 12.0	 5.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27127	 1	 4.4	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27128	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27129	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27130	 1	 4.55	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27131	 1	 0.24	 0.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27132	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27133	 1	 12.94	 4.12	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27134	 1	 4.39	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27135	 1	 3.74	 1.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27136	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27137	 1	 7.35	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27138	 1	 18.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27139	 1	 14.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27140	 1	 5.94	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27141	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27142	 1	 9.09	 3.37	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27143	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27144	 1	 13.58	 5.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27145	 1	 8.41	 3.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27146	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27147	 1	 8.98	 4.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27148	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27149	 1	 4.01	 1.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27150	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27151	 1	 11.44	 3.44	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27152	 1	 3.29	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27153	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27154	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27155	 1	 6.84	 3.1	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27156	 1	 12.57	 3.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27157	 1	 8.74	 4.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27158	 1	 9.24	 3.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27159	 1	 10.62	 4.17	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27160	 1	 6.94	 3.29	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27161	 1	 7.1	 3.48	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27162	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	27163	 1	 3.6	 1.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27164	 1	 2.32	 0.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27165	 1	 1.85	 0.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27166	 1	 1.64	 0.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27167	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27168	 1	 2.48	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27169	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27170	 1	 3.2	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27171	 1	 4.08	 1.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27172	 1	 4.17	 1.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27173	 1	 22.37	 9.02	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27174	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27175	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27176	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27177	 1	 3.52	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27178	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27179	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27180	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27181	 1	 6.4	 2.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27182	 1	 22.35	 8.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27183	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27184	 1	 11.27	 3.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27185	 1	 12.27	 5.87	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27186	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27187	 1	 10.83	 4.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27188	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27189	 1	 5.83	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27190	 1	 5.17	 2.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27191	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27192	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27193	 1	 7.58	 3.83	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27194	 1	 18.4	 6.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27195	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27196	 1	 6.59	 2.89	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27197	 1	 16.14	 6.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27198	 1	 10.06	 4.02	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27199	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27200	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27201	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27202	 1	 21.64	 9.66	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27203	 1	 3.48	 1.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27204	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27205	 1	 5.99	 2.77	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27206	 1	 4.33	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27207	 1	 5.41	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27208	 1	 12.83	 3.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27209	 1	 20.47	 4.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27210	 1	 11.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27211	 1	 37.02	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27212	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27213	 1	 10.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27214	 1	 15.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27215	 1	 7.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27216	 1	 3.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27217	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27218	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27219	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27220	 1	 3.73	 1.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27221	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27222	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27223	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27224	 1	 12.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27225	 1	 10.3	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27226	 1	 8.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27227	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27228	 1	 12.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27229	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27230	 1	 4.01	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27231	 1	 11.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27232	 1	 6.47	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27233	 1	 9.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27234	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27235	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27236	 1	 12.7	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27237	 1	 10.31	 3.93	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27238	 1	 11.19	 4.66	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27239	 1	 5.91	 2.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27240	 1	 9.81	 4.05	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27241	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27242	 1	 4.84	 1.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27243	 1	 2.68	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27244	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27245	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27246	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27247	 1	 8.82	 3.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27248	 1	 13.91	 4.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27249	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27250	 1	 3.33	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27251	 1	 3.46	 1.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27252	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27253	 1	 4.76	 1.93	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27254	 1	 26.64	 8.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27255	 1	 14.9	 3.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27256	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27257	 1	 9.38	 3.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27258	 1	 8.22	 3.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27259	 1	 8.78	 3.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27260	 1	 7.64	 3.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27261	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27262	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27263	 1	 5.6	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27264	 1	 10.3	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27265	 1	 5.5	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27266	 1	 12.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27267	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27268	 1	 2.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27269	 1	 3.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27270	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27271	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27272	 1	 7.45	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27273	 1	 12.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27274	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27275	 1	 4.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27276	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27277	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27278	 1	 11.81	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27279	 1	 5.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27280	 1	 14.53	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27281	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27282	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27283	 1	 15.47	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27284	 1	 6.34	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27285	 1	 12.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27286	 1	 4.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27287	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27288	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27289	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27290	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27291	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27292	 1	 6.53	 2.34	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27293	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27294	 1	 4.32	 2.22	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27295	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27296	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27297	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27298	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27299	 1	 6.93	 3.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27300	 1	 2.29	 1.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27301	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27302	 1	 4.33	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27303	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27304	 1	 6.31	 3.02	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27305	 1	 7.52	 3.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27306	 1	 6.14	 2.89	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27307	 1	 4.92	 2.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27308	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27309	 1	 10.76	 3.6	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27310	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27311	 1	 7.76	 2.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27312	 1	 11.12	 2.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27313	 1	 5.27	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27314	 1	 3.36	 1.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27315	 1	 9.68	 2.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27316	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27317	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27318	 1	 7.23	 2.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27319	 1	 5.35	 1.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27320	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27321	 1	 8.43	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27322	 1	 12.38	 2.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27323	 1	 5.2	 2.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27324	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27325	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27326	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27327	 1	 3.08	 1.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27328	 1	 5.27	 2.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27329	 1	 4.81	 2.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27330	 1	 50.29	 11.02	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27331	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	27332	 1	 4.04	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27333	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27334	 1	 2.32	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27335	 1	 2.36	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27336	 1	 6.52	 3.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27337	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27338	 1	 5.55	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27339	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27340	 1	 4.97	 2.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27341	 1	 3.84	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27342	 1	 6.25	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27343	 1	 5.76	 1.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27344	 1	 10.41	 2.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27345	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27346	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27347	 1	 9.42	 2.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27348	 1	 17.23	 3.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27349	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27350	 1	 7.58	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27351	 1	 26.31	 5.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27352	 1	 15.13	 3.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27353	 1	 4.77	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27354	 1	 4.27	 0.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27355	 1	 5.41	 1.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27356	 1	 6.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27357	 1	 9.36	 2.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27358	 1	 10.97	 2.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27359	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27360	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27361	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27362	 1	 67.78	 15.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27363	 1	 5.42	 1.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27364	 1	 7.51	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27365	 1	 9.36	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27366	 1	 12.47	 2.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27367	 1	 4.13	 1.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27368	 1	 12.14	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27369	 1	 2.51	 0.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27370	 1	 4.49	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27371	 1	 4.36	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27372	 1	 3.68	 1.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27373	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27374	 1	 5.88	 2.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27375	 1	 6.36	 2.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27376	 1	 6.58	 2.42	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27377	 1	 7.57	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27378	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27379	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27380	 1	 3.25	 1.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27381	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27382	 1	 23.2	 7.96	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27383	 1	 27.53	 10.36	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27384	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27385	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27386	 1	 4.72	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27387	 1	 1.98	 0.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27388	 1	 15.08	 5.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27389	 1	 7.35	 3.42	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27390	 1	 3.89	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27391	 1	 28.58	 9.41	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27392	 1	 13.51	 4.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27393	 1	 19.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27394	 1	 5.45	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27395	 1	 4.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27396	 1	 6.34	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27397	 1	 10.25	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27398	 1	 4.94	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27399	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27400	 1	 2.54	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27401	 1	 13.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27402	 1	 7.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27403	 1	 7.24	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27404	 1	 5.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27405	 1	 7.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27406	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27407	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27408	 1	 5.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27409	 1	 3.5	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27410	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27411	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27412	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27413	 1	 6.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27414	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27415	 1	 16.02	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27416	 1	 12.17	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27417	 1	 2.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27418	 1	 6.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27419	 1	 5.5	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27420	 1	 11.24	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27421	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27422	 1	 2.05	 0.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27423	 1	 17.26	 6.59	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27424	 1	 6.8	 2.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27425	 1	 5.8	 2.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27426	 1	 5.74	 2.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27427	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27428	 1	 4.76	 1.87	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27429	 1	 24.08	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27430	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27431	 1	 4.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27432	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27433	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27434	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27435	 1	 5.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27436	 1	 13.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27437	 1	 2.67	 1.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27438	 1	 2.88	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27439	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27440	 1	 4.32	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27441	 1	 3.7	 1.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27442	 1	 7.18	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27443	 1	 5.06	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27444	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27445	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27446	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27447	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27448	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27449	 1	 3.83	 1.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27450	 1	 26.5	 10.7	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27451	 1	 25.35	 9.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27452	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27453	 1	 4.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27454	 1	 1.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27455	 1	 1.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27456	 1	 2.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27457	 1	 4.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27458	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27459	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27460	 1	 6.7	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27461	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27462	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27463	 1	 8.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27464	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27465	 1	 1.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27466	 1	 2.75	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27467	 1	 8.61	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27468	 1	 9.69	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27469	 1	 14.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27470	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27471	 1	 6.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27472	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27473	 1	 66.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27474	 1	 3.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27475	 1	 2.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27476	 1	 5.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27477	 1	 5.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27478	 1	 4.25	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27479	 1	 6.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27480	 1	 8.57	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27481	 1	 1.5	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27482	 1	 1.74	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27483	 1	 6.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27484	 1	 3.1	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27485	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27486	 1	 3.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27487	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27488	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27489	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27490	 1	 5.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27491	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27492	 1	 5.8	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27493	 1	 3.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27494	 1	 1.56	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27495	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27496	 1	 7.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27497	 1	 3.68	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27498	 1	 2.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27499	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27500	 1	 5.67	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27501	 1	 4.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27502	 1	 1.98	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27503	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27504	 1	 5.59	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27505	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27506	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27507	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27508	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27509	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27510	 1	 35.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27511	 1	 5.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27512	 1	 13.61	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27513	 1	 13.24	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27514	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27515	 1	 6.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27516	 1	 10.78	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27517	 1	 13.81	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27518	 1	 13.98	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27519	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27520	 1	 4.3	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27521	 1	 2.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27522	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27523	 1	 5.29	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27524	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27525	 1	 5.68	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27526	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27527	 1	 4.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27528	 1	 8.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27529	 1	 5.86	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27530	 1	 11.73	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27531	 1	 8.11	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27532	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27533	 1	 4.7	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27534	 1	 4.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27535	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27536	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27537	 1	 7.76	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27538	 1	 19.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27539	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27540	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27541	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27542	 1	 2.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27543	 1	 7.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27544	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27545	 1	 12.56	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27546	 1	 5.17	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27547	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27548	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27549	 1	 5.1	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27550	 1	 5.14	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27551	 1	 9.73	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27552	 1	 27.78	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27553	 1	 7.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27554	 1	 12.37	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27555	 1	 9.54	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27556	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27557	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27558	 1	 7.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27559	 1	 11.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27560	 1	 12.29	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27561	 1	 61.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27562	 1	 6.46	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27563	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27564	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27565	 1	 7.13	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27566	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27567	 1	 8.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27568	 1	 11.69	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27569	 1	 11.17	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27570	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27571	 1	 7.96	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27572	 1	 10.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27573	 1	 10.6	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27574	 1	 3.68	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27575	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27576	 1	 1.46	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27577	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27578	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27579	 1	 5.11	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27580	 1	 4.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27581	 1	 2.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27582	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27583	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27584	 1	 12.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27585	 1	 8.74	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27586	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27587	 1	 5.12	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27588	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27589	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27590	 1	 19.3	 4.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27591	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27592	 1	 5.52	 1.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27593	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27594	 1	 3.34	 0.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27595	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27596	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27597	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27598	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27599	 1	 3.47	 0.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27600	 1	 8.92	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27601	 1	 6.07	 2.73	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27602	 1	 4.82	 1.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27603	 1	 6.27	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27604	 1	 4.86	 1.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27605	 1	 3.82	 0.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27606	 1	 9.13	 2.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27607	 1	 6.05	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27608	 1	 3.61	 0.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27609	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27610	 1	 7.04	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27611	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27612	 1	 6.76	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27613	 1	 4.13	 0.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27614	 1	 7.43	 1.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27615	 1	 7.77	 1.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27616	 1	 7.44	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27617	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27618	 1	 10.2	 2.41	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27619	 1	 4.37	 1.03	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27620	 1	 1.96	 0.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27621	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27622	 1	 7.23	 1.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27623	 1	 2.72	 1.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27624	 1	 6.32	 1.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27625	 1	 6.35	 1.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27626	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27627	 1	 8.08	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27628	 1	 3.98	 0.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27629	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27630	 1	 10.11	 3.73	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27631	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27632	 1	 6.12	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27633	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27634	 1	 6.24	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27635	 1	 14.09	 3.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27636	 1	 9.11	 2.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27637	 1	 27.41	 6.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27638	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27639	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27640	 1	 5.22	 1.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27641	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27642	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27643	 1	 9.87	 3.71	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27644	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27645	 1	 9.52	 3.21	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27646	 1	 10.63	 3.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27647	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27648	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27649	 1	 8.48	 3.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27650	 1	 24.47	 9.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27651	 1	 6.58	 2.81	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27652	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27653	 1	 36.19	 8.18	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27654	 1	 6.82	 2.64	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27655	 1	 19.47	 6.48	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27656	 1	 2.89	 1.41	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27657	 1	 8.61	 3.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27658	 1	 5.28	 2.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27659	 1	 22.38	 7.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27660	 1	 5.95	 2.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27661	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27662	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27663	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27664	 1	 4.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27665	 1	 5.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27666	 1	 87.39	 19.95	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27667	 1	 7.06	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27668	 1	 2.52	 0.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27669	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27670	 1	 20.81	 4.81	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27671	 1	 8.62	 2.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27672	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27673	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27674	 1	 7.14	 3.35	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27675	 1	 10.58	 4.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27676	 1	 3.28	 1.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27677	 1	 13.34	 5.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27678	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27679	 1	 3.5	 1.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27680	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27681	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27682	 1	 4.21	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27683	 1	 5.35	 2.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27684	 1	 7.6	 3.01	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27685	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27686	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27687	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27688	 1	 10.85	 3.33	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27689	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27690	 1	 11.94	 5.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27691	 1	 8.2	 3.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27692	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27693	 1	 13.86	 6.04	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27694	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27695	 1	 12.57	 5.77	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27696	 1	 8.92	 4.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27697	 1	 5.7	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27698	 1	 8.09	 3.23	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27699	 1	 10.91	 4.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27700	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27701	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27702	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27703	 1	 5.0	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27704	 1	 28.92	 10.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27705	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27706	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27707	 1	 12.63	 4.84	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27708	 1	 8.06	 3.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27709	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27710	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27711	 1	 7.98	 3.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27712	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27713	 1	 29.57	 12.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27714	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27715	 1	 4.75	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27716	 1	 5.77	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27717	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27718	 1	 18.67	 5.66	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27719	 1	 16.14	 4.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27720	 1	 7.31	 2.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27721	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27722	 1	 67.43	 21.92	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27723	 1	 5.72	 1.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27724	 1	 7.04	 3.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27725	 1	 4.64	 2.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27726	 1	 7.5	 3.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27727	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27728	 1	 8.18	 3.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27729	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27730	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27731	 1	 6.48	 3.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27732	 1	 8.51	 3.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27733	 1	 9.48	 2.73	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27734	 1	 6.08	 2.91	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27735	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27736	 1	 3.81	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27737	 1	 3.03	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27738	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27739	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27740	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27741	 1	 19.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27742	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27743	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27744	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27745	 1	 22.36	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27746	 1	 7.74	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27747	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27748	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27749	 1	 4.0	 1.92	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27750	 1	 6.47	 2.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27751	 1	 4.52	 1.79	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27752	 1	 2.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27753	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27754	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27755	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27756	 1	 2.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27757	 1	 5.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27758	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27759	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27760	 1	 3.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27761	 1	 13.35	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27762	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27763	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27764	 1	 3.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27765	 1	 8.47	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27766	 1	 4.14	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27767	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27768	 1	 8.05	 1.85	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27769	 1	 11.71	 3.45	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27770	 1	 24.76	 5.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27771	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27772	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27773	 1	 14.21	 5.17	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27774	 1	 3.61	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27775	 1	 5.29	 2.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27776	 1	 41.28	 16.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27777	 1	 20.91	 5.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27778	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27779	 1	 6.28	 2.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27780	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27781	 1	 5.45	 2.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27782	 1	 6.08	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27783	 1	 20.85	 8.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27784	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27785	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27786	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	27787	 1	 4.81	 2.14	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27788	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27789	 1	 9.01	 3.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27790	 1	 5.78	 2.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27791	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27792	 1	 6.5	 3.03	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27793	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27794	 1	 6.34	 2.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27795	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27796	 1	 5.79	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27797	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27798	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27799	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27800	 1	 19.05	 4.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27801	 1	 9.98	 2.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27802	 1	 14.94	 3.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27803	 1	 28.78	 8.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	27804	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27805	 1	 17.49	 4.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27806	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27807	 1	 21.19	 4.92	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27808	 1	 15.05	 3.48	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27809	 1	 9.54	 2.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81859	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81860	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81861	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81862	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81863	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81864	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81865	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81866	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81867	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81868	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81869	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81870	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81871	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81872	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81873	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81874	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81875	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81876	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81877	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81878	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81879	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81880	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81881	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81882	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81883	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81884	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81885	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81886	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81887	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81888	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81889	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81890	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81891	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81892	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81893	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81894	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81895	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81896	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81897	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81898	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81899	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81900	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81901	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81902	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81903	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81904	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81905	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81906	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81907	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81908	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81909	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81910	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81911	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81912	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81913	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81914	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81915	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81916	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81917	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81918	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81919	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81920	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81921	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81922	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81923	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81924	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81925	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81926	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81927	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81928	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81929	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81930	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81931	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81932	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81933	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81934	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81935	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81936	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81937	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81938	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81939	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81940	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81941	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81942	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81943	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81944	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81945	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81946	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81947	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81948	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81949	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81950	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81951	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81952	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81953	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81954	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81955	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81956	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81957	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81958	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81959	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81960	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81961	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81962	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81963	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81964	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81965	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81966	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81967	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81968	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81969	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81970	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81971	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81972	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81973	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81974	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81975	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81976	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81977	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81978	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81979	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81980	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81981	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81982	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81983	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81984	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81985	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81986	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81987	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81988	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81989	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81990	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81991	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81992	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81993	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81994	 2	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81995	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81996	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	81997	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	81998	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	81999	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82000	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82001	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82002	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82003	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82004	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82005	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82006	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82007	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82008	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82009	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82010	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82011	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82012	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82013	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82014	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82015	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82016	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82017	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82018	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82019	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82020	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82021	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82022	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82023	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82024	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82025	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82026	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82027	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82028	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82029	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82030	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82031	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82032	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82033	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82034	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82035	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82036	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82037	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82038	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82039	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82040	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82041	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82042	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82043	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82044	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82045	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82046	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82047	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82048	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82049	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82050	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82051	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82052	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82053	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82054	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82055	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82056	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82057	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82058	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82059	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82060	 2	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82061	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82062	 1	 19.91	 4.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82063	 1	 41.55	 9.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82064	 1	 4.9	 1.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82065	 1	 4.99	 1.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82066	 1	 111.86	 24.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82067	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82068	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82069	 1	 15.6	 3.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82070	 1	 38.87	 8.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82071	 1	 52.61	 11.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82072	 1	 7.37	 1.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82073	 1	 4.46	 1.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82074	 1	 21.52	 4.82	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82075	 1	 16.0	 3.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82076	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82077	 1	 41.82	 9.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82078	 1	 9.77	 2.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82079	 1	 50.62	 11.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82080	 1	 9.44	 2.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82081	 1	 8.28	 1.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82082	 1	 51.55	 11.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82083	 1	 11.98	 2.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82084	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82085	 1	 35.46	 7.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82086	 1	 15.38	 3.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82087	 1	 10.45	 2.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82088	 1	 8.5	 1.89	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82089	 1	 6.58	 1.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82090	 1	 10.41	 2.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82091	 1	 53.86	 12.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82092	 1	 12.51	 2.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82093	 1	 62.23	 19.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82094	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82095	 1	 14.79	 3.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82096	 1	 22.18	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82097	 1	 42.29	 9.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82098	 1	 37.59	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82099	 1	 54.01	 12.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82100	 1	 5.4	 1.84	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82101	 1	 62.63	 14.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82102	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82103	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82104	 1	 40.77	 11.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82105	 1	 10.63	 3.72	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82106	 1	 4.41	 2.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82107	 1	 15.17	 4.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82108	 1	 12.38	 5.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82109	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82110	 1	 32.9	 11.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82111	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82112	 1	 15.3	 4.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82113	 1	 23.01	 7.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82114	 1	 113.33	 24.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82115	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82116	 1	 28.11	 11.77	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82117	 1	 8.65	 2.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82118	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82119	 1	 47.42	 13.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82120	 1	 17.62	 8.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82121	 1	 15.13	 6.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82122	 1	 3.64	 1.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82123	 1	 5.46	 2.46	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82124	 1	 14.1	 4.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82125	 1	 25.18	 5.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82126	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82127	 1	 12.22	 3.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82128	 1	 9.22	 3.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82129	 1	 22.51	 6.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82130	 1	 4.36	 2.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82131	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82132	 1	 143.14	 26.23	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82133	 1	 16.97	 6.43	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82134	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82135	 1	 44.19	 11.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82136	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82137	 1	 20.87	 6.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82138	 1	 27.02	 7.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82139	 1	 14.4	 6.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82140	 1	 112.74	 33.78	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82141	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82142	 1	 28.78	 8.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82143	 1	 13.72	 3.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82144	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82145	 1	 14.12	 4.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82146	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82147	 1	 18.01	 4.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82148	 1	 7.24	 2.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82149	 1	 7.28	 3.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82150	 1	 5.36	 2.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82151	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82152	 1	 12.63	 4.89	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82153	 1	 24.11	 8.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82154	 1	 52.91	 16.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82155	 1	 15.09	 5.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82156	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82157	 1	 36.26	 11.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82158	 1	 24.03	 6.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82159	 1	 43.54	 14.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82160	 1	 25.94	 7.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82161	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82162	 1	 15.85	 4.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82163	 1	 29.63	 6.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82164	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82165	 1	 73.96	 16.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82166	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82167	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82168	 1	 36.86	 8.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82169	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82170	 1	 5.07	 1.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82171	 1	 15.32	 5.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82172	 1	 9.04	 3.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82173	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82174	 1	 25.64	 8.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82175	 1	 10.5	 3.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82176	 1	 10.54	 3.86	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82177	 1	 17.61	 5.6	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82178	 1	 22.55	 4.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82179	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82180	 1	 49.22	 13.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82181	 1	 12.37	 4.95	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82182	 1	 8.55	 3.24	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82183	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82184	 1	 16.91	 5.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82185	 1	 33.18	 11.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82186	 1	 9.75	 3.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82187	 1	 8.26	 3.41	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82188	 1	 9.77	 3.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82189	 1	 106.59	 29.95	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82190	 1	 32.26	 11.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82191	 1	 32.97	 9.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82192	 1	 62.61	 20.43	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82193	 1	 8.68	 1.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82194	 1	 149.7	 32.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82195	 1	 31.94	 7.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82196	 1	 21.73	 5.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82197	 1	 78.97	 21.09	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82198	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82199	 1	 171.53	 40.5	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82200	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82201	 1	 31.5	 7.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82202	 1	 113.19	 20.99	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82203	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82204	 1	 26.28	 5.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82205	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82206	 1	 97.01	 27.76	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82207	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82208	 1	 29.19	 6.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82209	 1	 80.24	 16.29	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82210	 1	 47.59	 10.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82211	 1	 8.76	 3.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82212	 1	 17.56	 5.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82213	 1	 39.66	 14.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82214	 1	 14.31	 5.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82215	 1	 4.76	 2.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82216	 1	 5.05	 2.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82217	 1	 17.73	 5.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82218	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82219	 1	 18.86	 6.33	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82220	 1	 7.2	 2.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82221	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82222	 1	 16.29	 4.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82223	 1	 8.7	 4.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82224	 1	 8.07	 3.16	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82225	 1	 6.94	 2.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82226	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82227	 1	 8.99	 4.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82228	 1	 2.54	 1.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82229	 1	 24.14	 7.96	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82230	 1	 24.34	 6.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82231	 1	 32.56	 8.77	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82232	 1	 6.37	 3.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82233	 1	 20.0	 7.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82234	 1	 30.46	 7.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82235	 1	 19.71	 5.93	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82236	 1	 35.88	 13.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82237	 1	 24.69	 5.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82238	 1	 21.97	 5.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82239	 1	 26.5	 6.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82240	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82241	 1	 32.68	 7.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82242	 1	 9.95	 3.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82243	 1	 4.83	 1.92	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82244	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82245	 1	 21.67	 4.89	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82246	 1	 7.41	 3.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82247	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82248	 1	 23.51	 7.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82249	 1	 21.29	 8.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82250	 1	 64.56	 21.68	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82251	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82252	 1	 25.0	 10.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82253	 1	 16.1	 6.18	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82254	 1	 6.81	 2.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82255	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82256	 1	 16.63	 5.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82257	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82258	 1	 25.39	 11.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82259	 1	 12.47	 6.18	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82260	 1	 10.74	 4.98	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82261	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82262	 1	 7.35	 3.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82263	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82264	 1	 14.15	 6.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82265	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82266	 1	 9.15	 3.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82267	 1	 17.63	 5.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82268	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82269	 1	 16.49	 4.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82270	 1	 22.39	 7.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82271	 1	 80.04	 17.13	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82272	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82273	 1	 14.95	 5.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82274	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82275	 1	 23.6	 8.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82276	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82277	 1	 36.48	 9.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82278	 1	 60.99	 24.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82279	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82280	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82281	 1	 10.59	 5.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82282	 1	 9.73	 4.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82283	 1	 22.41	 6.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82284	 1	 22.07	 8.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82285	 1	 45.38	 15.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82286	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82287	 1	 16.43	 5.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82288	 1	 6.95	 2.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82289	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82290	 1	 46.25	 10.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82291	 1	 20.66	 4.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82292	 1	 13.59	 4.16	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82293	 1	 16.97	 4.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82294	 1	 14.92	 3.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82295	 1	 57.56	 11.04	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82296	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82297	 1	 23.62	 6.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82298	 1	 51.03	 11.64	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82299	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82300	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82301	 1	 48.79	 11.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82302	 1	 12.21	 2.85	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82303	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82304	 1	 7.53	 2.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82305	 1	 6.63	 2.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82306	 1	 14.44	 5.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82307	 1	 19.86	 5.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82308	 1	 1.88	 0.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82309	 1	 17.93	 5.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82310	 1	 12.45	 5.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82311	 1	 11.19	 3.97	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82312	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82313	 1	 38.39	 7.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82314	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82315	 1	 21.5	 7.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82316	 1	 17.64	 5.54	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82317	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82318	 1	 10.55	 2.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82319	 1	 24.79	 5.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82320	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82321	 1	 45.07	 10.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82322	 1	 15.15	 4.99	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82323	 1	 13.49	 5.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82324	 1	 11.14	 3.99	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82325	 1	 57.8	 19.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82326	 1	 46.73	 11.27	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82327	 1	 7.2	 2.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82328	 1	 40.82	 11.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82329	 1	 86.73	 27.87	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82330	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82331	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82332	 1	 29.48	 9.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82333	 1	 24.65	 7.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82334	 1	 15.15	 4.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82335	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82336	 1	 25.72	 5.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82337	 1	 27.38	 6.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82338	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82339	 1	 24.64	 5.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82340	 1	 17.22	 3.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82341	 1	 4.0	 1.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82342	 1	 22.06	 5.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82343	 1	 37.26	 8.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82344	 1	 19.09	 4.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82345	 1	 47.79	 10.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82346	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82347	 1	 38.79	 10.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82348	 1	 215.37	 52.27	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82349	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82350	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82351	 1	 55.92	 18.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82352	 1	 7.42	 2.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82353	 1	 1.75	 0.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82354	 1	 25.95	 6.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82355	 1	 3.4	 1.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82356	 1	 2.93	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82357	 1	 4.58	 1.72	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82358	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82359	 1	 33.73	 11.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82360	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82361	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82362	 1	 52.93	 14.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82363	 1	 548.41	 159.58	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82364	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82365	 1	 362.07	 91.63	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82366	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82367	 1	 40.98	 8.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82368	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82369	 1	 18.38	 6.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82370	 1	 6.39	 2.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82371	 1	 78.25	 19.06	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82372	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82373	 1	 11.6	 3.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82374	 1	 8.97	 4.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82375	 1	 11.24	 4.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82376	 1	 10.77	 4.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82377	 1	 19.88	 7.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82378	 1	 10.8	 3.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82379	 1	 116.99	 36.18	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82380	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82381	 1	 20.56	 8.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82382	 1	 11.32	 4.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82383	 1	 11.56	 5.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82384	 1	 19.2	 4.5	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82385	 1	 35.27	 7.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82386	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82387	 1	 18.04	 7.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82388	 1	 5.92	 1.92	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82389	 1	 1.34	 0.69	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82390	 1	 41.11	 10.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82391	 1	 83.61	 25.15	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82392	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82393	 1	 20.37	 6.94	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82394	 1	 12.93	 5.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82395	 1	 6.4	 2.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82396	 1	 27.72	 10.03	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82397	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82398	 1	 25.84	 8.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82399	 1	 23.75	 7.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82400	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82401	 1	 26.64	 8.89	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82402	 1	 8.57	 3.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82403	 1	 16.39	 5.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82404	 1	 17.52	 5.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82405	 1	 9.33	 3.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82406	 1	 7.6	 3.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82407	 1	 25.53	 5.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82408	 1	 25.33	 6.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82409	 1	 3.65	 1.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82410	 1	 2.41	 1.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82411	 1	 11.98	 4.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82412	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82413	 1	 192.19	 61.58	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82414	 1	 8.93	 3.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82415	 1	 67.2	 16.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82416	 1	 19.87	 6.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82417	 1	 46.91	 15.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82418	 1	 19.53	 7.3	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82419	 1	 6.07	 2.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82420	 1	 11.98	 4.35	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82421	 1	 4.66	 1.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82422	 1	 19.01	 6.49	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82423	 1	 5.92	 2.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82424	 1	 13.39	 5.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82425	 1	 7.35	 3.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82426	 1	 8.38	 3.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82427	 1	 12.5	 5.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82428	 1	 6.85	 3.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82429	 1	 11.44	 4.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82430	 1	 15.07	 6.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82431	 1	 4.65	 2.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82432	 1	 3.42	 1.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82433	 1	 5.57	 2.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82434	 1	 9.21	 3.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82435	 1	 3.84	 1.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82436	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82437	 1	 29.32	 7.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82438	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82439	 1	 30.92	 8.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82440	 1	 17.42	 6.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82441	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82442	 1	 27.38	 7.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82443	 1	 6.99	 2.59	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82444	 1	 6.68	 3.14	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82445	 1	 9.96	 3.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82446	 1	 12.86	 5.59	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82447	 1	 18.63	 6.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82448	 1	 14.2	 4.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82449	 1	 36.04	 13.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82450	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82451	 1	 3.73	 1.69	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82452	 1	 9.91	 4.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82453	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82454	 1	 176.03	 56.71	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82455	 1	 25.34	 6.8	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82456	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82457	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	82458	 1	 166.48	 38.71	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82459	 1	 17.9	 4.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82460	 1	 2.7	 1.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82461	 1	 7.51	 3.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82462	 1	 4.48	 1.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82463	 1	 4.35	 1.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82464	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82465	 1	 3.33	 1.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82466	 1	 27.02	 6.87	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82467	 1	 47.17	 9.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82468	 1	 12.13	 3.85	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82469	 1	 13.32	 4.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82470	 1	 5.14	 2.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82471	 1	 4.0	 1.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82472	 1	 10.99	 3.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82473	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82474	 1	 5.52	 2.04	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82475	 1	 4.63	 1.77	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82476	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82477	 1	 30.98	 9.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82478	 1	 27.1	 6.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82479	 1	 4.83	 1.89	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82480	 1	 42.88	 12.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82481	 1	 5.14	 1.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82482	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82483	 1	 53.22	 13.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82484	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82485	 1	 34.26	 8.36	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82486	 1	 78.67	 22.65	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82487	 1	 89.89	 23.96	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82488	 1	 27.45	 8.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82489	 1	 66.35	 19.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82490	 1	 52.06	 16.55	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82491	 1	 11.23	 4.66	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82492	 1	 14.91	 4.95	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82493	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82494	 1	 29.24	 8.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82495	 1	 45.76	 13.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82496	 1	 23.43	 7.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82497	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82498	 1	 23.56	 7.01	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82499	 1	 20.66	 7.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82500	 1	 6.12	 2.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82501	 1	 10.23	 3.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82502	 1	 6.6	 2.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82503	 1	 11.64	 4.17	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82504	 1	 10.62	 4.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82505	 1	 58.54	 19.18	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82506	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82507	 1	 16.05	 6.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82508	 1	 18.67	 6.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82509	 1	 5.09	 2.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82510	 1	 71.36	 16.86	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82511	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82512	 1	 121.53	 29.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82513	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82514	 1	 40.64	 9.06	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82515	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82516	 1	 5.97	 2.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82517	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82518	 1	 21.16	 6.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82519	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82520	 1	 6.62	 1.56	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82521	 1	 8.46	 2.89	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82522	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82523	 1	 30.0	 9.13	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82524	 1	 15.54	 5.34	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82525	 1	 12.59	 3.62	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82526	 1	 3.6	 1.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82527	 1	 70.22	 24.31	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82528	 1	 12.22	 5.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82529	 1	 11.25	 4.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82530	 1	 26.25	 6.94	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82531	 1	 9.87	 3.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82532	 1	 10.48	 3.98	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82533	 1	 6.44	 2.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82534	 1	 7.43	 3.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82535	 1	 13.7	 4.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82536	 1	 11.49	 3.99	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82537	 1	 78.06	 24.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82538	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82539	 1	 23.66	 7.09	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82540	 1	 6.87	 2.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82541	 1	 3.8	 1.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82542	 1	 33.44	 9.24	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82543	 1	 8.72	 3.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82544	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82545	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82546	 1	 54.9	 12.84	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82547	 1	 20.1	 6.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82548	 1	 21.95	 6.32	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82549	 1	 12.09	 5.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82550	 1	 10.1	 3.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82551	 1	 18.23	 5.59	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82552	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82553	 1	 31.09	 9.46	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82554	 1	 59.86	 13.26	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82555	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82556	 1	 34.4	 7.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82557	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82558	 1	 7.78	 1.78	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82559	 1	 81.65	 18.66	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82560	 1	 17.41	 4.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82561	 1	 13.31	 5.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82562	 1	 16.78	 5.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82563	 1	 5.35	 2.41	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82564	 1	 4.87	 2.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82565	 1	 6.68	 3.08	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82566	 1	 5.99	 2.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82567	 1	 14.18	 5.76	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82568	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82569	 1	 45.52	 12.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82570	 1	 29.23	 8.89	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82571	 1	 22.4	 8.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82572	 1	 15.18	 3.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82573	 1	 11.89	 5.21	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82574	 1	 20.48	 6.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82575	 1	 50.41	 17.33	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82576	 1	 50.34	 12.25	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82577	 1	 6.77	 3.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82578	 1	 5.57	 2.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82579	 1	 27.67	 8.44	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82580	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82581	 1	 9.29	 3.65	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82582	 1	 32.62	 10.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82583	 1	 140.23	 27.25	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82584	 1	 26.98	 7.96	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82585	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82586	 1	 35.79	 8.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82587	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82588	 1	 8.41	 3.67	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82589	 1	 23.86	 7.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82590	 1	 49.4	 13.08	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82591	 1	 26.37	 6.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82592	 1	 29.58	 6.75	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82593	 1	 18.23	 4.22	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82594	 1	 34.67	 7.93	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82595	 1	 7.34	 1.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82596	 1	 20.33	 5.85	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82597	 1	 15.57	 3.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82598	 1	 23.06	 8.19	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82599	 1	 51.6	 11.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82600	 1	 17.47	 4.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82601	 1	 5.87	 2.34	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82602	 1	 28.73	 6.63	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82603	 1	 3.43	 0.79	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82604	 1	 4.51	 1.05	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82605	 1	 17.15	 3.92	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82606	 1	 14.9	 3.45	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82607	 1	 8.44	 2.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82608	 1	 4.33	 1.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82609	 1	 5.98	 2.3	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82610	 1	 81.44	 16.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82611	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82612	 1	 5.36	 1.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82613	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82614	 1	 11.78	 2.7	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82615	 1	 20.0	 5.17	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82616	 1	 45.4	 10.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82617	 1	 79.08	 18.89	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82618	 1	 14.23	 5.48	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82619	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82620	 1	 8.24	 1.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82621	 1	 14.33	 3.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82622	 1	 39.3	 8.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82623	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82624	 1	 19.0	 6.11	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82625	 1	 5.65	 2.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82626	 1	 13.74	 5.2	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82627	 1	 11.01	 2.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82628	 1	 9.16	 3.45	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82629	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82630	 1	 35.37	 10.58	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82631	 1	 11.16	 3.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82632	 1	 12.01	 3.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82633	 1	 37.98	 11.77	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82634	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82635	 1	 31.13	 7.62	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82636	 1	 55.53	 15.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82637	 1	 33.34	 10.54	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82638	 1	 13.83	 3.97	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82639	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82640	 1	 22.91	 7.91	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82641	 1	 25.4	 8.52	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82642	 1	 12.96	 3.74	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82643	 1	 25.18	 6.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82644	 1	 15.06	 5.73	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82645	 1	 16.96	 4.95	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82646	 1	 37.03	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82647	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82648	 1	 25.26	 5.57	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82649	 1	 25.75	 9.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82650	 1	 12.82	 4.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82651	 1	 12.01	 4.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82652	 1	 10.91	 4.12	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82653	 1	 40.54	 12.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82654	 1	 8.51	 3.51	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82655	 1	 73.19	 15.73	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82656	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82657	 1	 38.02	 7.55	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82658	 1	 20.1	 6.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82659	 1	 10.16	 4.4	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82660	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82661	 1	 16.72	 5.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82662	 1	 92.78	 28.99	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82663	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82664	 1	 13.07	 4.42	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82665	 1	 28.16	 7.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82666	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82667	 1	 33.87	 11.01	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82668	 1	 29.86	 9.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82669	 1	 16.86	 6.81	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82670	 1	 3.48	 1.47	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82671	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82672	 1	 21.56	 6.6	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82673	 1	 11.54	 4.29	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82674	 1	 30.77	 6.89	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82675	 1	 55.0	 17.73	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82676	 1	 6.82	 2.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82677	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82678	 1	 39.57	 14.88	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82679	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82680	 1	 56.19	 16.76	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82681	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82682	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82683	 1	 11.58	 4.31	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82684	 1	 25.12	 9.61	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82685	 1	 51.08	 11.68	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82686	 1	 13.01	 4.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82687	 1	 5.0	 2.02	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82688	 1	 8.93	 3.38	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82689	 1	 9.62	 2.37	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82690	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82691	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82692	 1	 38.42	 10.9	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82693	 1	 29.68	 9.39	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82694	 1	 46.77	 9.07	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82695	 1	 34.46	 12.1	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82696	 1	 35.81	 15.67	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82697	 1	 22.34	 7.76	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82698	 1	 23.27	 5.47	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82699	 1	 60.45	 16.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82700	 1	 24.85	 8.38	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82701	 1	 37.35	 8.39	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82702	 1	 19.63	 5.31	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82703	 1	 7.83	 2.7	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82704	 1	 11.3	 5.15	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82705	 1	 14.3	 4.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82706	 1	 22.6	 6.23	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82707	 1	 12.86	 4.83	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82708	 1	 99.83	 18.56	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82709	 1	 33.54	 10.07	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82710	 1	 36.22	 9.48	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82711	 1	 10.1	 4.18	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82712	 1	 8.23	 2.81	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82713	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82714	 1	 5.54	 2.28	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82715	 1	 28.42	 7.4	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82716	 1	 11.13	 4.43	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82717	 1	 15.38	 4.71	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82718	 1	 23.59	 8.28	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82719	 1	 5.41	 1.83	 0.0	 0.0	 9	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82720	 1	 11.3	 2.53	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82721	 1	 16.51	 3.69	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82722	 1	 47.19	 10.49	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82723	 1	 43.28	 9.54	 0.0	 0.0	 9	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82724	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82725	 1	 11.98	 8.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82726	 1	 1.58	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82727	 1	 7.07	 5.43	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82728	 1	 10.83	 5.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82729	 1	 17.71	 10.88	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82730	 1	 5.99	 3.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82731	 1	 5.19	 3.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82732	 1	 1.51	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82733	 1	 9.66	 6.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82734	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82735	 1	 16.01	 9.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82736	 1	 10.51	 6.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82737	 1	 15.81	 8.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82738	 1	 13.19	 7.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82739	 1	 29.38	 14.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82740	 1	 60.87	 18.31	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82741	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82742	 1	 7.1	 4.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82743	 1	 9.06	 4.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82744	 1	 9.23	 4.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82745	 1	 18.22	 10.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82746	 1	 1.71	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82747	 1	 2.85	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82748	 1	 12.65	 7.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82749	 1	 4.8	 3.05	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82750	 1	 13.38	 7.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82751	 1	 8.79	 6.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82752	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82753	 1	 22.64	 12.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82754	 1	 7.84	 5.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82755	 1	 10.28	 6.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82756	 1	 14.4	 5.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82757	 1	 2.69	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82758	 1	 4.04	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82759	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82760	 1	 17.04	 7.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82761	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82762	 1	 14.29	 5.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82763	 1	 5.34	 3.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82764	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82765	 1	 5.39	 2.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82766	 1	 5.24	 3.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82767	 1	 13.45	 7.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82768	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82769	 1	 7.88	 4.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82770	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82771	 1	 8.83	 4.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82772	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82773	 1	 4.81	 3.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82774	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82775	 1	 8.87	 5.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82776	 1	 14.47	 7.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82777	 1	 3.93	 2.46	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82778	 1	 6.31	 3.13	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82779	 1	 2.88	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82780	 1	 17.87	 7.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82781	 1	 27.31	 6.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82782	 1	 5.34	 3.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82783	 1	 13.22	 3.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82784	 1	 7.92	 1.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82785	 1	 41.09	 19.11	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82786	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82787	 1	 8.12	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82788	 1	 3.97	 0.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82789	 1	 4.22	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82790	 1	 9.88	 2.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82791	 1	 29.29	 15.24	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82792	 1	 26.89	 6.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82793	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82794	 1	 19.18	 4.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82795	 1	 6.25	 3.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82796	 1	 4.29	 2.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82797	 1	 12.75	 6.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82798	 1	 8.93	 5.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82799	 1	 9.65	 4.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82800	 1	 3.45	 2.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82801	 1	 2.23	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82802	 1	 2.19	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82803	 1	 24.96	 12.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82804	 1	 1.63	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82805	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82806	 1	 13.45	 6.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82807	 1	 2.73	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82808	 1	 3.52	 2.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82809	 1	 10.09	 5.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82810	 1	 24.17	 10.22	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82811	 1	 6.08	 3.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82812	 1	 8.62	 5.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82813	 1	 24.75	 10.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82814	 1	 7.69	 3.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82815	 1	 2.79	 1.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82816	 1	 7.05	 4.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82817	 1	 11.51	 4.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82818	 1	 3.64	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82819	 1	 5.2	 2.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82820	 1	 1.77	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82821	 1	 1.32	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82822	 1	 2.5	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82823	 1	 1.4	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82824	 1	 2.55	 1.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82825	 1	 4.66	 2.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82826	 1	 3.1	 1.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82827	 1	 2.32	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82828	 1	 5.29	 2.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82829	 1	 6.46	 2.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82830	 1	 8.31	 5.11	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82831	 1	 4.95	 3.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82832	 1	 2.1	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82833	 1	 2.37	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82834	 1	 7.89	 4.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82835	 1	 2.42	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82836	 1	 1.53	 0.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82837	 1	 3.16	 1.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82838	 1	 2.67	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82839	 1	 4.71	 2.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82840	 1	 4.69	 3.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82841	 1	 2.57	 2.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82842	 1	 3.15	 2.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82843	 1	 4.85	 3.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82844	 1	 11.06	 6.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82845	 1	 6.92	 4.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82846	 1	 12.47	 4.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82847	 1	 4.13	 2.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82848	 1	 6.75	 4.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82849	 1	 4.6	 3.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82850	 1	 7.67	 5.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82851	 1	 1.4	 1.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82852	 1	 2.81	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82853	 1	 12.34	 6.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82854	 1	 2.51	 1.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82855	 1	 6.56	 3.65	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82856	 1	 7.27	 3.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82857	 1	 8.1	 4.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82858	 1	 8.23	 4.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82859	 1	 2.64	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82860	 1	 2.94	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82861	 1	 3.06	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82862	 1	 11.86	 2.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82863	 1	 10.3	 4.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82864	 1	 11.42	 5.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82865	 1	 8.27	 3.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82866	 1	 4.62	 2.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82867	 1	 6.82	 4.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82868	 1	 7.48	 1.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82869	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82870	 1	 22.64	 10.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82871	 1	 9.16	 5.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82872	 1	 15.76	 7.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82873	 1	 13.01	 7.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82874	 1	 8.02	 4.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82875	 1	 17.89	 10.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82876	 1	 4.87	 3.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82877	 1	 2.75	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82878	 1	 3.34	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82879	 1	 25.29	 6.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82880	 1	 7.46	 4.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82881	 1	 8.94	 3.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82882	 1	 7.8	 5.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82883	 1	 12.48	 6.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82884	 1	 3.9	 2.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82885	 1	 5.13	 3.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82886	 1	 4.84	 2.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82887	 1	 10.18	 3.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82888	 1	 1.71	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82889	 1	 7.47	 5.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82890	 1	 2.24	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82891	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82892	 1	 17.25	 10.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82893	 1	 7.02	 3.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82894	 1	 4.92	 3.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82895	 1	 7.51	 4.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82896	 1	 22.36	 12.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82897	 1	 7.31	 3.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82898	 1	 5.97	 3.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82899	 1	 6.36	 3.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82900	 1	 6.01	 3.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82901	 1	 6.78	 3.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82902	 1	 7.82	 3.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82903	 1	 6.85	 3.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82904	 1	 7.85	 4.44	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82905	 1	 9.28	 5.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82906	 1	 12.69	 8.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82907	 1	 2.43	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82908	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82909	 1	 14.04	 8.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82910	 1	 11.24	 5.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82911	 1	 12.36	 7.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82912	 1	 2.55	 1.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82913	 1	 24.69	 11.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82914	 1	 6.0	 3.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82915	 1	 6.15	 4.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82916	 1	 21.49	 11.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82917	 1	 9.63	 5.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82918	 1	 10.73	 6.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82919	 1	 5.64	 2.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82920	 1	 4.11	 2.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82921	 1	 2.44	 1.59	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82922	 1	 6.0	 3.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82923	 1	 10.73	 4.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82924	 1	 10.36	 5.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82925	 1	 13.74	 7.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82926	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82927	 1	 30.38	 15.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82928	 1	 16.75	 3.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82929	 1	 45.67	 16.42	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82930	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82931	 1	 6.13	 4.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82932	 1	 9.6	 6.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82933	 1	 12.86	 5.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82934	 1	 11.04	 5.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82935	 1	 4.6	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82936	 1	 5.96	 4.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82937	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82938	 1	 7.76	 3.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82939	 1	 10.4	 6.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82940	 1	 11.55	 2.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82941	 1	 24.6	 11.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82942	 1	 13.02	 4.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82943	 1	 5.37	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82944	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82945	 1	 6.48	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82946	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82947	 1	 8.06	 3.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82948	 1	 3.93	 2.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82949	 1	 4.9	 2.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82950	 1	 4.39	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82951	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82952	 1	 23.0	 10.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82953	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82954	 1	 18.43	 5.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82955	 1	 7.14	 3.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82956	 1	 7.96	 5.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82957	 1	 4.49	 2.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82958	 1	 4.44	 3.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82959	 1	 3.71	 2.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82960	 1	 17.86	 7.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82961	 1	 11.66	 5.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82962	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82963	 1	 24.7	 13.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82964	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82965	 1	 30.38	 15.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82966	 1	 26.18	 13.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82967	 1	 8.43	 4.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82968	 1	 21.35	 8.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82969	 1	 42.03	 18.59	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82970	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82971	 1	 4.93	 2.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82972	 1	 31.61	 12.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82973	 1	 41.15	 13.12	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82974	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82975	 1	 15.14	 8.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82976	 1	 10.53	 5.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82977	 1	 12.8	 5.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82978	 1	 13.7	 5.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82979	 1	 4.34	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82980	 1	 7.55	 2.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82981	 1	 27.58	 9.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82982	 1	 16.65	 7.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82983	 1	 18.47	 11.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82984	 1	 7.19	 3.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82985	 1	 1.47	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82986	 1	 3.48	 2.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82987	 1	 1.59	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82988	 1	 1.12	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82989	 1	 5.92	 3.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82990	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82991	 1	 23.36	 13.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82992	 1	 6.46	 3.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82993	 1	 3.05	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82994	 1	 2.0	 0.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82995	 1	 12.72	 2.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82996	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	82997	 1	 31.55	 7.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82998	 1	 6.17	 1.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	82999	 1	 23.7	 5.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83000	 1	 5.37	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83001	 1	 7.71	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83002	 1	 1.25	 0.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83003	 1	 3.13	 0.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83004	 1	 2.55	 0.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83005	 1	 1.47	 0.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83006	 1	 11.17	 4.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83007	 1	 15.3	 3.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83008	 1	 0.94	 0.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83009	 1	 16.06	 3.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83010	 1	 1.34	 0.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83011	 1	 9.19	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83012	 1	 5.2	 1.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83013	 1	 1.95	 0.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83014	 1	 19.04	 4.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83015	 1	 8.25	 1.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83016	 1	 1.3	 0.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83017	 1	 6.98	 3.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83018	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83019	 1	 9.4	 5.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83020	 1	 13.39	 7.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83021	 1	 8.99	 3.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83022	 1	 4.85	 3.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83023	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83024	 1	 12.6	 6.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83025	 1	 7.36	 3.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83026	 1	 6.06	 3.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83027	 1	 26.15	 9.95	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83028	 1	 5.22	 3.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83029	 1	 4.5	 3.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83030	 1	 4.2	 2.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83031	 1	 3.78	 2.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83032	 1	 13.3	 7.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83033	 1	 32.85	 15.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83034	 1	 5.12	 2.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83035	 1	 2.04	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83036	 1	 2.32	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83037	 1	 2.9	 1.98	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83038	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83039	 1	 2.96	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83040	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83041	 1	 4.13	 2.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83042	 1	 3.91	 2.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83043	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83044	 1	 4.64	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83045	 1	 4.14	 2.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83046	 1	 4.85	 2.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83047	 1	 4.55	 3.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83048	 1	 4.72	 2.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83049	 1	 8.48	 4.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83050	 1	 9.12	 5.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83051	 1	 5.51	 3.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83052	 1	 5.52	 3.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83053	 1	 7.73	 4.16	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83054	 1	 8.47	 4.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83055	 1	 18.17	 7.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83056	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83057	 1	 24.99	 8.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83058	 1	 7.01	 3.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83059	 1	 4.84	 2.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83060	 1	 5.13	 2.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83061	 1	 2.52	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83062	 1	 3.15	 1.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83063	 1	 4.57	 3.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83064	 1	 19.96	 10.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83065	 1	 3.35	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83066	 1	 3.44	 2.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83067	 1	 11.58	 4.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83068	 1	 10.46	 4.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83069	 1	 6.54	 3.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83070	 1	 5.44	 3.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83071	 1	 8.15	 4.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83072	 1	 35.57	 14.47	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83073	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83074	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	83075	 1	 57.45	 21.75	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83076	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83077	 1	 16.59	 9.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83078	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83079	 1	 14.6	 5.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83080	 1	 4.8	 3.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83081	 1	 41.49	 15.22	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83082	 1	 9.88	 4.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83083	 1	 4.81	 3.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83084	 1	 3.58	 2.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83085	 1	 1.69	 1.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83086	 1	 13.49	 4.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83087	 1	 22.81	 8.76	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83088	 1	 8.18	 5.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83089	 1	 5.45	 3.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83090	 1	 3.44	 2.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83091	 1	 3.28	 2.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83092	 1	 24.42	 11.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83093	 1	 4.11	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83094	 1	 6.16	 3.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83095	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	83096	 1	 187.48	 79.63	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83097	 1	 6.73	 4.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83098	 1	 4.05	 2.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83099	 1	 4.45	 2.84	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83100	 1	 5.36	 3.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83101	 1	 5.35	 3.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83102	 1	 11.46	 4.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83103	 1	 10.97	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83104	 1	 4.04	 2.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83105	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83106	 1	 19.74	 9.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83107	 1	 6.82	 4.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83108	 1	 7.63	 4.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83109	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83110	 1	 10.79	 6.43	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83111	 1	 5.69	 4.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83112	 1	 5.22	 2.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83113	 1	 22.72	 12.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83114	 1	 13.4	 7.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83115	 1	 4.6	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83116	 1	 41.73	 14.87	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83117	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83118	 1	 9.42	 4.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83119	 1	 9.5	 5.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83120	 1	 1.91	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83121	 1	 16.85	 9.5	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83122	 1	 1.57	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83123	 1	 22.27	 12.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83124	 1	 17.15	 7.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83125	 1	 5.41	 3.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83126	 1	 14.78	 6.83	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83127	 1	 20.63	 7.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83128	 1	 20.31	 10.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83129	 1	 1.42	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83130	 1	 8.73	 5.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83131	 1	 5.95	 3.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83132	 1	 18.83	 7.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83133	 1	 4.94	 2.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83134	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83135	 1	 10.13	 5.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83136	 1	 4.97	 2.62	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83137	 1	 4.69	 2.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83138	 1	 1.56	 1.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83139	 1	 3.33	 2.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83140	 1	 6.46	 3.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83141	 1	 5.48	 2.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83142	 1	 3.21	 2.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83143	 1	 6.47	 3.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83144	 1	 5.93	 3.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83145	 1	 17.93	 9.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83146	 1	 2.71	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83147	 1	 11.84	 6.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83148	 1	 3.26	 1.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83149	 1	 3.04	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83150	 1	 1.37	 1.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83151	 1	 3.69	 2.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83152	 1	 3.18	 1.66	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83153	 1	 7.77	 1.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83154	 1	 3.73	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83155	 1	 3.68	 0.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83156	 1	 41.68	 21.4	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83157	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83158	 1	 12.13	 5.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83159	 1	 9.4	 4.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83160	 1	 1.18	 0.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83161	 1	 7.17	 1.7	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83162	 1	 29.31	 6.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83163	 1	 12.48	 2.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83164	 1	 12.98	 3.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83165	 1	 9.45	 2.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83166	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83167	 1	 21.48	 12.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83168	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83169	 1	 31.0	 15.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83170	 1	 13.1	 5.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83171	 1	 5.69	 3.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83172	 1	 10.66	 5.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83173	 1	 13.57	 8.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83174	 1	 6.6	 4.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83175	 1	 13.28	 7.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83176	 1	 16.59	 3.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83177	 1	 3.04	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83178	 1	 4.39	 2.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83179	 1	 5.25	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83180	 1	 9.66	 2.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83181	 1	 4.25	 1.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83182	 1	 4.54	 1.07	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83183	 1	 18.17	 5.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83184	 1	 9.68	 2.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83185	 1	 1.51	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83186	 1	 3.02	 1.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83187	 1	 4.44	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83188	 1	 3.18	 2.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83189	 1	 2.57	 1.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83190	 1	 2.35	 1.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83191	 1	 3.67	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83192	 1	 6.48	 3.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83193	 1	 6.93	 4.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83194	 1	 8.16	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83195	 1	 14.29	 7.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83196	 1	 2.97	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83197	 1	 17.15	 4.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83198	 1	 13.15	 6.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83199	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83200	 1	 11.93	 5.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83201	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83202	 1	 22.7	 7.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83203	 1	 3.9	 1.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83204	 1	 22.42	 12.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83205	 1	 27.3	 10.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83206	 1	 7.68	 3.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83207	 1	 10.8	 6.42	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83208	 1	 2.12	 1.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83209	 1	 4.26	 2.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83210	 1	 4.87	 2.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83211	 1	 2.33	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83212	 1	 3.85	 2.27	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83213	 1	 5.13	 2.8	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83214	 1	 5.31	 3.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83215	 1	 10.93	 5.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83216	 1	 4.09	 2.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83217	 1	 5.36	 3.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83218	 1	 6.53	 4.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83219	 1	 2.96	 1.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83220	 1	 3.22	 2.21	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83221	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83222	 1	 18.34	 10.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83223	 1	 2.74	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83224	 1	 16.48	 8.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83225	 1	 15.21	 6.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83226	 1	 5.68	 3.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83227	 1	 6.24	 3.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83228	 1	 11.61	 6.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83229	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83230	 1	 12.99	 7.75	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83231	 1	 6.77	 4.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83232	 1	 4.67	 2.74	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83233	 1	 14.05	 8.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83234	 1	 7.16	 4.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83235	 1	 13.67	 6.37	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83236	 1	 3.45	 2.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83237	 1	 5.77	 3.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83238	 1	 16.0	 9.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83239	 1	 6.1	 3.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83240	 1	 18.37	 7.77	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83241	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83242	 1	 4.16	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83243	 1	 6.86	 4.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83244	 1	 4.66	 2.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83245	 1	 2.89	 1.65	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83246	 1	 11.29	 6.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83247	 1	 50.5	 16.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83248	 1	 9.44	 5.5	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83249	 1	 9.29	 5.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83250	 1	 6.28	 4.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83251	 1	 43.47	 19.3	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83252	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83253	 1	 13.31	 8.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83254	 1	 13.7	 6.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83255	 1	 4.45	 2.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83256	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83257	 1	 14.09	 4.94	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83258	 1	 10.67	 6.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83259	 1	 1.94	 1.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83260	 1	 3.8	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83261	 1	 5.58	 3.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83262	 1	 6.06	 3.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83263	 1	 1.51	 1.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83264	 1	 2.99	 2.34	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83265	 1	 8.31	 6.4	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83266	 1	 10.64	 5.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83267	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83268	 1	 4.24	 2.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83269	 1	 4.76	 3.43	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83270	 1	 1.37	 0.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83271	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83272	 1	 21.86	 10.53	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83273	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83274	 1	 20.61	 7.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83275	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83276	 1	 6.25	 3.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83277	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83278	 1	 7.78	 4.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83279	 1	 2.14	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83280	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83281	 1	 7.92	 4.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83282	 1	 7.5	 3.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83283	 1	 4.04	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83284	 1	 14.67	 5.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83285	 1	 5.11	 3.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83286	 1	 4.45	 2.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83287	 1	 5.61	 3.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83288	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83289	 1	 6.15	 4.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83290	 1	 5.73	 3.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83291	 1	 24.06	 7.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83292	 1	 16.69	 9.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83293	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83294	 1	 7.65	 3.93	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83295	 1	 14.24	 7.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83296	 1	 7.44	 4.17	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83297	 1	 7.29	 4.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83298	 1	 4.4	 2.87	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83299	 1	 2.39	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83300	 1	 11.81	 2.63	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83301	 1	 12.45	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83302	 1	 27.74	 6.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83303	 1	 3.7	 0.84	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83304	 1	 27.58	 6.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83305	 1	 4.2	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83306	 1	 11.72	 7.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83307	 1	 14.7	 7.91	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83308	 1	 17.78	 8.14	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83309	 1	 28.55	 15.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83310	 1	 2.93	 0.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83311	 1	 10.46	 5.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83312	 1	 4.15	 2.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83313	 1	 2.29	 1.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83314	 1	 13.71	 7.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83315	 1	 8.27	 4.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83316	 1	 3.5	 2.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83317	 1	 16.29	 8.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83318	 1	 19.4	 8.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83319	 1	 5.96	 2.9	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83320	 1	 5.54	 3.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83321	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83322	 1	 23.94	 13.55	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83323	 1	 10.61	 5.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83324	 1	 3.95	 2.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83325	 1	 9.91	 5.86	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83326	 1	 8.76	 2.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83327	 1	 1.37	 0.32	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83328	 1	 3.0	 0.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83329	 1	 11.26	 6.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83330	 1	 4.66	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83331	 1	 6.19	 3.73	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83332	 1	 7.15	 3.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83333	 1	 3.55	 2.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83334	 1	 1.86	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83335	 1	 14.33	 3.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83336	 1	 2.74	 1.77	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83337	 1	 5.58	 1.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83338	 1	 9.29	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83339	 1	 7.25	 4.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83340	 1	 20.01	 4.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83341	 1	 19.67	 11.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83342	 1	 2.61	 1.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83343	 1	 5.56	 3.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83344	 1	 1.56	 0.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83345	 1	 5.6	 2.98	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83346	 1	 3.3	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83347	 1	 2.77	 1.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83348	 1	 1.85	 1.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83349	 1	 10.92	 6.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83350	 1	 11.73	 4.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83351	 1	 14.6	 6.01	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83352	 1	 39.04	 18.17	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83353	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83354	 1	 2.08	 1.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83355	 1	 2.28	 1.64	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83356	 1	 1.64	 1.06	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83357	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83358	 1	 19.05	 12.29	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83359	 1	 9.66	 4.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83360	 1	 11.35	 7.45	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83361	 1	 20.92	 11.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83362	 1	 1.33	 0.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83363	 1	 6.16	 3.35	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83364	 1	 2.51	 1.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83365	 1	 5.97	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83366	 1	 3.53	 2.16	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83367	 1	 3.04	 2.08	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83368	 1	 3.62	 2.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83369	 1	 3.34	 2.06	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83370	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83371	 1	 3.49	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83372	 1	 1.79	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83373	 1	 55.77	 24.91	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83374	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83375	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83376	 1	 17.64	 7.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83377	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83378	 1	 13.87	 7.83	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83379	 1	 2.39	 1.6	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83380	 1	 6.49	 3.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83381	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83382	 1	 2.45	 1.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83383	 1	 1.93	 1.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83384	 1	 1.97	 1.18	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83385	 1	 1.7	 1.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83386	 1	 4.15	 2.54	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83387	 1	 1.06	 0.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83388	 1	 7.92	 2.56	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83389	 1	 6.98	 4.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83390	 1	 9.09	 4.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83391	 1	 3.01	 1.36	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83392	 1	 1.64	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83393	 1	 11.47	 5.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83394	 1	 7.91	 2.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83395	 1	 3.27	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83396	 1	 3.19	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83397	 1	 3.12	 1.88	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83398	 1	 3.32	 2.13	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83399	 1	 2.89	 2.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83400	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83401	 1	 17.71	 9.05	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83402	 1	 11.8	 5.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83403	 1	 7.99	 4.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83404	 1	 11.79	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83405	 1	 1.86	 1.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83406	 1	 2.04	 1.52	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83407	 1	 2.66	 1.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83408	 1	 2.9	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83409	 1	 5.04	 3.03	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83410	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83411	 1	 3.02	 2.25	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83412	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	83413	 1	 97.0	 50.97	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83414	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83415	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83416	 1	 6.27	 2.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83417	 1	 2.14	 1.19	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83418	 1	 1.55	 1.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83419	 1	 10.57	 5.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83420	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83421	 1	 6.93	 4.28	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83422	 1	 8.77	 4.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83423	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83424	 1	 14.41	 7.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83425	 1	 3.89	 2.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83426	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83427	 1	 2.76	 2.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83428	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83429	 1	 2.31	 1.61	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83430	 1	 13.12	 7.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83431	 1	 12.39	 5.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83432	 1	 3.65	 2.4	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83433	 1	 6.06	 2.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83434	 1	 1.86	 1.38	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83435	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83436	 1	 22.0	 11.04	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83437	 1	 3.27	 2.24	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83438	 1	 3.31	 1.89	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83439	 1	 3.14	 1.85	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83440	 1	 4.5	 2.97	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83441	 1	 3.27	 2.09	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83442	 1	 2.27	 1.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83443	 1	 2.72	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83444	 1	 2.69	 1.78	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83445	 1	 14.91	 8.72	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83446	 1	 4.05	 2.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83447	 1	 1.55	 1.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83448	 1	 2.1	 1.34	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83449	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83450	 1	 22.16	 11.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83451	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83452	 1	 20.61	 10.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83453	 1	 3.85	 2.68	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83454	 1	 3.16	 2.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83455	 1	 4.6	 3.22	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83456	 1	 12.09	 6.46	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83457	 1	 2.37	 1.79	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83458	 1	 7.25	 4.23	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83459	 1	 16.77	 9.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83460	 1	 1.89	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83461	 1	 5.91	 3.65	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83462	 1	 12.69	 7.81	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83463	 1	 5.2	 2.96	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83464	 1	 1.96	 1.47	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83465	 1	 5.2	 2.67	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83466	 1	 9.78	 5.49	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83467	 1	 40.22	 17.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83468	 1	 16.11	 7.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83469	 1	 2.8	 2.02	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83470	 1	 5.36	 2.76	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83471	 1	 11.11	 6.41	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83472	 1	 18.53	 11.31	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83473	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83474	 1	 12.37	 6.95	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83475	 1	 14.93	 6.58	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83476	 1	 11.73	 5.57	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83477	 1	 3.83	 2.48	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83478	 1	 39.15	 18.93	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83479	 1	 3.19	 2.26	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83480	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83481	 1	 22.18	 13.39	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83482	 1	 10.54	 6.2	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83483	 1	 4.93	 3.69	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83484	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83485	 1	 26.76	 13.15	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83486	 1	 3.5	 2.33	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83487	 1	 15.84	 9.65	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83488	 1	 2.47	 1.92	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83489	 1	 4.48	 2.82	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83490	 1	 8.7	 5.71	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83491	 1	 10.71	 4.51	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83492	 1	 3.79	 1.99	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83493	 1	 40.67	 19.5	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83494	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83495	 1	 56.7	 25.12	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83496	 1	 7.39	 4.1	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83497	 1	 0.0	 0.0	 0.0	 0.0	 17	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83498	 1	 28.1	 11.3	 0.0	 0.0	 17	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83499	 1	 10.27	 4.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83500	 1	 8.95	 3.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83501	 1	 20.63	 7.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83502	 1	 17.98	 5.1	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83503	 1	 6.33	 2.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83504	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83505	 1	 29.12	 9.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83506	 1	 19.24	 6.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83507	 1	 10.15	 3.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83508	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	83509	 1	 186.26	 63.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83510	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83511	 1	 70.99	 25.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83512	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83513	 1	 10.67	 3.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83514	 1	 3.58	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83515	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83516	 1	 19.65	 8.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83517	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83518	 1	 3.69	 1.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83519	 1	 1.12	 0.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83520	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83521	 1	 26.82	 6.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83522	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83523	 1	 35.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83524	 1	 8.34	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83525	 1	 16.2	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83526	 1	 37.42	 15.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83527	 1	 131.7	 31.36	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83528	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83529	 1	 17.54	 5.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83530	 1	 20.61	 8.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83531	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83532	 1	 7.99	 3.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83533	 1	 18.0	 6.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83534	 1	 9.89	 4.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83535	 1	 28.01	 11.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83536	 1	 5.08	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83537	 1	 10.76	 4.84	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83538	 1	 17.07	 6.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83539	 1	 4.1	 1.85	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83540	 1	 8.65	 3.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83541	 1	 6.27	 3.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83542	 1	 25.99	 6.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83543	 1	 11.95	 2.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83544	 1	 14.35	 3.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83545	 1	 13.12	 3.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83546	 1	 18.67	 4.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83547	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83548	 1	 9.73	 4.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83549	 1	 5.73	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83550	 1	 10.5	 4.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83551	 1	 6.58	 2.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83552	 1	 5.06	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83553	 1	 17.92	 6.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83554	 1	 9.74	 2.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83555	 1	 5.33	 2.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83556	 1	 17.65	 8.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83557	 1	 13.43	 5.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83558	 1	 5.35	 2.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83559	 1	 8.32	 3.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83560	 1	 12.42	 5.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83561	 1	 4.31	 2.23	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83562	 1	 7.33	 3.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83563	 1	 5.66	 2.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83564	 1	 10.0	 4.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83565	 1	 32.07	 10.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83566	 1	 4.97	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83567	 1	 13.7	 5.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83568	 1	 5.13	 2.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83569	 1	 14.78	 7.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83570	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83571	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83572	 1	 5.37	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83573	 1	 14.46	 7.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83574	 1	 8.15	 3.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83575	 1	 7.37	 3.77	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83576	 1	 134.65	 41.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83577	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83578	 1	 10.52	 5.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83579	 1	 6.32	 3.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83580	 1	 29.69	 9.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83581	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83582	 1	 38.31	 12.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83583	 1	 60.83	 22.69	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83584	 1	 7.98	 3.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83585	 1	 4.6	 2.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83586	 1	 24.41	 8.26	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83587	 1	 2.67	 1.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83588	 1	 2.25	 1.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83589	 1	 5.21	 1.98	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83590	 1	 2.85	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83591	 1	 25.86	 7.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83592	 1	 36.72	 10.59	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83593	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83594	 1	 25.7	 5.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83595	 1	 14.5	 4.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83596	 1	 25.37	 8.23	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83597	 1	 12.08	 4.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83598	 1	 5.17	 1.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83599	 1	 15.69	 6.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83600	 1	 15.96	 3.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83601	 1	 21.26	 4.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83602	 1	 21.53	 4.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83603	 1	 17.93	 4.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83604	 1	 6.94	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83605	 1	 14.21	 3.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83606	 1	 31.55	 7.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83607	 1	 18.7	 4.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83608	 1	 22.5	 5.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83609	 1	 32.25	 7.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83610	 1	 5.7	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83611	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83612	 1	 30.07	 6.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83613	 1	 12.85	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83614	 1	 7.32	 1.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83615	 1	 7.6	 1.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83616	 1	 14.93	 3.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83617	 1	 10.63	 5.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83618	 1	 2.36	 1.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83619	 1	 7.96	 3.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83620	 1	 9.43	 4.19	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83621	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83622	 1	 9.77	 3.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83623	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83624	 1	 5.08	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83625	 1	 8.35	 3.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83626	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83627	 1	 17.35	 6.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83628	 1	 7.1	 3.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83629	 1	 22.99	 7.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83630	 1	 11.51	 4.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83631	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83632	 1	 35.05	 11.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83633	 1	 9.33	 4.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83634	 1	 9.72	 4.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83635	 1	 6.69	 3.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83636	 1	 10.85	 4.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83637	 1	 11.95	 5.01	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83638	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83639	 1	 43.29	 16.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83640	 1	 20.48	 7.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83641	 1	 9.82	 3.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83642	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83643	 1	 12.48	 5.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83644	 1	 18.92	 6.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83645	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83646	 1	 28.19	 8.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83647	 1	 5.35	 2.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83648	 1	 18.4	 8.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83649	 1	 10.84	 3.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83650	 1	 6.73	 3.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83651	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83652	 1	 8.59	 4.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83653	 1	 19.55	 8.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83654	 1	 131.37	 44.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83655	 1	 3.68	 1.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83656	 1	 5.9	 2.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83657	 1	 4.24	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83658	 1	 26.95	 9.15	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83659	 1	 19.82	 5.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83660	 1	 51.29	 15.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83661	 1	 2.26	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83662	 1	 6.83	 2.72	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83663	 1	 6.05	 3.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83664	 1	 22.72	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83665	 1	 16.1	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83666	 1	 4.47	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83667	 1	 10.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83668	 1	 35.92	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83669	 1	 5.58	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83670	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83671	 1	 3.85	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83672	 1	 9.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83673	 1	 6.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83674	 1	 13.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83675	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83676	 1	 5.8	 2.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83677	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83678	 1	 5.8	 2.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83679	 1	 10.38	 4.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83680	 1	 54.43	 17.54	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83681	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83682	 1	 1.56	 0.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83683	 1	 3.22	 1.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83684	 1	 84.78	 31.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83685	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83686	 1	 6.46	 2.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83687	 1	 13.08	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83688	 1	 5.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83689	 1	 12.35	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83690	 1	 24.57	 9.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83691	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83692	 1	 6.86	 2.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83693	 1	 10.35	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83694	 1	 24.3	 7.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83695	 1	 1.61	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83696	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83697	 1	 22.66	 5.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83698	 1	 4.89	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83699	 1	 12.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83700	 1	 21.35	 7.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83701	 1	 9.97	 3.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83702	 1	 13.5	 5.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83703	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83704	 1	 11.0	 3.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83705	 1	 7.68	 3.87	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83706	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83707	 1	 24.12	 6.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83708	 1	 22.5	 5.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83709	 1	 9.51	 4.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83710	 1	 5.98	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83711	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83712	 1	 9.26	 3.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83713	 1	 5.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83714	 1	 3.4	 1.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83715	 1	 2.59	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83716	 1	 20.35	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83717	 1	 13.88	 3.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83718	 1	 8.92	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83719	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83720	 1	 41.94	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83721	 1	 9.15	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83722	 1	 37.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83723	 1	 30.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83724	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83725	 1	 33.29	 11.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83726	 1	 14.62	 5.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83727	 1	 11.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83728	 1	 46.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83729	 1	 38.45	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83730	 1	 20.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83731	 1	 10.56	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83732	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83733	 1	 17.14	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83734	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83735	 1	 19.27	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83736	 1	 40.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83737	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83738	 1	 23.23	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83739	 1	 7.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83740	 1	 13.32	 3.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83741	 1	 6.6	 3.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83742	 1	 11.51	 5.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83743	 1	 107.67	 31.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83744	 1	 9.11	 3.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83745	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83746	 1	 30.69	 9.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83747	 1	 1.64	 0.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83748	 1	 14.68	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83749	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83750	 1	 24.66	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83751	 1	 10.76	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83752	 1	 27.39	 8.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83753	 1	 23.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83754	 1	 21.15	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83755	 1	 7.03	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83756	 1	 15.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83757	 1	 7.3	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83758	 1	 8.12	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83759	 1	 9.58	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83760	 1	 5.61	 2.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83761	 1	 9.3	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83762	 1	 14.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83763	 1	 3.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83764	 1	 9.77	 4.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83765	 1	 7.51	 2.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83766	 1	 23.74	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83767	 1	 5.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83768	 1	 9.27	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83769	 1	 9.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83770	 1	 6.72	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83771	 1	 7.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83772	 1	 10.9	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83773	 1	 11.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83774	 1	 7.02	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83775	 1	 11.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83776	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83777	 1	 43.35	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83778	 1	 6.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83779	 1	 17.76	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83780	 1	 6.18	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83781	 1	 5.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83782	 1	 7.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83783	 1	 6.42	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83784	 1	 13.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83785	 1	 11.63	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83786	 1	 14.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83787	 1	 11.24	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83788	 1	 10.9	 3.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83789	 1	 2.46	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83790	 1	 2.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83791	 1	 4.05	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83792	 1	 114.84	 27.73	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83793	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83794	 1	 15.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83795	 1	 7.67	 3.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83796	 1	 17.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83797	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83798	 1	 46.03	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83799	 1	 3.61	 1.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83800	 1	 22.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83801	 1	 16.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83802	 1	 24.12	 8.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83803	 1	 13.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83804	 1	 17.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83805	 1	 40.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83806	 1	 10.17	 3.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83807	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	83808	 1	 153.52	 39.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83809	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83810	 1	 21.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83811	 1	 9.79	 4.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83812	 1	 3.81	 1.83	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83813	 1	 45.35	 18.14	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83814	 1	 31.16	 8.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83815	 1	 20.29	 7.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83816	 1	 8.59	 2.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83817	 1	 7.0	 1.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83818	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83819	 1	 40.56	 9.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83820	 1	 9.79	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83821	 1	 9.29	 2.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83822	 1	 13.03	 3.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83823	 1	 12.37	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83824	 1	 12.14	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83825	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83826	 1	 5.59	 1.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83827	 1	 8.53	 3.54	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83828	 1	 13.18	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83829	 1	 11.78	 5.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83830	 1	 33.47	 12.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83831	 1	 28.91	 6.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83832	 1	 5.16	 2.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83833	 1	 6.96	 2.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83834	 1	 15.47	 6.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83835	 1	 29.88	 9.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83836	 1	 46.56	 16.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83837	 1	 4.34	 1.67	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83838	 1	 8.7	 4.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83839	 1	 10.66	 2.95	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83840	 1	 5.16	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83841	 1	 9.64	 2.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83842	 1	 15.81	 6.8	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83843	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83844	 1	 47.89	 14.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83845	 1	 13.53	 4.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83846	 1	 8.12	 3.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83847	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83848	 1	 23.35	 10.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83849	 1	 10.05	 2.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83850	 1	 12.47	 5.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83851	 1	 25.93	 9.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83852	 1	 5.39	 2.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83853	 1	 3.78	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83854	 1	 4.89	 1.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83855	 1	 2.95	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83856	 1	 3.31	 0.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83857	 1	 5.66	 1.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83858	 1	 12.82	 2.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83859	 1	 4.68	 1.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83860	 1	 13.56	 3.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83861	 1	 11.21	 2.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83862	 1	 5.02	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83863	 1	 3.09	 0.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83864	 1	 22.44	 5.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83865	 1	 16.32	 3.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83866	 1	 5.41	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83867	 1	 2.3	 0.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83868	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83869	 1	 27.66	 6.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83870	 1	 5.61	 1.3	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83871	 1	 4.3	 1.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83872	 1	 8.78	 2.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83873	 1	 21.38	 5.01	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83874	 1	 3.27	 0.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83875	 1	 3.05	 0.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83876	 1	 7.35	 1.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83877	 1	 4.95	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83878	 1	 4.1	 0.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83879	 1	 4.11	 0.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83880	 1	 6.86	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83881	 1	 20.11	 4.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83882	 1	 18.6	 4.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83883	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83884	 1	 25.77	 6.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83885	 1	 5.8	 1.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83886	 1	 5.31	 1.25	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83887	 1	 8.23	 1.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83888	 1	 6.3	 1.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83889	 1	 11.72	 2.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83890	 1	 7.72	 1.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83891	 1	 6.1	 1.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83892	 1	 5.12	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83893	 1	 9.53	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83894	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83895	 1	 8.96	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83896	 1	 18.71	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83897	 1	 4.79	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83898	 1	 6.57	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83899	 1	 7.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83900	 1	 12.06	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83901	 1	 14.25	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83902	 1	 6.97	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83903	 1	 8.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83904	 1	 4.46	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83905	 1	 8.69	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83906	 1	 32.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83907	 1	 32.09	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83908	 1	 6.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83909	 1	 4.86	 1.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83910	 1	 5.58	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83911	 1	 4.29	 1.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83912	 1	 11.56	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83913	 1	 5.33	 1.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83914	 1	 5.74	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83915	 1	 3.12	 0.73	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83916	 1	 11.29	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83917	 1	 20.59	 4.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83918	 1	 18.27	 4.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83919	 1	 16.92	 3.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83920	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83921	 1	 33.01	 7.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83922	 1	 28.64	 6.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83923	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83924	 1	 15.79	 3.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83925	 1	 134.89	 44.73	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83926	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83927	 1	 4.89	 1.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83928	 1	 14.32	 3.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83929	 1	 7.41	 1.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83930	 1	 8.71	 2.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83931	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83932	 1	 30.18	 7.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83933	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83934	 1	 44.56	 10.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83935	 1	 31.3	 7.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83936	 1	 7.31	 3.46	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83937	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83938	 1	 6.11	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83939	 1	 5.4	 1.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83940	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83941	 1	 7.52	 1.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83942	 1	 4.79	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83943	 1	 12.66	 2.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83944	 1	 2.72	 0.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83945	 1	 6.6	 1.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83946	 1	 9.04	 2.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83947	 1	 33.01	 7.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83948	 1	 2.45	 1.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83949	 1	 4.96	 1.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83950	 1	 19.5	 4.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83951	 1	 17.33	 7.67	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83952	 1	 7.03	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83953	 1	 12.31	 2.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83954	 1	 26.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83955	 1	 29.73	 6.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83956	 1	 32.96	 10.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83957	 1	 52.49	 16.42	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83958	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83959	 1	 35.06	 11.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83960	 1	 4.18	 2.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83961	 1	 7.17	 2.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83962	 1	 17.27	 6.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83963	 1	 3.53	 1.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83964	 1	 17.98	 5.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83965	 1	 7.1	 2.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83966	 1	 27.63	 7.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83967	 1	 50.36	 18.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83968	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83969	 1	 43.9	 15.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83970	 1	 15.11	 3.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83971	 1	 11.51	 3.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83972	 1	 7.2	 3.04	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83973	 1	 11.37	 4.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83974	 1	 24.85	 6.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83975	 1	 12.51	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83976	 1	 2.57	 1.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83977	 1	 241.78	 93.74	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83978	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83979	 1	 6.14	 3.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83980	 1	 13.4	 4.44	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83981	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83982	 1	 16.69	 6.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83983	 1	 27.67	 10.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83984	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	83985	 1	 18.56	 8.49	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83986	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83987	 1	 5.29	 2.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83988	 1	 9.88	 3.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83989	 1	 18.6	 4.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83990	 1	 8.92	 4.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83991	 1	 25.38	 7.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83992	 1	 10.68	 4.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83993	 1	 10.62	 4.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83994	 1	 120.47	 46.33	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	83995	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83996	 1	 9.05	 2.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83997	 1	 6.32	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83998	 1	 47.56	 12.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	83999	 1	 4.37	 1.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84000	 1	 3.9	 1.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84001	 1	 3.05	 1.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84002	 1	 4.33	 1.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84003	 1	 5.48	 2.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84004	 1	 5.42	 2.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84005	 1	 4.59	 2.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84006	 1	 4.96	 2.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84007	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84008	 1	 5.19	 2.35	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84009	 1	 11.49	 4.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84010	 1	 17.2	 6.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84011	 1	 62.2	 27.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84012	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84013	 1	 4.5	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84014	 1	 2.53	 0.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84015	 1	 8.4	 3.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84016	 1	 41.31	 11.56	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84017	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84018	 1	 4.74	 2.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84019	 1	 13.87	 5.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84020	 1	 5.96	 2.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84021	 1	 8.62	 3.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84022	 1	 10.82	 4.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84023	 1	 5.04	 2.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84024	 1	 4.13	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84025	 1	 10.18	 3.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84026	 1	 4.87	 2.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84027	 1	 10.91	 4.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84028	 1	 8.99	 4.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84029	 1	 3.7	 1.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84030	 1	 6.0	 2.76	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84031	 1	 4.98	 2.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84032	 1	 6.16	 3.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84033	 1	 7.04	 2.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84034	 1	 7.28	 3.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84035	 1	 7.2	 2.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84036	 1	 6.27	 2.68	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84037	 1	 5.17	 1.87	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84038	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84039	 1	 3.81	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84040	 1	 6.79	 2.6	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84041	 1	 8.38	 3.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84042	 1	 4.18	 1.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84043	 1	 14.68	 6.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84044	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84045	 1	 54.86	 13.86	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84046	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84047	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84048	 1	 86.52	 30.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84049	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84050	 1	 26.41	 7.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84051	 1	 25.52	 9.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84052	 1	 42.53	 13.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84053	 1	 37.28	 12.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84054	 1	 11.4	 4.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84055	 1	 17.38	 6.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84056	 1	 9.99	 4.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84057	 1	 9.91	 3.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84058	 1	 13.12	 4.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84059	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84060	 1	 24.86	 8.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84061	 1	 8.35	 3.84	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84062	 1	 9.31	 4.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84063	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84064	 1	 12.86	 6.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84065	 1	 13.79	 3.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84066	 1	 11.21	 3.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84067	 1	 151.69	 38.59	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84068	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84069	 1	 16.3	 6.27	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84070	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84071	 1	 25.97	 8.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84072	 1	 22.63	 9.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84073	 1	 16.9	 5.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84074	 1	 15.68	 6.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84075	 1	 17.38	 6.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84076	 1	 9.27	 2.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84077	 1	 26.84	 8.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84078	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84079	 1	 30.17	 7.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84080	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84081	 1	 37.89	 8.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84082	 1	 29.47	 6.91	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84083	 1	 5.76	 1.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84084	 1	 9.8	 2.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84085	 1	 15.2	 3.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84086	 1	 93.01	 28.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84087	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84088	 1	 29.2	 7.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84089	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84090	 1	 16.24	 5.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84091	 1	 13.28	 4.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84092	 1	 4.33	 2.21	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84093	 1	 5.39	 2.62	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84094	 1	 18.14	 6.92	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84095	 1	 18.91	 6.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84096	 1	 16.9	 7.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84097	 1	 16.75	 6.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84098	 1	 8.15	 3.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84099	 1	 10.26	 3.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84100	 1	 18.98	 6.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84101	 1	 16.62	 5.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84102	 1	 13.06	 3.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84103	 1	 7.14	 3.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84104	 1	 33.02	 11.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84105	 1	 7.33	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84106	 1	 30.88	 9.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84107	 1	 5.81	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84108	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84109	 1	 8.06	 3.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84110	 1	 5.98	 3.07	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84111	 1	 11.9	 5.12	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84112	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84113	 1	 10.32	 4.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84114	 1	 15.67	 4.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84115	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84116	 1	 8.79	 4.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84117	 1	 5.74	 2.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84118	 1	 17.84	 6.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84119	 1	 16.12	 5.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84120	 1	 6.17	 2.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84121	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84122	 1	 25.95	 9.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84123	 1	 9.6	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84124	 1	 7.8	 3.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84125	 1	 6.36	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84126	 1	 15.36	 5.34	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84127	 1	 38.66	 11.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84128	 1	 21.31	 5.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84129	 1	 53.69	 15.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84130	 1	 26.48	 8.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84131	 1	 18.02	 7.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84132	 1	 5.17	 2.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84133	 1	 5.98	 3.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84134	 1	 6.14	 3.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84135	 1	 12.45	 4.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84136	 1	 9.81	 5.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84137	 1	 10.27	 3.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84138	 1	 14.28	 4.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84139	 1	 21.63	 10.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84140	 1	 57.66	 16.55	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84141	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84142	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84143	 1	 8.88	 3.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84144	 1	 33.52	 11.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84145	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84146	 1	 20.45	 8.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84147	 1	 76.42	 29.87	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84148	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84149	 1	 7.71	 3.25	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84150	 1	 18.73	 7.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84151	 1	 34.77	 11.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84152	 1	 9.35	 3.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84153	 1	 12.91	 2.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84154	 1	 13.18	 3.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84155	 1	 23.96	 5.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84156	 1	 12.84	 2.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84157	 1	 13.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84158	 1	 9.33	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84159	 1	 9.16	 2.13	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84160	 1	 9.35	 2.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84161	 1	 3.16	 1.38	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84162	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84163	 1	 2.96	 0.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84164	 1	 7.65	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84165	 1	 28.53	 6.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84166	 1	 30.76	 6.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84167	 1	 65.2	 22.83	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84168	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84169	 1	 23.11	 11.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84170	 1	 7.58	 3.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84171	 1	 4.28	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84172	 1	 16.13	 6.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84173	 1	 22.08	 7.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84174	 1	 7.25	 3.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84175	 1	 26.35	 7.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84176	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84177	 1	 15.05	 5.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84178	 1	 11.85	 4.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84179	 1	 30.18	 10.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84180	 1	 11.96	 5.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84181	 1	 11.04	 4.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84182	 1	 26.59	 9.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84183	 1	 34.05	 8.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84184	 1	 8.4	 3.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84185	 1	 5.09	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84186	 1	 9.52	 4.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84187	 1	 18.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84188	 1	 43.19	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84189	 1	 27.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84190	 1	 2.96	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84191	 1	 18.02	 8.01	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84192	 1	 5.92	 2.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84193	 1	 9.38	 3.48	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84194	 1	 4.88	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84195	 1	 30.47	 9.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84196	 1	 22.81	 8.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84197	 1	 3.2	 1.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84198	 1	 6.87	 3.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84199	 1	 13.21	 3.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84200	 1	 1.79	 0.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84201	 1	 15.28	 3.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84202	 1	 31.83	 10.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84203	 1	 5.75	 2.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84204	 1	 25.87	 8.82	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84205	 1	 6.06	 3.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84206	 1	 6.12	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84207	 1	 2.88	 1.2	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84208	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84209	 1	 4.84	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84210	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84211	 1	 2.96	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84212	 1	 7.55	 3.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84213	 1	 5.45	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84214	 1	 57.07	 15.08	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84215	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84216	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84217	 1	 8.85	 3.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84218	 1	 24.44	 7.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84219	 1	 7.95	 3.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84220	 1	 11.3	 3.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84221	 1	 4.28	 1.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84222	 1	 7.19	 3.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84223	 1	 20.0	 6.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84224	 1	 23.34	 6.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84225	 1	 5.38	 2.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84226	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84227	 1	 10.7	 4.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84228	 1	 81.98	 25.56	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84229	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84230	 1	 27.59	 11.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84231	 1	 2.58	 1.1	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84232	 1	 17.11	 4.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84233	 1	 25.69	 7.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84234	 1	 16.12	 3.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84235	 1	 5.47	 1.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84236	 1	 1.35	 0.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84237	 1	 3.44	 0.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84238	 1	 4.72	 1.11	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84239	 1	 10.06	 2.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84240	 1	 6.7	 1.57	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84241	 1	 10.07	 3.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84242	 1	 10.77	 2.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84243	 1	 6.53	 2.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84244	 1	 25.81	 12.11	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84245	 1	 15.21	 5.18	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84246	 1	 13.02	 4.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84247	 1	 13.16	 5.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84248	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84249	 1	 16.92	 6.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84250	 1	 3.8	 0.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84251	 1	 24.12	 5.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84252	 1	 14.24	 5.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84253	 1	 14.92	 6.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84254	 1	 9.82	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84255	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84256	 1	 17.2	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84257	 1	 13.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84258	 1	 23.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84259	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84260	 1	 10.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84261	 1	 11.67	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84262	 1	 9.84	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84263	 1	 32.36	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84264	 1	 16.21	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84265	 1	 14.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84266	 1	 16.06	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84267	 1	 25.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84268	 1	 7.31	 3.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84269	 1	 5.15	 2.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84270	 1	 5.8	 2.32	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84271	 1	 5.2	 2.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84272	 1	 7.08	 1.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84273	 1	 16.36	 3.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84274	 1	 8.76	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84275	 1	 12.38	 2.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84276	 1	 2.14	 0.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84277	 1	 8.91	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84278	 1	 30.07	 6.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84279	 1	 20.89	 4.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84280	 1	 30.33	 6.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84281	 1	 24.53	 5.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84282	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84283	 1	 46.68	 10.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84284	 1	 24.33	 5.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84285	 1	 16.66	 3.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84286	 1	 8.84	 2.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84287	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84288	 1	 6.62	 2.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84289	 1	 4.38	 2.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84290	 1	 8.97	 3.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84291	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84292	 1	 3.04	 1.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84293	 1	 3.27	 1.42	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84294	 1	 17.85	 7.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84295	 1	 40.3	 9.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84296	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84297	 1	 26.32	 9.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84298	 1	 3.6	 1.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84299	 1	 4.32	 2.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84300	 1	 11.42	 4.64	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84301	 1	 17.83	 7.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84302	 1	 33.89	 10.76	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84303	 1	 8.16	 2.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84304	 1	 13.12	 5.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84305	 1	 7.11	 2.85	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84306	 1	 5.48	 2.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84307	 1	 5.55	 2.34	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84308	 1	 17.19	 6.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84309	 1	 14.65	 5.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84310	 1	 9.11	 3.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84311	 1	 4.24	 1.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84312	 1	 4.99	 2.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84313	 1	 10.34	 3.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84314	 1	 12.34	 4.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84315	 1	 5.17	 1.93	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84316	 1	 12.97	 5.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84317	 1	 17.38	 7.02	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84318	 1	 6.08	 2.57	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84319	 1	 10.69	 4.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84320	 1	 15.43	 6.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84321	 1	 10.55	 4.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84322	 1	 10.67	 5.02	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84323	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84324	 1	 8.86	 3.07	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84325	 1	 14.03	 5.77	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84326	 1	 35.22	 13.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84327	 1	 19.19	 7.98	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84328	 1	 4.89	 1.76	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84329	 1	 40.25	 14.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84330	 1	 1.98	 0.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84331	 1	 11.2	 3.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84332	 1	 6.73	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84333	 1	 11.5	 5.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84334	 1	 9.84	 4.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84335	 1	 18.13	 6.16	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84336	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84337	 1	 9.32	 4.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84338	 1	 5.78	 1.95	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84339	 1	 10.26	 4.75	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84340	 1	 6.09	 2.28	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84341	 1	 12.69	 2.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84342	 1	 10.54	 2.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84343	 1	 18.31	 4.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84344	 1	 14.52	 3.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84345	 1	 32.44	 7.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84346	 1	 22.37	 5.1	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84347	 1	 15.87	 3.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84348	 1	 16.38	 3.79	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84349	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84350	 1	 17.71	 7.99	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84351	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84352	 1	 13.15	 4.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84353	 1	 18.64	 6.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84354	 1	 7.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84355	 1	 6.18	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84356	 1	 17.79	 5.19	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84357	 1	 11.37	 4.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84358	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84359	 1	 27.42	 9.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84360	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84361	 1	 15.1	 4.22	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84362	 1	 4.83	 1.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84363	 1	 5.16	 2.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84364	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	84365	 1	 18.76	 6.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84366	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84367	 1	 2.78	 1.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84368	 1	 11.25	 3.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84369	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84370	 1	 13.08	 4.98	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84371	 1	 7.04	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84372	 1	 26.98	 8.6	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84373	 1	 34.44	 8.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84374	 1	 14.65	 5.99	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84375	 1	 17.51	 6.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84376	 1	 18.39	 6.82	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84377	 1	 19.3	 5.89	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84378	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84379	 1	 6.45	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84380	 1	 5.54	 2.75	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84381	 1	 10.61	 3.67	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84382	 1	 3.49	 1.56	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84383	 1	 5.54	 2.58	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84384	 1	 121.35	 30.24	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84385	 1	 108.61	 35.13	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84386	 1	 17.86	 7.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84387	 1	 22.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84388	 1	 9.85	 2.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84389	 1	 1.98	 0.46	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84390	 1	 17.29	 4.03	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84391	 1	 5.36	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84392	 1	 18.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84393	 1	 24.09	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84394	 1	 14.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84395	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84396	 1	 13.58	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84397	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84398	 1	 36.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84399	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84400	 1	 31.32	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84401	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84402	 1	 38.84	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84403	 1	 21.92	 7.86	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84404	 1	 3.89	 1.84	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84405	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84406	 1	 13.8	 4.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84407	 1	 15.14	 6.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84408	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84409	 1	 18.89	 7.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84410	 1	 27.73	 10.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84411	 1	 2.65	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84412	 1	 9.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84413	 1	 6.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84414	 1	 3.27	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84415	 1	 7.91	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84416	 1	 33.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84417	 1	 6.52	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84418	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84419	 1	 13.5	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84420	 1	 15.92	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84421	 1	 16.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84422	 1	 19.64	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84423	 1	 7.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84424	 1	 4.01	 1.94	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84425	 1	 29.59	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84426	 1	 8.67	 3.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84427	 1	 17.07	 6.55	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84428	 1	 6.49	 2.68	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84429	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84430	 1	 9.77	 3.96	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84431	 1	 6.97	 2.67	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84432	 1	 5.5	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84433	 1	 25.26	 8.78	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84434	 1	 56.63	 22.62	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84435	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84436	 1	 33.6	 11.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84437	 1	 22.52	 5.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84438	 1	 29.75	 9.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84439	 1	 30.48	 9.89	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84440	 1	 23.49	 7.17	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84441	 1	 6.98	 3.41	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84442	 1	 5.88	 2.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84443	 1	 5.85	 2.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84444	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	84445	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84446	 1	 9.24	 3.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84447	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84448	 1	 10.78	 4.4	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84449	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84450	 1	 18.39	 6.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84451	 1	 7.92	 2.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84452	 1	 15.51	 3.62	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84453	 1	 24.77	 5.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84454	 1	 17.26	 4.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84455	 1	 8.25	 1.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84456	 1	 27.76	 6.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84457	 1	 22.18	 4.97	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84458	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84459	 1	 10.16	 3.78	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84460	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84461	 1	 19.37	 6.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84462	 1	 19.05	 7.38	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84463	 1	 36.54	 12.44	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84464	 1	 132.42	 26.11	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84465	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84466	 1	 33.8	 8.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84467	 1	 7.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84468	 1	 3.72	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84469	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84470	 1	 7.51	 2.5	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84471	 1	 6.09	 2.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84472	 1	 10.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84473	 1	 7.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84474	 1	 19.43	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84475	 1	 17.95	 6.52	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84476	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84477	 1	 21.7	 8.21	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84478	 1	 48.71	 19.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84479	 1	 47.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84480	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84481	 1	 14.72	 5.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84482	 1	 6.44	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84483	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84484	 1	 8.99	 3.31	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84485	 1	 44.06	 14.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84486	 1	 16.54	 4.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84487	 1	 6.12	 3.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84488	 1	 4.95	 2.23	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84489	 1	 10.72	 3.77	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84490	 1	 14.88	 4.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84491	 1	 28.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84492	 1	 39.59	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84493	 1	 5.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84494	 1	 8.17	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84495	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84496	 1	 13.28	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84497	 1	 37.31	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84498	 1	 15.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84499	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84500	 1	 5.8	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84501	 1	 16.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84502	 1	 88.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84503	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84504	 1	 6.64	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84505	 1	 5.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84506	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84507	 1	 19.62	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84508	 1	 6.39	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84509	 1	 7.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84510	 1	 18.16	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84511	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84512	 1	 9.89	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84513	 1	 16.41	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84514	 1	 3.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84515	 1	 9.26	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84516	 1	 20.93	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84517	 1	 11.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84518	 1	 4.87	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84519	 1	 4.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84520	 1	 9.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84521	 1	 28.81	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84522	 1	 4.56	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84523	 1	 8.84	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84524	 1	 11.82	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84525	 1	 6.88	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84526	 1	 8.02	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84527	 1	 43.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84528	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84529	 1	 24.51	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84530	 1	 10.68	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84531	 1	 5.95	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84532	 1	 28.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84533	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84534	 1	 20.07	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84535	 1	 15.54	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84536	 1	 10.85	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84537	 1	 129.19	 37.31	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84538	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84539	 1	 7.49	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84540	 1	 42.61	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84541	 1	 12.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84542	 1	 13.01	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84543	 1	 18.99	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84544	 1	 10.58	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84545	 1	 2.98	 0.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84546	 1	 9.81	 2.37	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84547	 1	 32.95	 7.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84548	 1	 14.46	 3.49	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84549	 1	 5.78	 1.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84550	 1	 25.87	 6.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84551	 1	 18.59	 4.45	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84552	 1	 43.06	 10.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84553	 1	 10.15	 2.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84554	 1	 12.71	 3.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84555	 1	 15.91	 3.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84556	 1	 21.28	 5.01	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84557	 1	 15.65	 3.84	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84558	 1	 10.1	 2.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84559	 1	 14.72	 3.61	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84560	 1	 10.37	 2.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84561	 1	 4.83	 1.14	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84562	 1	 8.57	 2.02	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84563	 1	 10.6	 2.56	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84564	 1	 13.63	 3.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84565	 1	 12.63	 3.47	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84566	 1	 27.49	 11.8	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84567	 1	 52.39	 13.37	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84568	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84569	 1	 17.85	 5.43	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84570	 1	 11.53	 4.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84571	 1	 6.59	 2.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84572	 1	 21.2	 6.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84573	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84574	 1	 22.03	 5.08	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84575	 1	 69.02	 20.28	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84576	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84577	 1	 18.28	 5.4	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84578	 1	 9.28	 3.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84579	 1	 23.93	 8.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84580	 1	 21.36	 7.04	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84581	 1	 22.26	 6.61	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84582	 1	 4.26	 2.17	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84583	 1	 6.85	 2.3	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84584	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84585	 1	 28.39	 9.72	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84586	 1	 24.89	 8.52	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84587	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84588	 1	 34.1	 15.69	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84589	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84590	 1	 10.9	 4.26	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84591	 1	 11.36	 3.94	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84592	 1	 31.68	 10.81	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84593	 1	 19.17	 9.24	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84594	 1	 19.39	 6.71	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84595	 1	 21.84	 8.05	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84596	 1	 9.33	 3.9	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84597	 1	 49.32	 14.06	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84598	 1	 6.09	 2.89	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84599	 1	 10.2	 3.63	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84600	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84601	 1	 47.37	 11.29	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84602	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84603	 1	 25.03	 7.15	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84604	 1	 8.76	 4.06	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84605	 1	 6.64	 2.54	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84606	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84607	 1	 19.71	 4.88	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84608	 1	 21.58	 7.36	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84609	 1	 38.79	 11.74	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84610	 1	 9.08	 3.65	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84611	 1	 10.22	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84612	 1	 5.04	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84613	 1	 31.48	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84614	 1	 7.08	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84615	 1	 18.38	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84616	 1	 8.57	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84617	 1	 3.8	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84618	 1	 5.77	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84619	 1	 6.05	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84620	 1	 2.35	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84621	 1	 12.04	 2.92	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84622	 1	 33.55	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84623	 1	 7.37	 1.7	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84624	 1	 15.01	 5.51	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84625	 1	 44.82	 10.7	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84626	 1	 4.97	 2.09	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84627	 1	 6.93	 2.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84628	 1	 37.84	 10.59	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84629	 1	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84630	 1	 44.14	 15.66	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84631	 1	 13.59	 5.43	 0.0	 0.0	 27	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	84632	 1	 14.7	 4.39	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84633	 1	 8.78	 3.73	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84634	 1	 28.41	 9.47	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84635	 1	 5.46	 2.53	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84636	 1	 11.11	 4.58	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84637	 1	 22.61	 9.32	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84638	 1	 13.56	 3.2	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84639	 1	 28.87	 6.65	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	84640	 1	 5.68	 1.33	 0.0	 0.0	 27	    1.00000	    0.00000	 69.0	 1	    1.10000	    0.90000;
	95338	 4	 0.0	 0.0	 0.0	 0.0	 27	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin	Pc1	Pc2	Qc1min	Qc1max	Qc2min	Qc2max	ramp_agc	ramp_10	ramp_30	ramp_q	apf
mpc.gen = [
	20401	 900.0	 98.15	 629.6	 -433.3	 1.0	 100.0	 1	 1300.0	 500.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1300.0;
	20401	 0.0	 0.0	 629.6	 -433.3	 1.0	 100.0	 0	 1300.0	 500.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1300.0;
	20402	 458.95	 50.45	 323.5	 -222.6	 1.0	 100.0	 1	 667.9	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 667.9;
	20402	 458.95	 50.45	 323.5	 -222.6	 1.0	 100.0	 1	 667.9	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 667.9;
	20402	 458.95	 50.45	 323.5	 -222.6	 1.0	 100.0	 1	 667.9	 250.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 667.9;
	20402	 448.95	 50.45	 323.5	 -222.6	 1.0	 100.0	 1	 667.9	 230.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 667.9;
	20402	 448.95	 50.45	 323.5	 -222.6	 1.0	 100.0	 1	 667.9	 230.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 667.9;
	20403	 44.975	 8.45	 40.2	 -23.3	 1.0	 100.0	 1	 70.0	 19.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	20403	 44.975	 8.45	 40.2	 -23.3	 1.0	 100.0	 1	 70.0	 19.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	20403	 425.0	 40.75	 261.5	 -180.0	 1.0	 100.0	 1	 540.0	 310.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 540.0;
	20404	 400.0	 40.75	 261.5	 -180.0	 1.0	 100.0	 1	 540.0	 260.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 540.0;
	20404	 400.0	 40.75	 261.5	 -180.0	 1.0	 100.0	 1	 540.0	 260.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 540.0;
	20405	 83.75	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	20405	 415.5	 40.1	 257.2	 -177.0	 1.0	 100.0	 1	 531.0	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 531.0;
	20405	 380.5	 40.1	 257.2	 -177.0	 1.0	 100.0	 1	 531.0	 230.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 531.0;
	20406	 447.95	 96.1	 415.8	 -223.6	 1.0	 100.0	 1	 670.9	 225.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 670.9;
	20406	 445.45	 96.1	 415.8	 -223.6	 1.0	 100.0	 1	 670.9	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 670.9;
	20406	 205.8	 40.3	 174.5	 -93.9	 1.0	 100.0	 1	 281.6	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 281.6;
	20406	 374.15	 74.95	 324.3	 -174.4	 1.0	 100.0	 1	 523.3	 225.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 523.3;
	20407	 49.1	 12.65	 54.7	 -29.4	 1.0	 100.0	 1	 88.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	20407	 49.1	 12.65	 54.7	 -29.4	 1.0	 100.0	 1	 88.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	20407	 192.6	 20.0	 128.4	 -88.4	 1.0	 100.0	 1	 265.2	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 265.2;
	20407	 192.6	 20.0	 128.4	 -88.4	 1.0	 100.0	 1	 265.2	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 265.2;
	20408	 190.15	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3;
	20408	 190.15	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3;
	20408	 190.15	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3;
	20408	 190.15	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3;
	20408	 190.15	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3;
	20408	 190.15	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 163.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3;
	20409	 156.6	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.2;
	20409	 156.6	 29.1	 125.9	 -67.7	 1.0	 100.0	 1	 203.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.2;
	20409	 161.5	 30.5	 132.0	 -71.0	 1.0	 100.0	 1	 213.0	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.0;
	20410	 100.65	 15.05	 96.7	 -66.6	 1.0	 100.0	 1	 199.7	 1.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20411	 145.2	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4;
	20411	 28.75	 5.35	 23.2	 -12.5	 1.0	 100.0	 1	 37.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5;
	20411	 281.55	 59.15	 256.0	 -137.7	 1.0	 100.0	 1	 413.1	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 413.1;
	20412	 136.95	 26.05	 112.7	 -60.6	 1.0	 100.0	 1	 181.9	 92.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.9;
	20412	 136.95	 26.05	 112.7	 -60.6	 1.0	 100.0	 1	 181.9	 92.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.9;
	20412	 119.0	 16.1	 103.2	 -71.0	 1.0	 100.0	 1	 213.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.0;
	20413	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	20413	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	20413	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	20413	 122.0	 24.9	 107.8	 -58.0	 1.0	 100.0	 1	 174.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.0;
	20413	 169.0	 38.4	 166.1	 -89.3	 1.0	 100.0	 1	 268.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 268.0;
	20413	 169.0	 38.4	 166.1	 -89.3	 1.0	 100.0	 1	 268.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 268.0;
	20414	 77.0	 14.35	 62.0	 -33.3	 1.0	 100.0	 1	 100.0	 54.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	20414	 16.95	 4.15	 17.65	 -9.35	 1.0	 100.0	 1	 28.05	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.05;
	20414	 16.95	 4.15	 17.65	 -9.35	 1.0	 100.0	 1	 28.05	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.05;
	20414	 341.5	 66.3	 286.9	 -154.3	 1.0	 100.0	 1	 463.0	 220.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 463.0;
	20414	 77.0	 14.35	 62.0	 -33.3	 1.0	 100.0	 1	 100.0	 54.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	20414	 64.0	 17.3	 62.3	 -27.7	 1.0	 100.0	 1	 83.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.0;
	20414	 64.0	 17.3	 62.3	 -27.7	 1.0	 100.0	 1	 83.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.0;
	20414	 125.5	 23.05	 99.8	 -53.7	 1.0	 100.0	 1	 161.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.0;
	20414	 16.95	 4.15	 17.65	 -9.35	 1.0	 100.0	 1	 28.05	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.05;
	20414	 16.95	 4.15	 17.65	 -9.35	 1.0	 100.0	 1	 28.05	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.05;
	20414	 16.95	 4.15	 17.65	 -9.35	 1.0	 100.0	 1	 28.05	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.05;
	20414	 16.95	 4.15	 17.65	 -9.35	 1.0	 100.0	 1	 28.05	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.05;
	20415	 103.3	 23.85	 103.2	 -55.5	 1.0	 100.0	 1	 166.6	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.6;
	20415	 103.3	 23.85	 103.2	 -55.5	 1.0	 100.0	 1	 166.6	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.6;
	20415	 103.3	 23.85	 103.2	 -55.5	 1.0	 100.0	 1	 166.6	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.6;
	20415	 201.5	 46.25	 200.2	 -107.7	 1.0	 100.0	 1	 323.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 323.0;
	20416	 105.5	 12.15	 78.0	 -53.7	 1.0	 100.0	 1	 161.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.0;
	20417	 101.25	 31.8	 114.4	 -50.8	 1.0	 100.0	 1	 152.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 152.5;
	20417	 101.25	 31.8	 114.4	 -50.8	 1.0	 100.0	 1	 152.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 152.5;
	20417	 140.2	 44.9	 161.6	 -71.8	 1.0	 100.0	 1	 215.4	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 215.4;
	20417	 439.85	 83.05	 359.3	 -193.2	 1.0	 100.0	 1	 579.7	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 579.7;
	20418	 28.5	 0.0	 18.1	 -18.1	 1.0	 100.0	 1	 55.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	20418	 16.4	 3.22	 16.58	 -10.14	 1.0	 100.0	 1	 30.4	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	20418	 16.4	 3.22	 16.58	 -10.14	 1.0	 100.0	 1	 30.4	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	20418	 16.4	 3.22	 16.58	 -10.14	 1.0	 100.0	 1	 30.4	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	20418	 16.4	 3.22	 16.58	 -10.14	 1.0	 100.0	 1	 30.4	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	20418	 16.4	 3.22	 16.58	 -10.14	 1.0	 100.0	 1	 30.4	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	20418	 22.0	 5.75	 24.8	 -13.3	 1.0	 100.0	 1	 40.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	20418	 17.0	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0;
	20419	 107.5	 21.5	 93.0	 -50.0	 1.0	 100.0	 1	 150.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	20419	 107.5	 21.5	 93.0	 -50.0	 1.0	 100.0	 1	 150.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	20419	 104.25	 21.5	 93.0	 -50.0	 1.0	 100.0	 1	 150.0	 58.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	20419	 104.25	 21.5	 93.0	 -50.0	 1.0	 100.0	 1	 150.0	 58.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	20421	 99.5	 9.75	 62.5	 -43.0	 1.0	 100.0	 1	 129.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0;
	20421	 99.5	 9.75	 62.5	 -43.0	 1.0	 100.0	 1	 129.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0;
	20422	 86.315	 16.15	 78.3	 -46.0	 1.0	 100.0	 1	 138.1	 34.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 138.1;
	20422	 88.61	 23.9	 90.3	 -42.5	 1.0	 100.0	 1	 127.5	 49.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 127.5;
	20422	 88.96	 24.0	 90.7	 -42.7	 1.0	 100.0	 1	 128.0	 49.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 128.0;
	20422	 88.96	 24.0	 90.7	 -42.7	 1.0	 100.0	 1	 128.0	 49.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 128.0;
	20423	 85.05	 9.45	 60.6	 -41.7	 1.0	 100.0	 1	 125.1	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.1;
	20423	 85.05	 9.45	 60.6	 -41.7	 1.0	 100.0	 1	 125.1	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.1;
	20423	 85.05	 9.45	 60.6	 -41.7	 1.0	 100.0	 1	 125.1	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.1;
	20423	 85.05	 9.45	 60.6	 -41.7	 1.0	 100.0	 1	 125.1	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.1;
	20425	 91.0	 17.9	 77.5	 -41.7	 1.0	 100.0	 1	 125.0	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	20425	 86.6	 17.65	 76.4	 -41.1	 1.0	 100.0	 1	 123.2	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 123.2;
	20425	 81.25	 16.1	 69.7	 -37.5	 1.0	 100.0	 1	 112.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	20425	 81.25	 16.1	 69.7	 -37.5	 1.0	 100.0	 1	 112.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	20425	 83.75	 23.45	 84.4	 -37.5	 1.0	 100.0	 1	 112.5	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	20425	 146.0	 40.0	 144.0	 -64.0	 1.0	 100.0	 1	 192.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.0;
	20425	 258.5	 55.4	 239.8	 -129.0	 1.0	 100.0	 1	 387.0	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 387.0;
	20428	 74.35	 14.85	 64.3	 -34.6	 1.0	 100.0	 1	 103.7	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.7;
	20428	 200.1	 0.0	 87.2	 -87.2	 1.0	 100.0	 1	 265.2	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 265.2;
	20429	 52.45	 0.0	 45.6	 -45.6	 1.0	 100.0	 1	 103.5	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20430	 101.8	 15.1	 96.9	 -66.7	 1.0	 100.0	 1	 200.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20430	 100.95	 15.2	 97.5	 -67.1	 1.0	 100.0	 1	 201.3	 0.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20430	 60.0	 0.0	 44.1	 -44.1	 1.0	 100.0	 1	 100.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20430	 49.65	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 99.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20431	 50.25	 0.0	 43.7	 -43.7	 1.0	 100.0	 1	 99.0	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20432	 49.7	 0.0	 43.5	 -43.5	 1.0	 100.0	 1	 98.7	 0.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20433	 52.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 94.6	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.6;
	20434	 49.5	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 90.0	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	20435	 17.5	 0.0	 9.9	 -9.9	 1.0	 100.0	 1	 30.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	20435	 8.635	 1.3	 7.53	 -4.93	 1.0	 100.0	 1	 14.8	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8;
	20435	 8.635	 1.3	 7.53	 -4.93	 1.0	 100.0	 1	 14.8	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8;
	20435	 8.635	 1.3	 7.53	 -4.93	 1.0	 100.0	 1	 14.8	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8;
	20435	 8.635	 1.3	 7.53	 -4.93	 1.0	 100.0	 1	 14.8	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8;
	20435	 8.635	 1.3	 7.53	 -4.93	 1.0	 100.0	 1	 14.8	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8;
	20435	 8.635	 1.3	 7.53	 -4.93	 1.0	 100.0	 1	 14.8	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8;
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20436	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20437	 65.0	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	20437	 65.0	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	20437	 65.0	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	20437	 65.0	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	20438	 43.5	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0;
	20438	 43.5	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0;
	20438	 43.5	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0;
	20438	 43.5	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0;
	20438	 43.5	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0;
	20438	 43.5	 9.6	 41.5	 -22.3	 1.0	 100.0	 1	 67.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0;
	20439	 44.0	 10.0	 40.3	 -20.3	 1.0	 100.0	 1	 61.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0;
	20440	 36.9	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	20440	 36.9	 10.4	 37.5	 -16.7	 1.0	 100.0	 1	 50.0	 23.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	20440	 45.02	 12.75	 45.8	 -20.3	 1.0	 100.0	 1	 61.0	 29.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0;
	20440	 45.02	 12.75	 45.8	 -20.3	 1.0	 100.0	 1	 61.0	 29.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0;
	20440	 45.02	 12.75	 45.8	 -20.3	 1.0	 100.0	 1	 61.0	 29.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0;
	20442	 34.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	20442	 34.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	20442	 34.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	20442	 34.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	20444	 30.5	 0.0	 16.8	 -16.8	 1.0	 100.0	 1	 51.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0;
	20444	 36.6	 0.0	 20.8	 -20.8	 1.0	 100.0	 1	 63.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.2;
	20444	 32.0	 0.0	 20.4	 -20.4	 1.0	 100.0	 1	 62.0	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0;
	20445	 42.0	 7.15	 31.0	 -16.7	 1.0	 100.0	 1	 50.0	 34.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	20445	 83.8	 16.25	 70.4	 -37.9	 1.0	 100.0	 1	 113.6	 54.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6;
	20445	 50.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0;
	20445	 50.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0;
	20445	 31.28	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 16.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	20445	 31.28	 6.6	 28.5	 -15.3	 1.0	 100.0	 1	 46.0	 16.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	20446	 21.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8;
	20446	 21.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8;
	20448	 29.2	 5.95	 25.7	 -13.8	 1.0	 100.0	 1	 41.4	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4;
	20448	 29.2	 5.95	 25.7	 -13.8	 1.0	 100.0	 1	 41.4	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4;
	20448	 60.95	 12.3	 53.2	 -28.6	 1.0	 100.0	 1	 85.9	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.9;
	20449	 27.135	 8.4	 30.2	 -13.4	 1.0	 100.0	 1	 40.2	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.2;
	20449	 46.575	 14.4	 51.8	 -23.0	 1.0	 100.0	 1	 69.0	 24.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0;
	20449	 23.8	 7.3	 26.3	 -11.7	 1.0	 100.0	 1	 35.0	 12.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	20450	 44.45	 8.7	 37.7	 -20.3	 1.0	 100.0	 1	 60.9	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.9;
	20450	 23.0	 4.75	 20.5	 -11.0	 1.0	 100.0	 1	 33.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0;
	20451	 17.9	 6.4	 23.1	 -10.3	 1.0	 100.0	 1	 30.8	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.8;
	20452	 17.25	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 9.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	20453	 6.775	 1.725	 7.45	 -4.0	 1.0	 100.0	 1	 12.05	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.05;
	20453	 6.775	 1.725	 7.45	 -4.0	 1.0	 100.0	 1	 12.05	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.05;
	20454	 3.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 5.85	 0.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.85;
	20454	 3.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 5.85	 0.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.85;
	20454	 3.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 5.85	 0.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.85;
	20454	 3.3	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 5.85	 0.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.85;
	20455	 6.55	 1.6	 6.9	 -3.7	 1.0	 100.0	 1	 11.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.1;
	20455	 6.55	 1.6	 6.9	 -3.7	 1.0	 100.0	 1	 11.1	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.1;
	20457	 11.3	 4.5	 16.2	 -7.2	 1.0	 100.0	 1	 21.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6;
	20457	 11.3	 4.5	 16.2	 -7.2	 1.0	 100.0	 1	 21.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6;
	20457	 11.3	 4.5	 16.2	 -7.2	 1.0	 100.0	 1	 21.6	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6;
	20458	 459.1	 79.515	 364.43	 -205.4	 1.0	 100.0	 1	 616.2	 302.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 616.2;
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1;
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1;
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1;
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1;
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1;
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1;
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1;
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1;
	20458	 459.1	 79.515	 364.43	 -205.4	 1.0	 100.0	 1	 616.2	 302.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 616.2;
	20458	 459.1	 79.515	 364.43	 -205.4	 1.0	 100.0	 1	 616.2	 302.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 616.2;
	20458	 217.5	 30.95	 198.6	 -136.7	 1.0	 100.0	 1	 410.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 410.0;
	20458	 210.0	 54.4	 235.5	 -126.7	 1.0	 100.0	 1	 380.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 380.0;
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1;
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1;
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1;
	20458	 78.55	 12.5	 54.0	 -29.0	 1.0	 100.0	 1	 87.1	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.1;
	20459	 1093.15	 85.55	 548.9	 -377.8	 1.0	 100.0	 1	 1133.3	 1053.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20459	 1079.0	 86.95	 557.9	 -384.0	 1.0	 100.0	 1	 1152.0	 1006.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20460	 405.9	 169.15	 608.9	 -270.6	 1.0	 100.0	 1	 811.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20461	 426.25	 52.65	 337.8	 -232.5	 1.0	 100.0	 1	 697.5	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 697.5;
	20461	 426.25	 52.65	 337.8	 -232.5	 1.0	 100.0	 1	 697.5	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 697.5;
	20461	 48.65	 12.25	 52.9	 -28.4	 1.0	 100.0	 1	 85.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3;
	20461	 48.65	 12.25	 52.9	 -28.4	 1.0	 100.0	 1	 85.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3;
	20461	 48.65	 12.25	 52.9	 -28.4	 1.0	 100.0	 1	 85.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3;
	20462	 284.9	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8;
	20462	 284.9	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8;
	20462	 284.9	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8;
	20462	 284.9	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8;
	20462	 284.9	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8;
	20462	 284.9	 47.25	 204.4	 -109.9	 1.0	 100.0	 1	 329.8	 240.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.8;
	20463	 176.25	 60.95	 219.4	 -97.5	 1.0	 100.0	 1	 292.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 292.5;
	20463	 141.3	 58.9	 212.0	 -94.2	 1.0	 100.0	 1	 282.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 282.6;
	20463	 246.55	 74.6	 268.6	 -119.4	 1.0	 100.0	 1	 358.1	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 358.1;
	20464	 633.4	 119.2	 544.0	 -305.6	 1.0	 100.0	 1	 916.8	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 916.8;
	20464	 0.0	 0.0	 164.4	 -88.4	 1.0	 100.0	 0	 265.2	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 265.2;
	20464	 0.0	 0.0	 313.9	 -126.3	 1.0	 100.0	 0	 378.8	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 378.8;
	20465	 118.5	 21.05	 91.1	 -49.0	 1.0	 100.0	 1	 147.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.0;
	20465	 118.5	 21.05	 91.1	 -49.0	 1.0	 100.0	 1	 147.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.0;
	20465	 118.5	 21.05	 91.1	 -49.0	 1.0	 100.0	 1	 147.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.0;
	20465	 207.5	 35.05	 151.8	 -81.7	 1.0	 100.0	 1	 245.0	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 245.0;
	20465	 207.5	 35.05	 151.8	 -81.7	 1.0	 100.0	 1	 245.0	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 245.0;
	20465	 207.5	 35.05	 151.8	 -81.7	 1.0	 100.0	 1	 245.0	 170.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 245.0;
	20466	 19.3	 4.8	 20.8	 -11.2	 1.0	 100.0	 1	 33.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.6;
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111;
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111;
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111;
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111;
	20466	 19.3	 4.8	 20.8	 -11.2	 1.0	 100.0	 1	 33.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.6;
	20466	 19.3	 4.8	 20.8	 -11.2	 1.0	 100.0	 1	 33.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.6;
	20466	 19.3	 4.8	 20.8	 -11.2	 1.0	 100.0	 1	 33.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.6;
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111;
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111;
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111;
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111;
	20466	 14.195	 3.185	 14.6	 -8.23	 1.0	 100.0	 1	 24.71	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.7111;
	20467	 151.85	 27.0	 116.9	 -62.9	 1.0	 100.0	 1	 188.7	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.7;
	20467	 151.85	 27.0	 116.9	 -62.9	 1.0	 100.0	 1	 188.7	 115.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.7;
	20467	 166.7	 30.6	 132.3	 -71.1	 1.0	 100.0	 1	 213.4	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.4;
	20467	 139.35	 27.0	 116.9	 -62.9	 1.0	 100.0	 1	 188.7	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.7;
	20467	 139.35	 27.0	 116.9	 -62.9	 1.0	 100.0	 1	 188.7	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.7;
	20468	 131.5	 35.8	 154.9	 -83.3	 1.0	 100.0	 1	 250.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 250.0;
	20468	 132.5	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	20468	 132.5	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	20468	 132.5	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	20469	 143.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 116.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	20469	 143.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 116.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	20469	 143.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 116.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	20469	 143.0	 24.35	 105.4	 -56.7	 1.0	 100.0	 1	 170.0	 116.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.0;
	20470	 22.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8;
	20470	 22.9	 3.15	 20.2	 -13.9	 1.0	 100.0	 1	 41.8	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8;
	20470	 15.015	 2.9	 14.7	 -8.9	 1.0	 100.0	 1	 26.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7;
	20470	 15.015	 2.9	 14.7	 -8.9	 1.0	 100.0	 1	 26.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7;
	20470	 15.015	 2.9	 14.7	 -8.9	 1.0	 100.0	 1	 26.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7;
	20470	 15.015	 2.9	 14.7	 -8.9	 1.0	 100.0	 1	 26.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7;
	20470	 15.015	 2.9	 14.7	 -8.9	 1.0	 100.0	 1	 26.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7;
	20470	 15.015	 2.9	 14.7	 -8.9	 1.0	 100.0	 1	 26.7	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7;
	20471	 113.15	 22.4	 96.9	 -52.1	 1.0	 100.0	 1	 156.3	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.3;
	20471	 113.15	 22.4	 96.9	 -52.1	 1.0	 100.0	 1	 156.3	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.3;
	20472	 127.35	 22.15	 95.9	 -51.6	 1.0	 100.0	 1	 154.7	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 154.7;
	20473	 103.0	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0;
	20473	 103.0	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0;
	20473	 100.5	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0;
	20473	 100.5	 19.5	 84.3	 -45.3	 1.0	 100.0	 1	 136.0	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.0;
	20473	 376.25	 99.2	 429.2	 -230.8	 1.0	 100.0	 1	 692.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 692.5;
	20473	 384.9	 101.65	 439.9	 -236.6	 1.0	 100.0	 1	 709.8	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 709.8;
	20475	 84.095	 22.7	 85.7	 -40.3	 1.0	 100.0	 1	 121.0	 47.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0;
	20476	 73.0	 9.05	 58.1	 -40.0	 1.0	 100.0	 1	 120.0	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0;
	20476	 68.5	 25.0	 90.0	 -40.0	 1.0	 100.0	 1	 120.0	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0;
	20476	 346.75	 40.45	 259.4	 -178.5	 1.0	 100.0	 1	 535.5	 158.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 535.5;
	20477	 103.9	 19.0	 82.3	 -44.3	 1.0	 100.0	 1	 132.8	 75.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8;
	20477	 83.15	 15.25	 65.9	 -35.4	 1.0	 100.0	 1	 106.3	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.3;
	20477	 83.15	 15.25	 65.9	 -35.4	 1.0	 100.0	 1	 106.3	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.3;
	20479	 69.7	 12.8	 55.4	 -29.8	 1.0	 100.0	 1	 89.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4;
	20479	 69.7	 12.8	 55.4	 -29.8	 1.0	 100.0	 1	 89.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4;
	20479	 69.7	 12.8	 55.4	 -29.8	 1.0	 100.0	 1	 89.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4;
	20479	 69.7	 12.8	 55.4	 -29.8	 1.0	 100.0	 1	 89.4	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4;
	20480	 485.2	 61.55	 394.9	 -271.8	 1.0	 100.0	 1	 815.4	 155.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 815.4;
	20480	 48.65	 12.25	 52.9	 -28.4	 1.0	 100.0	 1	 85.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3;
	20480	 48.65	 12.25	 52.9	 -28.4	 1.0	 100.0	 1	 85.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3;
	20480	 48.65	 12.25	 52.9	 -28.4	 1.0	 100.0	 1	 85.3	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.3;
	20481	 65.0	 14.4	 57.1	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	20481	 65.0	 14.4	 57.1	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	20481	 65.0	 14.4	 57.1	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	20481	 65.0	 14.4	 57.1	 -28.3	 1.0	 100.0	 1	 85.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	20483	 12.0	 1.86	 9.06	 -5.34	 1.0	 100.0	 1	 16.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20483	 12.0	 1.86	 9.06	 -5.34	 1.0	 100.0	 1	 16.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20483	 12.0	 1.86	 9.06	 -5.34	 1.0	 100.0	 1	 16.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20483	 12.0	 1.86	 9.06	 -5.34	 1.0	 100.0	 1	 16.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20483	 12.0	 1.86	 9.06	 -5.34	 1.0	 100.0	 1	 16.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20485	 50.625	 10.25	 45.5	 -25.0	 1.0	 100.0	 1	 75.0	 26.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	20485	 50.625	 10.25	 45.5	 -25.0	 1.0	 100.0	 1	 75.0	 26.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	20487	 34.95	 0.0	 27.3	 -27.3	 1.0	 100.0	 1	 69.0	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20489	 10.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20489	 10.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20489	 10.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20489	 10.0	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20490	 11.31	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 6.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20490	 11.31	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 6.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20490	 11.31	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 6.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20490	 11.31	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 6.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20490	 14.6	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2;
	20490	 14.6	 3.0	 13.1	 -7.1	 1.0	 100.0	 1	 21.2	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2;
	20490	 15.7	 3.35	 14.5	 -7.8	 1.0	 100.0	 1	 23.4	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4;
	20493	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	20494	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	20494	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	20494	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	20494	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	20494	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	20494	 36.0	 8.6	 37.2	 -20.0	 1.0	 100.0	 1	 60.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	20494	 62.0	 6.0	 38.3	 -26.3	 1.0	 100.0	 1	 79.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.0;
	20494	 58.5	 15.05	 65.1	 -35.0	 1.0	 100.0	 1	 105.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0;
	20494	 58.5	 15.05	 65.1	 -35.0	 1.0	 100.0	 1	 105.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0;
	20496	 40.0	 4.15	 26.6	 -18.3	 1.0	 100.0	 1	 55.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	20497	 26.85	 0.0	 20.9	 -20.9	 1.0	 100.0	 1	 52.8	 0.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20498	 6.07	 1.68	 6.5	 -3.14	 1.0	 100.0	 1	 9.44	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.44;
	20498	 6.07	 1.68	 6.5	 -3.14	 1.0	 100.0	 1	 9.44	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.44;
	20498	 6.07	 1.68	 6.5	 -3.14	 1.0	 100.0	 1	 9.44	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.44;
	20498	 6.07	 1.68	 6.5	 -3.14	 1.0	 100.0	 1	 9.44	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.44;
	20498	 6.07	 1.68	 6.5	 -3.14	 1.0	 100.0	 1	 9.44	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.44;
	20500	 60.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	20500	 60.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	20500	 60.0	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	20500	 32.0	 6.3	 27.3	 -14.7	 1.0	 100.0	 1	 44.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	20500	 32.0	 6.3	 27.3	 -14.7	 1.0	 100.0	 1	 44.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	20500	 33.5	 6.7	 29.1	 -15.7	 1.0	 100.0	 1	 47.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	20502	 35.4	 6.1	 26.3	 -14.1	 1.0	 100.0	 1	 42.4	 28.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4;
	20502	 34.6	 6.1	 26.3	 -14.1	 1.0	 100.0	 1	 42.4	 26.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4;
	20502	 34.05	 6.15	 26.6	 -14.3	 1.0	 100.0	 1	 42.9	 25.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.9;
	20502	 33.4	 6.1	 26.3	 -14.1	 1.0	 100.0	 1	 42.4	 24.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4;
	20504	 24.75	 5.65	 24.5	 -13.2	 1.0	 100.0	 1	 39.5	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.5;
	20505	 27.05	 5.6	 24.2	 -13.0	 1.0	 100.0	 1	 39.1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.1;
	20505	 27.05	 5.6	 24.2	 -13.0	 1.0	 100.0	 1	 39.1	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.1;
	20505	 66.75	 11.95	 51.7	 -27.8	 1.0	 100.0	 1	 83.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.5;
	20506	 24.0	 5.45	 23.6	 -12.7	 1.0	 100.0	 1	 38.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	20507	 12.87	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 7.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	20507	 12.87	 2.575	 11.15	 -6.0	 1.0	 100.0	 1	 18.0	 7.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	20509	 5.25	 2.185	 7.87	 -3.5	 1.0	 100.0	 1	 10.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5;
	20509	 5.25	 2.185	 7.87	 -3.5	 1.0	 100.0	 1	 10.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5;
	20509	 5.25	 2.185	 7.87	 -3.5	 1.0	 100.0	 1	 10.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5;
	20510	 22.25	 0.0	 6.2	 -6.2	 1.0	 100.0	 1	 30.3	 14.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.3;
	20512	 16.5	 5.85	 21.0	 -9.3	 1.0	 100.0	 1	 28.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	20513	 4.255	 0.915	 3.93	 -2.1	 1.0	 100.0	 1	 6.3	 2.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.3;
	20513	 4.255	 0.915	 3.93	 -2.1	 1.0	 100.0	 1	 6.3	 2.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.3;
	20513	 4.255	 0.915	 3.93	 -2.1	 1.0	 100.0	 1	 6.3	 2.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.3;
	20513	 4.255	 0.915	 3.93	 -2.1	 1.0	 100.0	 1	 6.3	 2.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.3;
	20513	 13.15	 3.05	 13.2	 -7.1	 1.0	 100.0	 1	 21.3	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.3;
	20514	 22.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	20514	 22.0	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	20515	 14.5	 0.0	 7.9	 -7.9	 1.0	 100.0	 1	 24.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0;
	20516	 17.0	 1.8	 11.6	 -8.0	 1.0	 100.0	 1	 24.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0;
	20517	 4.685	 1.25	 5.17	 -2.67	 1.0	 100.0	 1	 7.97	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.9667;
	20517	 4.685	 1.25	 5.17	 -2.67	 1.0	 100.0	 1	 7.97	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.9667;
	20517	 4.685	 1.25	 5.17	 -2.67	 1.0	 100.0	 1	 7.97	 1.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.9667;
	20518	 4.34	 0.42	 2.42	 -1.58	 1.0	 100.0	 1	 4.74	 3.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.74;
	20518	 4.34	 0.42	 2.42	 -1.58	 1.0	 100.0	 1	 4.74	 3.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.74;
	20518	 4.34	 0.42	 2.42	 -1.58	 1.0	 100.0	 1	 4.74	 3.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.74;
	20518	 4.34	 0.42	 2.42	 -1.58	 1.0	 100.0	 1	 4.74	 3.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.74;
	20518	 4.34	 0.42	 2.42	 -1.58	 1.0	 100.0	 1	 4.74	 3.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.74;
	20520	 7.75	 1.65	 7.15	 -3.85	 1.0	 100.0	 1	 11.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5;
	20520	 7.75	 1.65	 7.15	 -3.85	 1.0	 100.0	 1	 11.5	 4.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5;
	20522	 13.8	 1.7	 10.9	 -7.5	 1.0	 100.0	 1	 22.6	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.6;
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857;
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857;
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857;
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857;
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857;
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857;
	20523	 2.4	 0.665	 2.39	 -1.06	 1.0	 100.0	 1	 3.19	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.1857;
	20524	 18.5	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	20524	 23.65	 4.2	 18.2	 -9.8	 1.0	 100.0	 1	 29.3	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.3;
	20527	 3.35	 0.0	 2.2	 -2.2	 1.0	 100.0	 1	 6.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.7;
	20527	 3.35	 0.0	 2.2	 -2.2	 1.0	 100.0	 1	 6.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.7;
	20527	 3.35	 0.0	 2.2	 -2.2	 1.0	 100.0	 1	 6.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.7;
	20528	 12.5	 4.15	 15.0	 -6.7	 1.0	 100.0	 1	 20.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	20529	 13.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	20529	 13.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	20529	 13.0	 1.5	 9.7	 -6.7	 1.0	 100.0	 1	 20.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	20530	 14.0	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	20531	 0.0	 0.0	 468.6	 -468.6	 1.0	 100.0	 0	 1425.6	 302.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1425.6;
	20532	 722.3	 0.0	 558.7	 -558.7	 1.0	 100.0	 1	 1311.6	 133.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20533	 1000.0	 98.15	 629.6	 -433.3	 1.0	 100.0	 1	 1300.0	 700.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1300.0;
	20533	 0.0	 0.0	 629.6	 -433.3	 1.0	 100.0	 0	 1300.0	 650.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1300.0;
	20534	 517.6	 69.85	 448.1	 -308.4	 1.0	 100.0	 1	 925.2	 110.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	20535	 23.35	 5.95	 21.5	 -9.6	 1.0	 100.0	 1	 28.7	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.7;
	20535	 395.3	 49.85	 319.9	 -220.2	 1.0	 100.0	 1	 660.6	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 660.6;
	20536	 537.5	 49.05	 314.8	 -216.7	 1.0	 100.0	 1	 650.0	 425.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 650.0;
	20536	 520.1	 88.1	 381.3	 -205.1	 1.0	 100.0	 1	 615.2	 425.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 615.2;
	20536	 520.1	 88.1	 381.3	 -205.1	 1.0	 100.0	 1	 615.2	 425.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 615.2;
	20537	 455.1	 46.05	 295.5	 -203.4	 1.0	 100.0	 1	 610.2	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 610.2;
	20537	 455.1	 46.05	 295.5	 -203.4	 1.0	 100.0	 1	 610.2	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 610.2;
	20537	 455.1	 46.05	 295.5	 -203.4	 1.0	 100.0	 1	 610.2	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 610.2;
	20537	 455.1	 46.05	 295.5	 -203.4	 1.0	 100.0	 1	 610.2	 300.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 610.2;
	20538	 87.5	 19.35	 83.7	 -45.0	 1.0	 100.0	 1	 135.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	20538	 87.5	 19.35	 83.7	 -45.0	 1.0	 100.0	 1	 135.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	20538	 87.5	 19.35	 83.7	 -45.0	 1.0	 100.0	 1	 135.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	20538	 56.1	 12.46	 53.92	 -29.0	 1.0	 100.0	 1	 87.0	 25.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.0;
	20538	 56.1	 12.46	 53.92	 -29.0	 1.0	 100.0	 1	 87.0	 25.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.0;
	20538	 56.1	 12.46	 53.92	 -29.0	 1.0	 100.0	 1	 87.0	 25.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.0;
	20538	 56.1	 12.46	 53.92	 -29.0	 1.0	 100.0	 1	 87.0	 25.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.0;
	20538	 56.1	 12.46	 53.92	 -29.0	 1.0	 100.0	 1	 87.0	 25.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.0;
	20540	 163.0	 53.35	 192.0	 -85.3	 1.0	 100.0	 1	 256.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 256.0;
	20541	 139.8	 45.75	 164.7	 -73.2	 1.0	 100.0	 1	 219.6	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 219.6;
	20541	 139.8	 45.75	 164.7	 -73.2	 1.0	 100.0	 1	 219.6	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 219.6;
	20541	 148.75	 49.45	 178.1	 -79.2	 1.0	 100.0	 1	 237.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.5;
	20541	 148.75	 49.45	 178.1	 -79.2	 1.0	 100.0	 1	 237.5	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.5;
	20541	 482.6	 88.1	 381.3	 -205.1	 1.0	 100.0	 1	 615.2	 350.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 615.2;
	20542	 198.65	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3;
	20542	 198.65	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3;
	20542	 198.65	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3;
	20542	 198.65	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3;
	20542	 198.65	 36.8	 146.0	 -72.4	 1.0	 100.0	 1	 217.3	 180.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.3;
	20543	 218.55	 45.4	 196.5	 -105.7	 1.0	 100.0	 1	 317.1	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.1;
	20543	 144.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9;
	20543	 144.45	 28.5	 123.3	 -66.3	 1.0	 100.0	 1	 198.9	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9;
	20544	 149.0	 28.35	 122.7	 -66.0	 1.0	 100.0	 1	 198.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.0;
	20544	 149.0	 28.35	 122.7	 -66.0	 1.0	 100.0	 1	 198.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.0;
	20544	 149.0	 28.35	 122.7	 -66.0	 1.0	 100.0	 1	 198.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.0;
	20545	 155.5	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 115.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5;
	20545	 155.5	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 115.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5;
	20545	 155.5	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 115.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5;
	20545	 155.5	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 115.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5;
	20545	 155.5	 28.0	 121.2	 -65.2	 1.0	 100.0	 1	 195.5	 115.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 195.5;
	20546	 122.7	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4;
	20546	 122.7	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4;
	20546	 122.7	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4;
	20546	 122.7	 27.25	 118.0	 -63.5	 1.0	 100.0	 1	 190.4	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.4;
	20546	 545.0	 97.35	 421.4	 -226.7	 1.0	 100.0	 1	 680.0	 410.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 680.0;
	20546	 545.0	 97.35	 421.4	 -226.7	 1.0	 100.0	 1	 680.0	 410.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 680.0;
	20546	 234.5	 47.85	 207.0	 -111.3	 1.0	 100.0	 1	 334.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 334.0;
	20547	 134.1	 24.95	 108.0	 -58.1	 1.0	 100.0	 1	 174.2	 94.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.2;
	20547	 134.1	 24.95	 108.0	 -58.1	 1.0	 100.0	 1	 174.2	 94.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.2;
	20547	 134.1	 24.95	 108.0	 -58.1	 1.0	 100.0	 1	 174.2	 94.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.2;
	20547	 246.5	 57.15	 247.3	 -133.0	 1.0	 100.0	 1	 399.0	 94.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 399.0;
	20548	 159.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 146.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0;
	20548	 159.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 146.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0;
	20548	 159.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 146.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0;
	20548	 159.0	 24.65	 106.6	 -57.3	 1.0	 100.0	 1	 172.0	 146.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.0;
	20549	 131.75	 23.4	 101.3	 -54.5	 1.0	 100.0	 1	 163.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5;
	20549	 131.75	 23.4	 101.3	 -54.5	 1.0	 100.0	 1	 163.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5;
	20549	 131.75	 23.4	 101.3	 -54.5	 1.0	 100.0	 1	 163.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5;
	20549	 131.75	 23.4	 101.3	 -54.5	 1.0	 100.0	 1	 163.5	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.5;
	20549	 298.55	 45.4	 196.5	 -105.7	 1.0	 100.0	 1	 317.1	 280.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.1;
	20549	 298.55	 45.4	 196.5	 -105.7	 1.0	 100.0	 1	 317.1	 280.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.1;
	20550	 80.75	 30.3	 114.4	 -53.8	 1.0	 100.0	 1	 161.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 161.5;
	20550	 578.25	 63.55	 407.6	 -280.5	 1.0	 100.0	 1	 841.5	 315.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 841.5;
	20550	 286.95	 33.5	 215.0	 -148.0	 1.0	 100.0	 1	 443.9	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 443.9;
	20550	 286.95	 33.5	 215.0	 -148.0	 1.0	 100.0	 1	 443.9	 130.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 443.9;
	20551	 0.0	 0.0	 75.9	 -46.9	 1.0	 100.0	 0	 140.6	 54.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.6;
	20551	 97.715	 14.5	 75.9	 -46.9	 1.0	 100.0	 1	 140.6	 54.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.6;
	20551	 151.23	 22.45	 117.4	 -72.5	 1.0	 100.0	 1	 217.6	 84.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 217.6;
	20552	 92.295	 19.0	 82.3	 -44.3	 1.0	 100.0	 1	 132.8	 51.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8;
	20552	 92.295	 19.0	 82.3	 -44.3	 1.0	 100.0	 1	 132.8	 51.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8;
	20552	 16.0	 3.85	 16.7	 -9.0	 1.0	 100.0	 1	 27.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286;
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286;
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286;
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286;
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286;
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286;
	20553	 16.0	 2.57	 11.11	 -5.97	 1.0	 100.0	 1	 17.93	 14.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.9286;
	20554	 86.5	 17.6	 76.2	 -41.0	 1.0	 100.0	 1	 123.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 123.0;
	20554	 86.5	 17.6	 76.2	 -41.0	 1.0	 100.0	 1	 123.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 123.0;
	20554	 144.56	 39.0	 147.3	 -69.3	 1.0	 100.0	 1	 208.0	 81.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 208.0;
	20554	 86.5	 25.65	 92.3	 -41.0	 1.0	 100.0	 1	 123.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 123.0;
	20554	 20.0	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0;
	20554	 483.82	 55.15	 337.0	 -226.7	 1.0	 100.0	 1	 680.0	 287.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 680.0;
	20555	 112.1	 12.3	 79.0	 -54.4	 1.0	 100.0	 1	 163.2	 61.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2;
	20555	 260.9	 34.8	 223.2	 -153.6	 1.0	 100.0	 1	 460.8	 61.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 460.8;
	20555	 86.875	 9.4	 60.5	 -41.7	 1.0	 100.0	 1	 125.0	 48.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	20555	 75.94	 8.5	 54.5	 -37.5	 1.0	 100.0	 1	 112.5	 39.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	20555	 77.625	 8.7	 55.7	 -38.3	 1.0	 100.0	 1	 115.0	 40.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.0;
	20555	 31.45	 4.0	 25.6	 -17.6	 1.0	 100.0	 1	 52.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.9;
	20555	 31.45	 4.0	 25.6	 -17.6	 1.0	 100.0	 1	 52.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.9;
	20555	 31.45	 4.0	 25.6	 -17.6	 1.0	 100.0	 1	 52.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.9;
	20555	 31.45	 4.0	 25.6	 -17.6	 1.0	 100.0	 1	 52.9	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.9;
	20555	 160.9	 35.05	 151.7	 -81.6	 1.0	 100.0	 1	 244.8	 77.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 244.8;
	20556	 59.6	 15.2	 65.8	 -35.4	 1.0	 100.0	 1	 106.2	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.2;
	20557	 108.56	 29.3	 110.7	 -52.1	 1.0	 100.0	 1	 156.2	 60.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.2;
	20557	 108.56	 29.3	 110.7	 -52.1	 1.0	 100.0	 1	 156.2	 60.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 156.2;
	20557	 69.795	 14.1	 62.7	 -34.5	 1.0	 100.0	 1	 103.4	 36.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.4;
	20559	 67.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	20559	 67.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	20559	 67.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	20559	 67.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	20559	 67.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	20559	 67.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	20560	 83.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	20560	 83.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	20560	 83.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	20560	 83.0	 13.5	 58.3	 -31.3	 1.0	 100.0	 1	 94.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20561	 68.25	 12.4	 53.6	 -28.8	 1.0	 100.0	 1	 86.5	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.5;
	20562	 57.0	 12.3	 53.3	 -28.7	 1.0	 100.0	 1	 86.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.0;
	20562	 28.5	 4.15	 18.0	 -9.7	 1.0	 100.0	 1	 29.0	 28.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.0;
	20562	 505.0	 97.35	 421.4	 -226.7	 1.0	 100.0	 1	 680.0	 330.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 680.0;
	20563	 42.65	 9.35	 40.5	 -21.8	 1.0	 100.0	 1	 65.3	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.3;
	20563	 42.65	 9.35	 40.5	 -21.8	 1.0	 100.0	 1	 65.3	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.3;
	20563	 57.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	20563	 57.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	20563	 57.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	20563	 57.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	20563	 57.5	 12.2	 52.7	 -28.3	 1.0	 100.0	 1	 85.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	20564	 62.6	 12.05	 52.2	 -28.1	 1.0	 100.0	 1	 84.2	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.2;
	20564	 72.25	 14.8	 64.1	 -34.5	 1.0	 100.0	 1	 103.5	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5;
	20564	 73.55	 15.2	 65.8	 -35.4	 1.0	 100.0	 1	 106.1	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.1;
	20565	 28.8	 4.65	 20.2	 -10.9	 1.0	 100.0	 1	 32.6	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.6;
	20565	 49.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0;
	20565	 49.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0;
	20565	 49.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0;
	20565	 49.5	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0;
	20565	 47.0	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0;
	20565	 47.0	 9.9	 42.8	 -23.0	 1.0	 100.0	 1	 69.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.0;
	20566	 8.3	 1.02	 6.58	 -4.54	 1.0	 100.0	 1	 13.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6;
	20566	 8.3	 1.02	 6.58	 -4.54	 1.0	 100.0	 1	 13.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6;
	20566	 8.3	 1.02	 6.58	 -4.54	 1.0	 100.0	 1	 13.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6;
	20566	 8.3	 1.02	 6.58	 -4.54	 1.0	 100.0	 1	 13.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6;
	20566	 8.3	 1.02	 6.58	 -4.54	 1.0	 100.0	 1	 13.6	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6;
	20566	 13.0	 1.7	 11.1	 -7.7	 1.0	 100.0	 1	 23.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	20567	 38.5	 0.0	 22.0	 -22.0	 1.0	 100.0	 1	 67.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0;
	20568	 9.75	 2.365	 10.23	 -5.5	 1.0	 100.0	 1	 16.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5;
	20568	 9.75	 2.365	 10.23	 -5.5	 1.0	 100.0	 1	 16.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5;
	20568	 9.75	 2.365	 10.23	 -5.5	 1.0	 100.0	 1	 16.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5;
	20568	 9.75	 2.365	 10.23	 -5.5	 1.0	 100.0	 1	 16.5	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5;
	20568	 120.6	 23.35	 101.1	 -54.4	 1.0	 100.0	 1	 163.2	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.2;
	20568	 355.55	 79.8	 345.3	 -185.7	 1.0	 100.0	 1	 557.1	 154.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 557.1;
	20568	 355.85	 79.85	 345.6	 -185.9	 1.0	 100.0	 1	 557.7	 154.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 557.7;
	20569	 44.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	20569	 44.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	20569	 44.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	20569	 44.5	 8.45	 36.6	 -19.7	 1.0	 100.0	 1	 59.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	20570	 14.0	 0.0	 0.0	 0.0	 1.0	 100.0	 1	 22.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	20570	 8.755	 1.065	 6.58	 -4.45	 1.0	 100.0	 1	 13.38	 4.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.375;
	20570	 8.755	 1.065	 6.58	 -4.45	 1.0	 100.0	 1	 13.38	 4.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.375;
	20570	 8.755	 1.065	 6.58	 -4.45	 1.0	 100.0	 1	 13.38	 4.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.375;
	20570	 8.755	 1.065	 6.58	 -4.45	 1.0	 100.0	 1	 13.38	 4.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.375;
	20571	 32.15	 8.05	 31.2	 -15.1	 1.0	 100.0	 1	 45.3	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.3;
	20572	 7.585	 1.435	 5.95	 -3.08	 1.0	 100.0	 1	 9.25	 5.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.25;
	20572	 7.585	 1.435	 5.95	 -3.08	 1.0	 100.0	 1	 9.25	 5.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.25;
	20572	 7.585	 1.435	 5.95	 -3.08	 1.0	 100.0	 1	 9.25	 5.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.25;
	20572	 7.585	 1.435	 5.95	 -3.08	 1.0	 100.0	 1	 9.25	 5.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.25;
	20573	 7.3	 1.865	 7.83	 -4.1	 1.0	 100.0	 1	 12.27	 2.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.2667;
	20573	 7.3	 1.865	 7.83	 -4.1	 1.0	 100.0	 1	 12.27	 2.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.2667;
	20573	 7.3	 1.865	 7.83	 -4.1	 1.0	 100.0	 1	 12.27	 2.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.2667;
	20575	 29.5	 4.75	 20.5	 -11.0	 1.0	 100.0	 1	 33.0	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0;
	20577	 10.5	 2.275	 9.9	 -5.35	 1.0	 100.0	 1	 16.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20577	 10.5	 2.275	 9.9	 -5.35	 1.0	 100.0	 1	 16.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	20578	 30.5	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0;
	20579	 30.5	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0;
	20580	 20.0	 4.55	 19.8	 -10.7	 1.0	 100.0	 1	 32.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0;
	20581	 3.075	 0.77	 3.27	 -1.73	 1.0	 100.0	 1	 5.22	 0.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2167;
	20581	 3.075	 0.77	 3.27	 -1.73	 1.0	 100.0	 1	 5.22	 0.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2167;
	20581	 3.075	 0.77	 3.27	 -1.73	 1.0	 100.0	 1	 5.22	 0.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2167;
	20581	 3.075	 0.77	 3.27	 -1.73	 1.0	 100.0	 1	 5.22	 0.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2167;
	20581	 3.075	 0.77	 3.27	 -1.73	 1.0	 100.0	 1	 5.22	 0.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2167;
	20581	 3.075	 0.77	 3.27	 -1.73	 1.0	 100.0	 1	 5.22	 0.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.2167;
	20584	 500.0	 0.0	 9900.0	 -9900.0	 1.0	 100.0	 1	 1000.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	20584	 37.3	 7.25	 31.4	 -16.9	 1.0	 100.0	 1	 50.6	 24.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.6;
	20584	 16.5	 3.6	 15.5	 -8.3	 1.0	 100.0	 1	 25.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	20585	 18.6	 3.9	 16.9	 -9.1	 1.0	 100.0	 1	 27.2	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.2;
	20585	 16.0	 3.45	 14.9	 -8.0	 1.0	 100.0	 1	 24.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0;
	20585	 20.5	 4.45	 19.2	 -10.3	 1.0	 100.0	 1	 31.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0;
	20587	 8.775	 2.725	 9.8	 -4.35	 1.0	 100.0	 1	 13.05	 4.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.05;
	20587	 8.775	 2.725	 9.8	 -4.35	 1.0	 100.0	 1	 13.05	 4.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.05;
	20588	 12.35	 0.0	 7.8	 -7.8	 1.0	 100.0	 1	 23.7	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.7;
	20588	 12.35	 0.0	 7.8	 -7.8	 1.0	 100.0	 1	 23.7	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.7;
	20589	 12.2	 0.0	 4.8	 -4.8	 1.0	 100.0	 1	 23.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4;
	20589	 12.2	 0.0	 4.8	 -4.8	 1.0	 100.0	 1	 23.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4;
	20589	 12.2	 0.0	 4.8	 -4.8	 1.0	 100.0	 1	 23.4	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4;
	20590	 14.5	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	20590	 16.0	 5.25	 18.8	 -8.3	 1.0	 100.0	 1	 25.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	20590	 16.0	 5.25	 18.8	 -8.3	 1.0	 100.0	 1	 25.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	20591	 3.915	 1.43	 5.13	 -2.27	 1.0	 100.0	 1	 6.83	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8333;
	20591	 3.915	 1.43	 5.13	 -2.27	 1.0	 100.0	 1	 6.83	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8333;
	20591	 3.915	 1.43	 5.13	 -2.27	 1.0	 100.0	 1	 6.83	 1.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8333;
	20592	 17.0	 2.85	 12.4	 -6.7	 1.0	 100.0	 1	 20.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	81895	 130.5	 0.0	 57.5	 -57.5	 1.0	 100.0	 1	 130.5	 130.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	81900	 90.8	 13.3	 65.5	 -38.9	 1.0	 100.0	 1	 116.6	 65.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 116.6;
	81900	 85.8	 13.3	 65.5	 -38.9	 1.0	 100.0	 1	 116.6	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 116.6;
	81904	 53.0	 0.0	 46.7	 -46.7	 1.0	 100.0	 1	 106.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	81905	 10.215	 2.49	 10.8	 -5.82	 1.0	 100.0	 1	 17.43	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.4333;
	81905	 10.215	 2.49	 10.8	 -5.82	 1.0	 100.0	 1	 17.43	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.4333;
	81905	 10.215	 2.49	 10.8	 -5.82	 1.0	 100.0	 1	 17.43	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.4333;
	81905	 10.215	 2.49	 10.8	 -5.82	 1.0	 100.0	 1	 17.43	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.4333;
	81905	 10.215	 2.49	 10.8	 -5.82	 1.0	 100.0	 1	 17.43	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.4333;
	81905	 10.215	 2.49	 10.8	 -5.82	 1.0	 100.0	 1	 17.43	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.4333;
	81917	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	81917	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	81917	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	81917	 40.25	 8.65	 37.5	 -20.2	 1.0	 100.0	 1	 60.5	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	81921	 31.55	 4.0	 25.7	 -17.7	 1.0	 100.0	 1	 53.1	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	81921	 49.4	 6.7	 43.0	 -29.6	 1.0	 100.0	 1	 88.8	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.8;
	81925	 29.2	 5.95	 25.7	 -13.8	 1.0	 100.0	 1	 41.4	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4;
	81925	 29.2	 5.95	 25.7	 -13.8	 1.0	 100.0	 1	 41.4	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4;
	81927	 13.5	 3.15	 13.6	 -7.3	 1.0	 100.0	 1	 22.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	81952	 84.375	 15.75	 76.5	 -45.0	 1.0	 100.0	 1	 135.0	 33.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	81952	 84.375	 15.75	 76.5	 -45.0	 1.0	 100.0	 1	 135.0	 33.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	81959	 73.5	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.0	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	81959	 73.5	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.0	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	81959	 73.5	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.0	 57.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	81959	 60.0	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	81959	 60.0	 6.8	 43.6	 -30.0	 1.0	 100.0	 1	 90.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	81967	 39.0	 8.3	 35.9	 -19.3	 1.0	 100.0	 1	 58.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.0;
	81967	 65.05	 11.45	 49.6	 -26.7	 1.0	 100.0	 1	 80.1	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.1;
	81970	 50.0	 6.0	 38.7	 -26.7	 1.0	 100.0	 1	 80.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	81972	 54.05	 5.5	 35.4	 -24.4	 1.0	 100.0	 1	 73.1	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 73.1;
	81975	 38.7	 0.0	 5.3	 -5.3	 1.0	 100.0	 1	 68.4	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.4;
	81978	 10.5	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	81978	 10.5	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	81978	 10.5	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	81978	 10.5	 2.305	 9.93	 -5.32	 1.0	 100.0	 1	 16.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	81979	 13.0	 3.0	 13.0	 -7.0	 1.0	 100.0	 1	 21.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	81979	 14.5	 3.45	 14.9	 -8.0	 1.0	 100.0	 1	 24.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0;
	81979	 9.565	 2.7	 10.72	 -5.32	 1.0	 100.0	 1	 16.0	 3.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	81979	 9.565	 2.7	 10.72	 -5.32	 1.0	 100.0	 1	 16.0	 3.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	81979	 9.565	 2.7	 10.72	 -5.32	 1.0	 100.0	 1	 16.0	 3.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	81979	 9.565	 2.7	 10.72	 -5.32	 1.0	 100.0	 1	 16.0	 3.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	81981	 30.0	 0.0	 23.7	 -23.7	 1.0	 100.0	 1	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	81982	 8.83	 3.1	 11.13	 -4.93	 1.0	 100.0	 1	 14.83	 2.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8333;
	81982	 8.83	 3.1	 11.13	 -4.93	 1.0	 100.0	 1	 14.83	 2.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8333;
	81982	 8.83	 3.1	 11.13	 -4.93	 1.0	 100.0	 1	 14.83	 2.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8333;
	81985	 27.0	 3.3	 21.3	 -14.7	 1.0	 100.0	 1	 44.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81987	 0.485	 0.045	 0.28	 -0.19	 1.0	 100.0	 1	 0.57	 0.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.5726;
	81988	 18.5	 1.7	 11.1	 -7.7	 1.0	 100.0	 1	 23.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	81988	 25.05	 2.5	 16.0	 -11.0	 1.0	 100.0	 1	 33.1	 17.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.1;
	81990	 32.9	 0.0	 5.5	 -5.5	 1.0	 100.0	 1	 38.6	 27.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.6;
	81990	 25.95	 0.0	 8.7	 -8.7	 1.0	 100.0	 1	 29.8	 22.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.8;
	81990	 49.5	 4.1	 26.2	 -18.0	 1.0	 100.0	 1	 54.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0;
	81991	 17.55	 4.9	 17.6	 -7.8	 1.0	 100.0	 1	 23.4	 11.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4;
	81991	 17.55	 4.9	 17.6	 -7.8	 1.0	 100.0	 1	 23.4	 11.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4;
	81991	 17.55	 4.9	 17.6	 -7.8	 1.0	 100.0	 1	 23.4	 11.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4;
	81992	 21.1	 5.15	 18.6	 -8.3	 1.0	 100.0	 1	 24.8	 17.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.8;
	81992	 19.0	 2.95	 13.6	 -7.7	 1.0	 100.0	 1	 23.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	81993	 0.0	 0.0	 5.7	 -3.55	 1.0	 100.0	 0	 10.6	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.6;
	81993	 0.0	 0.0	 5.7	 -3.55	 1.0	 100.0	 0	 10.6	 0.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.6;
	81994	 30.0	 6.3	 27.3	 -14.7	 1.0	 100.0	 1	 44.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	81994	 13.0	 3.0	 13.0	 -7.0	 1.0	 100.0	 1	 21.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	82010	 163.0	 53.35	 192.0	 -85.3	 1.0	 100.0	 1	 256.0	 70.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 256.0;
	82037	 52.5	 7.55	 48.4	 -33.3	 1.0	 100.0	 1	 100.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	82052	 29.5	 4.75	 20.5	 -11.0	 1.0	 100.0	 1	 33.0	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0;
	82053	 29.5	 4.75	 20.5	 -11.0	 1.0	 100.0	 1	 33.0	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0;
	82056	 20.375	 2.95	 15.5	 -9.6	 1.0	 100.0	 1	 28.8	 11.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8;
	82056	 20.375	 2.95	 15.5	 -9.6	 1.0	 100.0	 1	 28.8	 11.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.8;
	82057	 9.625	 1.225	 7.05	 -4.6	 1.0	 100.0	 1	 13.75	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.75;
	82057	 9.625	 1.225	 7.05	 -4.6	 1.0	 100.0	 1	 13.75	 5.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.75;
	82058	 8.985	 7.7	 7.7	 7.7	 1.0	 100.0	 1	 13.75	 4.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.75;
	82058	 8.985	 7.7	 7.7	 7.7	 1.0	 100.0	 1	 13.75	 4.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.75;
	82058	 16.5	 15.5	 15.5	 15.5	 1.0	 100.0	 1	 25.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	82060	 19.1	 2.75	 14.5	 -9.0	 1.0	 100.0	 1	 27.0	 11.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	82060	 19.1	 2.75	 14.5	 -9.0	 1.0	 100.0	 1	 27.0	 11.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.001000	  12.513000	 2114.900000;
	2	 0.0	 0.0	 3	   0.001000	  12.513000	 2114.900000;
	2	 0.0	 0.0	 3	   0.002000	  13.037000	 1047.400000;
	2	 0.0	 0.0	 3	   0.002000	  13.037000	 1047.400000;
	2	 0.0	 0.0	 3	   0.002000	  13.037000	 1047.400000;
	2	 0.0	 0.0	 3	   0.002000	  13.037000	 1047.400000;
	2	 0.0	 0.0	 3	   0.002000	  13.037000	 1047.400000;
	2	 0.0	 0.0	 3	   0.034000	  24.825000	 226.450000;
	2	 0.0	 0.0	 3	   0.034000	  24.825000	 226.450000;
	2	 0.0	 0.0	 3	   0.002000	  13.277000	 813.680000;
	2	 0.0	 0.0	 3	   0.002000	  13.279000	 815.220000;
	2	 0.0	 0.0	 3	   0.002000	  13.279000	 815.220000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.002000	  13.269000	 803.200000;
	2	 0.0	 0.0	 3	   0.002000	  13.269000	 803.200000;
	2	 0.0	 0.0	 3	   0.002000	  13.035000	 1052.200000;
	2	 0.0	 0.0	 3	   0.002000	  13.035000	 1052.200000;
	2	 0.0	 0.0	 3	   0.005000	  13.538000	 463.610000;
	2	 0.0	 0.0	 3	   0.002000	  13.256000	 781.990000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.005000	  13.588000	 445.010000;
	2	 0.0	 0.0	 3	   0.005000	  13.588000	 445.010000;
	2	 0.0	 0.0	 3	   0.006000	  13.811000	 385.350000;
	2	 0.0	 0.0	 3	   0.006000	  13.811000	 385.350000;
	2	 0.0	 0.0	 3	   0.006000	  13.811000	 385.350000;
	2	 0.0	 0.0	 3	   0.006000	  13.811000	 385.350000;
	2	 0.0	 0.0	 3	   0.006000	  13.811000	 385.350000;
	2	 0.0	 0.0	 3	   0.006000	  13.811000	 385.350000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.007000	  13.961000	 355.300000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.003000	  13.138000	 631.770000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.014000	  14.920000	 188.180000;
	2	 0.0	 0.0	 3	   0.046000	  77.147000	 1586.400000;
	2	 0.0	 0.0	 3	   0.046000	  77.147000	 1586.400000;
	2	 0.0	 0.0	 3	   0.003000	  13.196000	 696.710000;
	2	 0.0	 0.0	 3	   0.014000	  14.920000	 188.180000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.046000	  77.147000	 1586.400000;
	2	 0.0	 0.0	 3	   0.046000	  77.147000	 1586.400000;
	2	 0.0	 0.0	 3	   0.046000	  77.147000	 1586.400000;
	2	 0.0	 0.0	 3	   0.046000	  77.147000	 1586.400000;
	2	 0.0	 0.0	 3	   0.008000	  14.135000	 307.360000;
	2	 0.0	 0.0	 3	   0.008000	  14.135000	 307.360000;
	2	 0.0	 0.0	 3	   0.008000	  14.135000	 307.360000;
	2	 0.0	 0.0	 3	   0.004000	  13.397000	 512.160000;
	2	 0.0	 0.0	 3	   0.013000	  22.680000	 468.140000;
	2	 0.0	 0.0	 3	   0.009000	  14.342000	 276.670000;
	2	 0.0	 0.0	 3	   0.009000	  14.342000	 276.670000;
	2	 0.0	 0.0	 3	   0.006000	  13.813000	 382.200000;
	2	 0.0	 0.0	 3	   0.002000	  13.329000	 887.350000;
	2	 0.0	 0.0	 3	   0.047000	  25.435000	 175.850000;
	2	 0.0	 0.0	 3	   0.014000	  22.845000	 442.950000;
	2	 0.0	 0.0	 3	   0.014000	  22.845000	 442.950000;
	2	 0.0	 0.0	 3	   0.014000	  22.845000	 442.950000;
	2	 0.0	 0.0	 3	   0.014000	  22.845000	 442.950000;
	2	 0.0	 0.0	 3	   0.014000	  22.845000	 442.950000;
	2	 0.0	 0.0	 3	   0.063000	  25.545000	 130.870000;
	2	 0.0	 0.0	 3	   0.074000	  25.545000	 111.240000;
	2	 0.0	 0.0	 3	   0.009000	  14.376000	 271.890000;
	2	 0.0	 0.0	 3	   0.009000	  14.376000	 271.890000;
	2	 0.0	 0.0	 3	   0.009000	  14.376000	 271.890000;
	2	 0.0	 0.0	 3	   0.009000	  14.376000	 271.890000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.016000	  23.121000	 404.830000;
	2	 0.0	 0.0	 3	   0.011000	  14.595000	 239.210000;
	2	 0.0	 0.0	 3	   0.011000	  14.594000	 242.120000;
	2	 0.0	 0.0	 3	   0.011000	  14.594000	 242.120000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.011000	  14.645000	 233.210000;
	2	 0.0	 0.0	 3	   0.011000	  14.658000	 229.960000;
	2	 0.0	 0.0	 3	   0.013000	  14.813000	 208.070000;
	2	 0.0	 0.0	 3	   0.013000	  14.813000	 208.070000;
	2	 0.0	 0.0	 3	   0.013000	  14.813000	 208.070000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.004000	  13.172000	 584.570000;
	2	 0.0	 0.0	 3	   0.014000	  14.886000	 195.250000;
	2	 0.0	 0.0	 3	   0.005000	  13.597000	 442.210000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.019000	  15.070000	 176.370000;
	2	 0.0	 0.0	 3	   0.026000	  24.168000	 277.160000;
	2	 0.0	 0.0	 3	   0.087000	  25.545000	  94.880000;
	2	 0.0	 0.0	 3	   0.027000	  24.223000	 271.680000;
	2	 0.0	 0.0	 3	   0.027000	  24.223000	 271.680000;
	2	 0.0	 0.0	 3	   0.027000	  24.223000	 271.680000;
	2	 0.0	 0.0	 3	   0.027000	  24.223000	 271.680000;
	2	 0.0	 0.0	 3	   0.027000	  24.223000	 271.680000;
	2	 0.0	 0.0	 3	   0.027000	  24.223000	 271.680000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.051000	  25.545000	 163.590000;
	2	 0.0	 0.0	 3	   0.039000	  25.105000	 203.100000;
	2	 0.0	 0.0	 3	   0.040000	  25.160000	 199.510000;
	2	 0.0	 0.0	 3	   0.030000	  16.003000	 102.290000;
	2	 0.0	 0.0	 3	   0.013000	  14.778000	 211.580000;
	2	 0.0	 0.0	 3	   0.022000	  15.601000	 135.810000;
	2	 0.0	 0.0	 3	   0.022000	  15.601000	 135.810000;
	2	 0.0	 0.0	 3	   0.180000	  87.000000	 507.300000;
	2	 0.0	 0.0	 3	   0.180000	  87.000000	 507.300000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.036000	  16.010000	  84.870000;
	2	 0.0	 0.0	 3	   0.022000	  15.587000	 137.470000;
	2	 0.0	 0.0	 3	   0.246000	  87.000000	 372.940000;
	2	 0.0	 0.0	 3	   0.025000	  15.780000	 122.030000;
	2	 0.0	 0.0	 3	   0.045000	  16.010000	  66.830000;
	2	 0.0	 0.0	 3	   0.085000	  25.309000	 135.160000;
	2	 0.0	 0.0	 3	   0.061000	  16.010000	  51.080000;
	2	 0.0	 0.0	 3	   0.062000	  16.010000	  50.490000;
	2	 0.0	 0.0	 3	   0.062000	  16.010000	  50.490000;
	2	 0.0	 0.0	 3	   0.114000	  25.478000	  83.380000;
	2	 0.0	 0.0	 3	   0.114000	  25.478000	  83.380000;
	2	 0.0	 0.0	 3	   0.114000	  25.478000	  83.380000;
	2	 0.0	 0.0	 3	   0.114000	  25.478000	  83.380000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.002000	  15.698000	 5647.540000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.002000	  15.698000	 5647.540000;
	2	 0.0	 0.0	 3	   0.002000	  15.698000	 5647.540000;
	2	 0.0	 0.0	 3	   0.009000	  13.659000	 2130.630000;
	2	 0.0	 0.0	 3	   0.009000	  13.659000	 2130.630000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  12.935000	 1094.500000;
	2	 0.0	 0.0	 3	   0.002000	  12.935000	 1094.500000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.009000	  14.879000	 303.560000;
	2	 0.0	 0.0	 3	   0.005000	  13.503000	 473.560000;
	2	 0.0	 0.0	 3	   0.008000	  21.527000	 741.260000;
	2	 0.0	 0.0	 3	   0.004000	  13.270000	 554.220000;
	2	 0.0	 0.0	 3	   0.002000	  12.513000	 1488.700000;
	2	 0.0	 0.0	 3	   0.005000	  13.596000	 444.790000;
	2	 0.0	 0.0	 3	   0.004000	  13.196000	 576.640000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  21.727000	 669.800000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.009000	  14.307000	 283.220000;
	2	 0.0	 0.0	 3	   0.009000	  14.307000	 283.220000;
	2	 0.0	 0.0	 3	   0.009000	  14.342000	 278.480000;
	2	 0.0	 0.0	 3	   0.010000	  14.522000	 251.020000;
	2	 0.0	 0.0	 3	   0.010000	  14.522000	 251.020000;
	2	 0.0	 0.0	 3	   0.010000	  14.522000	 251.020000;
	2	 0.0	 0.0	 3	   0.010000	  14.522000	 251.020000;
	2	 0.0	 0.0	 3	   0.003000	  20.549000	 1734.800000;
	2	 0.0	 0.0	 3	   0.003000	  20.180000	 1898.450000;
	2	 0.0	 0.0	 3	   0.012000	  14.708000	 224.010000;
	2	 0.0	 0.0	 3	   0.012000	  14.713000	 221.980000;
	2	 0.0	 0.0	 3	   0.012000	  14.713000	 221.980000;
	2	 0.0	 0.0	 3	   0.002000	  13.270000	 810.800000;
	2	 0.0	 0.0	 3	   0.011000	  14.561000	 243.670000;
	2	 0.0	 0.0	 3	   0.013000	  14.852000	 200.420000;
	2	 0.0	 0.0	 3	   0.013000	  14.852000	 200.420000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.003000	  19.790000	 2091.800000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.020000	  15.433000	 149.280000;
	2	 0.0	 0.0	 3	   0.020000	  15.433000	 149.280000;
	2	 0.0	 0.0	 3	   0.004000	  17.200000	   0.380000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.027000	  15.878000	 113.740000;
	2	 0.0	 0.0	 3	   0.004000	  17.200000	   0.380000;
	2	 0.0	 0.0	 3	   0.032000	  16.010000	  95.400000;
	2	 0.0	 0.0	 3	   0.032000	  16.010000	  95.400000;
	2	 0.0	 0.0	 3	   0.032000	  16.010000	  95.400000;
	2	 0.0	 0.0	 3	   0.032000	  16.010000	  95.400000;
	2	 0.0	 0.0	 3	   0.032000	  16.010000	  95.400000;
	2	 0.0	 0.0	 3	   0.019000	  15.391000	 153.010000;
	2	 0.0	 0.0	 3	   0.019000	  15.391000	 153.010000;
	2	 0.0	 0.0	 3	   0.019000	  15.391000	 153.010000;
	2	 0.0	 0.0	 3	   0.035000	  16.010000	  88.480000;
	2	 0.0	 0.0	 3	   0.035000	  16.010000	  88.480000;
	2	 0.0	 0.0	 3	   0.033000	  16.010000	  95.260000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.086000	  34.988000	 172.090000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.088000	  34.988000	 165.540000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.118000	  34.988000	 122.660000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.065000	  16.010000	  49.510000;
	2	 0.0	 0.0	 3	   0.065000	  16.010000	  49.510000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.070000	  26.977000	 128.600000;
	2	 0.0	 0.0	 3	   0.072000	  16.010000	  43.360000;
	2	 0.0	 0.0	 3	   0.053000	  16.010000	  58.580000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.123000	  25.535000	  69.930000;
	2	 0.0	 0.0	 3	   0.123000	  25.535000	  69.930000;
	2	 0.0	 0.0	 3	   0.123000	  25.535000	  69.930000;
	2	 0.0	 0.0	 3	   0.167000	  34.988000	  89.960000;
	2	 0.0	 0.0	 3	   0.001000	  12.513000	 2314.900000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  12.513000	 2116.400000;
	2	 0.0	 0.0	 3	   0.001000	  12.513000	 2116.400000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.002000	  13.054000	 1039.680000;
	2	 0.0	 0.0	 3	   0.002000	  13.133000	 1005.530000;
	2	 0.0	 0.0	 3	   0.002000	  13.286000	 941.590000;
	2	 0.0	 0.0	 3	   0.002000	  13.286000	 941.590000;
	2	 0.0	 0.0	 3	   0.002000	  13.317000	 933.800000;
	2	 0.0	 0.0	 3	   0.002000	  13.317000	 933.800000;
	2	 0.0	 0.0	 3	   0.002000	  13.317000	 933.800000;
	2	 0.0	 0.0	 3	   0.002000	  13.317000	 933.800000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.006000	  13.669000	 419.600000;
	2	 0.0	 0.0	 3	   0.006000	  13.758000	 397.440000;
	2	 0.0	 0.0	 3	   0.006000	  13.758000	 397.440000;
	2	 0.0	 0.0	 3	   0.006000	  13.738000	 404.830000;
	2	 0.0	 0.0	 3	   0.006000	  13.738000	 404.830000;
	2	 0.0	 0.0	 3	   0.002000	  13.283000	 942.000000;
	2	 0.0	 0.0	 3	   0.006000	  13.799000	 390.610000;
	2	 0.0	 0.0	 3	   0.006000	  13.799000	 390.610000;
	2	 0.0	 0.0	 3	   0.006000	  13.799000	 390.610000;
	2	 0.0	 0.0	 3	   0.006000	  13.799000	 390.610000;
	2	 0.0	 0.0	 3	   0.006000	  13.799000	 390.610000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.007000	  13.959000	 356.390000;
	2	 0.0	 0.0	 3	   0.007000	  13.959000	 356.390000;
	2	 0.0	 0.0	 3	   0.007000	  13.959000	 356.390000;
	2	 0.0	 0.0	 3	   0.007000	  13.959000	 356.390000;
	2	 0.0	 0.0	 3	   0.002000	  13.009000	 1062.570000;
	2	 0.0	 0.0	 3	   0.002000	  13.009000	 1062.570000;
	2	 0.0	 0.0	 3	   0.004000	  13.352000	 528.490000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.009000	  13.659000	 2130.630000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.005000	  60.757000	 2894.550000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.032000	   9.547000	 2249.860000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.026000	  11.398000	 993.750000;
	2	 0.0	 0.0	 3	   0.009000	  14.265000	 284.210000;
	2	 0.0	 0.0	 3	   0.002000	  12.513000	 1345.250000;
	2	 0.0	 0.0	 3	   0.003000	  13.169000	 666.380000;
	2	 0.0	 0.0	 3	   0.003000	  13.169000	 666.380000;
	2	 0.0	 0.0	 3	   0.010000	  14.452000	 259.520000;
	2	 0.0	 0.0	 3	   0.010000	  14.452000	 259.520000;
	2	 0.0	 0.0	 3	   0.006000	  13.768000	 396.440000;
	2	 0.0	 0.0	 3	   0.011000	  14.560000	 246.920000;
	2	 0.0	 0.0	 3	   0.011000	  14.560000	 246.920000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.011000	  14.678000	 227.690000;
	2	 0.0	 0.0	 3	   0.011000	  14.678000	 227.690000;
	2	 0.0	 0.0	 3	   0.006000	  13.832000	 378.400000;
	2	 0.0	 0.0	 3	   0.011000	  14.678000	 227.690000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.002000	  13.009000	 1062.400000;
	2	 0.0	 0.0	 3	   0.008000	  14.143000	 298.040000;
	2	 0.0	 0.0	 3	   0.003000	  13.190000	 694.520000;
	2	 0.0	 0.0	 3	   0.011000	  14.615000	 233.840000;
	2	 0.0	 0.0	 3	   0.013000	  14.801000	 209.390000;
	2	 0.0	 0.0	 3	   0.013000	  14.784000	 210.690000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.006000	  13.683000	 416.320000;
	2	 0.0	 0.0	 3	   0.013000	  14.852000	 200.270000;
	2	 0.0	 0.0	 3	   0.009000	  14.312000	 281.170000;
	2	 0.0	 0.0	 3	   0.009000	  14.312000	 281.170000;
	2	 0.0	 0.0	 3	   0.014000	  14.904000	 191.540000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.017000	  15.194000	 165.960000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.002000	  13.009000	 1062.200000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.022000	  15.579000	 137.830000;
	2	 0.0	 0.0	 3	   0.022000	  15.579000	 137.830000;
	2	 0.0	 0.0	 3	   0.022000	  15.579000	 137.830000;
	2	 0.0	 0.0	 3	   0.022000	  15.579000	 137.830000;
	2	 0.0	 0.0	 3	   0.022000	  15.579000	 137.830000;
	2	 0.0	 0.0	 3	   0.022000	  15.579000	 137.830000;
	2	 0.0	 0.0	 3	   0.036000	  24.939000	 216.730000;
	2	 0.0	 0.0	 3	   0.036000	  24.939000	 216.730000;
	2	 0.0	 0.0	 3	   0.036000	  24.939000	 216.730000;
	2	 0.0	 0.0	 3	   0.036000	  24.939000	 216.730000;
	2	 0.0	 0.0	 3	   0.036000	  24.939000	 216.730000;
	2	 0.0	 0.0	 3	   0.105000	  25.545000	  78.250000;
	2	 0.0	 0.0	 3	   0.037000	  24.994000	 210.860000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.008000	  14.140000	 301.150000;
	2	 0.0	 0.0	 3	   0.002000	  13.302000	 843.830000;
	2	 0.0	 0.0	 3	   0.002000	  13.302000	 844.560000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.069000	  16.010000	  45.900000;
	2	 0.0	 0.0	 3	   0.028000	  15.948000	 108.310000;
	2	 0.0	 0.0	 3	   0.028000	  15.948000	 108.310000;
	2	 0.0	 0.0	 3	   0.028000	  15.948000	 108.310000;
	2	 0.0	 0.0	 3	   0.028000	  15.948000	 108.310000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.042000	  16.010000	  74.740000;
	2	 0.0	 0.0	 3	   0.042000	  16.010000	  74.740000;
	2	 0.0	 0.0	 3	   0.042000	  16.010000	  74.740000;
	2	 0.0	 0.0	 3	   0.042000	  16.010000	  74.740000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.074000	  25.545000	 115.300000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.114000	  26.977000	  78.780000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.054000	  25.110000	 186.540000;
	2	 0.0	 0.0	 3	   0.104000	  25.420000	 100.320000;
	2	 0.0	 0.0	 3	   0.056000	  16.010000	  54.740000;
	2	 0.0	 0.0	 3	   0.136000	  34.988000	 109.210000;
	2	 0.0	 0.0	 3	   0.109000	  34.988000	 141.800000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.070000	  16.010000	  45.880000;
	2	 0.0	 0.0	 3	   0.061000	  16.010000	  51.450000;
	2	 0.0	 0.0	 3	   0.061000	  16.010000	  51.450000;
	2	 0.0	 0.0	 3	   0.125000	  25.545000	  67.650000;
	2	 0.0	 0.0	 3	   0.125000	  25.545000	  67.650000;
	2	 0.0	 0.0	 3	   0.125000	  25.545000	  67.650000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.012000	  14.730000	 217.970000;
	2	 0.0	 0.0	 3	   0.012000	  14.730000	 217.970000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.073000	  16.010000	  43.050000;
	2	 0.0	 0.0	 3	   0.017000	  23.176000	 397.060000;
	2	 0.0	 0.0	 3	   0.017000	  23.176000	 397.060000;
	2	 0.0	 0.0	 3	   0.016000	  15.159000	 172.080000;
	2	 0.0	 0.0	 3	   0.016000	  15.159000	 172.080000;
	2	 0.0	 0.0	 3	   0.016000	  15.159000	 172.080000;
	2	 0.0	 0.0	 3	   0.016000	  15.159000	 172.080000;
	2	 0.0	 0.0	 3	   0.016000	  15.159000	 172.080000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.009000	  18.772000	 588.040000;
	2	 0.0	 0.0	 3	   0.019000	  15.394000	 152.100000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.010000	  59.305000	 1952.100000;
	2	 0.0	 0.0	 3	   0.076000	  16.010000	  41.170000;
	2	 0.0	 0.0	 3	   0.112000	  25.445000	  86.200000;
	2	 0.0	 0.0	 3	   0.041000	  25.030000	 203.900000;
	2	 0.0	 0.0	 3	   0.041000	  25.030000	 203.900000;
	2	 0.0	 0.0	 3	   0.041000	  25.030000	 203.900000;
	2	 0.0	 0.0	 3	   0.041000	  25.030000	 203.900000;
	2	 0.0	 0.0	 3	   0.004000	  17.200000	   0.380000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.078000	  34.988000	 191.590000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.062000	  14.879000	  43.970000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.088000	  34.988000	 168.970000;
	2	 0.0	 0.0	 3	   0.115000	  34.988000	 134.340000;
	2	 0.0	 0.0	 3	   0.062000	  34.836000	 237.170000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.053000	  14.879000	  51.340000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.035000	  16.010000	  89.260000;
	2	 0.0	 0.0	 3	   0.076000	  16.010000	  40.950000;
	2	 0.0	 0.0	 3	   0.006000	  13.669000	 419.600000;
	2	 0.0	 0.0	 3	   0.007000	  16.922000	 371.490000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.056000	  16.010000	  55.780000;
	2	 0.0	 0.0	 3	   0.056000	  16.010000	  55.780000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.026000	  13.537000	 318.860000;
	2	 0.0	 0.0	 3	   0.104000	  25.417000	 100.320000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
	2	 0.0	 0.0	 3	   0.008000	  50.578000	 1755.230000;
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	20401	 20415	 0.000971	 0.011043	 0.09974	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20401	 20441	 0.004723	 0.052055	 0.50897	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20401	 20857	 0.001011	 0.016464	 0.25723	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20401	 21714	 0.00078	 0.013891	 0.14413	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20401	 21992	 0.001457	 0.016943	 0.14655	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20401	 81859	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20401	 81859	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20402	 21030	 0.000668	 0.014038	 4.9409	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20402	 21381	 0.000382	 0.011965	 6.2567	 6811.0	 7151.6	 7492.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20402	 81861	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20402	 81861	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20402	 81861	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20403	 20412	 0.000709	 0.0128	 0.28386	 1959.0	 2056.9	 2154.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20403	 21305	 6.6e-05	 0.001087	 0.01019	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20403	 21313	 0.000101	 0.00186	 0.01787	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20403	 21323	 0.000512	 0.008481	 0.09059	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20403	 81864	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20403	 81864	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20404	 20406	 0.000211	 0.004335	 1.5345	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20404	 21483	 0.000216	 0.007605	 3.4258	 6388.0	 6707.4	 7026.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20404	 81866	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20404	 81866	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20405	 20436	 7e-05	 0.000814	 0.00713	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20405	 21667	 0.001745	 0.020148	 0.17678	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20405	 21940	 0.001573	 0.019834	 0.30271	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20405	 81869	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20405	 81869	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20406	 21483	 0.000375	 0.009514	 4.1878	 5108.0	 5363.4	 5618.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20406	 81871	 0.000163	 0.013066	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20406	 81871	 0.000163	 0.013066	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81872	 20406	 0.000336	 0.025174	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 0	 -30.0	 30.0;
	81872	 20406	 0.000336	 0.025174	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 0	 -30.0	 30.0;
	20407	 21758	 0.000769	 0.008434	 0.08193	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20407	 21997	 0.000388	 0.004258	 0.04135	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81861	 20407	 0.001947	 0.02207	 0.20114	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20407	 81873	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20407	 81873	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20408	 21120	 4e-05	 0.000644	 0.00649	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20408	 81875	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20408	 81875	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20408	 81883	 0.001224	 0.019116	 0.32546	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20409	 22032	 0.000379	 0.004291	 0.03906	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20409	 22034	 0.000104	 0.001923	 0.01848	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20409	 81877	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20409	 81877	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20409	 81902	 0.000437	 0.005109	 0.09053	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20410	 22091	 0.000732	 0.008146	 0.07682	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20410	 81878	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20410	 81878	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20411	 21191	 0.00041	 0.005419	 0.0868	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20411	 21726	 5.1e-05	 0.000936	 0.0175	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20411	 81880	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20411	 81880	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20412	 21238	 5.6e-05	 0.001078	 0.01817	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20412	 21238	 5.6e-05	 0.001078	 0.01817	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20412	 21239	 4.7e-05	 0.000794	 0.0146	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20412	 81881	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20412	 81881	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20413	 20417	 4e-06	 8.6e-05	 0.02971	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20413	 24882	 0.000339	 0.010448	 5.5896	 6811.0	 7151.6	 7492.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20413	 81883	 0.000169	 0.013516	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20413	 81883	 0.000169	 0.013516	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20413	 81883	 0.000169	 0.013516	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20414	 21132	 0.000387	 0.005262	 0.05421	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20414	 21540	 0.000137	 0.001505	 0.01462	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20414	 21570	 0.000124	 0.001358	 0.0132	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20414	 21591	 0.000408	 0.004705	 0.04125	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20414	 81886	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20414	 81886	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20415	 20428	 2.1e-05	 0.000254	 0.00258	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20415	 21992	 0.000585	 0.006657	 0.06012	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20415	 21995	 0.000955	 0.010483	 0.10185	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81861	 20415	 0.002367	 0.02638	 0.24916	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20415	 81888	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20415	 81888	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20416	 81889	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20416	 81889	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20416	 82348	 0.000556	 0.003197	 0.00091	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20417	 21487	 0.000328	 0.008322	 3.6545	 5108.0	 5363.4	 5618.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20417	 27331	 0.000473	 0.010961	 4.6888	 4718.0	 4953.9	 5189.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20417	 81890	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20417	 81890	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20417	 81890	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20418	 21238	 5e-05	 0.000533	 0.00797	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20418	 21239	 6.8e-05	 0.000698	 0.01097	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20418	 81893	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20418	 81893	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20419	 20751	 0.000317	 0.003481	 0.03381	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20419	 20752	 0.000294	 0.004158	 0.03965	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20419	 20766	 0.000517	 0.007337	 0.0694	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20419	 20910	 9.2e-05	 0.001027	 0.00968	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20419	 20913	 0.000235	 0.002714	 0.02379	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20419	 20924	 0.000251	 0.002791	 0.02631	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20419	 81894	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20419	 81894	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20420	 20713	 0.000378	 0.004877	 0.04549	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20420	 21685	 0.000455	 0.005254	 0.04606	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20420	 81895	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20420	 81895	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20421	 21745	 0.014922	 0.060732	 0.0148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20421	 21751	 0.004787	 0.021554	 0.00574	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20421	 21891	 0.005417	 0.061948	 0.01735	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20421	 81896	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20421	 81896	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20422	 21190	 6.4e-05	 0.001079	 0.01956	 1556.0	 1556.0	 1556.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20422	 21193	 8.4e-05	 0.000967	 0.00848	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20422	 21238	 7.7e-05	 0.001163	 0.02114	 1420.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20422	 81897	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20422	 81897	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20423	 20796	 0.000566	 0.006532	 0.05726	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81866	 20423	 0.001155	 0.014636	 0.2558	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81871	 20423	 0.000611	 0.006775	 0.06451	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20423	 81898	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20423	 81898	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81871	 20424	 5.6e-05	 0.000642	 0.00563	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20424	 81900	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20424	 81900	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20425	 20748	 0.000357	 0.00876	 4.5852	 5793.0	 6082.6	 6372.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20425	 21483	 0.000322	 0.00663	 2.3519	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20425	 81902	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20425	 81902	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20425	 81902	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81903	 20425	 0.000214	 0.017119	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81903	 20425	 0.000214	 0.017119	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20426	 20713	 0.000451	 0.008189	 0.08186	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20426	 21107	 0.001082	 0.012998	 0.12862	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20426	 81904	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20426	 81904	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20427	 22037	 0.000227	 0.003957	 0.04281	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20427	 22039	 5.7e-05	 0.000663	 0.00581	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20427	 81905	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20427	 81905	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20428	 81906	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20428	 81906	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20429	 20431	 0.001391	 0.011929	 0.00339	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20429	 21936	 0.011012	 0.044813	 0.01092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81878	 20429	 0.001157	 0.017119	 0.00589	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20429	 81907	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20429	 81907	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20430	 20436	 0.002767	 0.030857	 0.29162	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20430	 21108	 0.001163	 0.012695	 0.12468	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20430	 21289	 0.003815	 0.043345	 0.3963	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20430	 21685	 0.000585	 0.010818	 0.10396	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20430	 21926	 0.000992	 0.017402	 0.18632	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20430	 81908	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20430	 81908	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20431	 20432	 0.002996	 0.010591	 0.00239	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20431	 82585	 0.037013	 0.1568	 0.03533	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20432	 22088	 0.003871	 0.01328	 0.00318	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20433	 20434	 0.000311	 0.001561	 0.00041	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20433	 21237	 0.002555	 0.009711	 0.00272	 212.0	 212.0	 212.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81893	 20433	 0.002418	 0.008148	 0.00202	 142.0	 149.1	 156.2	 0.0	 0.0	 0	 -30.0	 30.0;
	20435	 21219	 0.000513	 0.00739	 0.00268	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81881	 20435	 0.000111	 0.000654	 0.00053	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20435	 81910	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20435	 81910	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20435	 82365	 0.000908	 0.005754	 0.00156	 233.0	 233.0	 233.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20436	 20929	 0.000417	 0.007362	 0.06887	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20436	 22020	 0.002001	 0.023111	 0.20283	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20436	 81911	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20436	 81911	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20437	 21382	 5e-06	 5.5e-05	 0.00054	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20437	 21387	 4.6e-05	 0.00063	 0.00628	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20438	 20710	 0.001339	 0.021386	 0.21639	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20438	 20857	 0.002026	 0.026157	 0.24436	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20438	 21339	 0.000249	 0.002873	 0.02518	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20438	 81913	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20438	 81913	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20439	 21729	 0.001269	 0.008515	 0.00206	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20439	 21752	 0.000205	 0.002246	 0.00062	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20439	 81915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20439	 81915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20440	 20973	 0.000183	 0.002068	 0.01882	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20440	 20985	 0.000213	 0.003535	 0.03313	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20440	 81916	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20440	 81916	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20441	 21651	 0.001453	 0.01678	 0.14718	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20441	 22034	 0.001945	 0.021671	 0.20457	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20441	 81917	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20441	 81917	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20442	 22084	 0.000583	 0.006602	 0.06011	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20442	 81919	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20442	 81919	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20443	 21970	 9.5e-05	 0.001038	 0.01008	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20443	 21997	 0.000212	 0.002397	 0.02183	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20443	 81921	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20443	 81921	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20444	 21722	 0.00125	 0.016948	 0.0098	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20444	 21752	 0.001412	 0.005654	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20444	 21753	 0.000171	 0.001983	 0.00106	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20444	 81922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20444	 81922	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20445	 21150	 0.0065	 0.06119	 0.01854	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20445	 21671	 0.002725	 0.027539	 0.0081	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20445	 21672	 0.006038	 0.038243	 0.01038	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20445	 21676	 0.006145	 0.029821	 0.00682	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20445	 21678	 0.004176	 0.011035	 0.00258	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20445	 21681	 0.010215	 0.031929	 0.00925	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20445	 81923	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20445	 81923	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20446	 20900	 0.005371	 0.017919	 0.00454	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20446	 20901	 0.002034	 0.008144	 0.00205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20446	 81924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20446	 81924	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20447	 22065	 0.000127	 0.001468	 0.01287	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20447	 81925	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20447	 81925	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20448	 21345	 0.000718	 0.008672	 0.00492	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20448	 21356	 0.000819	 0.008001	 0.00225	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20448	 21373	 0.000741	 0.00464	 0.00334	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20448	 81926	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20448	 81926	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20449	 20793	 0.006579	 0.050409	 0.0135	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20449	 21151	 0.003191	 0.016032	 0.00417	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20449	 21152	 0.001007	 0.009615	 0.00353	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20450	 22066	 0.002835	 0.009918	 0.00329	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20450	 22067	 0.001502	 0.006014	 0.00152	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20450	 22068	 8.4e-05	 0.000701	 0.00018	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20450	 22070	 0.000897	 0.011284	 0.0035	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20451	 21921	 0.021214	 0.030912	 0.0007	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20451	 21932	 0.000593	 0.003369	 6e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20451	 82665	 0.008366	 0.016396	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20452	 20739	 0.048436	 0.12452	 0.00193	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20452	 20740	 0.11118	 0.091518	 0.00185	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20452	 20745	 0.005721	 0.008764	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20452	 82129	 0.023953	 0.018956	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20453	 21663	 0.002713	 0.007781	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20453	 21665	 0.013916	 0.022213	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20453	 82544	 0.005443	 0.013991	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20454	 82511	 0.003098	 0.00576	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20455	 21954	 0.001731	 0.005103	 0.00119	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20455	 21994	 0.000764	 0.0027	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20456	 21623	 0.000342	 0.000888	 0.00022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20456	 81927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20456	 81927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20457	 21907	 0.006728	 0.023447	 0.00544	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20457	 81928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20457	 81928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20458	 22106	 0.001112	 0.023692	 8.8332	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20458	 23398	 8e-06	 0.000162	 0.05715	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20458	 24603	 0.00027	 0.008413	 4.3569	 6811.0	 7151.6	 7492.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20458	 81929	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20458	 81929	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20459	 20878	 0.000189	 0.003838	 1.3887	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20459	 23398	 0.000612	 0.015928	 6.9715	 5108.0	 5363.4	 5618.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20459	 81932	 0.000163	 0.013066	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 4.0	 1	 -30.0	 30.0;
	20459	 81932	 0.000163	 0.013066	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 4.0	 1	 -30.0	 30.0;
	81933	 20459	 0.000317	 0.023776	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 0	 -30.0	 30.0;
	81933	 20459	 0.000317	 0.023776	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 0	 -30.0	 30.0;
	20460	 20465	 5.6e-05	 0.000734	 0.00655	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20460	 22199	 0.000975	 0.010647	 0.10455	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20460	 22222	 0.000566	 0.006529	 0.05723	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20460	 81934	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20460	 81934	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20461	 23330	 0.000153	 0.003087	 1.3207	 4345.0	 4562.3	 4779.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20461	 81935	 0.000373	 0.026131	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20461	 81935	 0.000373	 0.026131	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81936	 20461	 0.000634	 0.047551	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81936	 20461	 0.000634	 0.047551	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20462	 20482	 0.00019	 0.002147	 0.01955	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20462	 22759	 0.003108	 0.057795	 0.55979	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20462	 23371	 0.000229	 0.002546	 0.02401	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20462	 23475	 0.00139	 0.024496	 0.40774	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20462	 81937	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20462	 81937	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20463	 24310	 0.000584	 0.006742	 0.05911	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20463	 24383	 0.000135	 0.001478	 0.01435	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20463	 24387	 0.000127	 0.001389	 0.0135	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20463	 24766	 0.000249	 0.002879	 0.02524	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20463	 24853	 2.1e-05	 0.000231	 0.00227	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20464	 22936	 0.000973	 0.011462	 0.20031	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20464	 23910	 0.000174	 0.003047	 0.0326	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20464	 23944	 0.000246	 0.004234	 0.07373	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20464	 81939	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20464	 81939	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20465	 22826	 0.001101	 0.019898	 0.31448	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20465	 24144	 0.000813	 0.012782	 0.13327	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20465	 81941	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20465	 81941	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20466	 22527	 0.001523	 0.010565	 0.00302	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20466	 22529	 0.002524	 0.021227	 0.00629	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20466	 81942	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20466	 81942	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20467	 22949	 0.001198	 0.01702	 0.16107	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20467	 23932	 5.8e-05	 0.000665	 0.00583	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20467	 81943	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20467	 81943	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20468	 24386	 0.000103	 0.001185	 0.01039	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20468	 24716	 4.5e-05	 0.000506	 0.00461	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20468	 24854	 3.8e-05	 0.000432	 0.00393	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20468	 81944	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20468	 81944	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20469	 22365	 0.001133	 0.013081	 0.11471	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20469	 81946	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20469	 81946	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20469	 83095	 0.002575	 0.029752	 0.26132	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20470	 23590	 0.001029	 0.004632	 0.00123	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20470	 23693	 0.000394	 0.003383	 0.00096	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20470	 81948	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20470	 81948	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20471	 20473	 2.3e-05	 0.000275	 0.00272	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20471	 23996	 0.000693	 0.007564	 0.07427	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20471	 81949	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20471	 81949	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20472	 22402	 0.000639	 0.007062	 0.00212	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20472	 22423	 0.003097	 0.010626	 0.00255	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20472	 81950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20472	 81950	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20473	 22178	 0.000194	 0.002236	 0.0196	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20473	 22185	 0.000125	 0.001436	 0.01407	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20473	 23010	 0.001557	 0.024876	 0.405	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20473	 81951	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20473	 81951	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20474	 24324	 1.8e-05	 0.000204	 0.00179	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20474	 81952	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20474	 81952	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20475	 22639	 0.002185	 0.0227	 0.00702	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20475	 81954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20475	 81954	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20476	 24766	 0.000424	 0.004798	 0.04368	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20476	 24807	 0.000563	 0.006381	 0.05809	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20476	 24835	 3.6e-05	 0.000403	 0.0038	 810.0	 810.0	 810.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20476	 81955	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20476	 81955	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20477	 23432	 0.000601	 0.006934	 0.06079	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20477	 23450	 0.000194	 0.0022	 0.02002	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20477	 26733	 0.000381	 0.004176	 0.04057	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20477	 81957	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20477	 81957	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20478	 22106	 0.000293	 0.006094	 2.1146	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20478	 81959	 0.000213	 0.017042	 0.0	 1150.0	 1150.0	 1150.0	 0.975	 0.0	 1	 -30.0	 30.0;
	20478	 81959	 0.000213	 0.017042	 0.0	 1150.0	 1150.0	 1150.0	 0.975	 0.0	 1	 -30.0	 30.0;
	20479	 24048	 0.000114	 0.001611	 0.02602	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81935	 20479	 9e-06	 0.000145	 0.00135	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20479	 81962	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20479	 81962	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20480	 23619	 0.001598	 0.025147	 0.26251	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20480	 24000	 0.002627	 0.036392	 0.36449	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20480	 81964	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20480	 81964	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20481	 23439	 0.030273	 0.078612	 0.01909	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20481	 24204	 0.000977	 0.008377	 0.00238	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20481	 24207	 0.00728	 0.02453	 0.0061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20481	 24216	 0.016438	 0.047151	 0.0116	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20481	 24809	 0.002527	 0.014679	 0.00346	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20481	 81966	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20481	 81966	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20482	 23340	 0.001199	 0.013589	 0.12376	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20482	 81967	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20482	 81967	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20483	 23890	 0.007945	 0.046147	 0.01087	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20483	 23892	 0.001576	 0.003797	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20483	 81968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20483	 81968	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20484	 23902	 5e-05	 0.000618	 0.00621	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20484	 23907	 0.000175	 0.00201	 0.01969	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20484	 81969	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20484	 81969	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20485	 24021	 0.001349	 0.007399	 0.00196	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20485	 24044	 0.00263	 0.010231	 0.00273	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20485	 81971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20485	 81971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20486	 22281	 0.000675	 0.007407	 0.07196	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20486	 22826	 0.000334	 0.003856	 0.03381	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20486	 81972	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20486	 81972	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20487	 22639	 0.022832	 0.053008	 0.01615	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20487	 24096	 0.029727	 0.10365	 0.02405	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20487	 81974	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20487	 81974	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20488	 24352	 0.000489	 0.001676	 0.0004	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20488	 81975	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20488	 81975	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20489	 23427	 0.004895	 0.012708	 0.00308	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20489	 81976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20489	 81976	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20490	 23320	 0.000862	 0.002237	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20490	 24287	 0.000598	 0.002052	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20490	 81977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20490	 81977	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20491	 24185	 0.001218	 0.003061	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20491	 81978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20491	 81978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20492	 22676	 0.000255	 0.001806	 0.0005	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20492	 81979	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20492	 81979	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20493	 22858	 0.019691	 0.10844	 0.00245	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20493	 22859	 0.010719	 0.030745	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20493	 22860	 0.15826	 0.17409	 0.00232	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20493	 22862	 0.067541	 0.13823	 0.0034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 22764	 0.001907	 0.007635	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 22772	 0.000273	 0.002897	 0.00086	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 22774	 0.002168	 0.008678	 0.00219	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 22780	 0.002845	 0.016175	 0.00468	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 22784	 0.00287	 0.009844	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 22786	 0.001265	 0.01073	 0.00643	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 24240	 0.007663	 0.096446	 0.0299	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 81980	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20494	 81980	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20495	 24860	 0.00716	 0.024125	 0.006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20495	 81981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20495	 81981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20496	 22286	 0.028555	 0.087694	 0.00165	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20496	 22608	 0.001896	 0.010777	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20496	 82878	 0.020107	 0.12355	 0.00282	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20496	 82879	 0.011965	 0.088911	 0.00212	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20497	 22632	 0.17719	 0.14024	 0.00177	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20497	 22633	 0.012139	 0.050398	 0.00131	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20497	 22634	 0.053317	 0.10557	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20497	 22635	 0.095282	 0.18867	 0.00277	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20498	 22135	 0.02989	 0.069394	 0.00103	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20498	 22136	 0.003177	 0.009747	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20498	 22141	 0.059201	 0.16981	 0.00261	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20499	 24147	 0.000614	 0.002497	 0.00061	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20499	 24159	 0.002364	 0.008561	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20499	 81982	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20499	 81982	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20500	 22365	 0.001187	 0.013509	 0.12204	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20500	 22695	 0.00021	 0.002374	 0.02161	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20500	 81983	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20500	 81983	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20501	 24859	 0.004233	 0.015398	 0.00471	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20501	 24863	 0.001512	 0.004337	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20501	 81985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20501	 81985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20502	 23891	 0.002445	 0.007642	 0.00221	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20502	 23892	 0.001392	 0.00856	 0.00247	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20502	 81986	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20502	 81986	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20503	 22337	 0.029286	 0.07605	 0.01846	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20503	 81987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20503	 81987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20504	 82852	 0.010613	 0.02813	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20504	 82853	 0.002334	 0.00542	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20505	 22130	 3.4e-05	 0.00038	 0.00346	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20505	 23944	 0.000218	 0.002521	 0.0221	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20506	 22376	 0.033977	 0.080458	 0.00147	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20506	 22377	 0.070407	 0.17907	 0.00283	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20506	 82809	 0.016031	 0.042378	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20507	 22857	 0.001488	 0.007711	 0.00188	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81972	 20507	 0.000149	 0.000615	 0.00015	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20508	 22942	 0.002338	 0.00802	 0.00192	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20508	 81988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20508	 81988	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20508	 82969	 0.009259	 0.021494	 0.00655	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20509	 23382	 0.029992	 0.14471	 0.00256	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20509	 23519	 0.042939	 0.11038	 0.00171	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20509	 23520	 0.023105	 0.018285	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20509	 23521	 0.069699	 0.090708	 0.00127	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20510	 24243	 0.058358	 0.046184	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20510	 24244	 0.18432	 0.18619	 0.00247	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20510	 83420	 0.008457	 0.02961	 0.00082	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20511	 22383	 9.9e-05	 0.001667	 0.03022	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20511	 23392	 0.001956	 0.03554	 0.35637	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20511	 81989	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20511	 81989	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20512	 22393	 0.01909	 0.063682	 0.00101	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20512	 82813	 0.009215	 0.026149	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20513	 22327	 0.04386	 0.092185	 0.00168	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20513	 23949	 0.29402	 0.23275	 0.00293	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20513	 23952	 0.052843	 0.11325	 0.00198	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20514	 23379	 0.028402	 0.1386	 0.00239	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20514	 23881	 0.052263	 0.13546	 0.00256	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20514	 23883	 0.024751	 0.15218	 0.00274	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20514	 23884	 0.03743	 0.065826	 0.00124	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20515	 23349	 0.026757	 0.029429	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20515	 83085	 0.000917	 0.000977	 1e-05	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20516	 23943	 0.000253	 0.000854	 0.00021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20516	 83251	 0.001095	 0.003653	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20517	 24050	 0.006938	 0.0129	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20518	 22330	 0.020858	 0.041298	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20518	 22331	 0.00666	 0.013186	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81987	 20518	 0.030812	 0.024384	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20519	 23891	 0.006088	 0.015805	 0.00384	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20519	 23893	 0.005419	 0.045576	 0.0135	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20519	 81991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20519	 81991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20520	 22386	 0.003032	 0.018638	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81990	 20520	 0.018697	 0.043408	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20521	 22113	 0.00485	 0.054604	 0.01579	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20521	 22114	 0.00361	 0.027459	 0.00863	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20521	 81992	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20521	 81992	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20521	 82727	 0.000541	 0.008271	 0.00266	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20522	 82811	 0.008596	 0.018067	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20523	 23930	 0.00475	 0.008484	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20523	 23945	 0.020698	 0.027203	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20523	 23946	 0.038485	 0.030166	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20523	 83247	 0.050311	 0.039816	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20524	 23948	 0.001117	 0.004544	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20524	 83251	 0.000609	 0.002394	 0.00063	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20525	 22126	 0.000994	 0.003409	 0.00082	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20525	 81993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20525	 81993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20526	 22392	 0.091699	 0.25638	 0.05398	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20526	 22743	 0.077855	 0.20615	 0.04836	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20526	 23345	 0.001258	 0.003608	 0.00089	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20526	 24101	 0.10661	 0.27777	 0.0677	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81960	 20526	 0.005364	 0.014177	 0.00332	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20526	 81994	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20526	 81994	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20527	 23339	 0.00611	 0.015863	 0.00385	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20527	 24858	 0.011948	 0.050573	 0.01138	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20527	 81995	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20527	 81995	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20528	 22321	 0.065499	 0.16839	 0.00261	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20528	 22425	 0.15806	 0.12509	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20528	 23114	 0.44051	 0.44226	 0.00715	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20528	 23116	 0.30164	 0.222	 0.00325	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20529	 23878	 0.019201	 0.097116	 0.00189	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20529	 83230	 0.076445	 0.20265	 0.00514	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20530	 22133	 0.062216	 0.14445	 0.00215	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20530	 23467	 0.090455	 0.068534	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20530	 23469	 0.22644	 0.17923	 0.00226	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20531	 20537	 0.000174	 0.003583	 1.2675	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20531	 81996	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20531	 81996	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20531	 81996	 0.000175	 0.013999	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20532	 26524	 0.000128	 0.002388	 0.04226	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20532	 26532	 8.6e-05	 0.001543	 0.03003	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20532	 26539	 6.3e-05	 0.000869	 0.00859	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20532	 81999	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20532	 81999	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20533	 20541	 0.000148	 0.004579	 2.356	 6811.0	 7151.6	 7492.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20533	 27331	 0.000161	 0.004077	 1.7799	 5108.0	 5363.4	 5618.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20533	 82000	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20533	 82000	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20533	 82000	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82001	 20533	 0.000167	 0.013374	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82001	 20533	 0.000167	 0.013374	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20534	 24828	 0.00227	 0.025737	 0.23466	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20534	 27173	 0.000556	 0.005891	 0.06145	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20534	 27176	 0.000226	 0.003985	 0.06617	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20534	 27308	 0.0009	 0.010392	 0.09112	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20534	 82002	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20534	 82002	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20535	 24864	 0.000799	 0.012564	 0.13099	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20535	 24869	 0.000157	 0.002868	 0.04442	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20535	 25179	 0.002547	 0.035453	 0.35156	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20535	 82003	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20535	 82003	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20536	 20546	 0.000694	 0.012598	 0.12598	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20536	 24966	 0.000524	 0.009499	 0.09497	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20536	 26467	 0.000167	 0.002657	 0.04363	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20536	 26468	 0.000127	 0.001393	 0.01353	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20536	 27384	 0.003223	 0.037278	 0.32778	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20536	 82005	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20536	 82005	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20536	 84364	 0.001612	 0.028429	 0.47361	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20537	 27331	 0.000243	 0.004522	 1.976	 4162.0	 4370.1	 4578.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20537	 82006	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20537	 82006	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82007	 20537	 0.0003	 0.022524	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 0	 -30.0	 30.0;
	82007	 20537	 0.0003	 0.022524	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20538	 25689	 0.000223	 0.00247	 0.02351	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20538	 26078	 0.000872	 0.009709	 0.09157	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20538	 27179	 0.000887	 0.016416	 0.15782	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20538	 27772	 0.000928	 0.010189	 0.09899	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20538	 82008	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20538	 82008	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20539	 24918	 0.000115	 0.001134	 0.0194	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20539	 24918	 0.000115	 0.001134	 0.0194	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20539	 26532	 0.000451	 0.00748	 0.17004	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20539	 82010	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20539	 82010	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20540	 25283	 0.000449	 0.004073	 0.00213	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20540	 25293	 4.8e-05	 0.000795	 0.00024	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20540	 82011	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20540	 82011	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20541	 25669	 0.000363	 0.011199	 6.0053	 6811.0	 7151.6	 7492.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20541	 27162	 6.1e-05	 0.001545	 0.65751	 5108.0	 5363.4	 5618.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20541	 82012	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20541	 82012	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20541	 82012	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20541	 82012	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20541	 82012	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20542	 20545	 0.000755	 0.010279	 0.10592	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20542	 26942	 0.000266	 0.004716	 0.0494	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82000	 20542	 6.4e-05	 0.001056	 0.0099	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20542	 82013	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20542	 82013	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20543	 27721	 0.001137	 0.012658	 0.11941	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82012	 20543	 4e-05	 0.000669	 0.01302	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20543	 82014	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20543	 82014	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20543	 84364	 0.000318	 0.007542	 0.13657	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20544	 20693	 0.000357	 0.003915	 0.03803	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20544	 21110	 0.001089	 0.0203	 0.19238	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20544	 24873	 0.000939	 0.017369	 0.167	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20544	 27179	 0.000609	 0.006903	 0.06285	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20544	 82015	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20544	 82015	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20545	 24942	 0.000868	 0.013781	 0.14478	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20545	 27200	 0.001146	 0.018128	 0.3942	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20545	 27685	 0.000283	 0.003175	 0.06105	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82000	 20545	 0.000559	 0.009806	 0.10493	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20545	 82017	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20545	 82017	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20546	 25201	 0.000243	 0.00251	 0.03943	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 25201	 0.000243	 0.00251	 0.03943	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 25205	 0.000419	 0.004428	 0.06623	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 25205	 0.000419	 0.004428	 0.06623	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 26461	 0.000166	 0.002806	 0.02873	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 27241	 0.003041	 0.034508	 0.315	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 27385	 0.00224	 0.025878	 0.22718	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20546	 82019	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20546	 82019	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20547	 26940	 0.000871	 0.015955	 0.29441	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82012	 20547	 0.000221	 0.002339	 0.03498	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82012	 20547	 0.000221	 0.002339	 0.03498	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20547	 82021	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20547	 82021	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20548	 26379	 0.001784	 0.019584	 0.1904	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20548	 26798	 0.00063	 0.006881	 0.06756	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20548	 27174	 0.000304	 0.004411	 0.03989	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20548	 27786	 0.000308	 0.003434	 0.03239	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20548	 82023	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20548	 82023	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20549	 27331	 5.7e-05	 0.001179	 0.40798	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20549	 82025	 0.000373	 0.026131	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20549	 82025	 0.000373	 0.026131	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20550	 25211	 3e-05	 0.000553	 0.0102	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20550	 25213	 0.000255	 0.002693	 0.04028	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20550	 25213	 0.000255	 0.002693	 0.04028	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20550	 25759	 0.001608	 0.0292	 0.29249	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20550	 27142	 0.000151	 0.003659	 0.0631	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20550	 27648	 0.001172	 0.015857	 0.27962	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20550	 82028	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20550	 82028	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20551	 26683	 0.001934	 0.016049	 0.00422	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20551	 26736	 0.004117	 0.025551	 0.00619	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20551	 26795	 0.000745	 0.0057	 0.0042	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20551	 82029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20551	 82029	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20551	 83105	 0.016628	 0.058193	 0.01929	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20551	 83487	 0.039886	 0.13693	 0.03284	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20551	 84206	 0.001134	 0.00954	 0.00283	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20552	 27598	 0.011511	 0.030422	 0.00712	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20552	 27626	 0.000182	 0.002713	 0.0008	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20552	 27630	 0.001366	 0.005313	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20552	 82030	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20552	 82030	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20553	 27059	 0.000717	 0.008194	 0.0025	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20553	 27061	 0.00112	 0.004257	 0.00119	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20554	 25478	 0.000274	 0.003719	 0.05666	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20554	 26504	 2.5e-05	 0.000433	 0.00763	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20554	 82031	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20554	 82031	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20555	 25157	 0.000111	 0.002614	 0.04796	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20555	 25169	 0.000178	 0.002029	 0.01832	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20555	 26356	 0.000888	 0.010299	 0.1095	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81996	 20555	 0.000563	 0.00627	 0.05913	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20555	 82032	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20555	 82032	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20556	 26050	 0.000947	 0.013921	 0.00426	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20556	 27194	 0.000862	 0.013175	 0.00424	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20556	 27197	 0.001335	 0.015261	 0.00427	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20556	 82034	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20556	 82034	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20556	 83951	 0.000855	 0.011218	 0.00538	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20557	 24966	 0.000414	 0.007219	 0.07811	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20557	 82035	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20557	 82035	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20557	 84364	 0.001321	 0.021713	 0.33322	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20558	 25047	 8.3e-05	 0.001442	 0.0156	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20558	 25063	 9.8e-05	 0.001129	 0.0099	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20558	 25065	 6.9e-05	 0.000787	 0.00717	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20558	 82037	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20558	 82037	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20559	 25981	 0.000457	 0.008378	 0.15447	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20559	 27196	 0.000194	 0.002304	 0.02116	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20559	 27198	 0.00019	 0.002568	 0.03913	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20559	 82038	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20559	 82038	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20560	 20564	 4e-06	 6e-05	 0.00057	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20560	 27013	 2.4e-05	 0.00041	 0.00713	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20560	 27053	 0.000365	 0.0042	 0.04115	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20560	 82039	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20560	 82039	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20561	 25047	 0.000152	 0.001723	 0.01569	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20561	 25073	 4.3e-05	 0.000493	 0.00432	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20561	 27252	 0.000932	 0.01017	 0.09986	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20561	 82040	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20561	 82040	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20562	 26604	 4.2e-05	 0.000741	 0.00769	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20562	 82042	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20562	 82042	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20563	 25736	 0.000667	 0.008817	 0.14126	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20563	 26672	 3e-05	 0.000538	 0.0085	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20563	 82044	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20563	 82044	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20564	 27067	 0.000179	 0.003308	 0.03179	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20564	 82046	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20564	 82046	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20565	 25067	 0.000305	 0.005641	 0.0542	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20565	 27071	 4e-05	 0.000574	 0.00526	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20565	 82048	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20565	 82048	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20566	 25674	 0.000763	 0.002571	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20566	 82049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20566	 82049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20567	 27330	 0.000116	 0.001369	 0.02391	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82025	 20567	 0.000147	 0.001482	 0.0244	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20568	 20805	 0.00018	 0.001821	 0.02996	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20568	 20805	 0.00018	 0.001821	 0.02996	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20568	 25038	 0.000828	 0.015324	 0.14731	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20568	 26244	 0.00028	 0.005012	 0.09757	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20568	 26253	 0.000182	 0.00182	 0.03033	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20568	 26253	 0.000182	 0.00182	 0.03033	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81890	 20568	 0.000185	 0.001953	 0.0292	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81890	 20568	 0.000185	 0.001953	 0.0292	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20569	 25684	 0.001418	 0.005676	 0.00192	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20569	 25685	 0.00021	 0.002279	 0.0014	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20569	 25687	 0.005767	 0.024408	 0.00549	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20569	 82050	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20569	 82050	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20570	 26518	 0.000706	 0.003216	 0.00102	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20570	 26522	 0.000307	 0.001978	 0.00052	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20570	 26523	 0.001396	 0.009873	 0.00271	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20570	 82051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20570	 82051	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20571	 26163	 0.008099	 0.014833	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20571	 26168	 0.006495	 0.015078	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20571	 26169	 0.002264	 0.005257	 8e-05	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20571	 26170	 0.000657	 0.004509	 8e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20571	 26171	 0.008418	 0.006661	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20572	 27283	 0.014677	 0.042094	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20572	 27284	 0.004424	 0.011251	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20572	 27285	 0.018597	 0.072349	 0.00121	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20573	 27773	 0.000533	 0.004482	 0.00133	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20573	 83957	 0.007904	 0.050064	 0.01359	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20573	 84625	 0.000579	 0.001952	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20574	 27784	 0.011607	 0.040455	 0.00938	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20574	 27793	 0.003256	 0.008866	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20574	 27795	 0.003103	 0.007203	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20574	 82052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20574	 82052	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20575	 25227	 0.014547	 0.034696	 0.00078	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20575	 25228	 0.02672	 0.021146	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20575	 83667	 0.016758	 0.026748	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20576	 26401	 0.000711	 0.009103	 0.00272	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20576	 82053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20576	 82053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20576	 84086	 0.003434	 0.029247	 0.0073	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20577	 25255	 0.000253	 0.00065	 0.00016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20577	 82054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20577	 82054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20577	 83677	 0.000768	 0.002029	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20578	 25027	 0.001308	 0.004488	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20578	 82055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20578	 82055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20579	 27794	 0.008548	 0.012964	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20579	 27796	 0.014492	 0.01359	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82052	 20579	 0.004532	 0.010411	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20579	 84634	 0.031115	 0.037931	 0.00061	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20579	 84636	 0.060242	 0.047221	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20580	 84111	 0.006143	 0.017619	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20581	 27699	 0.001014	 0.00406	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20581	 27701	 0.000793	 0.003986	 0.00104	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20582	 26610	 0.001292	 0.005174	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20582	 26613	 0.001374	 0.007322	 0.00205	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20582	 82056	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20582	 82056	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20583	 27653	 0.000728	 0.002453	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20583	 82057	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20583	 82057	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20583	 84567	 0.002602	 0.00868	 0.0022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20584	 24999	 0.000267	 0.003003	 0.00079	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20584	 25069	 0.000665	 0.002661	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20584	 82058	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20584	 82058	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20585	 82059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20585	 82059	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20585	 84433	 0.005315	 0.014047	 0.00329	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20585	 84434	 0.00185	 0.005569	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20586	 25133	 0.001822	 0.00635	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20586	 82060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20586	 82060	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20587	 24919	 0.000238	 0.004224	 0.00212	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20587	 82061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20587	 82061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20587	 83527	 0.000219	 0.003885	 0.00195	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20588	 26944	 0.01194	 0.073405	 0.00132	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20588	 83540	 0.058265	 0.35423	 0.00654	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20589	 27330	 0.000108	 0.00127	 0.02218	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20589	 27337	 0.00053	 0.005878	 0.05597	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20589	 84444	 0.000316	 0.003644	 0.03195	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20590	 27743	 0.000577	 0.004714	 0.00128	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20590	 27744	 0.00143	 0.005179	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20590	 27745	 0.000407	 0.001629	 0.00041	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20591	 27590	 0.002022	 0.012431	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20591	 84547	 0.00211	 0.010737	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20592	 26957	 0.06073	 0.059421	 0.00084	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20592	 84280	 0.006398	 0.01835	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20592	 84283	 0.034197	 0.071873	 0.00131	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20593	 20594	 0.004909	 0.013178	 0.00299	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20593	 20692	 0.009382	 0.024117	 0.00597	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20594	 20595	 0.002638	 0.010562	 0.00266	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20594	 20598	 0.012549	 0.053117	 0.01195	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82015	 20594	 0.0158	 0.054205	 0.01299	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20595	 20596	 0.002004	 0.010651	 0.00247	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20596	 20597	 0.003859	 0.022606	 0.00616	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20597	 20599	 0.00996	 0.026324	 0.00616	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20597	 22081	 0.007396	 0.037163	 0.00967	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20597	 82062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20597	 82062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20598	 20599	 0.002195	 0.012476	 0.00361	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20598	 82063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20598	 82063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20599	 82317	 0.002292	 0.024735	 0.00847	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20600	 20601	 0.000864	 0.002912	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20600	 20627	 0.002066	 0.005762	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20600	 82064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20600	 82064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20601	 82065	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20601	 82065	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20601	 82076	 0.001616	 0.005542	 0.00133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20602	 82075	 0.005517	 0.014182	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20602	 82077	 0.003539	 0.010149	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20603	 20605	 0.012982	 0.009384	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82065	 20603	 0.019218	 0.012441	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20604	 20612	 0.023073	 0.01826	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20605	 20607	 0.013222	 0.013501	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20606	 20607	 0.017603	 0.017607	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20606	 82102	 0.008947	 0.017714	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20607	 20608	 0.00608	 0.011915	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20607	 82077	 0.073262	 0.051896	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20607	 82082	 0.013491	 0.03431	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20608	 20609	 0.004335	 0.00887	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20609	 82070	 0.006557	 0.015639	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20610	 82070	 0.016036	 0.010382	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20611	 20612	 0.009236	 0.010158	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20611	 82070	 0.006802	 0.017298	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20612	 82077	 0.022994	 0.023224	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20612	 82078	 0.011593	 0.020918	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 20614	 7.8e-05	 0.000852	 0.00828	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 20638	 6.4e-05	 0.000751	 0.00708	 1000.0	 1050.0	 1100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 20690	 0.000497	 0.00565	 0.05102	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 20695	 0.000322	 0.003652	 0.03325	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 20820	 0.001276	 0.014281	 0.13348	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 82066	 9.7e-05	 0.007789	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20613	 82412	 0.0049	 0.051197	 0.80414	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 82412	 0.0049	 0.051197	 0.80414	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20613	 82412	 0.0049	 0.051197	 0.80414	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20614	 82068	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20615	 20616	 0.000859	 0.002607	 0.00057	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20615	 20639	 0.001132	 0.002845	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20616	 20617	 0.001316	 0.004586	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20616	 20681	 0.002256	 0.014289	 0.00388	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 20616	 0.005215	 0.01354	 0.00329	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20616	 82070	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20616	 82070	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20617	 20680	 0.003212	 0.008956	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20617	 20681	 0.000993	 0.010038	 0.00295	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20617	 20686	 0.00677	 0.017891	 0.00419	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 20617	 0.006856	 0.017798	 0.00432	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20617	 82071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20617	 82071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20618	 20635	 0.00118	 0.00348	 0.00081	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20618	 82072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20618	 82072	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20619	 20620	 0.00706	 0.009279	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20619	 20631	 0.015887	 0.031456	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20620	 82078	 0.016051	 0.011603	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82069	 20621	 0.01254	 0.009226	 0.00013	 33.0	 33.0	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20621	 82073	 0.015523	 0.012285	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20621	 82078	 0.01591	 0.011705	 0.00017	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82067	 20622	 0.00789	 0.011201	 0.00018	 49.0	 49.0	 49.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82069	 20622	 0.014316	 0.017137	 0.00029	 45.0	 45.0	 45.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20623	 20635	 0.001022	 0.003506	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 20623	 0.00174	 0.005675	 0.00151	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20623	 82073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20623	 82073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20624	 20625	 0.005913	 0.015199	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20624	 20630	 0.010581	 0.025899	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82069	 20624	 0.0073	 0.028397	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82072	 20624	 0.00214	 0.01023	 0.00022	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20625	 20633	 0.024132	 0.024374	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20626	 20637	 0.016338	 0.015986	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20626	 20654	 0.024923	 0.019723	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20626	 82086	 0.025159	 0.025165	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20627	 82074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20627	 82074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20627	 82084	 0.003698	 0.010902	 0.00254	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20628	 20637	 0.019189	 0.029395	 0.00041	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20628	 82075	 0.004559	 0.01172	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20629	 82075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20629	 82075	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20629	 82076	 0.001065	 0.006184	 0.00146	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20630	 20634	 0.02697	 0.021344	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82071	 20631	 0.029848	 0.030148	 0.0004	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20631	 82097	 0.00915	 0.026242	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82071	 20632	 0.021896	 0.050834	 0.00076	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20632	 82099	 0.013875	 0.061827	 0.00105	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20636	 20668	 0.02522	 0.016328	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20638	 20673	 9.9e-05	 0.001788	 0.01787	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20638	 82076	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82068	 20639	 0.00127	 0.003264	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20639	 82078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20639	 82078	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20640	 82079	 0.036893	 0.09484	 0.00147	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20640	 84373	 0.064287	 0.14924	 0.00284	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20641	 82079	 0.012372	 0.047599	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20641	 82080	 0.022168	 0.063581	 0.00098	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20641	 82081	 0.018664	 0.047977	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20642	 20824	 0.004727	 0.029942	 0.00813	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 20642	 0.003899	 0.044571	 0.01359	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20642	 82079	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20642	 82079	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20643	 20644	 0.003675	 0.012381	 0.00308	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20643	 20656	 0.001846	 0.008961	 0.00205	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20643	 20660	 0.009394	 0.02415	 0.00598	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20643	 82080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20643	 82080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20644	 20823	 0.007435	 0.017917	 0.00506	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20644	 82081	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20644	 82081	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82081	 20645	 0.040317	 0.049149	 0.00079	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20645	 82083	 0.021028	 0.07512	 0.00149	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20646	 20647	 0.023895	 0.023965	 0.00039	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20647	 82087	 0.010921	 0.027773	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20648	 82083	 0.12914	 0.1022	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20649	 82082	 0.10783	 0.076388	 0.00121	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20650	 20686	 0.005096	 0.013467	 0.00315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20650	 82082	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20650	 82082	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20650	 82101	 0.003021	 0.010678	 0.00241	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20651	 22094	 0.003824	 0.036719	 0.01068	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20651	 82084	 0.000845	 0.007245	 0.00206	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20652	 82083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20652	 82083	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20652	 82084	 0.002089	 0.007165	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20653	 20695	 7.9e-05	 0.000893	 0.00813	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20653	 82084	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20654	 82086	 0.009007	 0.018432	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20654	 82087	 0.011478	 0.022725	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20655	 20656	 0.00108	 0.007243	 0.00175	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20655	 82086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20655	 82086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20655	 82101	 0.000622	 0.006396	 0.00181	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20656	 82087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20656	 82087	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20657	 20658	 0.008005	 0.015849	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20657	 20659	 0.012587	 0.026972	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20657	 20668	 0.008387	 0.013387	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82075	 20657	 0.005673	 0.037492	 0.00074	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20657	 82088	 0.039232	 0.035155	 0.00072	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20658	 82088	 0.03549	 0.027223	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20659	 20664	 0.01847	 0.02165	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20659	 20666	 0.009286	 0.023615	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20660	 20661	 0.001747	 0.004391	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20660	 82088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20660	 82088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20661	 82089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20661	 82089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20662	 82090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20662	 82090	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20662	 82093	 0.002259	 0.005866	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82089	 20663	 0.011415	 0.021574	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20663	 82092	 0.008661	 0.02484	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82074	 20664	 0.013913	 0.059754	 0.00109	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82080	 20664	 0.033705	 0.034043	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20665	 20666	 0.005876	 0.022608	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20665	 82168	 0.069411	 0.19699	 0.0031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82088	 20666	 0.005041	 0.022461	 0.00038	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20667	 20669	 0.007777	 0.014893	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82090	 20667	 0.01958	 0.019585	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20668	 20694	 0.009317	 0.023695	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82075	 20669	 0.006148	 0.012582	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20670	 82091	 0.019508	 0.087292	 0.0018	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20670	 84375	 0.1458	 0.23278	 0.00536	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20671	 20673	 0.000494	 0.005416	 0.05261	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20671	 20693	 0.000403	 0.00442	 0.04294	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20671	 27179	 0.000512	 0.007	 0.07134	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20671	 82091	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20671	 82091	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20672	 82092	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20672	 82092	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20672	 82093	 0.00374	 0.009709	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20673	 82093	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20674	 20675	 0.031373	 0.029421	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82094	 20674	 0.014634	 0.018165	 0.0004	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20675	 20676	 0.030812	 0.021826	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20675	 82095	 0.025305	 0.049594	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82092	 20676	 0.022429	 0.01452	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20677	 82095	 0.018538	 0.030916	 0.00045	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20678	 20679	 0.001396	 0.007906	 0.00196	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 20678	 0.000777	 0.007988	 0.00227	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20678	 82095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20678	 82095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20679	 20691	 0.003973	 0.015102	 0.00423	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20680	 82096	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20680	 82096	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20681	 82097	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20681	 82097	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20681	 82300	 0.010013	 0.078911	 0.02309	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20682	 20683	 0.007558	 0.015467	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20682	 20685	 0.009175	 0.018166	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82096	 20682	 0.05102	 0.05117	 0.00083	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20683	 20684	 0.00818	 0.021028	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20683	 20687	 0.027922	 0.049104	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20684	 20689	 0.026649	 0.069067	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82071	 20685	 0.092308	 0.073053	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20685	 82098	 0.01827	 0.018275	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20686	 82098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20686	 82098	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82098	 20687	 0.018674	 0.048004	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20687	 82723	 0.029442	 0.097162	 0.00157	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20688	 22100	 0.03048	 0.10889	 0.00216	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82098	 20688	 0.023021	 0.070696	 0.00133	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82097	 20689	 0.0251	 0.077002	 0.00209	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20689	 82298	 0.024935	 0.17117	 0.00312	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20690	 22084	 0.000577	 0.010463	 0.10461	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20690	 82099	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20690	 82099	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20691	 20692	 0.00733	 0.025147	 0.00602	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20692	 82100	 0.006249	 0.021778	 0.00505	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20693	 82100	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20693	 82100	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82064	 20694	 0.007577	 0.02173	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20695	 82101	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20696	 20702	 8.6e-05	 0.000994	 0.00871	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20696	 20710	 0.000489	 0.005443	 0.05133	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20696	 82103	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20697	 20698	 9.4e-05	 0.00109	 0.00956	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20697	 20702	 9e-05	 0.000992	 0.00964	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20697	 82105	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20697	 82105	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20698	 82106	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20698	 82106	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82106	 20699	 0.001995	 0.005272	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20699	 82107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20699	 82107	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20699	 82642	 0.018004	 0.045262	 0.01173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20700	 20707	 0.011438	 0.028753	 0.00745	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20700	 82108	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20700	 82108	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20700	 82109	 0.002732	 0.006869	 0.00178	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20701	 20709	 0.11071	 0.11183	 0.00148	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82108	 20701	 0.021038	 0.014902	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20701	 82110	 0.039269	 0.031077	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20702	 21880	 0.00083	 0.009104	 0.08845	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20702	 82109	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82104	 20703	 0.009313	 0.026712	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20703	 82115	 0.048311	 0.12287	 0.00194	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82104	 20704	 0.062503	 0.060392	 0.00088	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20704	 82112	 0.014682	 0.030045	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20705	 20710	 0.00043	 0.004721	 0.04586	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20705	 82111	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20706	 21148	 0.016554	 0.042558	 0.01054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82111	 20706	 0.012217	 0.031717	 0.0077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20706	 82113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20706	 82113	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20707	 82642	 0.009882	 0.022939	 0.00699	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20708	 21124	 0.053354	 0.12203	 0.00298	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82110	 20708	 0.032189	 0.10623	 0.00172	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20709	 82115	 0.063816	 0.11471	 0.00206	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20710	 21117	 0.001883	 0.02057	 0.20214	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20710	 82114	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81907	 20711	 0.02289	 0.13012	 0.00235	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81909	 20711	 0.017854	 0.12256	 0.00223	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20711	 82315	 0.098101	 0.28143	 0.00433	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81904	 20712	 0.004012	 0.020493	 0.00515	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81908	 20712	 0.003837	 0.019988	 0.00524	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20713	 82116	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20713	 82116	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20714	 20715	 0.001457	 0.016655	 0.00508	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81919	 20714	 0.002296	 0.026258	 0.00735	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20715	 20716	 0.000718	 0.006158	 0.00175	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20716	 20851	 0.002303	 0.025794	 0.0082	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20716	 82117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20716	 82117	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20717	 20962	 0.059122	 0.15199	 0.00235	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82117	 20717	 0.046408	 0.050548	 0.00069	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20717	 82180	 0.16868	 0.3307	 0.00496	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20718	 20723	 0.010697	 0.037281	 0.00864	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20718	 20788	 0.017609	 0.046541	 0.01089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20719	 20785	 0.005564	 0.044422	 0.01095	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20719	 21660	 0.003613	 0.030388	 0.009	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20719	 82118	 0.011292	 0.030745	 0.00677	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20720	 21924	 0.001793	 0.020319	 0.18515	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20720	 82118	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20720	 82280	 0.000785	 0.008891	 0.08095	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20721	 20722	 0.008713	 0.023033	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82119	 20721	 0.009407	 0.03138	 0.0005	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82119	 20722	 0.013538	 0.052666	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20722	 82251	 0.08423	 0.23906	 0.00376	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20723	 82120	 0.005763	 0.020083	 0.00466	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20724	 20726	 0.000174	 0.001905	 0.01851	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20724	 82120	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20724	 82120	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20724	 82280	 0.000299	 0.003446	 0.03021	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20725	 82121	 0.040236	 0.039526	 0.00067	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20726	 82121	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20726	 82121	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20726	 82412	 0.000137	 0.001508	 0.01465	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20727	 21033	 0.049123	 0.11633	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20728	 20730	 0.008329	 0.021623	 0.00525	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20728	 21676	 0.018278	 0.047456	 0.01152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20728	 82122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20728	 82122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20729	 82540	 0.035376	 0.13555	 0.00383	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20729	 82549	 0.049263	 0.16435	 0.00261	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20730	 20731	 0.013077	 0.036467	 0.00765	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20731	 21097	 0.020019	 0.05451	 0.01201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20732	 20737	 0.000419	 0.004685	 0.04377	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20732	 20747	 0.00056	 0.009823	 0.10512	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20732	 82123	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20732	 82123	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20733	 20734	 0.11197	 0.082386	 0.0012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20734	 22093	 0.072118	 0.11822	 0.00209	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20735	 20737	 0.000312	 0.005663	 0.05661	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20735	 21933	 0.000428	 0.00479	 0.04476	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20735	 82124	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20735	 82124	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20736	 20783	 0.023742	 0.062757	 0.01469	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82124	 20736	 0.002458	 0.018515	 0.00514	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20736	 82125	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20736	 82125	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20736	 82126	 0.005396	 0.022837	 0.00514	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20737	 82126	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20738	 21079	 0.035848	 0.1183	 0.00192	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82125	 20738	 0.056261	 0.15966	 0.00251	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82127	 20738	 0.029825	 0.085543	 0.00132	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20739	 82234	 0.13231	 0.21124	 0.00487	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20740	 82128	 0.028761	 0.086568	 0.00169	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20741	 20744	 0.007728	 0.039474	 0.00993	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20741	 20938	 0.009277	 0.054341	 0.01481	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20741	 82128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20741	 82128	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20741	 82719	 0.003099	 0.02242	 0.01206	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20742	 82129	 0.011368	 0.023264	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20743	 82129	 0.007675	 0.015041	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20744	 82129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20744	 82129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20744	 82132	 0.005399	 0.015056	 0.00316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82129	 20745	 0.024307	 0.019236	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82129	 20746	 0.0206	 0.040786	 0.0006	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20747	 21062	 0.001098	 0.012054	 0.11712	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20747	 21621	 0.000278	 0.004875	 0.05215	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20747	 82130	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20747	 82130	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20747	 82131	 0.000436	 0.005066	 0.04379	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20748	 20878	 0.000328	 0.006645	 2.8532	 4345.0	 4562.3	 4779.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20748	 82131	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20748	 82131	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82132	 20748	 0.000145	 0.011567	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 0	 -30.0	 30.0;
	20749	 21062	 0.00067	 0.007731	 0.06778	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20749	 21628	 0.000442	 0.004854	 0.04715	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20749	 22092	 0.000861	 0.015108	 0.16173	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20749	 82133	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20749	 82133	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20750	 82135	 0.003745	 0.012493	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20751	 20762	 0.000193	 0.002123	 0.02062	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20751	 82134	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20752	 20762	 0.00014	 0.00158	 0.01439	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20752	 82136	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20753	 20765	 0.019087	 0.014043	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82137	 20753	 0.007398	 0.018813	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20753	 82139	 0.004161	 0.018331	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20753	 82145	 0.013349	 0.11338	 0.00265	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82137	 20754	 0.022562	 0.01631	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82135	 20755	 0.009409	 0.018628	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82137	 20755	 0.00698	 0.012784	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20756	 20758	 0.017137	 0.017309	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82135	 20756	 0.008917	 0.022923	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20757	 20758	 0.016009	 0.011778	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82135	 20757	 0.014167	 0.02805	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20757	 82138	 0.016839	 0.025793	 0.00045	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20758	 20765	 0.019562	 0.035297	 0.00051	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20758	 20905	 0.004475	 0.025143	 0.00047	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20759	 20760	 0.000694	 0.003874	 0.00099	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20759	 20906	 0.00034	 0.001935	 0.00056	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20760	 20761	 0.000939	 0.003287	 0.00109	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20761	 20764	 0.001836	 0.007142	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20761	 82138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20761	 82138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20762	 20766	 0.00013	 0.002038	 0.02124	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20762	 82139	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20762	 82139	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82139	 20763	 0.01578	 0.024172	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20764	 82140	 0.003694	 0.013058	 0.00294	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20766	 20773	 0.000169	 0.002179	 0.03658	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20766	 82140	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20767	 20918	 0.001034	 0.007479	 0.00402	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20767	 82142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20767	 82142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20767	 82144	 0.001047	 0.016494	 0.00562	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82142	 20768	 0.051645	 0.037997	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20768	 82226	 0.024293	 0.062447	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20769	 20770	 0.001677	 0.023927	 0.00799	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20769	 20916	 0.006978	 0.023939	 0.00574	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20769	 82276	 0.009497	 0.065871	 0.03864	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20770	 20771	 0.001733	 0.017512	 0.00515	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20770	 82143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20770	 82143	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20771	 21870	 0.00352	 0.03019	 0.00859	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20772	 20775	 0.002776	 0.027549	 0.00749	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20772	 82144	 0.001376	 0.01522	 0.00456	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81883	 20773	 0.002448	 0.031503	 0.53777	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20773	 82144	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82143	 20774	 0.042368	 0.098365	 0.00146	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82145	 20774	 0.017603	 0.040257	 0.00098	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20775	 21118	 0.004696	 0.039493	 0.0117	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20776	 20777	 0.002989	 0.010253	 0.00246	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20776	 20779	 0.002576	 0.008011	 0.00167	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20776	 22029	 0.010321	 0.031067	 0.00972	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20777	 20778	 0.001022	 0.00709	 0.00202	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20777	 20780	 0.011162	 0.038293	 0.00917	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20778	 21771	 0.005501	 0.028122	 0.00766	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20779	 22029	 0.008191	 0.026716	 0.00709	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20780	 20781	 0.008434	 0.041591	 0.01125	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20781	 82247	 0.007744	 0.04536	 0.01236	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20782	 21080	 0.097581	 0.19322	 0.00284	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20782	 82251	 0.063245	 0.20084	 0.00352	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20783	 20787	 0.007906	 0.020525	 0.00498	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20784	 21944	 0.059387	 0.11374	 0.00179	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20785	 20786	 0.007067	 0.017765	 0.0046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20785	 82146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20785	 82146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20786	 20788	 0.003187	 0.008887	 0.00187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20786	 82147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20786	 82147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20787	 20788	 0.00215	 0.005581	 0.00135	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20787	 82148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20787	 82148	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20788	 82149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20788	 82149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82146	 20789	 0.042622	 0.0581	 0.00129	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82147	 20789	 0.02471	 0.019369	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82149	 20789	 0.025442	 0.018392	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20790	 22058	 0.008001	 0.059967	 0.01463	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20790	 82150	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20790	 82150	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20790	 82151	 0.003629	 0.040838	 0.01073	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20791	 82152	 0.17102	 0.18813	 0.00251	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20791	 82190	 0.21288	 0.21506	 0.00285	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20792	 20857	 0.001808	 0.019849	 0.19298	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20792	 21024	 0.000403	 0.007078	 0.07573	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20792	 21714	 0.001247	 0.014401	 0.1263	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20792	 82151	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20793	 20964	 0.008846	 0.05928	 0.01816	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20793	 82153	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20793	 82153	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81868	 20794	 0.28322	 0.41308	 0.00934	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82153	 20794	 0.065764	 0.18864	 0.0029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20794	 82155	 0.035728	 0.073115	 0.0018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20795	 21617	 0.001961	 0.014528	 0.00744	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20795	 82154	 0.003066	 0.027799	 0.01453	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81871	 20796	 0.000381	 0.004577	 0.04527	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20796	 82154	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20796	 82154	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20797	 20798	 0.001715	 0.005882	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81898	 20797	 0.008461	 0.023035	 0.00507	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20797	 82155	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20797	 82155	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20798	 20799	 0.001088	 0.004605	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82154	 20799	 0.004667	 0.018685	 0.00471	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20800	 20803	 0.030756	 0.079063	 0.00122	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20800	 20809	 0.047279	 0.12154	 0.00188	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20800	 82598	 0.032217	 0.082818	 0.00128	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20801	 20802	 0.059997	 0.047481	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20801	 82157	 0.017642	 0.086092	 0.00149	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20801	 84073	 0.015698	 0.052367	 0.00083	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20803	 20804	 0.032122	 0.072863	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20804	 84072	 0.033946	 0.067211	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81883	 20805	 5.3e-05	 0.000533	 0.00888	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81883	 20805	 5.3e-05	 0.000533	 0.00888	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81890	 20805	 5.5e-05	 0.000902	 0.01408	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20805	 82156	 0.000109	 0.008705	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20806	 21785	 0.009626	 0.064589	 0.0156	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82156	 20806	 0.002635	 0.011154	 0.00251	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20806	 82158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20806	 82158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81885	 20807	 0.027631	 0.054706	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81892	 20807	 0.02243	 0.041706	 0.00098	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20807	 82159	 0.036954	 0.10487	 0.00165	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20808	 21785	 0.003709	 0.031811	 0.00905	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81891	 20808	 0.008331	 0.038221	 0.00979	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20808	 82159	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20808	 82159	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82158	 20809	 0.14571	 0.10721	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82159	 20809	 0.040199	 0.10627	 0.00193	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20810	 20812	 0.006005	 0.031924	 0.00741	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20810	 21789	 0.024054	 0.063582	 0.01488	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20810	 82160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20810	 82160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20811	 20812	 0.006449	 0.019014	 0.00442	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20811	 20815	 0.011782	 0.0397	 0.00987	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82114	 20812	 0.00652	 0.10498	 0.03433	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20812	 82161	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20812	 82161	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82160	 20813	 0.031552	 0.081774	 0.00155	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82161	 20813	 0.016306	 0.036987	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82161	 20814	 0.036961	 0.11351	 0.00213	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20814	 82600	 0.044903	 0.11902	 0.00302	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20815	 21123	 0.017801	 0.045763	 0.01133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20815	 82162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20815	 82162	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20816	 20817	 0.00319	 0.025626	 0.0072	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20816	 21901	 0.004278	 0.01926	 0.00512	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20816	 82163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20816	 82163	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20817	 20822	 0.00448	 0.015676	 0.00519	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20817	 21901	 0.006595	 0.041775	 0.01134	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20817	 82165	 0.000911	 0.01146	 0.00355	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20818	 20824	 0.005592	 0.025653	 0.00657	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20818	 21898	 0.026536	 0.079486	 0.01791	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20818	 27775	 0.003341	 0.035847	 0.00933	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 20818	 0.011569	 0.099264	 0.02827	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20818	 82164	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20818	 82164	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82164	 20819	 0.038686	 0.11096	 0.00171	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20819	 82166	 0.005714	 0.044531	 0.00083	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20819	 82168	 0.038108	 0.10814	 0.0017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20820	 21688	 0.000597	 0.008444	 0.08053	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20820	 82165	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20821	 21694	 0.032049	 0.073296	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20821	 82167	 0.019618	 0.050431	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20822	 20823	 0.005844	 0.016296	 0.00342	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20822	 82167	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20822	 82167	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20824	 25691	 0.009612	 0.032975	 0.0079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20824	 82168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20824	 82168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20825	 20831	 7.6e-05	 0.001328	 0.01421	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20825	 20837	 5.7e-05	 0.000655	 0.00641	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20825	 82169	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20826	 20828	 0.000299	 0.003018	 0.00089	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20826	 20840	 0.000717	 0.003291	 0.00084	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82169	 20826	 0.000236	 0.0027	 0.00082	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20827	 20841	 7.8e-05	 0.000888	 0.00809	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20827	 20847	 0.000277	 0.003135	 0.02854	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20827	 82171	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20827	 82171	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82171	 20828	 0.000315	 0.004586	 0.00147	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20828	 82172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20828	 82172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20829	 20853	 0.005965	 0.013641	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82172	 20829	 0.003313	 0.007515	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20830	 20833	 0.001399	 0.004712	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82171	 20830	 0.000943	 0.003773	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20831	 20841	 0.000187	 0.002156	 0.0189	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20831	 20959	 0.00077	 0.014238	 0.13686	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20831	 82173	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20832	 20848	 0.032884	 0.070469	 0.00123	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20832	 82175	 0.003868	 0.020611	 0.00036	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20832	 82185	 0.022576	 0.064751	 0.001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20832	 82188	 0.028449	 0.022514	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20833	 82175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20833	 82175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82174	 20834	 0.002975	 0.007647	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20834	 82176	 0.004821	 0.011026	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20835	 20836	 0.000299	 0.004313	 0.00137	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82173	 20835	 0.00034	 0.002784	 0.00179	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20835	 82176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20835	 82176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20836	 82181	 0.000241	 0.003751	 0.00116	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20837	 20842	 0.000128	 0.00147	 0.0144	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20837	 82177	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20837	 82177	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20838	 20839	 0.014134	 0.011186	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20839	 20843	 0.025086	 0.025092	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82170	 20839	 0.005968	 0.015776	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20839	 82178	 0.00699	 0.012293	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20839	 82180	 0.013202	 0.030193	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82177	 20840	 0.000723	 0.007661	 0.00227	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20840	 82178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20840	 82178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20840	 82179	 0.000389	 0.005857	 0.00175	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20841	 21014	 0.001429	 0.019866	 0.19658	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20841	 82179	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20842	 20852	 0.000405	 0.00487	 0.04818	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20842	 82181	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20842	 82181	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20844	 21777	 0.00644	 0.030696	 0.00889	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82177	 20844	 0.003041	 0.018894	 0.00533	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82180	 20845	 0.037862	 0.056764	 0.00103	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20846	 20847	 0.000219	 0.002434	 0.02295	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20846	 22078	 0.00123	 0.022319	 0.22336	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20846	 82182	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20846	 82182	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20847	 20954	 0.000965	 0.017059	 0.15967	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20847	 82183	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82184	 20848	 0.013994	 0.036267	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20849	 20851	 0.002314	 0.026446	 0.00807	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20849	 21363	 0.002332	 0.016168	 0.00948	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20850	 20854	 0.002447	 0.013174	 0.00362	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20850	 21115	 0.002748	 0.045792	 0.01393	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82179	 20850	 0.004828	 0.026587	 0.0096	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20850	 82185	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20850	 82185	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20851	 82186	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20851	 82186	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20852	 21109	 0.000514	 0.009314	 0.09312	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20852	 82187	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20852	 82187	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82170	 20853	 0.006515	 0.012899	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82176	 20853	 0.008675	 0.020141	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82173	 20854	 0.00096	 0.005623	 0.00153	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20854	 82188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20854	 82188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20855	 21718	 0.010687	 0.031509	 0.00733	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20855	 82189	 0.007674	 0.020281	 0.00475	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20856	 82189	 0.003481	 0.012305	 0.00277	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20857	 20860	 0.000535	 0.006057	 0.05515	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81871	 20857	 0.001223	 0.013355	 0.13116	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20857	 82189	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20857	 82189	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20858	 21618	 0.017562	 0.060254	 0.01444	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82189	 20858	 0.002824	 0.015048	 0.00422	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20859	 21701	 0.006631	 0.046901	 0.01287	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82189	 20859	 0.003807	 0.028203	 0.01445	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20859	 82190	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20859	 82190	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20860	 20861	 0.000186	 0.002106	 0.01917	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20860	 82191	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20860	 82191	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20861	 82192	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20861	 82192	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20862	 20866	 0.004161	 0.010803	 0.00262	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20862	 20868	 0.0013	 0.004529	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20862	 82193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20862	 82193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20863	 20869	 0.034738	 0.06878	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82193	 20863	 0.00322	 0.022655	 0.00045	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20863	 82194	 0.003976	 0.033073	 0.00063	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20864	 20865	 0.000122	 0.001392	 0.01257	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20864	 20873	 0.000273	 0.002995	 0.02909	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20865	 21691	 0.00078	 0.008643	 0.0823	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20865	 82194	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20865	 82194	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20865	 82198	 0.000622	 0.008518	 0.08681	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20866	 20874	 0.00798	 0.021424	 0.00486	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20867	 20868	 0.001353	 0.005416	 0.00136	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20867	 20889	 0.002168	 0.011894	 0.00314	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20869	 82207	 0.011216	 0.063758	 0.00115	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20870	 24084	 0.003887	 0.027361	 0.01556	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20870	 82206	 0.001103	 0.018372	 0.00559	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20871	 20872	 0.001009	 0.011303	 0.00359	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20871	 21183	 0.004994	 0.027402	 0.00724	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20871	 21184	 0.014423	 0.043801	 0.00959	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20871	 24084	 0.011288	 0.035104	 0.00733	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20871	 82195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20871	 82195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20872	 82199	 0.00491	 0.042289	 0.02456	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20873	 21690	 0.000554	 0.006275	 0.05713	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20873	 24085	 0.001475	 0.016424	 0.15497	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20873	 82196	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20873	 82196	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20874	 82197	 0.006556	 0.030079	 0.00771	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20875	 21604	 0.00055	 0.006095	 0.05803	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20875	 82197	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20875	 82197	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20876	 21163	 0.006543	 0.022804	 0.00529	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82197	 20876	 0.004086	 0.010271	 0.00266	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20876	 82512	 0.007918	 0.030806	 0.00823	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82197	 20877	 0.009414	 0.022685	 0.00641	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20877	 82199	 0.007744	 0.027373	 0.00617	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20878	 82198	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20878	 82198	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20878	 82198	 0.000158	 0.012644	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82199	 20878	 0.000191	 0.015285	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 0	 -30.0	 30.0;
	82199	 20878	 0.000191	 0.015285	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 0	 -30.0	 30.0;
	20879	 21848	 0.008291	 0.021314	 0.00528	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82199	 20879	 0.002836	 0.013228	 0.00328	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20879	 82200	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20879	 82200	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20880	 21847	 0.003285	 0.008681	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20880	 82202	 0.003503	 0.009259	 0.00217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20881	 20884	 0.001638	 0.004116	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20881	 82201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20881	 82201	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82198	 20882	 0.000379	 0.004288	 0.03904	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20882	 82202	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82202	 20883	 0.001382	 0.008025	 0.00189	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20883	 82204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20883	 82204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20884	 20897	 0.002218	 0.005758	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82202	 20884	 0.003754	 0.010221	 0.00225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20885	 22301	 0.017838	 0.045859	 0.01136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82202	 20885	 0.004584	 0.014328	 0.00415	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82204	 20886	 0.075356	 0.059069	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20886	 82205	 0.017776	 0.045207	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20886	 82207	 0.01892	 0.037461	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20887	 20891	 0.002245	 0.005644	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20887	 20897	 0.002049	 0.005415	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82199	 20887	 0.004287	 0.021538	 0.00561	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20887	 82205	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20887	 82205	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20887	 82206	 0.001148	 0.007395	 0.00194	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82198	 20888	 0.000431	 0.004725	 0.0459	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20888	 82206	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20889	 20892	 0.002109	 0.015583	 0.0045	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82205	 20890	 0.070279	 0.055619	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20890	 82208	 0.023732	 0.036355	 0.00051	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20891	 20892	 0.003468	 0.00967	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82199	 20892	 0.001186	 0.010783	 0.00272	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20892	 82208	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20892	 82208	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20892	 82209	 0.002258	 0.008783	 0.00235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82198	 20893	 0.000152	 0.001759	 0.01542	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20893	 82209	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20893	 82209	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82202	 20894	 0.004896	 0.012711	 0.00309	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82209	 20894	 0.000739	 0.005315	 0.00141	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20894	 82210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20894	 82210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20895	 20896	 0.009184	 0.0114	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82205	 20895	 0.039939	 0.031607	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82210	 20896	 0.002618	 0.011667	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82209	 20897	 0.001845	 0.010239	 0.00311	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20898	 82213	 0.089999	 0.070547	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20899	 20901	 0.000282	 0.00204	 0.0011	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20899	 82211	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20899	 82211	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20899	 82712	 0.002767	 0.035439	 0.01058	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20900	 82212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20900	 82212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20901	 20902	 0.000635	 0.004635	 0.00119	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20902	 20903	 0.000618	 0.006663	 0.00191	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81884	 20902	 0.065872	 0.16956	 0.04205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20902	 82213	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20902	 82213	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20903	 20904	 0.001739	 0.012584	 0.00677	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20903	 82214	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20903	 82214	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20904	 21786	 0.002241	 0.03053	 0.01091	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20904	 82215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20904	 82215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20905	 82216	 0.003665	 0.010511	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20905	 82217	 0.004163	 0.022179	 0.00039	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20906	 20915	 0.000708	 0.004066	 0.00115	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20907	 20908	 0.001018	 0.003492	 0.00084	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20907	 20915	 0.001069	 0.003667	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20907	 82216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20907	 82216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20908	 20909	 0.000619	 0.002889	 0.00072	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20909	 82217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20909	 82217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20909	 82218	 0.000569	 0.005635	 0.00173	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20910	 21023	 0.00068	 0.010311	 0.11574	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20910	 82218	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82217	 20911	 0.01258	 0.011797	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20911	 82220	 0.01029	 0.017334	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82218	 20912	 0.001015	 0.006535	 0.00171	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20912	 82220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20912	 82220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20912	 82221	 0.00089	 0.00506	 0.00146	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20913	 82221	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20914	 20918	 0.000691	 0.008206	 0.00286	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20914	 20919	 0.000794	 0.005406	 0.00184	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82221	 20914	 0.000394	 0.003391	 0.00197	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82221	 20915	 0.000976	 0.004029	 0.00095	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20916	 82223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20916	 82223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20917	 82227	 0.10148	 0.080314	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20918	 82224	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20918	 82224	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20919	 20920	 0.001152	 0.004613	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20919	 82225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20919	 82225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20920	 82226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20920	 82226	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81894	 20921	 0.013891	 0.037294	 0.00845	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20921	 82227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20921	 82227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20921	 82274	 0.007942	 0.042217	 0.0098	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20922	 20923	 0.034459	 0.044844	 0.00063	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82220	 20922	 0.026295	 0.055266	 0.00101	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82227	 20922	 0.027397	 0.050942	 0.00119	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82219	 20923	 0.026015	 0.053463	 0.00102	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20923	 82228	 0.011691	 0.056408	 0.001	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20924	 21026	 0.000441	 0.005125	 0.0443	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20924	 82228	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20924	 82228	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20925	 20928	 0.000556	 0.006304	 0.05739	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20925	 21940	 0.000457	 0.00801	 0.0857	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20925	 82229	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20925	 82229	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20926	 20927	 0.015464	 0.044794	 0.0108	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20926	 22043	 0.009143	 0.031865	 0.00739	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82116	 20926	 0.014638	 0.08789	 0.02663	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82229	 20926	 0.001569	 0.017195	 0.00477	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20926	 82230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20926	 82230	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20927	 22002	 0.012703	 0.042803	 0.01064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20928	 20929	 0.000503	 0.005807	 0.05091	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20928	 82231	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20928	 82231	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20929	 82232	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20929	 82232	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20930	 20934	 0.048436	 0.11078	 0.0027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82160	 20930	 0.037779	 0.14698	 0.00245	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20930	 82599	 0.12433	 0.12696	 0.00198	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20931	 26359	 0.018792	 0.049669	 0.01163	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20931	 82233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20931	 82233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20932	 20933	 0.029595	 0.075265	 0.00119	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82233	 20932	 0.026623	 0.076359	 0.00117	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20933	 20934	 0.029157	 0.12993	 0.00221	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20933	 82598	 0.041204	 0.15789	 0.00446	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82215	 20934	 0.058241	 0.11532	 0.00169	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20935	 21615	 0.046009	 0.13197	 0.00203	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20935	 82234	 0.052903	 0.089121	 0.00127	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20936	 20939	 0.005706	 0.02169	 0.00607	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20936	 21605	 0.031419	 0.10591	 0.02634	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20936	 82234	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20936	 82234	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20936	 82235	 0.01371	 0.036235	 0.00848	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82234	 20937	 0.044123	 0.12054	 0.00205	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20938	 20939	 0.005806	 0.031261	 0.00859	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20940	 21608	 0.000976	 0.017712	 0.17718	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20940	 21619	 0.000515	 0.005828	 0.05306	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20940	 82235	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20940	 82235	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20941	 21754	 0.19435	 0.12584	 0.0024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81863	 20941	 0.056051	 0.10985	 0.00165	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20942	 82236	 0.070023	 0.1781	 0.00282	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20942	 82237	 0.078571	 0.15558	 0.00228	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20942	 82684	 0.020975	 0.11176	 0.00196	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20943	 20945	 0.010923	 0.028079	 0.00695	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20943	 21721	 0.009098	 0.030351	 0.0077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20943	 22046	 0.003085	 0.031433	 0.0081	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81900	 20943	 0.02172	 0.073196	 0.0182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20943	 82236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20943	 82236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20944	 20946	 0.004066	 0.019841	 0.00548	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20944	 21160	 0.007247	 0.038525	 0.00894	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20945	 20946	 0.0058	 0.017099	 0.00398	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81862	 20946	 0.003517	 0.041768	 0.01455	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20946	 82237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20946	 82237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82237	 20947	 0.011971	 0.030771	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20948	 20950	 0.004705	 0.023532	 0.00042	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20948	 82238	 0.002182	 0.013208	 0.00041	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20949	 20963	 0.009259	 0.032271	 0.00748	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20949	 82238	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20949	 82238	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20949	 82240	 0.000691	 0.007782	 0.00225	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81920	 20950	 0.072582	 0.28243	 0.00472	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20951	 82239	 0.017127	 0.02126	 0.00046	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20952	 82239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20952	 82239	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20952	 82240	 0.005094	 0.017164	 0.00427	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82238	 20953	 0.01307	 0.030343	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82239	 20953	 0.011055	 0.021888	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20954	 21072	 0.001452	 0.016764	 0.14704	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20954	 22042	 0.000949	 0.010755	 0.09794	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20954	 82240	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82238	 20955	 0.012485	 0.029565	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82241	 20955	 0.00628	 0.016644	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82241	 20956	 0.021993	 0.12358	 0.00229	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20956	 82301	 0.216	 0.29458	 0.00654	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20957	 21076	 0.056699	 0.14576	 0.00226	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82241	 20957	 0.038395	 0.10489	 0.00178	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20957	 82406	 0.12098	 0.1475	 0.00236	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20958	 21363	 0.004986	 0.040059	 0.01126	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20958	 82242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20958	 82242	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20958	 82243	 0.005993	 0.01584	 0.00371	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20959	 20960	 0.000122	 0.001383	 0.01259	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20959	 82243	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20959	 82243	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20960	 22042	 0.001138	 0.012675	 0.11956	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20960	 82244	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20961	 20963	 0.009127	 0.024849	 0.00547	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82244	 20961	 0.002638	 0.00905	 0.00217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82117	 20962	 0.038634	 0.11081	 0.0017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82186	 20962	 0.073015	 0.1431	 0.00215	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82242	 20962	 0.015844	 0.070209	 0.00211	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20963	 21090	 0.008859	 0.034464	 0.00921	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20964	 20965	 0.006066	 0.035529	 0.00968	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20965	 21650	 0.005252	 0.029304	 0.00749	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20965	 82565	 0.012703	 0.033574	 0.00786	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20966	 20967	 0.000361	 0.006257	 0.06852	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20966	 21339	 0.001797	 0.02002	 0.18896	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20966	 21708	 0.000626	 0.007005	 0.06545	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20966	 22034	 0.002086	 0.02291	 0.22281	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20966	 82246	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20966	 82246	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81861	 20967	 0.003638	 0.040616	 0.38448	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81866	 20967	 0.001312	 0.015149	 0.13287	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20967	 82247	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20968	 21905	 0.069716	 0.13664	 0.00205	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82248	 20968	 0.055595	 0.10183	 0.00176	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20968	 82564	 0.15023	 0.38955	 0.00737	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20969	 20970	 0.001555	 0.004584	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20969	 21906	 0.0126	 0.043227	 0.01036	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82247	 20970	 0.006859	 0.017805	 0.00432	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20971	 20972	 0.067803	 0.13425	 0.00197	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82153	 20971	 0.022162	 0.10061	 0.00218	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82248	 20971	 0.16117	 0.1628	 0.00216	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20972	 21637	 0.11376	 0.26025	 0.00636	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81918	 20972	 0.020425	 0.078579	 0.00134	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20973	 21950	 0.000813	 0.009058	 0.08543	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20973	 82249	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20973	 82249	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20974	 20975	 0.004271	 0.014651	 0.00351	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20974	 21949	 0.004846	 0.027039	 0.00691	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20974	 82250	 0.008804	 0.02937	 0.00745	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20975	 20986	 0.003849	 0.013938	 0.00299	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20976	 21072	 0.001283	 0.016481	 0.15509	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20976	 21950	 0.000908	 0.010551	 0.09122	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20976	 82250	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20976	 82412	 0.000505	 0.009152	 0.0915	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20977	 82252	 0.044662	 0.058699	 0.0008	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20978	 20979	 0.000317	 0.003412	 0.00182	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82250	 20978	 0.004486	 0.028412	 0.00771	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20978	 82252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20978	 82252	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20978	 82253	 0.000827	 0.010595	 0.00316	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20978	 82413	 0.002899	 0.03374	 0.00992	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20979	 82260	 0.000278	 0.003933	 0.0013	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20980	 20984	 0.002302	 0.008376	 0.00256	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20980	 20987	 0.002063	 0.008729	 0.00196	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81916	 20980	 0.000705	 0.005665	 0.00159	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20981	 20988	 0.002512	 0.006743	 0.00153	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20981	 20994	 0.003016	 0.011853	 0.0031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20982	 20985	 0.000148	 0.001624	 0.01577	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20982	 21003	 0.000292	 0.003687	 0.03288	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20982	 82253	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20982	 82253	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20983	 20988	 0.000667	 0.005903	 0.00324	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20983	 82261	 0.000856	 0.013077	 0.00421	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20984	 82254	 0.002177	 0.008557	 0.00224	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20985	 82254	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20985	 82254	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82254	 20986	 0.001547	 0.005468	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20987	 20988	 0.000722	 0.004364	 0.00111	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81916	 20988	 0.002824	 0.01755	 0.00495	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20989	 21375	 0.002158	 0.0183	 0.01096	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20989	 21377	 0.001486	 0.015744	 0.00467	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20989	 82257	 0.000741	 0.007792	 0.00438	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20990	 82256	 0.006661	 0.021982	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20990	 82258	 0.016089	 0.037353	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20991	 20994	 0.002499	 0.009722	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20991	 82257	 0.00188	 0.007315	 0.00195	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20992	 20993	 0.000184	 0.002048	 0.01931	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20992	 21434	 0.000129	 0.002149	 0.02029	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20992	 82255	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20993	 82257	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20994	 20997	 0.001488	 0.005387	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20994	 82436	 0.005097	 0.020406	 0.00514	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82255	 20995	 0.001994	 0.007049	 0.00159	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20995	 82436	 0.001521	 0.006976	 0.00179	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20996	 82269	 0.025204	 0.027721	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20997	 82263	 0.001576	 0.006194	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20998	 21001	 0.000173	 0.00193	 0.0182	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20998	 82259	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20998	 82259	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20999	 21000	 0.001497	 0.006092	 0.00148	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20999	 82261	 0.001152	 0.004482	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21000	 21009	 0.001368	 0.005789	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21000	 82260	 0.001756	 0.004232	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21001	 21008	 0.000131	 0.001515	 0.01328	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21001	 82260	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21001	 82260	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21002	 21008	 0.000135	 0.001502	 0.01416	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21002	 82261	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21003	 21010	 0.000183	 0.002049	 0.01914	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21003	 82263	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82259	 21004	 0.00059	 0.007006	 0.00244	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21004	 82413	 0.001068	 0.009455	 0.00519	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21005	 21006	 0.008128	 0.020894	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82262	 21005	 0.011544	 0.026522	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21005	 82266	 0.006578	 0.016728	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21006	 82269	 0.006228	 0.014457	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21007	 82266	 0.036241	 0.026198	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21007	 82267	 0.030379	 0.022351	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21007	 82421	 0.031149	 0.040938	 0.00056	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21008	 21400	 0.00021	 0.003685	 0.03943	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21008	 82265	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21009	 21011	 0.00211	 0.011946	 0.00296	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82265	 21009	 0.001902	 0.005028	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21009	 82267	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21009	 82267	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21010	 21434	 0.000144	 0.001632	 0.01486	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21010	 82268	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21011	 21398	 0.001028	 0.004	 0.00107	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82268	 21011	 0.001128	 0.016681	 0.00574	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21011	 82270	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21011	 82270	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21011	 82413	 0.000807	 0.007411	 0.00636	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21012	 82272	 0.12737	 0.12775	 0.00207	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21012	 82411	 0.064866	 0.085254	 0.00117	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82258	 21013	 0.019345	 0.093341	 0.00165	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21014	 21053	 0.001267	 0.013902	 0.13509	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21014	 21541	 0.000923	 0.01163	 0.17732	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21014	 21873	 0.001	 0.01133	 0.10318	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21014	 82271	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82271	 21015	 0.00264	 0.006128	 0.00187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21015	 82273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21015	 82273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82273	 21016	 0.023957	 0.026094	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82272	 21017	 0.016394	 0.032459	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82273	 21017	 0.022521	 0.022747	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21018	 21060	 0.067533	 0.1568	 0.00233	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82272	 21018	 0.017484	 0.085318	 0.00147	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21019	 21021	 0.029182	 0.052655	 0.00076	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21019	 82495	 0.022613	 0.10077	 0.00171	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21020	 82490	 0.031992	 0.082914	 0.00157	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82150	 21022	 0.06244	 0.16052	 0.00248	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82227	 21022	 0.071412	 0.15304	 0.00268	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21022	 82275	 0.079209	 0.092852	 0.00161	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21023	 21024	 0.000454	 0.005235	 0.04589	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21023	 82274	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21024	 21025	 0.000345	 0.003842	 0.03623	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21024	 21714	 0.00151	 0.01815	 0.17967	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21024	 82276	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21025	 21026	 0.000249	 0.002769	 0.02611	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82228	 21027	 0.23023	 0.25083	 0.00342	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82277	 21027	 0.069436	 0.16444	 0.00301	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21028	 21464	 0.00013	 0.001478	 0.01346	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21028	 82278	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21028	 82280	 0.000179	 0.00286	 0.02891	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21029	 82281	 0.016141	 0.041832	 0.00079	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21030	 21381	 3.6e-05	 0.000733	 0.26505	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21030	 21483	 5.7e-05	 0.001179	 0.40787	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21030	 82280	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21030	 82280	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21030	 82280	 0.000148	 0.011878	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21031	 21032	 0.013799	 0.027043	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21032	 21037	 0.049434	 0.052791	 0.00112	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82281	 21032	 0.014441	 0.069358	 0.00134	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82281	 21033	 0.015255	 0.093788	 0.00169	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21033	 82282	 0.036729	 0.091166	 0.00152	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21034	 21668	 0.06907	 0.17757	 0.00275	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21034	 82282	 0.036101	 0.091812	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21035	 21036	 0.006083	 0.015636	 0.00387	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21035	 82282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21035	 82282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21036	 21045	 0.012063	 0.03364	 0.00706	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21036	 21048	 0.009128	 0.029773	 0.0079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21036	 82283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21036	 82283	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82283	 21037	 0.13851	 0.10962	 0.00138	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21037	 82284	 0.030388	 0.060165	 0.00088	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82278	 21038	 0.005288	 0.013976	 0.00327	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21038	 82284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21038	 82284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21038	 82454	 0.004488	 0.015397	 0.00369	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21039	 21046	 0.042783	 0.043212	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21039	 82285	 0.021105	 0.054252	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21040	 82285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21040	 82285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21040	 82454	 0.003115	 0.012471	 0.00314	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21041	 21045	 0.002636	 0.006843	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21041	 82286	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21041	 82286	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21041	 82454	 0.001491	 0.012787	 0.00364	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21042	 21567	 0.004043	 0.013868	 0.00332	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21042	 21672	 0.002137	 0.011133	 0.00292	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21043	 21044	 0.003766	 0.009954	 0.00233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21043	 82287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21043	 82287	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21044	 21045	 0.001968	 0.004948	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82286	 21046	 0.038163	 0.050158	 0.00069	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82287	 21046	 0.056859	 0.048596	 0.00091	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21047	 21674	 0.032766	 0.07759	 0.00142	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82283	 21047	 0.12616	 0.099847	 0.00126	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82287	 21047	 0.11188	 0.088547	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21048	 21769	 0.009281	 0.032346	 0.0075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21048	 82288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21048	 82288	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21049	 21055	 0.044462	 0.068112	 0.00096	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21050	 21055	 0.090603	 0.11908	 0.00163	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21051	 21052	 0.005003	 0.023332	 0.00578	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21051	 82289	 0.005508	 0.022414	 0.00546	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21052	 21372	 0.00412	 0.022988	 0.00587	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21053	 82289	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21054	 21055	 0.012793	 0.019961	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21055	 21056	 0.006648	 0.013973	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82290	 21055	 0.007634	 0.046935	 0.00085	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21056	 21058	 0.00651	 0.01395	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21057	 21061	 0.015736	 0.083845	 0.00147	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82290	 21057	 0.005646	 0.01732	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82290	 21057	 0.005646	 0.01732	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21057	 82291	 0.002269	 0.018879	 0.00036	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21058	 82291	 0.004753	 0.009727	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21059	 21779	 0.005991	 0.066266	 0.01988	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82289	 21059	 0.000645	 0.009196	 0.00307	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21059	 82291	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21059	 82291	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82290	 21060	 0.067727	 0.12594	 0.00295	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82212	 21061	 0.037648	 0.1617	 0.00296	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21062	 21072	 8.5e-05	 0.000983	 0.00862	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21062	 82292	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21062	 82292	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21063	 82293	 0.008383	 0.016598	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21064	 21078	 0.004376	 0.010158	 0.00309	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82292	 21064	 0.002092	 0.005432	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21064	 82293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21064	 82293	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21065	 21066	 0.001556	 0.00404	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21065	 21069	 0.00165	 0.00436	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21066	 21078	 0.003783	 0.010298	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21067	 82294	 0.013047	 0.024985	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21068	 21080	 0.031195	 0.079334	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21068	 21081	 0.056805	 0.041064	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21068	 82296	 0.023741	 0.037895	 0.00087	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21069	 82294	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21069	 82294	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21069	 82295	 0.001896	 0.005011	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21070	 21071	 0.027485	 0.021751	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21070	 21073	 0.061122	 0.039571	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82294	 21070	 0.007695	 0.011786	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21071	 21081	 0.050264	 0.035605	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21071	 82296	 0.019313	 0.032208	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21072	 21950	 0.000524	 0.008189	 0.0863	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21072	 82295	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82296	 21073	 0.010014	 0.025466	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21073	 82297	 0.010922	 0.023318	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21074	 21075	 0.001877	 0.00644	 0.00154	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82295	 21074	 0.002837	 0.007724	 0.0017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21075	 21948	 0.005432	 0.017717	 0.0047	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82238	 21076	 0.085966	 0.2466	 0.00379	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82296	 21076	 0.056071	 0.14823	 0.00269	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21076	 82297	 0.022757	 0.10141	 0.00172	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82295	 21077	 0.004001	 0.013945	 0.00323	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21077	 82297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21077	 82297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82133	 21078	 0.010506	 0.029471	 0.00759	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21079	 21080	 0.034779	 0.091939	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21080	 21081	 0.039226	 0.076877	 0.00115	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21082	 22100	 0.031516	 0.096787	 0.00182	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21082	 82298	 0.019605	 0.075426	 0.00129	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21083	 21084	 0.000546	 0.00673	 0.00217	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21083	 82300	 0.000987	 0.007106	 0.00593	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21084	 21085	 0.000502	 0.005414	 0.00155	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21085	 82298	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21085	 82298	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21086	 21087	 0.001772	 0.016093	 0.00524	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21086	 22080	 0.001793	 0.023986	 0.00656	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 21086	 0.005293	 0.078532	 0.02422	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21086	 82299	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21086	 82299	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21087	 82300	 0.000971	 0.010294	 0.00306	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21088	 21089	 0.000187	 0.002168	 0.01874	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21088	 21691	 0.002568	 0.029129	 0.2657	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21088	 22038	 0.000377	 0.006607	 0.07069	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21088	 82300	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21089	 82302	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21089	 82302	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82302	 21090	 0.008724	 0.033162	 0.00928	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21091	 21092	 0.000914	 0.008775	 0.00255	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21091	 21126	 0.003706	 0.021068	 0.0061	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82114	 21091	 0.014711	 0.050471	 0.01209	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21092	 21094	 0.000612	 0.004243	 0.00249	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21092	 82303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21092	 82303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82115	 21093	 0.089716	 0.16189	 0.00234	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21093	 82305	 0.00427	 0.024029	 0.00052	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21093	 82307	 0.021424	 0.12178	 0.0022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21094	 21096	 0.000282	 0.002494	 0.00137	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21094	 82304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21094	 82304	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82303	 21095	 0.00573	 0.030528	 0.00054	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82304	 21095	 0.007447	 0.017109	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21095	 82305	 0.002078	 0.017255	 0.00042	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21096	 21098	 0.002133	 0.027759	 0.00802	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21096	 82305	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21096	 82305	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21097	 21099	 0.017417	 0.048574	 0.0102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21097	 21334	 0.008482	 0.066845	 0.01956	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21097	 82306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21097	 82306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21098	 21099	 0.005448	 0.024531	 0.00653	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81913	 21098	 0.009437	 0.074028	 0.03385	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21098	 82307	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21098	 82307	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21099	 22057	 0.011556	 0.039644	 0.0095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82307	 21100	 0.089812	 0.17603	 0.00264	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21100	 82632	 0.11233	 0.072723	 0.00138	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21101	 21104	 0.003171	 0.018573	 0.00506	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21101	 21105	 0.008356	 0.028666	 0.00687	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21101	 21302	 0.014447	 0.051072	 0.01151	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21101	 82308	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21101	 82308	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21102	 21104	 0.007774	 0.048308	 0.01364	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21102	 82309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21102	 82309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21102	 82312	 0.014382	 0.04934	 0.01182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21103	 21739	 0.25943	 0.28543	 0.00381	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81896	 21103	 0.031178	 0.063805	 0.00157	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21104	 21750	 0.009121	 0.029751	 0.0079	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21104	 82310	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21104	 82310	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21105	 82311	 0.009957	 0.034843	 0.01155	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21106	 21108	 0.000549	 0.006144	 0.0574	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21106	 82311	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21106	 82311	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21107	 21763	 0.000646	 0.011337	 0.12133	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21107	 82312	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21108	 82314	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21109	 21110	 0.000647	 0.007102	 0.06899	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21109	 21113	 0.000417	 0.004574	 0.04443	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21109	 82316	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21109	 82316	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21110	 82317	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21111	 82319	 0.016233	 0.079216	 0.00137	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21111	 82321	 0.044708	 0.09581	 0.00168	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21111	 82592	 0.035698	 0.13888	 0.00232	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21112	 26953	 0.004102	 0.04689	 0.0143	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21112	 82319	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21112	 82319	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21112	 82320	 0.000387	 0.006021	 0.00187	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21113	 21114	 0.000517	 0.005475	 0.05711	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21113	 82320	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21114	 82322	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21114	 82322	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82187	 21115	 0.001562	 0.022088	 0.00732	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82316	 21115	 0.003692	 0.030717	 0.0093	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82322	 21115	 0.001461	 0.013251	 0.00693	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21116	 21121	 0.001516	 0.016432	 0.01008	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21116	 21785	 0.003275	 0.051611	 0.0176	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21116	 82323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21116	 82323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21117	 21120	 0.000402	 0.004481	 0.04226	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21117	 82324	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21117	 82324	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21118	 21119	 0.002042	 0.016686	 0.00453	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21118	 21870	 0.002809	 0.02644	 0.00801	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81875	 21118	 0.003447	 0.029565	 0.00841	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81875	 21119	 0.002289	 0.014747	 0.00387	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21120	 82325	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21120	 82325	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81875	 21121	 0.000753	 0.011729	 0.0041	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81876	 21122	 0.048929	 0.038353	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21123	 21783	 0.003091	 0.028293	 0.01133	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82325	 21123	 0.004559	 0.073384	 0.02398	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21124	 21125	 0.006947	 0.047684	 0.00087	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82162	 21124	 0.026701	 0.12381	 0.00257	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21125	 21127	 0.031591	 0.062547	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21125	 82326	 0.014523	 0.089285	 0.00161	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21126	 21128	 0.010857	 0.028694	 0.00672	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21126	 82326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21126	 82326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21127	 82327	 0.024559	 0.10252	 0.00296	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82324	 21128	 0.012517	 0.042942	 0.01029	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21128	 82327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21128	 82327	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21129	 82328	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21129	 82328	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21129	 82329	 0.00244	 0.018376	 0.0051	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21130	 21589	 0.00462	 0.01849	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21130	 82330	 0.00335	 0.018825	 0.00035	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21131	 21136	 0.020243	 0.05806	 0.00089	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21131	 82330	 0.005769	 0.025706	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21132	 21651	 0.001335	 0.023796	 0.24715	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21132	 21879	 0.000692	 0.012139	 0.12992	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21132	 82329	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21133	 21588	 0.001815	 0.004562	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82329	 21133	 0.00208	 0.005662	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82330	 21134	 0.021069	 0.02769	 0.00038	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21135	 21139	 0.00198	 0.006791	 0.00163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82329	 21135	 0.00146	 0.004228	 0.00102	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82328	 21136	 0.017541	 0.053868	 0.00101	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21136	 82331	 0.018563	 0.042647	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21137	 21138	 0.003065	 0.009037	 0.0021	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21137	 21140	 0.002434	 0.006119	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21138	 21141	 0.004586	 0.012487	 0.00275	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21138	 21671	 0.006414	 0.034537	 0.00949	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21139	 21141	 0.002967	 0.009677	 0.00257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21140	 21586	 0.001825	 0.00469	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21141	 21142	 0.00328	 0.011878	 0.00255	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21142	 21676	 0.009267	 0.037711	 0.00919	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21143	 82331	 0.043152	 0.081556	 0.00132	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21143	 82332	 0.037307	 0.076347	 0.00188	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21144	 21145	 0.003485	 0.008761	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21144	 82331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21144	 82331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21145	 21146	 0.002064	 0.00554	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21146	 21147	 0.001581	 0.005726	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21146	 21150	 0.004018	 0.028667	 0.00889	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21147	 21148	 0.003314	 0.011998	 0.00257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82113	 21149	 0.035878	 0.064487	 0.00116	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82331	 21149	 0.11375	 0.21787	 0.00343	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21149	 82641	 0.29259	 0.2245	 0.00301	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21150	 82332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21150	 82332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81898	 21151	 0.005122	 0.027289	 0.00766	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21152	 21906	 0.007614	 0.037546	 0.01015	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21152	 82333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21152	 82333	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21153	 21154	 0.07205	 0.13197	 0.00228	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81868	 21153	 0.44401	 0.35162	 0.00443	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82333	 21153	 0.22745	 0.18004	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21154	 21155	 0.004848	 0.012462	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21154	 82334	 0.011859	 0.028082	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21155	 21157	 0.021759	 0.017055	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21155	 82334	 0.009578	 0.018964	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21156	 21160	 0.009828	 0.033115	 0.00823	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21156	 82334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21156	 82334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21157	 21158	 0.014909	 0.026798	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82334	 21157	 0.007927	 0.012653	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21158	 21159	 0.063602	 0.14767	 0.0022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81899	 21159	 0.016322	 0.063498	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81901	 21159	 0.11602	 0.1525	 0.00209	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81900	 21160	 0.026725	 0.070645	 0.01654	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21161	 82335	 0.072205	 0.057143	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21162	 21169	 0.01401	 0.037027	 0.00867	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82197	 21162	 0.005038	 0.050923	 0.01498	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21162	 82335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21162	 82335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21163	 82336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21163	 82336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21164	 21614	 0.052147	 0.12105	 0.00231	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82336	 21164	 0.037869	 0.10862	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21164	 82338	 0.13105	 0.10371	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21165	 82337	 0.026671	 0.060498	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21166	 21167	 0.026334	 0.042034	 0.00097	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21166	 21692	 0.020372	 0.10855	 0.0019	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82335	 21166	 0.012804	 0.056415	 0.00098	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21167	 21168	 0.02247	 0.050413	 0.0008	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21168	 82337	 0.024005	 0.061709	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21168	 82340	 0.093357	 0.060442	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21169	 21172	 0.002717	 0.011219	 0.00265	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21169	 82337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21169	 82337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21170	 21171	 0.002102	 0.010384	 0.00303	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21170	 21173	 0.003941	 0.019935	 0.00555	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21170	 21177	 0.002058	 0.031442	 0.01013	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21170	 82338	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21170	 82338	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21170	 82512	 0.011599	 0.069634	 0.02109	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21171	 21172	 0.000396	 0.004526	 0.00138	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21171	 21175	 0.002834	 0.011996	 0.0027	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21172	 21173	 0.002171	 0.007446	 0.00178	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21172	 82339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21172	 82339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21173	 21174	 0.004797	 0.018853	 0.00493	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21174	 82340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21174	 82340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21175	 82341	 0.00648	 0.03145	 0.00719	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82338	 21176	 0.046965	 0.068437	 0.00155	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21176	 82342	 0.055861	 0.14768	 0.00268	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82235	 21177	 0.002138	 0.022492	 0.01264	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21178	 22035	 0.000482	 0.005567	 0.04881	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82198	 21178	 0.002357	 0.027234	 0.23913	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21178	 82341	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21178	 82341	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21179	 82342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21179	 82342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21179	 82697	 0.009735	 0.032476	 0.00824	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21180	 24074	 0.020976	 0.10491	 0.00187	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21180	 82343	 0.039129	 0.10059	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21181	 21183	 0.002662	 0.029443	 0.00883	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21181	 82343	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21181	 82343	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82195	 21182	 0.036629	 0.094161	 0.00146	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82343	 21182	 0.037502	 0.11505	 0.00312	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21182	 83304	 0.019498	 0.10389	 0.00182	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21183	 82344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21183	 82344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21183	 82559	 0.010739	 0.043	 0.01083	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21183	 83303	 0.029246	 0.073537	 0.01906	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21184	 82345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21184	 82345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21184	 82559	 0.003327	 0.024296	 0.00624	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21185	 21186	 0.020424	 0.051942	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21185	 21187	 0.029656	 0.10965	 0.00203	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82343	 21185	 0.009137	 0.061994	 0.00116	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21186	 21689	 0.025189	 0.066588	 0.00121	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82345	 21186	 0.033305	 0.16253	 0.00281	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21186	 82554	 0.053852	 0.13844	 0.00214	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21187	 21900	 0.024253	 0.084864	 0.00176	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21187	 82554	 0.051942	 0.11934	 0.00181	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21188	 21189	 0.003654	 0.017831	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21188	 21728	 0.015147	 0.042982	 0.00068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21189	 21268	 0.037398	 0.048669	 0.00068	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21189	 82355	 0.003129	 0.022519	 0.00074	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21190	 21191	 9.1e-05	 0.00139	 0.02491	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21190	 82346	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21191	 21258	 0.000271	 0.004167	 0.07267	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21191	 21305	 0.000619	 0.011168	 0.17632	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21191	 82348	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21192	 21198	 0.008939	 0.025637	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21192	 21234	 0.006025	 0.023439	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21192	 21261	 0.008464	 0.017393	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21192	 82351	 0.007407	 0.03027	 0.00061	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21193	 82350	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21194	 21216	 0.000175	 0.002617	 0.00077	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82346	 21194	 0.000353	 0.00435	 0.0014	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21194	 82352	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21194	 82352	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21195	 21196	 0.000404	 0.00197	 0.00054	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21195	 21216	 0.000693	 0.003544	 0.00097	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82348	 21196	 0.000681	 0.003106	 0.00099	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21196	 82353	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21196	 82353	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21197	 21198	 0.005585	 0.015469	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21197	 21201	 0.006047	 0.015316	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82352	 21197	 0.00347	 0.011575	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21198	 21199	 0.020595	 0.016299	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21199	 21200	 0.005646	 0.016194	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21199	 21262	 0.004186	 0.016039	 0.00045	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21200	 21206	 0.005302	 0.015207	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21200	 21207	 0.002963	 0.015212	 0.00029	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82347	 21200	 0.007794	 0.038979	 0.00069	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21201	 21205	 0.002457	 0.009453	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21201	 21205	 0.002457	 0.009453	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21201	 21206	 0.003447	 0.008556	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21201	 82357	 0.001184	 0.008656	 0.00016	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21202	 21203	 0.000505	 0.004698	 0.00146	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21202	 21204	 0.000568	 0.002899	 0.00073	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21202	 82354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21202	 82354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21203	 21729	 0.002952	 0.022124	 0.0054	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21203	 82355	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21203	 82355	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21204	 82356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21204	 82356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82356	 21205	 0.002644	 0.009253	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82356	 21205	 0.002644	 0.009253	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21207	 21208	 0.005942	 0.007809	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21207	 21209	 0.002312	 0.012023	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21208	 21212	 0.009761	 0.017612	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21209	 21210	 0.001394	 0.007428	 0.00013	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82356	 21210	 0.001595	 0.008068	 0.00014	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21211	 21214	 0.007643	 0.018097	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82354	 21211	 0.008517	 0.028413	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21212	 21213	 0.009354	 0.024045	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21213	 21214	 0.005078	 0.01694	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21213	 21215	 0.023301	 0.01844	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21213	 21265	 0.01411	 0.01106	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21213	 82374	 0.004189	 0.022417	 0.00068	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21216	 82357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21216	 82357	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21217	 21247	 0.001789	 0.006712	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21217	 82358	 0.001864	 0.00615	 0.0001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81881	 21218	 0.001431	 0.00719	 0.00187	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21218	 82358	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21218	 82358	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21220	 82359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21220	 82359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21220	 82365	 0.001509	 0.009375	 0.00265	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21221	 21224	 0.000297	 0.003345	 0.00088	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21221	 21241	 0.000263	 0.003008	 0.00092	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82359	 21222	 0.018886	 0.014487	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21223	 21230	 0.008153	 0.023136	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82359	 21223	 0.004935	 0.019274	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21224	 21226	 0.002778	 0.009267	 0.00235	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21224	 21254	 0.003398	 0.013828	 0.00337	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21224	 82360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21224	 82360	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21225	 21242	 0.002632	 0.01114	 0.00251	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21225	 82361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21225	 82361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21225	 82379	 0.004197	 0.023285	 0.00708	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82350	 21226	 0.003664	 0.009835	 0.00223	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21226	 82362	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21226	 82362	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21227	 21235	 0.007949	 0.013391	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21227	 21255	 0.009813	 0.015664	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82361	 21227	 0.00837	 0.021516	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21228	 21233	 0.023068	 0.016676	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82361	 21228	 0.016477	 0.016642	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21229	 21230	 0.016169	 0.012796	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82360	 21229	 0.01102	 0.018564	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21230	 21231	 0.004849	 0.011141	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21231	 21232	 0.004455	 0.008283	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21232	 21249	 0.011314	 0.022174	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21233	 82370	 0.022613	 0.024872	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21234	 21235	 0.010621	 0.01627	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82362	 21234	 0.004637	 0.011059	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21234	 82368	 0.005522	 0.024471	 0.00073	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21236	 21245	 0.000692	 0.003895	 8e-05	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81897	 21236	 0.004645	 0.026403	 0.00048	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21237	 82363	 0.000182	 0.000739	 0.00018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21237	 82363	 0.000182	 0.000739	 0.00018	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21238	 82363	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21239	 82365	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21240	 21241	 0.000343	 0.003921	 0.0012	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82365	 21240	 0.000517	 0.004051	 0.00185	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21241	 82367	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21241	 82367	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82350	 21242	 0.000994	 0.006663	 0.00204	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82363	 21242	 0.000704	 0.005093	 0.00274	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21242	 82368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21242	 82368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21243	 21244	 0.010703	 0.01081	 0.00014	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82364	 21243	 0.00194	 0.009816	 0.00017	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82368	 21243	 0.00423	 0.018166	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21244	 21245	 0.00436	 0.009782	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82364	 21245	 0.001508	 0.009273	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21246	 21247	 0.005577	 0.014335	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81882	 21246	 0.000566	 0.003649	 0.00012	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81910	 21246	 0.000675	 0.002071	 6e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82366	 21247	 0.027689	 0.038589	 0.00066	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21248	 21249	 0.023172	 0.020906	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21248	 21251	 0.031028	 0.021978	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21248	 82380	 0.016608	 0.067875	 0.00137	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21249	 21251	 0.008953	 0.016921	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21249	 82370	 0.013724	 0.021414	 0.00036	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21250	 21290	 0.002042	 0.007005	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21250	 82369	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21250	 82369	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82369	 21251	 0.003164	 0.016003	 0.00028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21252	 21253	 0.000734	 0.00369	 0.00096	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21252	 21254	 0.001115	 0.004337	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21253	 21288	 0.001192	 0.007099	 0.00187	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21254	 82370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21254	 82370	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21255	 21256	 0.012433	 0.016341	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21255	 21259	 0.008931	 0.022957	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82370	 21255	 0.006094	 0.020328	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21256	 21257	 0.007023	 0.009788	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21256	 21259	 0.007537	 0.017494	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21256	 21260	 0.004261	 0.021555	 0.00038	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82370	 21257	 0.00881	 0.022315	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21258	 21289	 4.6e-05	 0.000724	 0.01571	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21258	 82371	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21259	 21261	 0.008065	 0.01872	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21259	 21262	 0.012989	 0.027731	 0.00063	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82372	 21259	 0.006491	 0.036898	 0.00067	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82372	 21260	 0.003055	 0.015359	 0.00042	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21262	 21263	 0.006894	 0.019774	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21263	 82373	 0.004425	 0.014761	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21264	 21274	 0.001518	 0.005966	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82371	 21264	 0.000968	 0.006813	 0.00387	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21264	 82373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21264	 82373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21266	 21270	 0.006274	 0.046342	 0.00097	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21266	 21271	 0.005721	 0.014707	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82349	 21266	 0.011218	 0.063766	 0.00115	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21267	 21268	 0.0047	 0.018648	 0.00053	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82355	 21267	 0.00357	 0.015821	 0.00048	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21268	 21269	 0.017779	 0.031955	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21268	 82576	 0.01461	 0.051121	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21269	 21270	 0.003446	 0.025188	 0.00046	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21269	 21736	 0.005829	 0.035835	 0.00065	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21270	 21273	 0.06143	 0.050563	 0.00102	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21271	 21272	 0.006447	 0.019778	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21272	 82376	 0.007072	 0.027097	 0.00077	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21273	 21747	 0.0174	 0.074389	 0.00168	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21273	 82380	 0.024154	 0.1468	 0.00271	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21273	 82384	 0.033226	 0.087836	 0.00159	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21274	 21279	 0.008019	 0.020818	 0.00505	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21274	 82374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21274	 82374	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21275	 21276	 0.001381	 0.007356	 0.00206	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21275	 21280	 0.00296	 0.010718	 0.0023	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21275	 21281	 0.000751	 0.009151	 0.00302	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21275	 82375	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21275	 82375	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21276	 82376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21276	 82376	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21277	 21283	 0.023404	 0.025492	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82375	 21277	 0.012817	 0.025119	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21277	 82377	 0.027531	 0.029987	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82375	 21278	 0.009272	 0.02358	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21278	 82377	 0.033875	 0.026553	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21279	 21280	 0.001544	 0.005037	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21279	 21294	 0.00313	 0.008273	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21279	 21750	 0.011077	 0.057426	 0.01402	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21280	 82377	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21280	 82377	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21281	 82379	 0.000583	 0.00596	 0.00354	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21282	 21284	 0.008912	 0.021815	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21282	 82378	 0.008907	 0.03969	 0.00067	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21283	 21284	 0.00916	 0.017952	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21285	 21286	 0.024767	 0.027241	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21286	 21291	 0.016371	 0.027579	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21286	 82378	 0.021907	 0.035714	 0.00054	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21286	 82380	 0.019959	 0.052761	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21287	 21288	 0.002803	 0.007407	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21287	 21301	 0.01913	 0.063828	 0.01619	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21287	 82378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21287	 82378	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21287	 82379	 0.000635	 0.00578	 0.00146	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21288	 82379	 0.000663	 0.005689	 0.00162	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21289	 82379	 0.000112	 0.008969	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82379	 21290	 0.001904	 0.009689	 0.00351	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21290	 82381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21290	 82381	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82381	 21291	 0.013215	 0.025898	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21292	 21298	 0.004021	 0.010627	 0.00249	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21292	 82382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21292	 82382	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82380	 21293	 0.023966	 0.11695	 0.00202	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82382	 21293	 0.042178	 0.042601	 0.00056	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21294	 21296	 0.004005	 0.009297	 0.00283	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21295	 21299	 0.008125	 0.035598	 0.00077	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82377	 21295	 0.007542	 0.037419	 0.00089	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21295	 82383	 0.004193	 0.028778	 0.00052	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21296	 21297	 0.002269	 0.007783	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21296	 21298	 0.003491	 0.009792	 0.00252	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82379	 21296	 0.004695	 0.029739	 0.00807	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21297	 82383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21297	 82383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21298	 21302	 0.008108	 0.020382	 0.00528	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21299	 21303	 0.18007	 0.13644	 0.00188	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21299	 82384	 0.016661	 0.064816	 0.00108	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21300	 21748	 0.006359	 0.016807	 0.00393	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21300	 82384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21300	 82384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21301	 21302	 0.006533	 0.016422	 0.00425	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21301	 21682	 0.014837	 0.038522	 0.00935	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81895	 21302	 0.050563	 0.18332	 0.0394	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21302	 82385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21302	 82385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21303	 21304	 0.046595	 0.074376	 0.00171	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82308	 21303	 0.2001	 0.14724	 0.00215	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82385	 21304	 0.017951	 0.046144	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21304	 82551	 0.16697	 0.30135	 0.00436	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21305	 21723	 0.000338	 0.004628	 0.04716	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21305	 82386	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21306	 21310	 0.00427	 0.018814	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21306	 21311	 0.002354	 0.010373	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81865	 21306	 0.003842	 0.014946	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81865	 21306	 0.003842	 0.014946	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82387	 21306	 0.003817	 0.014686	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82387	 21306	 0.003817	 0.014686	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21307	 21308	 0.000454	 0.00342	 0.00095	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82386	 21307	 0.000546	 0.0043	 0.00126	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21308	 21316	 0.000621	 0.004058	 0.0015	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21309	 21312	 0.002011	 0.007281	 0.00156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21309	 21316	 0.002001	 0.008143	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21310	 21311	 0.002293	 0.008824	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21310	 82390	 0.004513	 0.030542	 0.00088	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21312	 21332	 0.001623	 0.004288	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21313	 21314	 0.000132	 0.001521	 0.01333	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21313	 22229	 0.000283	 0.004957	 0.05303	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21313	 82388	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21313	 82388	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21314	 21325	 0.000583	 0.007245	 0.07278	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21314	 82389	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21314	 82389	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21315	 21332	 0.003466	 0.01208	 0.0028	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21315	 82390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21315	 82390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21316	 21317	 0.003139	 0.012336	 0.00323	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21317	 21327	 0.00213	 0.015777	 0.00808	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21317	 82573	 0.002139	 0.015476	 0.00833	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21318	 21322	 0.029717	 0.070881	 0.00159	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82390	 21318	 0.009431	 0.039366	 0.00114	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21318	 82773	 0.056002	 0.11088	 0.00163	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21319	 21320	 0.10307	 0.081573	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21319	 82775	 0.053281	 0.089758	 0.00128	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21320	 82392	 0.029341	 0.093168	 0.00163	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21321	 21861	 0.00393	 0.028431	 0.0153	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21321	 82391	 0.00227	 0.020579	 0.01076	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21322	 82392	 0.004775	 0.035479	 0.00085	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21322	 82395	 0.006743	 0.048716	 0.00092	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21322	 82773	 0.22518	 0.17823	 0.00224	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 21325	 5.4e-05	 0.000724	 0.01276	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 21325	 5.4e-05	 0.000724	 0.01276	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 21608	 0.00149	 0.016601	 0.15664	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 21833	 0.000529	 0.006314	 0.10738	 1600.0	 1680.0	 1720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 21863	 0.000848	 0.009301	 0.09036	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 21889	 0.001652	 0.018136	 0.1763	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 82391	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82392	 21324	 0.018147	 0.032617	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21324	 82397	 0.14458	 0.11443	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21325	 21723	 0.000471	 0.008704	 0.08363	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21325	 82393	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21325	 82393	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21326	 21328	 0.003968	 0.021143	 0.00593	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21326	 82394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21326	 82394	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82393	 21327	 0.000625	 0.009106	 0.00291	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21327	 82395	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21327	 82395	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21328	 82396	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21328	 82396	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21328	 82575	 0.004483	 0.051267	 0.01436	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82391	 21329	 0.013202	 0.034891	 0.00817	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21329	 82397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21329	 82397	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82396	 21330	 0.022543	 0.099328	 0.00173	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82397	 21330	 0.032084	 0.12344	 0.00211	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21331	 82581	 0.028635	 0.13	 0.00282	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21331	 82645	 0.052027	 0.14923	 0.0023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81864	 21332	 0.000222	 0.003388	 0.00109	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82388	 21332	 0.000641	 0.006947	 0.00217	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21333	 82401	 0.16172	 0.128	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21334	 82398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21334	 82398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21334	 82400	 0.002101	 0.022543	 0.00587	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21335	 21616	 0.005804	 0.041996	 0.0226	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21335	 21658	 0.003739	 0.02985	 0.00736	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21335	 82399	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21335	 82399	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81914	 21336	 0.068314	 0.13526	 0.00199	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21337	 21340	 0.021705	 0.023873	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81914	 21338	 0.093648	 0.093673	 0.00127	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82399	 21338	 0.052789	 0.12256	 0.00182	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21338	 82401	 0.032626	 0.035885	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21339	 82400	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82401	 21340	 0.008246	 0.016874	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81914	 21341	 0.010809	 0.061446	 0.00111	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21341	 82706	 0.13529	 0.30698	 0.00613	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21342	 21698	 0.063923	 0.11534	 0.00167	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81914	 21342	 0.030049	 0.071158	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21343	 21353	 0.000821	 0.006396	 0.00191	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21343	 21378	 0.000299	 0.002564	 0.00073	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21343	 82402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21343	 82402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82402	 21344	 0.00669	 0.01311	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21344	 82403	 0.005535	 0.018466	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21344	 82405	 0.006709	 0.0261	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21345	 21352	 0.001539	 0.011921	 0.00418	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21345	 21379	 0.000306	 0.003179	 0.00098	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21345	 82403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21345	 82403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21346	 21347	 8.8e-05	 0.001203	 0.00043	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21346	 21378	 0.000301	 0.003383	 0.00098	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21346	 21379	 0.000159	 0.001785	 0.00052	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21347	 21348	 0.000255	 0.002762	 0.00116	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21348	 21349	 0.001837	 0.004854	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21348	 21358	 0.000442	 0.005147	 0.00151	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21348	 21370	 0.000738	 0.0096	 0.00277	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21348	 82404	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21348	 82404	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21349	 21351	 0.003003	 0.007795	 0.00189	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82184	 21350	 0.020848	 0.11481	 0.00259	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82404	 21350	 0.002289	 0.015714	 0.00029	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21351	 21352	 0.00086	 0.004929	 0.00164	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21351	 21365	 0.003845	 0.015645	 0.00381	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21353	 21369	 0.001365	 0.021254	 0.00742	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21353	 82405	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21353	 82405	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21354	 21355	 0.004245	 0.016331	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81926	 21354	 0.035707	 0.054156	 0.00078	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21354	 82410	 0.018283	 0.081469	 0.00138	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82403	 21355	 0.006245	 0.017912	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21356	 21357	 0.000374	 0.005395	 0.00171	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21357	 21358	 0.000461	 0.006001	 0.00173	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21359	 21362	 0.001811	 0.029455	 0.00835	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82243	 21359	 0.0024	 0.03423	 0.01143	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21359	 82406	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21359	 82406	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21360	 21361	 0.000515	 0.004107	 0.00101	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21360	 82666	 0.006146	 0.039592	 0.01038	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21361	 21362	 0.001733	 0.011625	 0.00281	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21362	 21367	 0.002177	 0.008989	 0.00213	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81916	 21362	 0.004298	 0.038977	 0.02038	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21362	 82407	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21362	 82407	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21363	 21364	 0.001287	 0.00931	 0.00501	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21363	 21365	 0.005623	 0.022099	 0.00578	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21363	 82408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21363	 82408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21364	 21367	 0.001851	 0.0157	 0.0094	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82405	 21366	 0.031892	 0.052973	 0.00112	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82407	 21366	 0.052682	 0.10325	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21366	 82409	 0.034027	 0.067372	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21367	 21368	 0.001823	 0.0175	 0.00815	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21367	 82409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21367	 82409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82249	 21368	 0.001824	 0.017511	 0.00816	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21368	 82410	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21368	 82410	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81916	 21369	 0.002592	 0.034667	 0.00948	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21370	 21371	 0.00032	 0.005068	 0.00152	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82182	 21371	 0.001273	 0.015118	 0.00527	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21372	 21374	 0.00331	 0.020568	 0.0058	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21373	 21376	 0.000673	 0.004739	 0.00269	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21374	 21375	 0.001226	 0.009498	 0.00333	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21374	 82411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21374	 82411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21375	 21376	 0.000459	 0.005455	 0.0019	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21375	 21377	 0.001427	 0.01146	 0.00322	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82281	 21380	 0.014658	 0.065318	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21380	 82416	 0.012533	 0.029096	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21380	 82420	 0.057509	 0.06264	 0.00085	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21381	 82412	 0.000122	 0.009799	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21381	 82412	 0.000122	 0.009799	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21381	 82412	 0.000122	 0.009799	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82413	 21381	 0.000149	 0.011888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 0	 -30.0	 30.0;
	82413	 21381	 0.000149	 0.011888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 0	 -30.0	 30.0;
	82412	 21382	 6.4e-05	 0.000748	 0.00711	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21383	 21397	 0.001398	 0.005494	 0.00144	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82413	 21383	 0.000392	 0.004432	 0.00249	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21383	 82414	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21383	 82414	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21383	 82422	 0.000456	 0.003554	 0.00106	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82279	 21384	 0.008591	 0.022085	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21384	 82444	 0.018843	 0.033868	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21385	 21386	 0.00153	 0.004387	 0.00108	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21385	 21390	 0.001127	 0.002979	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82278	 21386	 0.003191	 0.013505	 0.00304	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21386	 82418	 0.002216	 0.007834	 0.00177	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21386	 82443	 0.001202	 0.002897	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21387	 21391	 0.000248	 0.002761	 0.02604	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21387	 82415	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21387	 82415	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21388	 21390	 0.003581	 0.009986	 0.0021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21388	 21393	 0.001327	 0.004427	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82415	 21388	 0.000951	 0.00575	 0.00147	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21388	 82416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21388	 82416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21389	 21392	 0.001779	 0.004777	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21389	 21415	 0.001045	 0.005532	 0.0014	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82415	 21389	 0.000289	 0.00334	 0.00207	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21389	 82417	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21389	 82417	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21390	 82418	 0.002069	 0.005553	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21391	 21465	 7e-05	 0.000769	 0.00747	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21391	 21489	 0.00035	 0.004041	 0.03543	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21391	 82418	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21391	 82418	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21392	 21396	 0.002131	 0.005802	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82418	 21392	 0.003828	 0.010276	 0.00233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21393	 21396	 0.001351	 0.003502	 0.00106	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21393	 82419	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21393	 82419	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82416	 21394	 0.012025	 0.014927	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82419	 21394	 0.018211	 0.014412	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21395	 21417	 0.004988	 0.01919	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21395	 82420	 0.004308	 0.018983	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82418	 21396	 0.001775	 0.004563	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21396	 82420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21396	 82420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21397	 21398	 0.00103	 0.004253	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21399	 21401	 0.00054	 0.005797	 0.00151	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21399	 21403	 0.000405	 0.004991	 0.00161	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21399	 82421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21399	 82421	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82412	 21400	 0.000148	 0.001706	 0.01496	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21400	 82422	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21400	 82422	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21401	 21412	 0.000965	 0.004847	 0.00126	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82422	 21401	 0.000226	 0.003641	 0.00119	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21402	 21405	 0.000486	 0.003254	 0.00205	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21402	 21412	 0.001062	 0.005643	 0.00131	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21402	 21413	 0.001859	 0.010795	 0.00254	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21403	 21404	 0.000365	 0.004329	 0.00151	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82268	 21404	 0.000611	 0.006981	 0.00196	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21405	 21407	 0.000512	 0.004917	 0.00143	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21405	 82423	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21405	 82423	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21406	 82424	 0.008933	 0.022172	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21406	 82437	 0.008019	 0.020784	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21407	 82424	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21407	 82424	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21407	 82438	 0.001223	 0.006144	 0.0016	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21408	 21421	 0.002035	 0.005837	 0.00144	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21408	 82438	 0.003332	 0.009292	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82423	 21409	 0.011257	 0.022061	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21409	 82426	 0.00955	 0.033414	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21409	 82427	 0.003362	 0.014375	 0.00032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21410	 21411	 0.025432	 0.016464	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21411	 21420	 0.003967	 0.017677	 0.0003	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21411	 82425	 0.005077	 0.022242	 0.00048	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21411	 82426	 0.022652	 0.017926	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21413	 21415	 0.00118	 0.004128	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21413	 82425	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21413	 82425	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82414	 21414	 0.005451	 0.016723	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82425	 21414	 0.004329	 0.016843	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21416	 21417	 0.039318	 0.025454	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21416	 21418	 0.006858	 0.018178	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82417	 21416	 0.003075	 0.021105	 0.00038	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21417	 82448	 0.006078	 0.018644	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21418	 82426	 0.03537	 0.026023	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21418	 82430	 0.007477	 0.021446	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21419	 21424	 0.000676	 0.003298	 0.00091	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82422	 21419	 0.003277	 0.015284	 0.00379	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21419	 82426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21419	 82426	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21420	 82429	 0.00314	 0.009631	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21421	 21422	 0.001618	 0.004275	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21421	 82427	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21421	 82427	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21422	 21423	 0.001941	 0.007027	 0.00151	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21422	 21432	 0.001978	 0.005311	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21422	 82428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21422	 82428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21423	 21425	 0.003045	 0.00882	 0.00213	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21423	 82429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21423	 82429	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21424	 21429	 0.000507	 0.002326	 0.0006	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21425	 21426	 0.001211	 0.003143	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21425	 21428	 0.001537	 0.003952	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21425	 82430	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21425	 82430	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21426	 21598	 0.001491	 0.004003	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21426	 82431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21426	 82431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21427	 21492	 0.00875	 0.008596	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82430	 21427	 0.013514	 0.020702	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21427	 82432	 0.003203	 0.008234	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21427	 82462	 0.011685	 0.019684	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21428	 21429	 0.000602	 0.002065	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21428	 82432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21428	 82432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21429	 82433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21429	 82433	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21430	 21431	 0.012891	 0.01302	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82428	 21430	 0.016476	 0.027478	 0.0004	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82433	 21430	 0.00566	 0.01455	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21431	 82460	 0.022341	 0.014463	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21432	 21493	 0.001439	 0.003804	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21432	 82434	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21432	 82434	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21433	 21455	 0.001234	 0.004158	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21433	 21494	 0.001373	 0.003739	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21433	 82435	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21433	 82435	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21434	 21435	 9.7e-05	 0.00106	 0.01041	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21434	 82436	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21435	 21547	 0.000387	 0.004247	 0.04125	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82412	 21435	 0.000582	 0.006595	 0.06005	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21435	 82438	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21436	 21437	 0.006951	 0.023188	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21436	 21439	 0.011595	 0.026639	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82439	 21436	 0.002386	 0.01271	 0.00022	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21437	 21438	 0.035729	 0.030536	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21437	 21441	 0.023127	 0.049559	 0.00087	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21438	 21439	 0.007478	 0.017101	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21438	 21441	 0.009979	 0.028316	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82437	 21439	 0.005865	 0.026136	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21440	 82490	 0.013778	 0.035418	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21441	 21443	 0.017336	 0.017702	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21441	 21444	 0.008262	 0.01918	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82410	 21441	 0.10344	 0.29675	 0.00457	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21442	 21599	 0.002641	 0.009061	 0.00217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21442	 82440	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21442	 82440	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82440	 21444	 0.01476	 0.029224	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82440	 21445	 0.009469	 0.02408	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21446	 21447	 0.002743	 0.006896	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82438	 21446	 0.002777	 0.007209	 0.00175	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21447	 21454	 0.001827	 0.004744	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21448	 21452	 0.001247	 0.004409	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21448	 21599	 0.001627	 0.005307	 0.00141	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21449	 21451	 0.007286	 0.011879	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21449	 82508	 0.011255	 0.026129	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21450	 21451	 0.004445	 0.008402	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21450	 21453	 0.005393	 0.013863	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21450	 82490	 0.005544	 0.012871	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21452	 21544	 0.001129	 0.00518	 0.00133	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21453	 82488	 0.006554	 0.016848	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21454	 21455	 0.001452	 0.00428	 0.001	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21454	 21544	 0.001749	 0.004694	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21455	 21543	 0.001641	 0.004337	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21456	 21463	 0.001847	 0.004644	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21456	 82441	 0.001231	 0.004291	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21457	 21464	 0.000164	 0.001798	 0.01747	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21457	 82441	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21457	 82453	 0.000125	 0.001422	 0.01294	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21458	 21460	 5.6e-05	 0.000675	 0.00668	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21458	 21465	 3.3e-05	 0.000392	 0.00387	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21459	 21473	 0.027639	 0.022749	 0.00046	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21459	 82444	 0.014137	 0.010014	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21460	 21462	 3.6e-05	 0.000488	 0.00498	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21460	 82443	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82441	 21461	 0.001372	 0.006894	 0.00179	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82443	 21461	 0.002208	 0.007439	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21461	 82445	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21461	 82445	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21462	 21464	 5.2e-05	 0.000718	 0.00731	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21463	 82446	 0.002131	 0.005533	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21464	 82446	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21464	 82446	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21465	 21600	 0.000155	 0.002768	 0.02871	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21466	 21467	 0.001257	 0.004553	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21466	 21474	 0.001096	 0.003967	 0.00085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21467	 21472	 0.000823	 0.004819	 0.00131	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82418	 21467	 0.000706	 0.004991	 0.00137	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21467	 82447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21467	 82447	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82447	 21468	 0.005274	 0.012243	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21468	 82448	 0.006649	 0.019071	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21469	 21471	 0.002467	 0.006879	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21469	 21490	 0.001409	 0.004596	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21469	 82448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21469	 82448	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82448	 21470	 0.020857	 0.022717	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21470	 82449	 0.009974	 0.019748	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21470	 82469	 0.026115	 0.020032	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21471	 21475	 0.001179	 0.004866	 0.00115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21471	 82449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21471	 82449	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21472	 21475	 0.000612	 0.003298	 0.00091	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21473	 21480	 0.033647	 0.021783	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82445	 21473	 0.009354	 0.01363	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21474	 21481	 0.001274	 0.005941	 0.00147	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21475	 21479	 0.000654	 0.003327	 0.00121	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21475	 82450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21475	 82450	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21475	 82458	 0.003001	 0.012494	 0.0039	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82449	 21476	 0.026211	 0.018567	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82450	 21476	 0.007174	 0.014681	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21476	 82511	 0.030185	 0.050849	 0.00072	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21477	 21513	 0.001012	 0.003975	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 0	 -30.0	 30.0;
	21477	 82451	 0.0005	 0.002003	 0.0005	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21478	 21600	 3.1e-05	 0.00034	 0.00321	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21478	 21603	 9.6e-05	 0.001338	 0.01323	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21478	 82451	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21478	 82451	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21479	 21488	 0.000494	 0.003848	 0.00115	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82442	 21480	 0.005867	 0.014361	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21480	 82452	 0.005769	 0.015251	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21481	 82452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21481	 82452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21481	 82455	 0.002094	 0.007184	 0.00172	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82452	 21482	 0.013314	 0.009796	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21483	 21487	 1.9e-05	 0.00053	 0.19264	 4426.0	 4647.3	 4868.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21483	 82453	 0.000163	 0.013066	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21483	 82453	 0.000163	 0.013066	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82454	 21483	 0.000149	 0.011888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 0	 -30.0	 30.0;
	82453	 21484	 4.5e-05	 0.000783	 0.01612	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21484	 82455	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21484	 82455	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21484	 82457	 8.5e-05	 0.001527	 0.02972	 1877.0	 1970.8	 2064.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21485	 21488	 0.0004	 0.004956	 0.00215	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82454	 21485	 0.00104	 0.007521	 0.00405	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82455	 21485	 0.000478	 0.004103	 0.00117	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21485	 82456	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21485	 82456	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21486	 21566	 0.010561	 0.025008	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82456	 21486	 0.003623	 0.020596	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21487	 82457	 0.000129	 0.010315	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21487	 82457	 0.000129	 0.010315	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82458	 21487	 0.000233	 0.018607	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 0	 -30.0	 30.0;
	82458	 21487	 0.000233	 0.018607	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 0	 -30.0	 30.0;
	21488	 82459	 0.001686	 0.006558	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82457	 21489	 8.3e-05	 0.000906	 0.0088	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21489	 82459	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21489	 82459	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21490	 21598	 0.001175	 0.003569	 0.00078	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82431	 21491	 0.006525	 0.012918	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21491	 82463	 0.005516	 0.009293	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82431	 21492	 0.018713	 0.024353	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21492	 82462	 0.005379	 0.010649	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21493	 21496	 0.001066	 0.002474	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21493	 82460	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21493	 82460	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21494	 21495	 0.001339	 0.003367	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21494	 82461	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21494	 82461	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21495	 21503	 0.001299	 0.003434	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21496	 21497	 0.001213	 0.003206	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21497	 21498	 0.001022	 0.002653	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21497	 82462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21497	 82462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21498	 82463	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21498	 82463	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21498	 82464	 0.001568	 0.003778	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21499	 21513	 0.001843	 0.004872	 0.00114	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21499	 21598	 0.001421	 0.0033	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82462	 21500	 0.020498	 0.016222	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21500	 82465	 0.010963	 0.00841	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21501	 21511	 4.5e-05	 0.000521	 0.00457	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21501	 82464	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21502	 21510	 0.001123	 0.003491	 0.00073	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21502	 21602	 0.000995	 0.004049	 0.00099	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21502	 82466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21502	 82466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21503	 21510	 0.001498	 0.003959	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21504	 21505	 0.001437	 0.003858	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21504	 21510	 0.001785	 0.005006	 0.00129	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21505	 21542	 0.00169	 0.004536	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21506	 21507	 0.015717	 0.012438	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21507	 21508	 0.022107	 0.014312	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21507	 21523	 0.023452	 0.01856	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21507	 82472	 0.008423	 0.014189	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21507	 82495	 0.091382	 0.066061	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21508	 21509	 0.020463	 0.015055	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21508	 82472	 0.01402	 0.014315	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82466	 21509	 0.022534	 0.02301	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21509	 82467	 0.014583	 0.011048	 0.00015	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21509	 82470	 0.008213	 0.01626	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21510	 82467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21510	 82467	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21510	 82510	 0.002748	 0.011346	 0.00268	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21511	 21538	 0.000214	 0.002466	 0.02161	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21511	 82468	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21511	 82468	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21512	 21513	 0.000883	 0.00347	 0.00091	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82468	 21512	 0.00069	 0.002764	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21513	 82469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21513	 82469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21514	 21515	 0.000593	 0.002372	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21514	 82510	 0.000816	 0.00406	 0.00131	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21515	 21516	 0.000528	 0.001779	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21516	 21517	 0.000373	 0.001317	 0.0003	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21516	 82470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21516	 82470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21517	 21520	 0.000852	 0.002288	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21517	 82471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21517	 82471	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82471	 21518	 0.006568	 0.007224	 0.0001	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21518	 82472	 0.015537	 0.012296	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21519	 21520	 0.001121	 0.002817	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21519	 82472	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21519	 82472	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21519	 82473	 0.000834	 0.002165	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21521	 21522	 4.7e-05	 0.000535	 0.00487	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21521	 21525	 5.3e-05	 0.000591	 0.00562	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21521	 82473	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21522	 21558	 6.8e-05	 0.000783	 0.00686	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21522	 21561	 8.7e-05	 0.000991	 0.00902	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21522	 82475	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21522	 82475	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82474	 21523	 0.010064	 0.009018	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21524	 21535	 0.023822	 0.018852	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21524	 82477	 0.005449	 0.015463	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21525	 21538	 0.000148	 0.001613	 0.01583	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21525	 82476	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21526	 21527	 0.000984	 0.00276	 0.00071	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82476	 21526	 0.001589	 0.003995	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21526	 82478	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21526	 82478	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21527	 21531	 0.000973	 0.003336	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21527	 82479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21527	 82479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82479	 21528	 0.015705	 0.011554	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21528	 82511	 0.00474	 0.016192	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82459	 21529	 0.000708	 0.004484	 0.00122	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21529	 82480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21529	 82480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21529	 82487	 0.002117	 0.007666	 0.00164	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21530	 82481	 0.011958	 0.00906	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21531	 82481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21531	 82481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21531	 82484	 0.000487	 0.002232	 0.00057	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21532	 21533	 0.006429	 0.009849	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21532	 21534	 0.020094	 0.015902	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82479	 21532	 0.014127	 0.010703	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82481	 21532	 0.00197	 0.007578	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21533	 21534	 0.013696	 0.010839	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82478	 21533	 0.020472	 0.016047	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21534	 21537	 0.020394	 0.016139	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21535	 82483	 0.008928	 0.017498	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21536	 21561	 0.000147	 0.001634	 0.01556	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21536	 21591	 0.000119	 0.001351	 0.0123	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21536	 82482	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21537	 82499	 0.007411	 0.015229	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21538	 21541	 0.000122	 0.001357	 0.01292	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21538	 82484	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82484	 21539	 0.000779	 0.00282	 0.00061	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21539	 82498	 0.000904	 0.00446	 0.00121	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21540	 21541	 5.6e-05	 0.000638	 0.00581	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21540	 82486	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21540	 82486	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21541	 21600	 0.000146	 0.001685	 0.01477	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21541	 21603	 0.000133	 0.001545	 0.01336	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82457	 21541	 8.3e-05	 0.000875	 0.01309	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82457	 21541	 8.3e-05	 0.000875	 0.01309	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21541	 82487	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21541	 82487	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21542	 21543	 0.00162	 0.004282	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21542	 82489	 0.00216	 0.005608	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21542	 82492	 0.001622	 0.00421	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21544	 82489	 0.000878	 0.004263	 0.00097	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21545	 82488	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21545	 82488	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21545	 82489	 0.001587	 0.007145	 0.0019	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82488	 21546	 0.009094	 0.018005	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21546	 82491	 0.013363	 0.026188	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21547	 21558	 0.000102	 0.001156	 0.01053	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21547	 21603	 0.000407	 0.004625	 0.04177	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21547	 82489	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21547	 82489	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21548	 82490	 0.008905	 0.017632	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82489	 21549	 0.001037	 0.010478	 0.00308	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21549	 82490	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21549	 82490	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21550	 21551	 0.011754	 0.018005	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82490	 21550	 0.008735	 0.024787	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21552	 21564	 0.042979	 0.043886	 0.00068	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82490	 21552	 0.042512	 0.049833	 0.00087	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21553	 21554	 0.012432	 0.019844	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21554	 82491	 0.003987	 0.012229	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21555	 21557	 0.0017	 0.004493	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21555	 82491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21555	 82491	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21556	 21557	 0.001322	 0.003897	 0.00091	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21556	 21560	 0.00126	 0.00432	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82489	 21557	 0.00174	 0.004737	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21558	 82492	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21558	 82492	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21559	 21560	 0.000766	 0.002086	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82475	 21559	 0.001374	 0.003742	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21560	 82493	 0.001121	 0.002911	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21561	 82493	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82491	 21562	 0.010885	 0.021332	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82494	 21562	 0.009983	 0.027616	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82493	 21563	 0.003234	 0.008395	 0.00204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21563	 82495	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21563	 82495	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21563	 82505	 0.003093	 0.01078	 0.0025	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82495	 21564	 0.012132	 0.05406	 0.00092	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21565	 21601	 0.002092	 0.008378	 0.00211	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81886	 21565	 0.002296	 0.0126	 0.00333	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21565	 82496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21565	 82496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81887	 21566	 0.009564	 0.024584	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82496	 21566	 0.010724	 0.027567	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21567	 21568	 0.003216	 0.011207	 0.0026	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21568	 21569	 0.003772	 0.00997	 0.00233	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81886	 21569	 0.00343	 0.010324	 0.00323	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21569	 82497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21569	 82497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21570	 82498	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21570	 82498	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21571	 21574	 0.001538	 0.005436	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82498	 21571	 0.001148	 0.007123	 0.00173	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21571	 82499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21571	 82499	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21572	 21575	 0.032337	 0.023376	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21572	 82506	 0.037291	 0.029511	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21573	 21574	 0.001278	 0.003565	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21573	 82500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21573	 82500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21573	 82505	 0.001639	 0.00395	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21575	 21576	 0.004782	 0.009468	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21575	 82502	 0.010702	 0.012811	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82499	 21576	 0.003965	 0.01259	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21577	 21578	 0.001215	 0.004169	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21577	 21582	 0.004212	 0.013739	 0.00365	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81886	 21577	 0.000877	 0.0087	 0.00237	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21578	 21579	 0.002825	 0.007584	 0.00172	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21578	 82501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21578	 82501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21579	 82502	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21579	 82502	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21580	 21581	 0.01806	 0.014292	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21580	 21583	 0.009729	 0.019262	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21581	 21596	 0.028292	 0.02239	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21581	 82503	 0.048362	 0.038273	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21582	 21587	 0.001116	 0.003233	 0.00078	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21582	 82503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21582	 82503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21583	 21584	 0.041942	 0.030858	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82502	 21583	 0.00572	 0.015122	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82503	 21583	 0.023782	 0.018821	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21584	 21585	 0.022252	 0.01761	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82501	 21584	 0.008797	 0.017418	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21585	 82504	 0.008771	 0.017366	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21586	 82504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21586	 82504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21587	 21588	 0.000838	 0.002249	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21589	 82507	 0.013877	 0.046293	 0.00073	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21590	 21592	 0.038959	 0.047493	 0.00076	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21590	 21596	 0.047009	 0.04702	 0.00064	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21590	 82506	 0.008183	 0.026351	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21591	 82505	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21593	 21595	 0.028502	 0.043661	 0.00061	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21594	 21597	 0.001653	 0.005672	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21594	 82507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21594	 82507	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82507	 21595	 0.004903	 0.019072	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82506	 21596	 0.012956	 0.030681	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82329	 21597	 0.00338	 0.013531	 0.00341	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21599	 82508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21599	 82508	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21600	 82509	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21600	 82509	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82454	 21601	 0.001027	 0.006432	 0.00463	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82468	 21602	 0.000699	 0.002796	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21603	 82510	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21604	 21817	 0.000971	 0.010651	 0.10348	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21604	 21855	 0.000766	 0.008565	 0.08003	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82131	 21604	 0.003027	 0.036036	 0.33181	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21604	 82512	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82512	 21605	 0.002751	 0.00714	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21605	 82514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21605	 82514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21606	 21610	 0.045083	 0.089263	 0.00131	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21606	 82519	 0.032859	 0.084469	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21606	 82611	 0.094466	 0.271	 0.00417	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21607	 82516	 0.096576	 0.12694	 0.00174	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21607	 82630	 0.047562	 0.093215	 0.0014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21608	 21609	 0.00042	 0.004851	 0.04253	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21608	 82515	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21609	 21762	 0.000917	 0.010581	 0.09278	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21609	 82517	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82513	 21610	 0.042436	 0.13019	 0.00353	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21610	 82519	 0.011347	 0.02917	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21610	 82520	 0.006122	 0.029402	 0.00057	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21611	 21612	 0.000764	 0.008736	 0.00266	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21611	 82519	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21611	 82519	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82515	 21612	 0.001113	 0.018553	 0.00564	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21612	 82520	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21612	 82520	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82520	 21613	 0.049456	 0.0505	 0.00079	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82514	 21614	 0.04492	 0.091928	 0.00226	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82518	 21615	 0.068568	 0.17628	 0.00273	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21616	 21617	 0.005477	 0.040001	 0.01028	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82154	 21616	 0.008647	 0.088977	 0.02525	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21617	 21618	 0.009369	 0.03214	 0.0077	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21618	 21700	 0.005169	 0.036563	 0.01003	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21619	 21621	 0.000619	 0.006798	 0.06603	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21619	 22041	 0.000519	 0.009592	 0.09217	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21619	 82521	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21619	 82521	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21620	 21621	 0.000127	 0.001416	 0.01336	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21620	 22037	 0.000405	 0.007067	 0.07646	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21620	 82522	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21621	 21628	 0.000458	 0.005445	 0.05	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21621	 82524	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21621	 82524	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81927	 21622	 0.02475	 0.023913	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21622	 82526	 0.010228	 0.020045	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21623	 82525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21623	 82525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21624	 21627	 0.002813	 0.015433	 0.00408	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82524	 21624	 0.002395	 0.008068	 0.00201	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21624	 82526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21624	 82526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21625	 21626	 0.001675	 0.017621	 0.0099	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21625	 82703	 0.00254	 0.020799	 0.01337	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82295	 21626	 0.011943	 0.047821	 0.01205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82522	 21626	 0.016946	 0.045498	 0.01031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21626	 82527	 0.002633	 0.014968	 0.00433	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82130	 21627	 0.004103	 0.022515	 0.00595	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21627	 82527	 0.006105	 0.016133	 0.00378	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21628	 21924	 0.002472	 0.027152	 0.26421	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21628	 22037	 0.00123	 0.013634	 0.12985	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21628	 82527	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21628	 82527	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21629	 21632	 0.010321	 0.013565	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21629	 21638	 0.015439	 0.015765	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21629	 21659	 0.012876	 0.012441	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21630	 21659	 0.017042	 0.013487	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21630	 82528	 0.006444	 0.012628	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21631	 21647	 0.003049	 0.008058	 0.00189	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21631	 82528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21631	 82528	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21632	 21633	 0.007647	 0.011142	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21632	 82529	 0.012804	 0.02535	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21632	 82535	 0.00609	 0.014907	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21634	 21636	 0.003109	 0.007991	 0.00198	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21634	 82529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21634	 82529	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82529	 21635	 0.009354	 0.013258	 0.00027	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21635	 82536	 0.037252	 0.088854	 0.00199	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82400	 21636	 0.026159	 0.087294	 0.02215	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21636	 82530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21636	 82530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82529	 21637	 0.022961	 0.038139	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82530	 21637	 0.014162	 0.025552	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21638	 21639	 0.014833	 0.011738	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82529	 21638	 0.006049	 0.01404	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21640	 21641	 0.002996	 0.010847	 0.00233	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21640	 21652	 0.004907	 0.017768	 0.00381	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21641	 21644	 0.005045	 0.013736	 0.00303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21641	 21655	 0.00844	 0.028952	 0.00694	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21641	 82531	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21641	 82531	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82528	 21642	 0.021528	 0.017037	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21642	 82533	 0.019873	 0.020292	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21643	 82532	 0.008828	 0.017301	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21644	 21645	 0.002061	 0.006259	 0.00137	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21644	 21656	 0.005915	 0.015357	 0.00373	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21644	 82532	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21644	 82532	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21645	 21646	 0.001313	 0.004642	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21645	 82533	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21645	 82533	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21646	 21657	 0.003795	 0.014425	 0.00404	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21646	 82534	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21646	 82534	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21647	 21648	 0.00176	 0.005929	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21647	 82535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21647	 82535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21648	 21649	 0.002284	 0.007833	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21649	 21650	 0.004718	 0.01997	 0.00449	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21650	 82536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21650	 82536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21651	 21708	 0.000414	 0.005663	 0.05771	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21651	 82537	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82537	 21652	 0.001062	 0.00966	 0.00244	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21652	 82539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21652	 82539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82538	 21653	 0.012097	 0.034328	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82539	 21653	 0.015179	 0.035241	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82530	 21654	 0.036299	 0.064837	 0.00096	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82539	 21654	 0.015725	 0.029239	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21655	 21677	 0.008859	 0.029555	 0.0075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21656	 82540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21656	 82540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21657	 21658	 0.003196	 0.014567	 0.00462	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21658	 82541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21658	 82541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21660	 21664	 0.002798	 0.028779	 0.00816	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21661	 21662	 0.002842	 0.021121	 0.00805	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21661	 21945	 0.006157	 0.033788	 0.00893	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21661	 82542	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21661	 82542	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21662	 21666	 0.012469	 0.032372	 0.00786	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82231	 21662	 0.004685	 0.039405	 0.01167	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21662	 82543	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21662	 82543	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82543	 21663	 0.017625	 0.078536	 0.00133	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21663	 82544	 0.017937	 0.023574	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21664	 82544	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21664	 82544	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21664	 82545	 0.001682	 0.024725	 0.00756	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82544	 21665	 0.010941	 0.027825	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21665	 82546	 0.017723	 0.078088	 0.00136	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21666	 21709	 0.018384	 0.050057	 0.01103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21666	 82545	 0.007433	 0.029759	 0.0075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21667	 82545	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82546	 21668	 0.019311	 0.094234	 0.00163	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21669	 82547	 0.028778	 0.073977	 0.00114	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21670	 82547	 0.057379	 0.037148	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21670	 82548	 0.02995	 0.023702	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21671	 21672	 0.003903	 0.010884	 0.00228	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21671	 82547	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21671	 82547	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21672	 82548	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21672	 82548	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21673	 21674	 0.02602	 0.067437	 0.00128	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81923	 21673	 0.20091	 0.15902	 0.002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21673	 82563	 0.068296	 0.1866	 0.00317	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82288	 21674	 0.18658	 0.12081	 0.0023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81923	 21675	 0.018097	 0.042853	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82547	 21675	 0.025644	 0.073551	 0.00113	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21676	 82549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21676	 82549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21677	 21679	 0.005482	 0.012725	 0.00388	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21678	 21679	 0.003439	 0.009233	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21679	 82550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21679	 82550	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82539	 21680	 0.091951	 0.26098	 0.0041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82550	 21680	 0.009077	 0.013608	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21681	 21704	 0.006849	 0.03142	 0.00805	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21682	 21683	 0.014336	 0.038489	 0.00872	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82311	 21683	 0.014517	 0.044084	 0.00966	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21683	 82551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21683	 82551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21683	 82552	 0.008119	 0.056336	 0.01608	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82315	 21684	 0.060944	 0.17481	 0.00269	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21684	 82553	 0.036841	 0.090179	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21685	 82552	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21686	 21688	 0.000218	 0.002517	 0.02207	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21686	 82554	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21686	 82554	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82167	 21687	 0.059149	 0.16966	 0.00261	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82554	 21687	 0.019789	 0.035569	 0.00064	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21687	 82556	 0.008477	 0.024928	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21688	 82555	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82556	 21689	 0.031285	 0.077653	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21690	 21691	 0.000141	 0.001551	 0.01506	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21690	 82557	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21691	 82559	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21691	 82559	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82558	 21692	 0.05537	 0.14234	 0.0022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21692	 82720	 0.057812	 0.22494	 0.00376	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21693	 21695	 0.007098	 0.02842	 0.00716	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82555	 21693	 0.001511	 0.014786	 0.01285	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82557	 21693	 0.001857	 0.024359	 0.01169	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82085	 21694	 0.32232	 0.25517	 0.00321	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82556	 21694	 0.05044	 0.12828	 0.00203	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21694	 82720	 0.043682	 0.14573	 0.00231	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21695	 22094	 0.006982	 0.028414	 0.00692	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21696	 21697	 0.13514	 0.090783	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82159	 21697	 0.022722	 0.088398	 0.00148	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21697	 82651	 0.019236	 0.11826	 0.00213	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82115	 21698	 0.22038	 0.50462	 0.01234	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21698	 82560	 0.037691	 0.21181	 0.00392	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21699	 82560	 0.035407	 0.091018	 0.00141	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21699	 82562	 0.069617	 0.13784	 0.00202	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21700	 82560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21700	 82560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21701	 21702	 0.004794	 0.028082	 0.00765	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21701	 82561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21701	 82561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21702	 22058	 0.007333	 0.053562	 0.01377	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21702	 82562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21702	 82562	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82562	 21703	 0.11943	 0.094523	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21704	 21707	 0.005357	 0.026648	 0.0086	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21704	 82563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21704	 82563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21705	 21706	 0.009349	 0.038925	 0.01214	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21705	 21770	 0.006407	 0.0419	 0.01066	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21705	 82564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21705	 82564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81917	 21706	 0.00996	 0.061819	 0.01498	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82537	 21707	 0.010508	 0.02728	 0.00662	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21707	 82565	 0.004321	 0.025741	 0.00677	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21708	 82565	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21708	 82565	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21709	 21711	 0.012484	 0.032995	 0.00772	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21709	 82566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21709	 82566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21710	 21711	 0.008991	 0.023762	 0.00556	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21710	 22006	 0.008869	 0.023025	 0.00559	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21710	 82567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21710	 82567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21712	 21766	 0.13163	 0.18347	 0.00314	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82567	 21712	 0.06815	 0.1752	 0.00271	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21713	 82569	 0.10013	 0.17612	 0.00331	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21714	 82568	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81859	 21715	 0.003509	 0.057523	 0.01809	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82568	 21715	 0.001981	 0.022185	 0.00705	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21715	 82570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21715	 82570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21716	 21717	 0.011474	 0.036946	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81860	 21716	 0.054896	 0.24466	 0.00416	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82570	 21716	 0.01757	 0.028045	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82569	 21717	 0.034652	 0.070914	 0.00175	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81900	 21718	 0.019939	 0.050127	 0.01299	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21718	 82571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21718	 82571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81901	 21719	 0.039961	 0.028888	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81901	 21720	 0.10903	 0.086285	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21720	 82572	 0.091761	 0.14648	 0.00337	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21721	 82572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21721	 82572	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21722	 21724	 0.000748	 0.008866	 0.00454	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21722	 21737	 0.00362	 0.012665	 0.0042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21723	 21725	 0.000123	 0.001863	 0.03338	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21723	 82573	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21723	 82573	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21724	 82574	 0.000469	 0.007649	 0.00456	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21724	 82575	 0.0004	 0.005892	 0.00288	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21725	 21726	 0.000108	 0.001647	 0.02952	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21725	 82574	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21725	 82574	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21726	 82575	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21726	 82575	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21727	 21734	 0.002744	 0.007253	 0.0017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21727	 21753	 0.004274	 0.013358	 0.00387	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81915	 21728	 0.007028	 0.019943	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21728	 82576	 0.011158	 0.022093	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21729	 82576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21729	 82576	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21730	 21733	 0.020314	 0.031118	 0.00044	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21730	 21735	 0.010549	 0.020887	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82576	 21730	 0.012892	 0.036976	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21731	 21734	 0.002254	 0.005794	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21731	 82577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21731	 82577	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21732	 21736	 0.017095	 0.039687	 0.00059	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21732	 21747	 0.021183	 0.044521	 0.00081	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82577	 21732	 0.003016	 0.014716	 0.00025	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21733	 21736	 0.013143	 0.037695	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81922	 21733	 0.11943	 0.086341	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82577	 21733	 0.035463	 0.043231	 0.00069	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21733	 82578	 0.035953	 0.026452	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21734	 82578	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21734	 82578	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21736	 21747	 0.069475	 0.051115	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21737	 21740	 0.001548	 0.006198	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21737	 21745	 0.010428	 0.027561	 0.00645	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21738	 21742	 0.002547	 0.023428	 0.00046	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82577	 21738	 0.004796	 0.047	 0.00092	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21739	 21742	 0.019736	 0.035473	 0.00064	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21739	 21744	 0.027501	 0.01948	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21739	 82580	 0.1209	 0.09274	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21740	 21745	 0.008181	 0.01899	 0.00579	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21740	 82579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21740	 82579	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21741	 21742	 0.008827	 0.016167	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82579	 21741	 0.011414	 0.017486	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21742	 21744	 0.015455	 0.0306	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82579	 21742	 0.019725	 0.033229	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21743	 21744	 0.022247	 0.018311	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82579	 21743	 0.00764	 0.019352	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21745	 82580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21745	 82580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21746	 21747	 0.070205	 0.050752	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21748	 21749	 0.005509	 0.014559	 0.00341	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21749	 21750	 0.007945	 0.019972	 0.00517	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21751	 82581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21751	 82581	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81880	 21752	 0.001638	 0.009594	 0.00261	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81880	 21753	 0.000146	 0.002201	 0.00155	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21754	 82582	 0.085907	 0.24643	 0.00379	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21755	 21756	 0.1515	 0.10953	 0.00166	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21755	 82584	 0.21571	 0.13968	 0.00266	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21756	 21998	 0.18553	 0.13144	 0.00208	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21756	 82582	 0.17861	 0.14136	 0.00178	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21757	 21760	 0.005947	 0.027281	 0.00699	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81873	 21757	 0.002058	 0.0155	 0.0043	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21757	 82582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21757	 82582	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21758	 82583	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21758	 82583	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21759	 21760	 0.001413	 0.005981	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82583	 21759	 0.00317	 0.013416	 0.00302	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21760	 82584	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21760	 82584	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21761	 82586	 0.078475	 0.057737	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21762	 21763	 0.000354	 0.006592	 0.06242	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21762	 22092	 0.001163	 0.013173	 0.11997	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21762	 82585	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21763	 21889	 0.000625	 0.007078	 0.06444	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21763	 82587	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21764	 22087	 0.009911	 0.038956	 0.01019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82587	 21764	 0.011129	 0.039338	 0.00886	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21765	 21766	 0.058471	 0.15032	 0.00233	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82546	 21765	 0.059484	 0.13494	 0.00269	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21766	 82589	 0.023674	 0.072701	 0.00136	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21767	 21768	 0.00383	 0.012777	 0.00324	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21767	 21771	 0.010022	 0.034379	 0.00824	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21767	 82589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21767	 82589	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21768	 21769	 0.006221	 0.02096	 0.00521	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21768	 21770	 0.009655	 0.032208	 0.00817	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82537	 21770	 0.025724	 0.0867	 0.02156	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21770	 82590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21770	 82590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21771	 82591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21771	 82591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21772	 21774	 0.006843	 0.023474	 0.00562	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21772	 21775	 0.002132	 0.025906	 0.00698	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21772	 82592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21772	 82592	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82117	 21773	 0.16916	 0.30415	 0.00546	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82592	 21773	 0.051124	 0.14143	 0.00329	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21773	 82595	 0.035321	 0.10131	 0.00156	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21774	 82593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21774	 82593	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21775	 21776	 0.00061	 0.005397	 0.00296	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21775	 82594	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21775	 82594	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21776	 21777	 0.006689	 0.026781	 0.00675	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21776	 21779	 0.008157	 0.03266	 0.00823	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21777	 82595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21777	 82595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21778	 22072	 0.004087	 0.035663	 0.00979	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21778	 25684	 0.007845	 0.043207	 0.0156	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21778	 82596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21778	 82596	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21779	 82597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21779	 82597	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21780	 21781	 0.007722	 0.027294	 0.00615	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21780	 82598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21780	 82598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21781	 21782	 0.002895	 0.026332	 0.00665	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21781	 82599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21781	 82599	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21782	 21784	 0.003259	 0.029647	 0.00748	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21782	 82600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21782	 82600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21783	 21784	 0.008905	 0.031161	 0.01033	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21784	 21785	 0.009647	 0.024799	 0.00614	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21786	 21789	 0.000851	 0.008603	 0.00253	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21787	 82601	 0.048308	 0.1144	 0.00209	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21787	 82634	 0.039505	 0.17605	 0.00299	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21788	 21789	 0.001111	 0.009242	 0.0028	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21788	 21790	 0.00368	 0.02772	 0.00769	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21788	 82601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21788	 82601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21790	 82637	 0.003359	 0.043717	 0.01264	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21791	 21813	 0.000811	 0.003649	 0.00097	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21791	 82602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21791	 82602	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21792	 21793	 0.015696	 0.014719	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21792	 21795	 0.012469	 0.011693	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82602	 21792	 0.007251	 0.017171	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21792	 82603	 0.009374	 0.01856	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21794	 21796	 0.00259	 0.008883	 0.00213	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21794	 21835	 0.002764	 0.008006	 0.00193	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21794	 82603	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21794	 82603	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21795	 82604	 0.003977	 0.007284	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21796	 21811	 0.000643	 0.00224	 0.00052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21796	 82604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21796	 82604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21797	 21798	 0.011814	 0.00854	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21797	 21809	 0.007618	 0.008297	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21798	 21799	 0.001428	 0.006365	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21798	 21809	 0.007523	 0.01068	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21798	 21810	 0.007072	 0.016248	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21798	 82606	 0.007529	 0.017958	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21799	 21801	 0.009643	 0.014051	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21799	 21838	 0.002803	 0.014933	 0.00026	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21800	 21801	 0.008043	 0.011209	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21800	 21807	 0.005983	 0.012295	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21800	 82605	 0.001978	 0.008715	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21802	 21804	 0.009373	 0.014358	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21802	 21849	 0.003245	 0.011361	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21802	 82605	 0.006663	 0.03253	 0.00068	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21803	 21804	 0.015334	 0.015488	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21803	 21807	 0.005934	 0.011749	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21804	 21805	 0.012001	 0.009205	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21805	 21806	 0.004734	 0.009372	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21806	 21821	 0.002592	 0.009075	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21806	 82614	 0.017405	 0.013774	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21808	 21819	 0.001206	 0.003101	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21808	 21826	 0.00303	 0.010561	 0.00245	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21808	 82605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21808	 82605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21808	 82610	 0.000506	 0.003169	 0.00228	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21809	 21810	 0.002151	 0.005702	 0.00014	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21810	 82611	 0.002799	 0.010931	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21811	 21812	 0.00056	 0.002497	 0.00068	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21811	 82606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21811	 82606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21812	 21813	 0.001137	 0.0039	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21812	 82610	 0.000893	 0.003235	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21813	 21815	 0.000337	 0.003297	 0.00093	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21813	 21835	 0.003973	 0.015908	 0.00401	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21813	 82607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21813	 82607	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21813	 82610	 0.002643	 0.006985	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82607	 21814	 0.001755	 0.009352	 0.00016	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21814	 82609	 0.0019	 0.009274	 0.00019	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21814	 82613	 0.043684	 0.037336	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21815	 21836	 0.000513	 0.0044	 0.00125	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21815	 82608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21815	 82608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21816	 21818	 0.001083	 0.004583	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21816	 21836	 0.001211	 0.006125	 0.0017	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21816	 82609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21816	 82609	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21817	 21829	 0.000324	 0.004023	 0.04041	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21817	 21834	 0.000228	 0.004038	 0.0423	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21817	 22239	 0.000655	 0.007566	 0.06633	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21817	 82610	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21818	 21861	 0.001827	 0.020571	 0.00595	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82610	 21818	 0.000627	 0.005211	 0.00204	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21819	 82612	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21819	 82612	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21820	 21823	 0.011883	 0.009115	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82612	 21820	 0.008253	 0.008794	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21821	 21822	 0.007059	 0.018145	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82612	 21821	 0.008306	 0.016446	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21822	 82627	 0.010101	 0.021566	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21824	 21858	 0.001028	 0.00651	 0.00177	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82610	 21824	 0.002184	 0.00644	 0.0015	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21824	 82613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21824	 82613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82613	 21825	 0.031677	 0.025069	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21826	 21827	 0.001272	 0.004364	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21826	 82614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21826	 82614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21827	 21828	 0.001599	 0.003711	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21828	 21832	 0.002324	 0.005975	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 0	 -30.0	 30.0;
	21828	 82615	 0.001655	 0.004297	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21829	 21856	 8.8e-05	 0.001	 0.0091	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21829	 82615	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21829	 82615	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21830	 82622	 0.034628	 0.025477	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21830	 82625	 0.032322	 0.025579	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21831	 82616	 0.022315	 0.01766	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21831	 82626	 0.043245	 0.067477	 0.00113	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82610	 21832	 0.004566	 0.019011	 0.00593	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21832	 82616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21832	 82616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21833	 21834	 0.000157	 0.002908	 0.02794	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21833	 82617	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21833	 82617	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21834	 22227	 0.001117	 0.012893	 0.11306	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21834	 82618	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21834	 82618	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21835	 21841	 0.003605	 0.012146	 0.00302	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81933	 21835	 0.034221	 0.088873	 0.02158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21835	 82619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21835	 82619	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82618	 21836	 0.00076	 0.00799	 0.00449	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21837	 21838	 0.006119	 0.012115	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82603	 21837	 0.015701	 0.030068	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21838	 21839	 0.0113	 0.03241	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82619	 21838	 0.087478	 0.067102	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21839	 21843	 0.039044	 0.030605	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21839	 21849	 0.012111	 0.022889	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21839	 21852	 0.014889	 0.031293	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21840	 21841	 0.001708	 0.005696	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21840	 82620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21840	 82620	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82620	 21842	 0.04123	 0.030334	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82620	 21843	 0.028873	 0.02285	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82620	 21844	 0.010413	 0.027598	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21844	 82621	 0.00932	 0.018453	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21845	 21846	 0.002166	 0.005444	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21845	 22242	 0.00778	 0.022937	 0.00534	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21845	 82621	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21845	 82621	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21846	 21848	 0.002894	 0.006717	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21847	 21848	 0.00311	 0.009169	 0.00213	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21848	 22303	 0.007313	 0.017624	 0.00498	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82199	 21848	 0.011682	 0.031806	 0.00701	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21849	 21853	 0.024112	 0.019082	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82199	 21850	 0.009653	 0.025512	 0.00597	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82615	 21850	 0.00115	 0.005776	 0.0015	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21850	 82622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21850	 82622	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21850	 82778	 0.019742	 0.053754	 0.01184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21851	 21852	 0.041332	 0.03876	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21851	 21854	 0.01937	 0.037961	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82622	 21851	 0.008407	 0.02161	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82616	 21853	 0.010193	 0.020181	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82200	 21854	 0.069463	 0.054972	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21855	 21856	 0.000151	 0.00171	 0.01557	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21855	 82623	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 0	 -30.0	 30.0;
	82198	 21856	 0.000315	 0.003657	 0.03162	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21856	 82625	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21856	 82625	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21857	 21859	 0.004041	 0.012632	 0.00366	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21857	 82626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21857	 82626	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21858	 21859	 0.001117	 0.006942	 0.00196	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21858	 21860	 0.000852	 0.009193	 0.00263	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21859	 82627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21859	 82627	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21860	 21864	 0.001801	 0.016953	 0.00514	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21862	 21863	 0.000322	 0.003531	 0.0343	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21862	 22230	 0.001301	 0.014738	 0.13424	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21862	 82628	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21862	 82628	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21863	 82629	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82628	 21864	 0.002401	 0.029176	 0.00786	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21864	 82631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21864	 82631	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82512	 21865	 0.009483	 0.024376	 0.00604	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82623	 21865	 0.011033	 0.02916	 0.00683	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21866	 82632	 0.093506	 0.073296	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21866	 82633	 0.12945	 0.083815	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21867	 21869	 0.007083	 0.019015	 0.00431	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21867	 82632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21867	 82632	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21868	 21869	 0.00247	 0.01419	 0.00402	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21868	 22056	 0.002961	 0.026234	 0.00698	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21869	 21870	 0.010481	 0.02814	 0.00638	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21869	 82633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21869	 82633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21871	 82634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21871	 82634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21871	 82635	 0.003522	 0.022683	 0.00595	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82328	 21872	 0.035207	 0.093319	 0.00237	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82634	 21872	 0.054289	 0.14352	 0.00261	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21873	 21875	 0.000248	 0.002623	 0.02736	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21873	 82635	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21873	 82635	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82329	 21874	 0.006713	 0.062507	 0.01937	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21874	 82636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21874	 82636	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21874	 82637	 0.003228	 0.013135	 0.0032	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21875	 21878	 6.2e-05	 0.001123	 0.01123	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21875	 82637	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21875	 82637	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21876	 21877	 0.000358	 0.002035	 0.00059	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82635	 21876	 0.004384	 0.017229	 0.00451	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82637	 21876	 0.001455	 0.006157	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21876	 82638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21876	 82638	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21877	 82639	 0.000461	 0.002831	 0.00082	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21878	 21879	 0.000119	 0.001504	 0.01342	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21878	 82639	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21879	 21880	 0.000345	 0.00379	 0.03682	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21879	 82641	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21879	 82641	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21880	 82642	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21880	 82642	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21881	 21882	 0.003372	 0.023736	 0.0135	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21881	 21883	 0.007702	 0.053441	 0.01526	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82191	 21881	 0.001733	 0.028397	 0.00893	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 21882	 0.002765	 0.02507	 0.01311	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 21883	 0.002241	 0.025616	 0.00781	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21883	 82643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21883	 82643	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81860	 21884	 0.12545	 0.13665	 0.00186	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82643	 21884	 0.08281	 0.16397	 0.00241	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21884	 82705	 0.10115	 0.20029	 0.00294	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81860	 21885	 0.086169	 0.068194	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21886	 21887	 0.0031	 0.019239	 0.00466	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82629	 21886	 0.004605	 0.025692	 0.00656	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21887	 21890	 0.002301	 0.016801	 0.00432	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82517	 21888	 0.002921	 0.021704	 0.00828	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21888	 82644	 0.001869	 0.020669	 0.0062	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21889	 82644	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21889	 82644	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21890	 21891	 0.002206	 0.0223	 0.00656	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82644	 21890	 0.007894	 0.020863	 0.00488	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82587	 21891	 0.016511	 0.042868	 0.01041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21891	 82645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21891	 82645	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81896	 21892	 0.060261	 0.15326	 0.00242	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82581	 21892	 0.062804	 0.16145	 0.0025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82588	 21892	 0.052619	 0.13383	 0.00212	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21893	 21897	 0.011242	 0.029713	 0.00696	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21893	 21898	 0.013011	 0.033448	 0.00828	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21893	 21901	 0.00843	 0.053402	 0.0145	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21893	 22610	 0.025774	 0.088445	 0.0212	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21893	 82646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21893	 82646	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21894	 21896	 0.03182	 0.058282	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21894	 22251	 0.040563	 0.11511	 0.00181	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21894	 22252	 0.04659	 0.095346	 0.00235	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21894	 82647	 0.031376	 0.089991	 0.00138	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21895	 82647	 0.12588	 0.12715	 0.00168	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21896	 21900	 0.033149	 0.12896	 0.00215	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21896	 82647	 0.012772	 0.049136	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21897	 21898	 0.00571	 0.026197	 0.00671	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21897	 27768	 0.004331	 0.031661	 0.00934	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21898	 82647	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21898	 82647	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82647	 21899	 0.014339	 0.042167	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21899	 82648	 0.009472	 0.053301	 0.00115	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21901	 82648	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21901	 82648	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21902	 21904	 0.005198	 0.029868	 0.00846	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21902	 22031	 0.012069	 0.043703	 0.00938	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81868	 21903	 0.012687	 0.032881	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21903	 82649	 0.036732	 0.075171	 0.00185	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81867	 21904	 0.003172	 0.022433	 0.00616	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21904	 82649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21904	 82649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82649	 21905	 0.12055	 0.095405	 0.0012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21905	 82650	 0.050044	 0.1323	 0.0024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21906	 82650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21906	 82650	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21907	 82651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21907	 82651	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21908	 21909	 0.11952	 0.12072	 0.0016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81928	 21909	 0.082497	 0.16335	 0.0024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82323	 21909	 0.033904	 0.15108	 0.00257	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21910	 82652	 0.007449	 0.015308	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21910	 82664	 0.017895	 0.041546	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21911	 82652	 0.016763	 0.013266	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21912	 21913	 0.000868	 0.004235	 0.00117	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21912	 21914	 0.00099	 0.003394	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21912	 82657	 0.001681	 0.005034	 0.00113	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21913	 21931	 0.001945	 0.005222	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21913	 21946	 0.000986	 0.005655	 0.00188	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21913	 82652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21913	 82652	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21914	 21915	 0.001753	 0.004552	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21915	 82653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21915	 82653	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21915	 82655	 0.002446	 0.005895	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21916	 21917	 0.00986	 0.007803	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21917	 21918	 0.003251	 0.008268	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82652	 21917	 0.031581	 0.02237	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21917	 82665	 0.004915	 0.015825	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82653	 21918	 0.003675	 0.008531	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21918	 82656	 0.02167	 0.026899	 0.00059	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21919	 21920	 0.000764	 0.002765	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21919	 21946	 0.002451	 0.006364	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21920	 21922	 0.001063	 0.003648	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21921	 82654	 0.008135	 0.020688	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21922	 21923	 0.000814	 0.005464	 0.00132	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21922	 82654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21922	 82654	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21923	 82662	 0.002803	 0.022751	 0.00724	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21924	 21926	 0.000201	 0.002285	 0.02063	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21924	 21940	 0.000351	 0.005819	 0.05454	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21924	 82655	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82655	 21925	 0.003137	 0.00854	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21925	 82657	 0.0017	 0.005545	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21926	 21933	 0.000234	 0.004097	 0.04383	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21926	 21942	 4.2e-05	 0.000477	 0.00434	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21926	 82657	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21926	 82657	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21927	 21928	 0.001917	 0.005219	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21927	 21936	 0.002611	 0.007488	 0.00184	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21927	 82658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21927	 82658	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21928	 21929	 0.001701	 0.005015	 0.00117	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21928	 21931	 0.00302	 0.01036	 0.00248	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81878	 21928	 0.014263	 0.051652	 0.01108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21929	 21931	 0.001606	 0.005018	 0.00145	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21930	 82659	 0.010583	 0.008295	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21931	 21946	 0.000783	 0.00572	 0.00147	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21931	 82659	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21931	 82659	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82659	 21932	 0.002299	 0.007668	 0.00012	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21933	 82660	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21934	 21935	 0.049185	 0.067105	 0.0012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81907	 21934	 0.043127	 0.10013	 0.00149	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82658	 21935	 0.023551	 0.030953	 0.00042	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21937	 21938	 0.008241	 0.009064	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82658	 21937	 0.042531	 0.033659	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21938	 21939	 0.011498	 0.009099	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82659	 21938	 0.005748	 0.011762	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21940	 82662	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21940	 82662	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21941	 21945	 0.006855	 0.024822	 0.00533	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82655	 21941	 0.006074	 0.016938	 0.00356	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21942	 82663	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82664	 21943	 0.040366	 0.064433	 0.00148	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82656	 21944	 0.015523	 0.078985	 0.00179	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82662	 21946	 0.001395	 0.015565	 0.01036	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21946	 82665	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21946	 82665	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82406	 21947	 0.060347	 0.15641	 0.00296	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21947	 82667	 0.03373	 0.096744	 0.00149	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21948	 21949	 0.007274	 0.029125	 0.00734	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21950	 82666	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21951	 21952	 0.060937	 0.10717	 0.00201	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82213	 21951	 0.041676	 0.18364	 0.00319	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21951	 82709	 0.20415	 0.16159	 0.00203	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21952	 25005	 0.1602	 0.16183	 0.00214	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21953	 21973	 0.021665	 0.01594	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21953	 21974	 0.024466	 0.019362	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21953	 82668	 0.026188	 0.027902	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21954	 82677	 0.002307	 0.007912	 0.0019	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21955	 21956	 0.001693	 0.004721	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21955	 82668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21955	 82668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21955	 82677	 0.002396	 0.010786	 0.00287	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21956	 21972	 0.001893	 0.005002	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21956	 82669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21956	 82669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82668	 21957	 0.020366	 0.016117	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82669	 21957	 0.014804	 0.011604	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21958	 21987	 0.002016	 0.005328	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21958	 82670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21958	 82670	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21959	 21960	 0.012324	 0.009753	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82670	 21959	 0.019678	 0.015573	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21960	 21961	 0.024083	 0.017719	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21960	 21963	 0.034508	 0.027309	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82668	 21961	 0.024082	 0.036891	 0.00052	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21961	 82676	 0.023551	 0.018638	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21962	 21963	 0.026137	 0.020685	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82669	 21962	 0.038998	 0.03768	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21963	 21996	 0.042207	 0.08674	 0.00165	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21964	 21965	 0.011764	 0.007616	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21964	 21968	 0.011474	 0.00908	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21965	 21967	 0.008301	 0.008384	 0.00011	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21966	 21967	 0.007642	 0.008405	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21966	 82673	 0.005439	 0.009162	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21968	 21969	 0.0042	 0.010797	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21969	 82672	 0.002367	 0.010164	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21970	 21992	 0.000374	 0.004109	 0.03991	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21970	 82671	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21971	 21975	 0.004849	 0.010879	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82672	 21971	 0.004327	 0.011124	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82671	 21972	 0.001405	 0.006326	 0.00168	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21972	 82673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21972	 82673	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82673	 21973	 0.002198	 0.009794	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21973	 82674	 0.011373	 0.029236	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21974	 21975	 0.008435	 0.0167	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21974	 21984	 0.013088	 0.025913	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21975	 82674	 0.007654	 0.015154	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21976	 21977	 0.001273	 0.003304	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82671	 21976	 0.000788	 0.003153	 0.00079	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21976	 82674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21976	 82674	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21977	 21978	 0.001966	 0.005918	 0.00185	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81921	 21978	 0.000129	 0.001126	 0.00031	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82671	 21978	 0.002212	 0.006717	 0.00147	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21978	 82675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21978	 82675	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82675	 21979	 0.017641	 0.01856	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21980	 21981	 0.001278	 0.003285	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81921	 21980	 0.001016	 0.002611	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21981	 82682	 0.003729	 0.009374	 0.00243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21982	 21991	 0.016454	 0.025205	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82674	 21982	 0.007941	 0.015386	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21983	 21991	 0.01604	 0.010385	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21984	 82679	 0.015888	 0.024339	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21985	 22001	 0.028167	 0.02134	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21985	 82676	 0.010552	 0.017776	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82668	 21986	 0.009057	 0.021026	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82670	 21986	 0.024094	 0.018482	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21986	 82704	 0.035914	 0.064551	 0.00116	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21987	 21988	 0.002009	 0.005308	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21987	 82676	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21987	 82676	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21988	 21989	 0.00193	 0.005101	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21989	 22051	 0.003056	 0.007935	 0.00193	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82676	 21990	 0.031037	 0.031045	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21990	 82678	 0.036356	 0.071252	 0.00107	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21991	 82681	 0.007896	 0.020297	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21992	 82677	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21993	 82681	 0.012521	 0.048709	 0.00081	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21993	 82684	 0.038417	 0.063812	 0.00135	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21994	 82679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21994	 82679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21995	 82680	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81874	 21996	 0.010694	 0.05698	 0.001	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81861	 21997	 0.001625	 0.017841	 0.17343	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21997	 82682	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21998	 21999	 0.1266	 0.081968	 0.00156	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82681	 21998	 0.06461	 0.057896	 0.00118	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82683	 21998	 0.029988	 0.058102	 0.00125	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82680	 22000	 0.004766	 0.023503	 0.00636	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22000	 82684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22000	 82684	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81869	 22002	 0.010775	 0.035144	 0.00933	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22003	 22004	 0.004231	 0.036291	 0.01033	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81869	 22003	 0.004109	 0.026464	 0.00694	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81911	 22003	 0.002818	 0.024587	 0.00675	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22003	 82685	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22003	 82685	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22004	 22005	 0.003406	 0.017111	 0.00445	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22004	 82686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22004	 82686	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22005	 22026	 0.006385	 0.020827	 0.00553	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22005	 82687	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22005	 82687	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22006	 22024	 0.007284	 0.023759	 0.00631	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22006	 82688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22006	 82688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22007	 82695	 0.010424	 0.019702	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22008	 22009	 0.000316	 0.00191	 0.00049	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22008	 22011	 0.001072	 0.006787	 0.00184	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22008	 22014	 0.00038	 0.00365	 0.00106	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22008	 22015	 0.000328	 0.002812	 0.0008	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22009	 22010	 0.000399	 0.002336	 0.00064	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22010	 22011	 0.000454	 0.002876	 0.00078	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22011	 82689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22011	 82689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22011	 82691	 0.000335	 0.003038	 0.00159	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22012	 22013	 0.000621	 0.00596	 0.00173	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22012	 22033	 0.000829	 0.007802	 0.00236	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22013	 22014	 0.00052	 0.004464	 0.00127	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81903	 22013	 0.000461	 0.005466	 0.0028	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22015	 22016	 0.000474	 0.004313	 0.00109	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22015	 22017	 0.002611	 0.00701	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81903	 22016	 0.002792	 0.015323	 0.00405	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22016	 82690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22016	 82690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22017	 22019	 0.001991	 0.005118	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82689	 22018	 0.02169	 0.01568	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82690	 22018	 0.017434	 0.050004	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22018	 82692	 0.007093	 0.017966	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22019	 22030	 0.005173	 0.012465	 0.00352	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22020	 22032	 0.000369	 0.006481	 0.06934	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22020	 22034	 0.000185	 0.003288	 0.0341	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81902	 22020	 0.000262	 0.003219	 0.05158	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22020	 82691	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22021	 22022	 0.001205	 0.004734	 0.00124	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82691	 22021	 0.001051	 0.003605	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22022	 82693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22022	 82693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22022	 82696	 0.001746	 0.015878	 0.00401	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22023	 22025	 0.024372	 0.048254	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81903	 22024	 0.008161	 0.021188	 0.00514	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82686	 22025	 0.083127	 0.17014	 0.00419	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82690	 22025	 0.015311	 0.0523	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81903	 22026	 0.003613	 0.012393	 0.00297	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22027	 22028	 0.000953	 0.009795	 0.00371	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81877	 22027	 0.001316	 0.015624	 0.00544	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22028	 22033	 0.000475	 0.005775	 0.00156	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82691	 22029	 0.00224	 0.022645	 0.00666	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22030	 22031	 0.006865	 0.024266	 0.00547	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81866	 22032	 0.000862	 0.011291	 0.10222	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22032	 82694	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22032	 82694	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82691	 22033	 0.001153	 0.007153	 0.00173	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22033	 82695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22033	 82695	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22034	 82696	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22034	 82696	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22035	 22036	 0.000104	 0.0012	 0.01052	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22035	 22037	 0.000434	 0.006819	 0.07107	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22035	 82697	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22035	 82697	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22036	 82698	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22036	 82698	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22037	 82699	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22037	 82699	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22038	 22039	 0.000219	 0.003103	 0.02935	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22038	 82700	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22038	 82700	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22039	 22041	 7.3e-05	 0.001159	 0.01216	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22039	 82701	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22039	 82701	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82699	 22040	 0.004132	 0.018954	 0.00486	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22040	 82702	 0.002106	 0.006868	 0.00182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22041	 22042	 0.000333	 0.003652	 0.03547	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22041	 82702	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22041	 82702	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22042	 82703	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22042	 82703	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81908	 22043	 0.012202	 0.053115	 0.01514	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81912	 22044	 0.15517	 0.44529	 0.00685	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82230	 22044	 0.074073	 0.15569	 0.00284	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82572	 22045	 0.090116	 0.21343	 0.0039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82643	 22045	 0.060191	 0.15308	 0.00242	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22046	 22050	 0.003236	 0.033806	 0.00929	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22047	 22054	 0.032866	 0.084488	 0.00131	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22048	 22054	 0.063742	 0.050445	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22049	 22050	 0.000938	 0.010503	 0.00334	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81888	 22049	 0.002332	 0.01679	 0.01402	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22051	 22055	 0.002251	 0.005948	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22051	 82704	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22051	 82704	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22052	 22053	 0.002411	 0.008269	 0.00198	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22052	 22055	 0.001695	 0.005815	 0.00139	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81888	 22053	 0.001213	 0.013859	 0.00423	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22053	 82705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22053	 82705	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82705	 22054	 0.006353	 0.04361	 0.00079	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22056	 22060	 0.002551	 0.02492	 0.00699	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22057	 22059	 0.007798	 0.031223	 0.00787	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22058	 22059	 0.001952	 0.020536	 0.01154	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22058	 22061	 0.014302	 0.037132	 0.00901	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22059	 22060	 0.000908	 0.009181	 0.0027	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22060	 82706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22060	 82706	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82274	 22061	 0.016883	 0.057922	 0.01388	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22062	 22068	 0.00178	 0.008299	 0.00206	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22062	 82707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22062	 82707	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22063	 22064	 0.01169	 0.027136	 0.00052	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22063	 82711	 0.020623	 0.043344	 0.00079	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82707	 22064	 0.002743	 0.009371	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22065	 22078	 0.000273	 0.003149	 0.0276	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22065	 82708	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22065	 82708	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22066	 82713	 0.001472	 0.010211	 0.00291	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82708	 22067	 0.002502	 0.008756	 0.0029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22068	 82709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22068	 82709	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82707	 22069	 0.008631	 0.00908	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22070	 27244	 0.010341	 0.062078	 0.0188	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22070	 82710	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22070	 82710	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22071	 22072	 0.00189	 0.018145	 0.00528	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82708	 22071	 0.000946	 0.009723	 0.00368	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22071	 82711	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22071	 82711	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22073	 22074	 0.09776	 0.097787	 0.00132	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82597	 22073	 0.048401	 0.12442	 0.00193	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22074	 22076	 0.12723	 0.13995	 0.00187	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22075	 22076	 0.024352	 0.09474	 0.00158	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22075	 82714	 0.026088	 0.084007	 0.00143	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82212	 22076	 0.087137	 0.13349	 0.00187	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82291	 22076	 0.030298	 0.18415	 0.0034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22077	 22078	 0.000205	 0.002282	 0.02152	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22077	 27252	 0.000758	 0.013815	 0.13698	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22077	 82712	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22077	 82712	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22078	 82713	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82099	 22079	 0.03876	 0.099639	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22080	 22082	 0.00263	 0.027872	 0.00827	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22081	 22083	 0.001046	 0.010571	 0.00311	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22082	 82715	 0.000878	 0.008874	 0.00261	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22083	 82715	 0.000676	 0.004685	 0.00275	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22084	 82715	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22084	 82715	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81920	 22085	 0.020617	 0.040405	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22086	 22090	 0.00917	 0.036716	 0.00925	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82585	 22086	 0.021876	 0.057823	 0.01354	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22086	 82716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22086	 82716	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22086	 82719	 0.006318	 0.024833	 0.0065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22087	 22088	 0.014852	 0.050952	 0.01221	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22087	 82717	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22087	 82717	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22089	 22090	 0.001388	 0.015866	 0.00484	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81878	 22089	 0.008271	 0.033657	 0.0082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82312	 22089	 0.011884	 0.073083	 0.02108	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22090	 82718	 0.001747	 0.006996	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22091	 22092	 0.000339	 0.003773	 0.03558	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22091	 82718	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22091	 82718	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22092	 82719	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22092	 82719	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81879	 22093	 0.014941	 0.049843	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22094	 22099	 0.00629	 0.025598	 0.00624	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22094	 82720	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22094	 82720	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82340	 22095	 0.020051	 0.13605	 0.00254	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22095	 82721	 0.023675	 0.092105	 0.00154	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22095	 82722	 0.060592	 0.14068	 0.00209	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22096	 22098	 0.001547	 0.021814	 0.00746	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82341	 22096	 0.001969	 0.025628	 0.00741	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22097	 22098	 0.002412	 0.016177	 0.00391	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22097	 22099	 0.003636	 0.021294	 0.0058	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22097	 82721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22097	 82721	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22098	 82722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22098	 82722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22099	 82723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22099	 82723	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82722	 22100	 0.035622	 0.10217	 0.00157	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22101	 22102	 0.079064	 0.13206	 0.00224	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22101	 22141	 0.073904	 0.14485	 0.00217	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22102	 22103	 0.25145	 0.18182	 0.00276	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22102	 22141	 0.080779	 0.20546	 0.00325	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22102	 22737	 0.16642	 0.38251	 0.00581	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22103	 22104	 0.082581	 0.19172	 0.00365	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22103	 22105	 0.050295	 0.10738	 0.00242	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22103	 22141	 0.18043	 0.35375	 0.0053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22103	 82904	 0.078059	 0.19109	 0.00327	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22104	 23886	 0.097898	 0.2517	 0.0039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22105	 22736	 0.028067	 0.07215	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22106	 82724	 0.001712	 0.085583	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22107	 22108	 0.2631	 0.20628	 0.00265	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22107	 23351	 0.38405	 0.30408	 0.00383	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22108	 22380	 0.15584	 0.33288	 0.00752	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22108	 23351	 0.4582	 0.35941	 0.00461	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22108	 23364	 0.19184	 0.29394	 0.00511	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22108	 24099	 0.13073	 0.58311	 0.00992	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22109	 22118	 0.011598	 0.030653	 0.00717	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22109	 22129	 0.005384	 0.014228	 0.00333	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22109	 82726	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22109	 82726	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22110	 23934	 0.000285	 0.003173	 0.02992	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22110	 82727	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22110	 82727	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22111	 22112	 0.038655	 0.099369	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81992	 22111	 0.043459	 0.11172	 0.00173	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22111	 82983	 0.036522	 0.083908	 0.00127	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22112	 82728	 0.043763	 0.1016	 0.00151	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22113	 22160	 0.004134	 0.024211	 0.00659	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22113	 82728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22113	 82728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22114	 22124	 0.004719	 0.035364	 0.00863	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22115	 22122	 0.000508	 0.005759	 0.05243	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22115	 22130	 0.000761	 0.008469	 0.07988	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22115	 82729	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22115	 82729	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22116	 82730	 0.051876	 0.082807	 0.00191	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22116	 82733	 0.11169	 0.11202	 0.00181	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22117	 22118	 0.009534	 0.023967	 0.00621	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22117	 82730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22117	 82730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22117	 82740	 0.012543	 0.032565	 0.0079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22118	 22119	 0.019458	 0.054266	 0.01139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22118	 82731	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22118	 82731	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22119	 24133	 0.011648	 0.029281	 0.00759	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22119	 24134	 0.006531	 0.021301	 0.00566	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22119	 82732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22119	 82732	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82731	 22120	 0.14235	 0.092165	 0.00175	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82732	 22120	 0.14106	 0.10379	 0.00152	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22121	 24133	 0.006296	 0.031047	 0.0084	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82729	 22121	 0.015147	 0.03894	 0.00964	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22121	 82733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22121	 82733	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22122	 24144	 0.001293	 0.014196	 0.13795	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22122	 82734	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81993	 22123	 0.052454	 0.15045	 0.00231	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82730	 22123	 0.064258	 0.17033	 0.00432	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82735	 22123	 0.013145	 0.030517	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22124	 22127	 0.00482	 0.020977	 0.00598	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22125	 22126	 0.003663	 0.012947	 0.00292	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22125	 22841	 0.003943	 0.024503	 0.00692	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82734	 22125	 0.001434	 0.021626	 0.00645	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22125	 82736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22125	 82736	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22126	 82737	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22126	 82737	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22127	 22128	 0.001293	 0.010018	 0.00351	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22127	 82738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22127	 82738	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22128	 22838	 0.002896	 0.029268	 0.00861	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22128	 22839	 0.006921	 0.020727	 0.00467	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22128	 82739	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22128	 82739	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22128	 82740	 0.015743	 0.13074	 0.03443	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22129	 23947	 0.001653	 0.00461	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22130	 82740	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82730	 22131	 0.040904	 0.076058	 0.00178	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82741	 22131	 0.040161	 0.035987	 0.00074	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22131	 83253	 0.041348	 0.074607	 0.00108	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22132	 23931	 0.017777	 0.014068	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82731	 22132	 0.20816	 0.16476	 0.00207	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22132	 83254	 0.044915	 0.029078	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22133	 82742	 0.052457	 0.12179	 0.00181	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22134	 23892	 0.038902	 0.21749	 0.05572	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22134	 82742	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22134	 82742	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22136	 22137	 0.03407	 0.026962	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22136	 22138	 0.093757	 0.0607	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22136	 22139	 0.043356	 0.085843	 0.00126	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22136	 22140	 0.039551	 0.0313	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22137	 22139	 0.022528	 0.057911	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22137	 22140	 0.018787	 0.013822	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22139	 22141	 0.06171	 0.12629	 0.00311	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82742	 22139	 0.009119	 0.053986	 0.00105	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22142	 22144	 0.047483	 0.12076	 0.00191	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22142	 22313	 0.062896	 0.12453	 0.00183	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22143	 22145	 0.061096	 0.12504	 0.00308	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22143	 22148	 0.21975	 0.17393	 0.00219	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22143	 22317	 0.048014	 0.13626	 0.00214	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22143	 22858	 0.15911	 0.30081	 0.00487	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22144	 22147	 0.061335	 0.12553	 0.00309	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22145	 22146	 0.036006	 0.092559	 0.00143	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22145	 22858	 0.11443	 0.16222	 0.00332	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22146	 22147	 0.041683	 0.094553	 0.00189	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22147	 22581	 0.037816	 0.14549	 0.00248	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22148	 22861	 0.11393	 0.12531	 0.00167	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22148	 22862	 0.089399	 0.20449	 0.00499	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81986	 22148	 0.12136	 0.24033	 0.00353	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22149	 22152	 0.12914	 0.10221	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22149	 22739	 0.19366	 0.15182	 0.00195	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22150	 22151	 0.073828	 0.1447	 0.00217	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22150	 23874	 0.068285	 0.17555	 0.00272	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22151	 22152	 0.21913	 0.15525	 0.00245	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22151	 23875	 0.27012	 0.21179	 0.00272	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22151	 82743	 0.054619	 0.10004	 0.00173	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22153	 22189	 0.009869	 0.025622	 0.00622	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22153	 82743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22153	 82743	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22154	 22626	 0.04825	 0.13146	 0.02899	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81960	 22154	 0.050675	 0.17096	 0.04256	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22154	 82744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22154	 82744	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22155	 22627	 0.33587	 0.2659	 0.00335	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22155	 23361	 0.61008	 0.44949	 0.00657	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82744	 22155	 0.34468	 0.22327	 0.00425	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22156	 22157	 0.055336	 0.12656	 0.00309	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22156	 22165	 0.040834	 0.10497	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22156	 82815	 0.084578	 0.22362	 0.00406	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22157	 82967	 0.051839	 0.13704	 0.00249	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82728	 22158	 0.081857	 0.14771	 0.00214	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22158	 82984	 0.081708	 0.10739	 0.00147	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22159	 22161	 0.052649	 0.10424	 0.00153	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82728	 22159	 0.042394	 0.14143	 0.00224	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22160	 22166	 0.004548	 0.024231	 0.0068	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22161	 22162	 0.020732	 0.086076	 0.00224	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82739	 22161	 0.017159	 0.071627	 0.00207	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22161	 82933	 0.10994	 0.10127	 0.00162	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22162	 22163	 0.024424	 0.074927	 0.00203	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22162	 22267	 0.11635	 0.20785	 0.00307	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22162	 82745	 0.052678	 0.14949	 0.00235	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22162	 82933	 0.093477	 0.16441	 0.00309	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22163	 22164	 0.037973	 0.089923	 0.00164	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22164	 22413	 0.039037	 0.10035	 0.00155	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22165	 82745	 0.018381	 0.092981	 0.00162	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22166	 82745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22166	 82745	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22167	 82746	 0.004386	 0.007713	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22167	 82747	 0.018364	 0.014533	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22167	 82748	 0.006377	 0.019582	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22168	 22170	 0.000725	 0.002266	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22168	 22191	 0.000914	 0.002415	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22168	 82746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22168	 82746	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22169	 22170	 0.00137	 0.004701	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22169	 22176	 0.001547	 0.006079	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22169	 82747	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22169	 82747	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22171	 22172	 0.018258	 0.01182	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22171	 82756	 0.009601	 0.019009	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22172	 22173	 0.010066	 0.021155	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82747	 22172	 0.016427	 0.032193	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22173	 23985	 0.080305	 0.10555	 0.00145	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22173	 82756	 0.038427	 0.050505	 0.00069	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22173	 83272	 0.039187	 0.09098	 0.00135	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82746	 22174	 0.022182	 0.026554	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22174	 82751	 0.008617	 0.033523	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22174	 82756	 0.008691	 0.020177	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22175	 22184	 0.002363	 0.008352	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22175	 82748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22175	 82748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22175	 82752	 0.001522	 0.005221	 0.00125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22176	 22177	 0.004036	 0.015861	 0.00415	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81949	 22176	 0.001976	 0.00719	 0.0022	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22177	 24121	 0.002958	 0.032026	 0.01348	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22177	 82749	 0.00109	 0.009286	 0.00232	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22178	 82749	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22178	 82749	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81949	 22179	 0.008229	 0.032344	 0.00846	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22179	 83275	 0.008338	 0.028603	 0.00685	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22180	 23985	 0.00936	 0.045676	 0.00079	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22180	 82750	 0.006253	 0.042919	 0.00078	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22181	 82750	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22181	 82750	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22181	 82752	 0.003907	 0.024023	 0.00693	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22181	 83265	 0.001887	 0.028453	 0.00849	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22182	 22187	 0.006694	 0.026799	 0.00675	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22182	 83096	 0.00467	 0.018698	 0.00471	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82750	 22183	 0.019562	 0.049748	 0.00079	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22183	 82751	 0.06346	 0.064097	 0.00085	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22184	 82751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22184	 82751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22185	 82752	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82753	 22186	 0.05983	 0.047349	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22187	 82754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22187	 82754	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22188	 22566	 0.11918	 0.27041	 0.0054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82754	 22188	 0.035059	 0.090864	 0.00172	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22188	 82755	 0.039399	 0.10415	 0.00189	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81951	 22189	 0.024589	 0.072511	 0.01687	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22189	 82755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22189	 82755	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22190	 22572	 0.052033	 0.14925	 0.0023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22190	 23874	 0.18207	 0.29075	 0.0067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82743	 22190	 0.049516	 0.11726	 0.00214	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82755	 22190	 0.043971	 0.099744	 0.00199	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82752	 22191	 0.003463	 0.01188	 0.00285	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22191	 82756	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22191	 82756	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82748	 22192	 0.023066	 0.021246	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22193	 22194	 0.008304	 0.033793	 0.00823	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22193	 22587	 0.012753	 0.0519	 0.01265	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22194	 22197	 0.011241	 0.045747	 0.01115	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22194	 82757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22194	 82757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22195	 22196	 0.044897	 0.061255	 0.00109	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82757	 22195	 0.1006	 0.13222	 0.00181	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22196	 82758	 0.065736	 0.13016	 0.00191	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22197	 23335	 0.006474	 0.029148	 0.00776	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22197	 82758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22197	 82758	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22198	 22216	 0.011945	 0.023651	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22198	 82760	 0.002887	 0.012721	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22199	 22204	 0.000189	 0.002182	 0.01913	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22199	 82759	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22200	 22201	 0.011432	 0.009047	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82760	 22201	 0.010842	 0.019487	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22202	 22206	 0.038367	 0.030074	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22202	 22214	 0.010061	 0.01797	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22202	 82763	 0.007043	 0.013312	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22203	 22205	 0.00172	 0.004465	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82759	 22203	 0.002088	 0.005248	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22204	 22209	 0.000294	 0.003279	 0.03092	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22204	 82761	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22205	 82763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22205	 82763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82762	 22206	 0.023637	 0.024136	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82761	 22207	 0.002156	 0.005871	 0.00129	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22207	 82764	 0.005711	 0.015549	 0.00343	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22208	 22210	 0.026406	 0.020897	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82762	 22208	 0.024548	 0.048603	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81932	 22209	 0.000182	 0.002066	 0.01881	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22209	 82764	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22210	 22211	 0.016071	 0.015071	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22211	 22212	 0.056213	 0.056777	 0.00075	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22211	 22226	 0.08363	 0.084471	 0.00112	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82765	 22211	 0.013432	 0.038115	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22212	 82766	 0.071237	 0.05584	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22213	 22215	 0.007781	 0.018751	 0.00529	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22213	 22244	 0.008129	 0.020896	 0.00517	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22213	 82766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22213	 82766	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22214	 82767	 0.031989	 0.025315	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82759	 22215	 0.002938	 0.010078	 0.00241	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22215	 82767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22215	 82767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22216	 22217	 0.02297	 0.018906	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22217	 22219	 0.027087	 0.021437	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22218	 22223	 0.10831	 0.082066	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82767	 22218	 0.016697	 0.045616	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22219	 22220	 0.086027	 0.068082	 0.00086	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82760	 22219	 0.028987	 0.056809	 0.00085	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22220	 22221	 0.082329	 0.065156	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22221	 24137	 0.050274	 0.090363	 0.00162	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22221	 82769	 0.041479	 0.054516	 0.00075	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22221	 83320	 0.12943	 0.13074	 0.00173	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22222	 22236	 0.001391	 0.015264	 0.14835	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22222	 82768	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82769	 22223	 0.037454	 0.09628	 0.00149	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22223	 82795	 0.054932	 0.11242	 0.00277	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82766	 22224	 0.10932	 0.083857	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22225	 22244	 0.005528	 0.014609	 0.00342	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22225	 82777	 0.008587	 0.022075	 0.00547	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22226	 82771	 0.013782	 0.053021	 0.00091	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22226	 82782	 0.03591	 0.0711	 0.00104	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81932	 22227	 0.000166	 0.001823	 0.0177	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22227	 82770	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82771	 22228	 0.017538	 0.089243	 0.00202	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22228	 82775	 0.011093	 0.067414	 0.00124	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22229	 22230	 0.000316	 0.003642	 0.03193	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22229	 82772	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22230	 82774	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22231	 22232	 0.004923	 0.019349	 0.00506	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82617	 22231	 0.007373	 0.028979	 0.00758	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82770	 22232	 0.007294	 0.025021	 0.00599	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22233	 82776	 0.070526	 0.055814	 0.0007	 28.0	 28.0	 28.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22233	 82782	 0.077738	 0.086256	 0.00168	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81933	 22234	 0.023335	 0.061681	 0.01444	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22234	 82776	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22234	 82776	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22234	 82778	 0.007731	 0.020432	 0.00478	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82619	 22235	 0.10786	 0.079361	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82776	 22235	 0.024666	 0.039372	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22236	 22238	 0.000162	 0.001866	 0.01636	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22236	 82777	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22236	 82777	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 0	 -30.0	 30.0;
	22237	 82780	 0.008035	 0.012826	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22238	 22239	 7.8e-05	 0.000901	 0.00779	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22238	 82778	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22238	 82778	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22239	 82779	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22239	 82779	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22240	 22300	 0.002734	 0.008918	 0.00237	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82777	 22240	 0.00417	 0.014049	 0.00349	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82779	 22240	 0.001123	 0.006047	 0.00166	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22240	 82780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22240	 82780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22241	 22242	 0.001921	 0.007816	 0.0019	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82779	 22241	 0.000914	 0.005013	 0.00133	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22242	 82781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22242	 82781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82620	 22243	 0.053857	 0.042216	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82780	 22243	 0.10958	 0.086724	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82781	 22243	 0.030305	 0.023983	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22244	 22245	 0.005514	 0.014574	 0.00341	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81933	 22245	 0.013689	 0.032989	 0.00931	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22245	 82782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22245	 82782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22246	 22284	 0.06525	 0.1515	 0.00225	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22246	 22608	 0.061395	 0.15553	 0.00308	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22246	 82784	 0.038846	 0.098795	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22247	 22248	 0.008735	 0.029965	 0.00718	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22247	 22283	 0.007179	 0.024626	 0.0059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22248	 82783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22248	 82783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22249	 22251	 0.03096	 0.088799	 0.00137	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22249	 22254	 0.016926	 0.083986	 0.002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22249	 22609	 0.016084	 0.091428	 0.00165	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22250	 22254	 0.042859	 0.04714	 0.00063	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22251	 22252	 0.035865	 0.083253	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22251	 82786	 0.017545	 0.098725	 0.00213	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22253	 24086	 0.030199	 0.10567	 0.00219	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82783	 22253	 0.047636	 0.097488	 0.0024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22254	 82784	 0.005522	 0.024707	 0.00051	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22254	 82786	 0.011344	 0.055358	 0.00096	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22255	 22295	 0.034028	 0.094922	 0.01993	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22255	 82784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22255	 82784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22255	 82785	 0.002264	 0.009066	 0.00228	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82784	 22256	 0.007294	 0.018549	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22256	 82786	 0.012363	 0.032681	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22257	 22826	 0.002054	 0.023287	 0.21226	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22257	 27179	 0.003648	 0.040128	 0.39129	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22257	 82785	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22258	 22262	 0.001951	 0.013239	 0.00025	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22258	 82787	 0.002319	 0.014042	 0.00044	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22259	 22265	 0.001671	 0.005733	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22259	 82787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22259	 82787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22260	 82794	 0.017339	 0.012757	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22261	 82794	 0.023455	 0.023461	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22262	 22274	 0.012733	 0.043493	 0.00095	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22262	 22276	 0.003729	 0.014287	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22262	 82794	 0.003921	 0.023741	 0.00074	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22263	 22264	 0.025732	 0.020364	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22264	 22278	 0.070869	 0.056086	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82787	 22264	 0.026189	 0.026195	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22264	 82788	 0.008119	 0.02087	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22265	 22266	 0.001531	 0.006018	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22265	 82788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22265	 82788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22266	 22269	 0.004574	 0.012452	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22266	 22280	 0.004481	 0.015098	 0.00375	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22266	 82789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22266	 82789	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82787	 22267	 0.057589	 0.063342	 0.00085	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82788	 22267	 0.050254	 0.047127	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82789	 22267	 0.02657	 0.024474	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82789	 22268	 0.022128	 0.024338	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22268	 82790	 0.013713	 0.024115	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22269	 82790	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22269	 82790	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22269	 82791	 0.000758	 0.008533	 0.00247	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22270	 22271	 0.017674	 0.045432	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22270	 22282	 0.024352	 0.074706	 0.00202	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82790	 22270	 0.016339	 0.038692	 0.00071	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22271	 22272	 0.02659	 0.019222	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82790	 22271	 0.012228	 0.031432	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22271	 82794	 0.012824	 0.026952	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22273	 22282	 0.024045	 0.063565	 0.00115	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82790	 22273	 0.015506	 0.054255	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22274	 22275	 0.017197	 0.045461	 0.00083	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22275	 22276	 0.014546	 0.042774	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22275	 22294	 0.023757	 0.10586	 0.0018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22276	 22277	 0.025691	 0.066042	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22277	 22413	 0.067162	 0.17266	 0.00267	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82788	 22279	 0.059863	 0.047375	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22280	 22837	 0.005048	 0.021363	 0.00481	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22281	 82791	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22281	 82791	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22282	 22284	 0.025534	 0.11315	 0.0034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22283	 82937	 0.011764	 0.064565	 0.01707	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22284	 22285	 0.035857	 0.09479	 0.00172	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22284	 82793	 0.094995	 0.12486	 0.00171	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22285	 22286	 0.026694	 0.098701	 0.00183	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22285	 82793	 0.044988	 0.11565	 0.00179	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22286	 22608	 0.052594	 0.10308	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22287	 82792	 0.039745	 0.043714	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22288	 82792	 0.038066	 0.02557	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22289	 82792	 0.061371	 0.044365	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22290	 22791	 0.018992	 0.092679	 0.0016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22290	 22792	 0.075219	 0.19338	 0.00299	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22290	 22793	 0.052696	 0.12234	 0.00182	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22290	 82792	 0.007964	 0.030641	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22290	 82792	 0.007964	 0.030641	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22291	 22295	 0.002206	 0.031108	 0.01064	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22291	 82792	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22291	 82792	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22292	 22293	 0.009778	 0.025843	 0.00605	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22292	 22418	 0.010754	 0.028423	 0.00665	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22293	 22295	 0.007283	 0.018907	 0.00459	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22294	 82793	 0.011623	 0.042975	 0.0008	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22295	 82793	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22295	 82793	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22295	 82929	 0.007553	 0.089537	 0.04586	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82791	 22296	 0.001692	 0.012801	 0.00629	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22296	 82794	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22296	 82794	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22297	 22298	 0.023503	 0.10473	 0.00178	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22297	 24080	 0.030725	 0.081436	 0.00207	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82204	 22298	 0.008073	 0.049631	 0.00089	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82203	 22299	 0.091904	 0.072733	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22300	 22303	 0.005433	 0.018125	 0.0046	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22301	 22305	 0.017344	 0.04584	 0.01073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22301	 22306	 0.009386	 0.025555	 0.00563	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22302	 24081	 0.006327	 0.035303	 0.00902	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22302	 24143	 0.005047	 0.033004	 0.00839	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22304	 22305	 0.004279	 0.020453	 0.00716	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82768	 22304	 0.01101	 0.047923	 0.01366	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22304	 82795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22304	 82795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22305	 22306	 0.013291	 0.033412	 0.00866	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22305	 24142	 0.008233	 0.028242	 0.00677	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22305	 24143	 0.005144	 0.040096	 0.01199	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82202	 22306	 0.020081	 0.053917	 0.01222	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82780	 22307	 0.053363	 0.085181	 0.00196	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82795	 22307	 0.19085	 0.15105	 0.0019	 27.0	 27.0	 27.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22308	 22309	 0.009624	 0.025435	 0.00595	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22308	 23891	 0.016432	 0.042663	 0.01036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22308	 82796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22308	 82796	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22309	 22430	 0.009682	 0.02636	 0.00581	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22310	 22318	 0.12874	 0.10092	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22310	 82797	 0.059227	 0.11727	 0.00172	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22311	 22320	 0.00698	 0.017942	 0.00444	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22311	 22430	 0.012582	 0.041041	 0.0109	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22311	 82797	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22311	 82797	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22311	 82869	 0.034625	 0.17725	 0.04841	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22312	 22320	 0.046581	 0.12319	 0.02886	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22312	 23115	 0.048785	 0.11765	 0.03325	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82797	 22313	 0.13549	 0.14904	 0.00199	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82797	 22314	 0.061772	 0.093638	 0.00195	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22315	 22316	 0.032454	 0.025439	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82797	 22316	 0.075881	 0.1553	 0.00382	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22317	 22318	 0.029712	 0.058828	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82796	 22317	 0.22406	 0.14509	 0.00276	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22317	 82819	 0.28314	 0.22413	 0.00282	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22318	 22319	 0.01877	 0.014713	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22321	 22322	 0.03982	 0.10236	 0.00158	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22321	 22325	 0.23855	 0.18882	 0.00238	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22322	 22323	 0.093888	 0.074304	 0.00094	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22322	 23117	 0.20229	 0.15858	 0.00204	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22323	 22324	 0.13989	 0.10293	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22323	 22429	 0.25337	 0.42706	 0.00609	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22324	 22327	 0.10289	 0.18496	 0.00332	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22325	 22326	 0.15833	 0.12411	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22325	 22327	 0.26005	 0.1684	 0.00321	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22325	 22328	 0.3647	 0.286	 0.00367	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22325	 22426	 0.28091	 0.22025	 0.00283	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22326	 22429	 0.21056	 0.15224	 0.00231	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22327	 22328	 0.08464	 0.16759	 0.00246	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22328	 83232	 0.07651	 0.1967	 0.00304	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22329	 22330	 0.16864	 0.13347	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22331	 22332	 0.019426	 0.015227	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22333	 22334	 0.10386	 0.22261	 0.0039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81987	 22333	 0.017447	 0.044371	 0.0007	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22334	 22335	 0.50215	 0.39774	 0.00501	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22334	 22336	 0.18729	 0.18099	 0.00263	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22334	 23114	 0.5912	 0.43553	 0.00637	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22335	 83017	 0.36307	 0.26725	 0.00391	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22336	 82798	 0.088905	 0.17604	 0.00258	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22337	 23111	 0.074924	 0.19836	 0.04653	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22337	 82798	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22337	 82798	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22338	 22339	 0.61045	 0.47912	 0.00615	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22338	 22340	 0.12323	 0.24156	 0.00362	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22338	 23113	 0.18136	 0.19757	 0.00269	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82798	 22340	 0.002947	 0.007496	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22341	 22349	 0.038028	 0.070711	 0.00166	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22341	 22567	 0.061917	 0.1776	 0.00273	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22341	 23962	 0.056711	 0.14579	 0.00226	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22342	 22350	 0.04239	 0.10897	 0.00169	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22342	 23879	 0.069979	 0.17991	 0.00278	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22343	 22351	 0.053466	 0.17837	 0.00283	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81981	 22343	 0.076618	 0.33769	 0.00587	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22344	 24860	 0.021968	 0.13295	 0.03396	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22344	 82799	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22344	 82799	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22344	 82908	 0.013364	 0.08467	 0.02299	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22345	 23883	 0.029848	 0.14566	 0.00251	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82799	 22345	 0.013214	 0.06448	 0.00111	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82799	 22346	 0.040567	 0.12446	 0.00337	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22346	 82800	 0.044305	 0.13607	 0.00255	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82799	 22347	 0.15848	 0.10261	 0.00195	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22348	 22571	 0.007876	 0.036134	 0.00926	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22348	 82800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22348	 82800	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22349	 22351	 0.026678	 0.05717	 0.001	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22350	 22351	 0.031404	 0.074365	 0.00136	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82800	 22351	 0.01917	 0.10214	 0.00179	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22352	 22357	 0.053411	 0.054539	 0.00085	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22352	 82801	 0.005484	 0.029347	 0.00089	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22352	 82807	 0.027369	 0.072351	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22353	 22354	 0.002077	 0.006773	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22353	 22355	 0.002437	 0.006634	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22353	 22368	 0.004751	 0.016559	 0.00384	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22354	 82801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22354	 82801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22355	 22358	 0.003918	 0.010354	 0.00242	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22355	 82802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22355	 82802	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22356	 22357	 0.035128	 0.0278	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22357	 22640	 0.030674	 0.024044	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22357	 22658	 0.00821	 0.016254	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22358	 22359	 0.003213	 0.017302	 0.00475	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22358	 22402	 0.010539	 0.027853	 0.00652	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22358	 22659	 0.001221	 0.006938	 0.00201	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22359	 82803	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22359	 82803	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22359	 82969	 0.01257	 0.15833	 0.04914	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22360	 22403	 0.057907	 0.1661	 0.00255	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22360	 82900	 0.039237	 0.11254	 0.00173	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22360	 82901	 0.057721	 0.10909	 0.00176	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82803	 22361	 0.10887	 0.21339	 0.0032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22361	 82804	 0.082455	 0.09871	 0.00164	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22361	 82877	 0.16784	 0.33241	 0.00488	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22361	 82899	 0.074982	 0.15346	 0.00378	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22362	 22363	 0.01095	 0.037566	 0.009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22362	 22603	 0.009942	 0.034106	 0.00817	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22362	 82804	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22362	 82804	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22363	 82805	 0.006152	 0.020065	 0.00533	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22364	 22369	 0.007409	 0.026187	 0.0059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22364	 22604	 0.00591	 0.036725	 0.01036	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22364	 24103	 0.004487	 0.028422	 0.00771	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22365	 82805	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22366	 22368	 0.007645	 0.026224	 0.00628	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82805	 22366	 0.001702	 0.00584	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82806	 22367	 0.011955	 0.030403	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22367	 82808	 0.084703	 0.22395	 0.00407	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22369	 22370	 0.007382	 0.024628	 0.00625	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82805	 22369	 0.003741	 0.028176	 0.00782	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22370	 22371	 0.006432	 0.020979	 0.00557	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22371	 22372	 0.004582	 0.011895	 0.00289	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22371	 82807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22371	 82807	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22372	 82808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22372	 82808	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22373	 22667	 0.020921	 0.016557	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22374	 22377	 0.20596	 0.20605	 0.00278	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22374	 23886	 0.14523	 0.3695	 0.00585	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22374	 23888	 0.095224	 0.22111	 0.00329	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22374	 83234	 0.033933	 0.13464	 0.00385	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22375	 22862	 0.040426	 0.14146	 0.00293	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22375	 82809	 0.04732	 0.13091	 0.00304	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22377	 23889	 0.072698	 0.18046	 0.003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22378	 82809	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22378	 82809	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22378	 83497	 0.021242	 0.16977	 0.04192	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22379	 22380	 0.11943	 0.23651	 0.00347	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22379	 24100	 0.14122	 0.27968	 0.00411	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22380	 82811	 0.020737	 0.11788	 0.00213	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22381	 22382	 0.037821	 0.16854	 0.00286	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22381	 23364	 0.054615	 0.2125	 0.00355	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81990	 22382	 0.017193	 0.066888	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81990	 22382	 0.017193	 0.066888	 0.00112	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22382	 82811	 0.004445	 0.027328	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81959	 22383	 0.001914	 0.035467	 0.34178	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22383	 82810	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22383	 82810	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22384	 24101	 0.023232	 0.1445	 0.04084	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81989	 22384	 0.002078	 0.016373	 0.00479	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22384	 82811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22384	 82811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22385	 23387	 0.021442	 0.055673	 0.01352	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82810	 22385	 0.011094	 0.043605	 0.01141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22385	 82812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22385	 82812	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22386	 22387	 0.011577	 0.029442	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22387	 22388	 0.014817	 0.011226	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22387	 22389	 0.01274	 0.029578	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22389	 83091	 0.18971	 0.31526	 0.00668	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22390	 22391	 0.3356	 0.24702	 0.00361	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22391	 23386	 0.10534	 0.26796	 0.00424	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22391	 82813	 0.1326	 0.13394	 0.00177	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22392	 23387	 0.017903	 0.12017	 0.02903	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22392	 82813	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22392	 82813	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22393	 22394	 0.013632	 0.03228	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22394	 22395	 0.009496	 0.017947	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22394	 22396	 0.011279	 0.026709	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82813	 22394	 0.035794	 0.10993	 0.00206	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22396	 22747	 0.10549	 0.24985	 0.00457	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22397	 22399	 0.011162	 0.016339	 0.00025	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22397	 22660	 0.0239	 0.031411	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22398	 22399	 0.009033	 0.017884	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22398	 22400	 0.00268	 0.012444	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22398	 22401	 0.019576	 0.012673	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22398	 22404	 0.002868	 0.021688	 0.00072	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22398	 22405	 0.044569	 0.035272	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22400	 22662	 0.00303	 0.014786	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22402	 82814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22402	 82814	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22403	 22404	 0.012651	 0.032788	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22403	 22406	 0.042986	 0.043417	 0.00058	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22403	 22408	 0.027097	 0.062909	 0.00094	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81950	 22403	 0.054245	 0.05087	 0.00079	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81950	 22404	 0.005739	 0.020082	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22404	 82818	 0.022408	 0.06427	 0.00099	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22406	 22407	 0.025064	 0.019226	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22406	 22408	 0.00944	 0.027074	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82803	 22406	 0.077727	 0.10116	 0.00141	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22408	 82815	 0.015289	 0.05858	 0.00166	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22409	 22411	 0.007737	 0.022409	 0.00541	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22409	 22728	 0.01095	 0.028941	 0.00677	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22409	 82815	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22409	 82815	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22410	 82816	 0.028257	 0.072638	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22410	 82818	 0.049799	 0.089509	 0.00161	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22411	 22414	 0.008497	 0.022813	 0.00517	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22412	 22415	 0.005116	 0.049119	 0.01429	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22412	 82969	 0.009136	 0.10449	 0.03189	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22413	 22416	 0.039634	 0.12763	 0.00217	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22414	 22415	 0.002004	 0.006537	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22414	 22423	 0.010255	 0.039898	 0.01066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22414	 82816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22414	 82816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22415	 22418	 0.009187	 0.02428	 0.00568	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22415	 82817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22415	 82817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82816	 22416	 0.011747	 0.033693	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82817	 22416	 0.01608	 0.026856	 0.00046	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22417	 22419	 0.033994	 0.087386	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82817	 22417	 0.023701	 0.056124	 0.00103	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22419	 22421	 0.01305	 0.043533	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22419	 22424	 0.044987	 0.075136	 0.00128	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22420	 22422	 0.006346	 0.032999	 0.00072	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22420	 22794	 0.033011	 0.1063	 0.00181	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22421	 22422	 0.010176	 0.02588	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81950	 22422	 0.05427	 0.16651	 0.00451	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22423	 82818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22423	 82818	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82818	 22424	 0.017303	 0.044478	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22425	 22426	 0.25225	 0.16335	 0.00311	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22426	 22427	 0.077632	 0.15371	 0.00226	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22426	 22429	 0.29171	 0.23093	 0.00291	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22427	 22428	 0.049151	 0.125	 0.00198	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22427	 22429	 0.36055	 0.28546	 0.00359	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22427	 23114	 0.94493	 0.74298	 0.00954	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22428	 22431	 0.029821	 0.070617	 0.00129	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81986	 22429	 0.071431	 0.36148	 0.00629	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22430	 82819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22430	 82819	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82819	 22431	 0.009364	 0.041724	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82797	 22432	 0.036179	 0.093003	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82819	 22432	 0.12926	 0.09345	 0.00142	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22433	 82820	 0.002319	 0.008112	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22433	 82822	 0.016336	 0.037926	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22433	 82839	 0.008768	 0.042787	 0.00074	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22434	 22436	 0.001558	 0.007793	 0.00014	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22434	 82838	 0.002855	 0.012773	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22435	 22439	 0.00099	 0.003851	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22435	 22478	 0.000732	 0.005513	 0.00153	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22435	 82820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22435	 82820	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22436	 82821	 0.001787	 0.007151	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82820	 22437	 0.010708	 0.008474	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22438	 22452	 0.000812	 0.003251	 0.00082	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22438	 82821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22438	 82821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22439	 22441	 0.00073	 0.003089	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82821	 22440	 0.004841	 0.008451	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22440	 82863	 0.014686	 0.024739	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22441	 22442	 0.000688	 0.002706	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22441	 82822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22441	 82822	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22442	 22443	 0.000506	 0.001841	 0.00056	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22442	 82823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22442	 82823	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22443	 22561	 0.000646	 0.002457	 0.00069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22444	 82824	 0.003944	 0.007117	 0.0001	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22444	 82826	 0.014034	 0.021498	 0.0003	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22445	 22448	 0.000711	 0.003261	 0.00084	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22445	 22490	 0.000414	 0.003975	 0.00116	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22445	 82824	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22445	 82824	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82823	 22446	 0.007626	 0.0151	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22446	 82863	 0.008584	 0.01302	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22447	 22448	 0.000982	 0.003998	 0.00097	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22447	 22458	 0.001093	 0.003748	 0.0009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22447	 82825	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22447	 82825	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22448	 82826	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22448	 82826	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22449	 22452	 0.001708	 0.004587	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22449	 22529	 0.001363	 0.004546	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22449	 82827	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22449	 82827	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22450	 22451	 0.003827	 0.009498	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82827	 22450	 0.008905	 0.015342	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22450	 82853	 0.00863	 0.019827	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22450	 82865	 0.035046	 0.027735	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22451	 82852	 0.004823	 0.007699	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22452	 22563	 0.000398	 0.002284	 0.00065	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22453	 22456	 0.001283	 0.003093	 0.00087	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22453	 22563	 0.000993	 0.002926	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22454	 82865	 0.011464	 0.019311	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22455	 22457	 0.000647	 0.003449	 0.00097	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22455	 22523	 0.000532	 0.003218	 0.00082	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22456	 22460	 0.000708	 0.00308	 0.00088	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22456	 22561	 0.001042	 0.004055	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22456	 82828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22456	 82828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22457	 22461	 0.000457	 0.005369	 0.00142	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22457	 22563	 0.002036	 0.008151	 0.00205	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22457	 82829	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22457	 82829	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22458	 22468	 0.001317	 0.004655	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82828	 22459	 0.006083	 0.013035	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22459	 82831	 0.009244	 0.016615	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22460	 22462	 0.000868	 0.0033	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22461	 22506	 0.001362	 0.010361	 0.00326	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22461	 82830	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22461	 82830	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22462	 22463	 0.000366	 0.003121	 0.00078	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22462	 82831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22462	 82831	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22463	 22465	 0.000612	 0.002663	 0.00076	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22463	 82832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22463	 82832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82832	 22464	 0.018775	 0.013813	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22465	 22505	 0.001032	 0.004367	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22465	 82833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22465	 82833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22466	 22467	 0.022784	 0.018031	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82825	 22467	 0.005779	 0.014696	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22467	 82834	 0.025861	 0.023821	 0.00038	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22468	 82834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22468	 82834	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22469	 22560	 0.019246	 0.015086	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82833	 22469	 0.005116	 0.013559	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82834	 22469	 0.002857	 0.010464	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22470	 22471	 0.000541	 0.006663	 0.00215	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22470	 22473	 0.000582	 0.004564	 0.00209	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22470	 82835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22470	 82835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22471	 24020	 0.001116	 0.01384	 0.00599	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22471	 82836	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22471	 82836	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82835	 22472	 0.012286	 0.031583	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82836	 22472	 0.007873	 0.03063	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22472	 82837	 0.005836	 0.036645	 0.0008	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22472	 83290	 0.023944	 0.079018	 0.00128	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22473	 22475	 0.000562	 0.006022	 0.00193	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22473	 82837	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22473	 82837	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22474	 22477	 0.01748	 0.027901	 0.00064	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82835	 22474	 0.021569	 0.023723	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22475	 22483	 0.000788	 0.008355	 0.00248	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22476	 22477	 0.015035	 0.046171	 0.00087	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82836	 22476	 0.009684	 0.032306	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22476	 82854	 0.007858	 0.061243	 0.00114	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22477	 82841	 0.021355	 0.056601	 0.00144	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22478	 22479	 0.000345	 0.004189	 0.00113	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22478	 82838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22478	 82838	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22479	 22483	 0.000596	 0.004312	 0.00232	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22480	 22481	 0.000657	 0.00736	 0.00234	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22480	 22490	 0.000605	 0.006911	 0.00211	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22481	 22484	 0.001065	 0.009136	 0.0026	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22481	 22488	 0.000691	 0.0079	 0.00241	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22481	 82855	 0.00195	 0.028155	 0.00894	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22482	 82839	 0.012396	 0.041353	 0.00066	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22482	 82841	 0.010553	 0.040601	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22483	 82839	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22483	 82839	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22484	 22486	 0.000615	 0.009567	 0.00297	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22484	 82840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22484	 82840	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22485	 22542	 0.020621	 0.058515	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82840	 22485	 0.006901	 0.014123	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22486	 82841	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22486	 82841	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22486	 82855	 0.000923	 0.013652	 0.0047	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22487	 24102	 0.06264	 0.12403	 0.00182	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82841	 22487	 0.033728	 0.051667	 0.00073	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22488	 22491	 0.000724	 0.007931	 0.0022	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22489	 82842	 0.024233	 0.018588	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22490	 82842	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22490	 82842	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22491	 22494	 0.000949	 0.008632	 0.00218	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22491	 82843	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22491	 82843	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22492	 22493	 0.01566	 0.014032	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22492	 82844	 0.025295	 0.033245	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82826	 22493	 0.011589	 0.014386	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22494	 22562	 0.001348	 0.006186	 0.00158	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22494	 82844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22494	 82844	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22495	 82849	 0.005848	 0.02275	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22495	 82864	 0.003672	 0.019651	 0.0006	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22496	 22498	 0.001393	 0.0083	 0.00218	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22496	 23537	 0.005238	 0.030095	 0.00853	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22496	 82845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22496	 82845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22497	 22500	 0.001465	 0.010821	 0.00312	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22497	 23539	 0.004116	 0.025577	 0.00722	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22497	 82846	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22497	 82846	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22497	 82990	 0.033589	 0.091479	 0.02016	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22498	 22502	 0.000946	 0.007123	 0.00198	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22498	 82847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22498	 82847	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82846	 22499	 0.04699	 0.047462	 0.00063	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82847	 22499	 0.007827	 0.018172	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22499	 82848	 0.013342	 0.044508	 0.00071	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22500	 22501	 0.000659	 0.005991	 0.00151	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22501	 22504	 0.000686	 0.005846	 0.00146	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22501	 82848	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22501	 82848	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22502	 22506	 0.000928	 0.007901	 0.00197	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82847	 22503	 0.022681	 0.017949	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22504	 22505	 0.001019	 0.004078	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22504	 82849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22504	 82849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22506	 82850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22506	 82850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82850	 22507	 0.046498	 0.03421	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22508	 22509	 0.023284	 0.017131	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22508	 22510	 0.006532	 0.021555	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22508	 22513	 0.020924	 0.048569	 0.00092	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82829	 22510	 0.002757	 0.014335	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82830	 22510	 0.008529	 0.021604	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82830	 22511	 0.008315	 0.021375	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82850	 22511	 0.010525	 0.027824	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22512	 22513	 0.014713	 0.037821	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22512	 22559	 0.030446	 0.070674	 0.00135	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22513	 22517	 0.015147	 0.020665	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22514	 22515	 0.021273	 0.016117	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22515	 22516	 0.015247	 0.030189	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22515	 22517	 0.034748	 0.027499	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22515	 22518	 0.045014	 0.03254	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22515	 82989	 0.21628	 0.17119	 0.00216	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22516	 22521	 0.018899	 0.053629	 0.00084	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22517	 22518	 0.011808	 0.021305	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22518	 22519	 0.01281	 0.029296	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22519	 22520	 0.016704	 0.055724	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22520	 22521	 0.059827	 0.059841	 0.00081	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81942	 22520	 0.011174	 0.086071	 0.00165	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22521	 23020	 0.029685	 0.058773	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22522	 22524	 0.002191	 0.009046	 0.00214	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22522	 22527	 0.001054	 0.006549	 0.00185	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22522	 82851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22522	 82851	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22523	 22524	 0.001824	 0.007718	 0.00174	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22523	 82852	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22523	 82852	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22525	 22526	 0.008693	 0.017212	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82852	 22525	 0.029726	 0.031745	 0.00067	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82851	 22526	 0.014162	 0.036406	 0.00056	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22528	 22530	 0.004772	 0.023286	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22528	 22531	 0.005429	 0.015572	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82839	 22528	 0.021767	 0.044544	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22528	 82853	 0.004094	 0.028104	 0.00051	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22529	 22563	 0.002975	 0.009703	 0.00258	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22529	 82853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22529	 82853	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22530	 22531	 0.004599	 0.011822	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82837	 22530	 0.007982	 0.047257	 0.00092	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22532	 22533	 0.017441	 0.039887	 0.00097	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22532	 22534	 0.048963	 0.043875	 0.0009	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22532	 83315	 0.049091	 0.12435	 0.00246	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22533	 23020	 0.05964	 0.11809	 0.00173	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81942	 22534	 0.013196	 0.028279	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22535	 22536	 0.07025	 0.055595	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81942	 22535	 0.003758	 0.029293	 0.00055	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82837	 22535	 0.007631	 0.034144	 0.0007	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22536	 24131	 0.12195	 0.089727	 0.00131	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22537	 22539	 0.00012	 0.001586	 0.0254	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22537	 24002	 0.000473	 0.005573	 0.09736	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22537	 24019	 0.00027	 0.00301	 0.02838	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22537	 82854	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22537	 82854	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82854	 22538	 0.044419	 0.029838	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22539	 23586	 0.001711	 0.031693	 0.30523	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22539	 82855	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22539	 82855	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22540	 22543	 0.019641	 0.076408	 0.00128	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82844	 22540	 0.025996	 0.045718	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22541	 22542	 0.068929	 0.05455	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82843	 22542	 0.014562	 0.033801	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22543	 24118	 0.020767	 0.054899	 0.001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22543	 82860	 0.045509	 0.13053	 0.00201	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22543	 83312	 0.032651	 0.093649	 0.00144	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22544	 82856	 0.034243	 0.05613	 0.00099	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22544	 82859	 0.043985	 0.05781	 0.00079	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22545	 22548	 0.001986	 0.012013	 0.00307	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22545	 22562	 0.003087	 0.010913	 0.00246	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22545	 82856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22545	 82856	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22546	 22547	 0.002292	 0.01298	 0.00322	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22546	 22562	 0.001075	 0.01067	 0.0029	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22546	 82857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22546	 82857	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22547	 22557	 0.003098	 0.012606	 0.00307	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22547	 82858	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22547	 82858	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22548	 22551	 0.003631	 0.012456	 0.00298	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22548	 82859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22548	 82859	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22549	 82860	 0.064101	 0.050729	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22550	 22554	 0.005195	 0.013946	 0.00316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22550	 82860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22550	 82860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22551	 22552	 0.002733	 0.009376	 0.00225	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22552	 22554	 0.00202	 0.00693	 0.00166	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82859	 22553	 0.059024	 0.11687	 0.00172	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22553	 82861	 0.038677	 0.030608	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22553	 82862	 0.018137	 0.046623	 0.00072	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22554	 22556	 0.003602	 0.014014	 0.00374	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22554	 82861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22554	 82861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22555	 22556	 0.0017	 0.005831	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22555	 22557	 0.003316	 0.011064	 0.00281	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22556	 23050	 0.001205	 0.006997	 0.00165	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22556	 82862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22556	 82862	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22558	 22559	 0.027116	 0.035639	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82847	 22558	 0.021177	 0.049158	 0.00094	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22559	 83142	 0.064805	 0.18589	 0.00286	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22561	 82863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22561	 82863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22562	 82864	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22562	 82864	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22562	 83273	 0.008181	 0.08612	 0.04842	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22563	 82865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22563	 82865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22564	 22565	 0.044663	 0.12372	 0.00204	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22564	 22570	 0.13983	 0.17049	 0.00273	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22564	 23963	 0.04303	 0.13664	 0.0024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22565	 22566	 0.069536	 0.13768	 0.00202	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22565	 23874	 0.057021	 0.14154	 0.00235	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22566	 22569	 0.10779	 0.11007	 0.00171	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22567	 22570	 0.026519	 0.068171	 0.00106	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22567	 82866	 0.17352	 0.15985	 0.00256	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22568	 22569	 0.028647	 0.067836	 0.00124	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22568	 22570	 0.025248	 0.064903	 0.001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22569	 22572	 0.037409	 0.1248	 0.00198	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22570	 83100	 0.397	 0.2572	 0.0049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22571	 23411	 0.011647	 0.039957	 0.00957	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22571	 82866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22571	 82866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22572	 23403	 0.050678	 0.085372	 0.00122	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22573	 22744	 0.6704	 0.53136	 0.00669	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22573	 82867	 0.5242	 0.33979	 0.00647	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22574	 82867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22574	 82867	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22574	 83229	 0.052838	 0.13729	 0.03336	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22575	 22577	 0.11428	 0.090441	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22575	 22579	 0.07379	 0.13181	 0.00195	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82867	 22576	 0.242	 0.18973	 0.00244	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22577	 22578	 0.038137	 0.030181	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82867	 22577	 0.13499	 0.31023	 0.00471	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22579	 23878	 0.1522	 0.39143	 0.00606	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22580	 22582	 0.034985	 0.086837	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22580	 82870	 0.028071	 0.071104	 0.00141	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22581	 22589	 0.18364	 0.14396	 0.00185	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22581	 82870	 0.024649	 0.1119	 0.00243	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22582	 22859	 0.054446	 0.12893	 0.00236	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22583	 22585	 0.1865	 0.14761	 0.00186	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22583	 22586	 0.15422	 0.12206	 0.00154	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22583	 24857	 0.081928	 0.14303	 0.00222	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22584	 22588	 0.073163	 0.056121	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22585	 22586	 0.15887	 0.12574	 0.00158	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22586	 82870	 0.025373	 0.098711	 0.00165	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22586	 82872	 0.061453	 0.083772	 0.00186	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22586	 83496	 0.2355	 0.29982	 0.00439	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22587	 22594	 0.004469	 0.011602	 0.00282	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22587	 82868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22587	 82868	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82868	 22588	 0.024619	 0.048743	 0.00072	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22590	 82871	 0.050853	 0.040244	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22591	 23340	 0.003052	 0.035293	 0.31023	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22591	 82869	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82869	 22592	 0.00179	 0.01074	 0.00325	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22592	 82871	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22592	 82871	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22593	 22594	 0.003429	 0.008902	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22593	 82872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22593	 82872	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22594	 82873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22594	 82873	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82873	 22595	 0.041004	 0.026546	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22596	 23454	 0.040099	 0.10308	 0.0016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81947	 22596	 0.24618	 0.24872	 0.00329	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22596	 82875	 0.058008	 0.10427	 0.00187	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22597	 22600	 0.002771	 0.011095	 0.0028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22597	 22602	 0.010853	 0.036569	 0.00909	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22598	 22599	 0.001515	 0.004004	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22598	 22600	 0.004298	 0.011048	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22598	 82874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22598	 82874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22599	 23407	 0.015322	 0.039779	 0.00966	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22600	 22756	 0.003801	 0.035776	 0.01084	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81946	 22600	 0.027257	 0.070778	 0.01718	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22600	 82875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22600	 82875	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82874	 22601	 0.088294	 0.057163	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82875	 22601	 0.013973	 0.022304	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22602	 24012	 0.010155	 0.027647	 0.00609	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22602	 82876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22602	 82876	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81946	 22603	 0.006582	 0.022577	 0.00541	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22604	 22605	 0.005035	 0.035614	 0.00977	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22604	 82877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22604	 82877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81946	 22605	 0.004806	 0.039014	 0.01242	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22606	 22611	 0.15714	 0.12437	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22606	 82919	 0.1416	 0.11206	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22607	 22610	 0.008764	 0.022753	 0.00552	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22607	 82878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22607	 82878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82786	 22608	 0.085862	 0.24631	 0.00379	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22609	 22614	 0.025423	 0.097809	 0.00167	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82646	 22609	 0.31094	 0.24615	 0.0031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22610	 22788	 0.009523	 0.06135	 0.01609	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22610	 82879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22610	 82879	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22611	 22615	 0.141	 0.10375	 0.00152	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22612	 22613	 0.010202	 0.015295	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82879	 22612	 0.020794	 0.059639	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22613	 22614	 0.045386	 0.057029	 0.00086	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22614	 22615	 0.032108	 0.14308	 0.00243	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22615	 22616	 0.064411	 0.12753	 0.00187	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22615	 83000	 0.052019	 0.14921	 0.00229	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22616	 84623	 0.033207	 0.11078	 0.00176	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82646	 22617	 0.21397	 0.16935	 0.00213	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22618	 82881	 0.1505	 0.11798	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22619	 22991	 0.36539	 0.26896	 0.00393	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22619	 82880	 0.036179	 0.060946	 0.00087	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22620	 22992	 0.088117	 0.22707	 0.05639	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22620	 82880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22620	 82880	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22621	 23366	 0.055174	 0.20009	 0.04302	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22621	 82881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22621	 82881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22622	 22623	 0.022351	 0.057457	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22622	 22625	 0.075202	 0.059515	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82881	 22622	 0.03597	 0.064653	 0.00116	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22623	 82882	 0.009777	 0.034233	 0.00095	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22624	 82882	 0.13441	 0.17348	 0.00349	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22624	 83230	 0.22037	 0.39634	 0.00712	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82744	 22625	 0.25111	 0.49756	 0.00731	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82881	 22625	 0.16276	 0.10538	 0.00201	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22626	 82882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22626	 82882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22627	 23876	 0.38422	 0.28283	 0.00414	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82744	 22627	 0.59724	 0.47322	 0.00596	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22627	 83230	 0.39677	 0.4325	 0.00589	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22628	 22629	 0.19645	 0.21402	 0.00291	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22628	 22630	 0.15474	 0.10019	 0.00191	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22628	 22737	 0.18717	 0.42842	 0.01047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81954	 22629	 0.035573	 0.13839	 0.00231	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22629	 82883	 0.052574	 0.1754	 0.00278	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22630	 22633	 0.23622	 0.18698	 0.00235	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22631	 22632	 0.1298	 0.10273	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22632	 22738	 0.43639	 0.48042	 0.00641	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22633	 22638	 0.03296	 0.076509	 0.00146	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22635	 24120	 0.17994	 0.14242	 0.00179	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22636	 22637	 0.093885	 0.10327	 0.00138	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22636	 22638	 0.16399	 0.12855	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81974	 22636	 0.01434	 0.030139	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22637	 22638	 0.034594	 0.068494	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22637	 24119	 0.14132	 0.27702	 0.00415	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81954	 22637	 0.086822	 0.26139	 0.00511	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22639	 24087	 0.008474	 0.047284	 0.01208	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22639	 82883	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22639	 82883	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22640	 22644	 0.00987	 0.01512	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22640	 22657	 0.006217	 0.016478	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22640	 22658	 0.004131	 0.010254	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82803	 22640	 0.022636	 0.11046	 0.00191	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22641	 22642	 0.004942	 0.012703	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22641	 22719	 0.003383	 0.008696	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22641	 82898	 0.009983	 0.012543	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22642	 22713	 0.003649	 0.00938	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22642	 22714	 0.003812	 0.009026	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22643	 22713	 0.008187	 0.0053	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22644	 22657	 0.004028	 0.015496	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22644	 22712	 0.021353	 0.016899	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22644	 22713	 0.002976	 0.011579	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22645	 22675	 0.004888	 0.018804	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22645	 22712	 0.002672	 0.011905	 0.0002	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22646	 22649	 0.003	 0.006963	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22646	 22712	 0.003794	 0.009754	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22647	 22716	 0.027145	 0.021482	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81983	 22648	 0.000261	 0.002224	 0.00055	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22648	 82884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22648	 82884	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82884	 22649	 0.005398	 0.01399	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22650	 22718	 0.004163	 0.01194	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22650	 82885	 0.003442	 0.009403	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22651	 22652	 0.000464	 0.002254	 0.00052	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81983	 22651	 0.000571	 0.004303	 0.00119	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22651	 82885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22651	 82885	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22652	 22653	 0.000763	 0.00323	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22653	 22654	 0.000762	 0.003226	 0.00073	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22654	 82891	 0.001311	 0.005153	 0.00135	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22655	 22718	 0.017994	 0.01424	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22656	 22717	 0.004277	 0.024314	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82885	 22656	 0.014872	 0.038229	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22656	 82892	 0.004322	 0.01926	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22657	 22666	 0.022655	 0.017929	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22657	 22667	 0.008984	 0.023094	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22657	 22670	 0.009779	 0.023156	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82808	 22657	 0.040711	 0.079788	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22658	 82898	 0.008487	 0.023508	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22659	 22715	 0.000783	 0.004811	 0.00176	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22659	 82886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22659	 82886	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82886	 22660	 0.006866	 0.009023	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82886	 22661	 0.004916	 0.016794	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22661	 82898	 0.005879	 0.017288	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22662	 22719	 0.004558	 0.012082	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82814	 22662	 0.014727	 0.037857	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22663	 22664	 0.003805	 0.008123	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82814	 22663	 0.00969	 0.02198	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22664	 22665	 0.004705	 0.010922	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22665	 22716	 0.008007	 0.018961	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22667	 22681	 0.009326	 0.019085	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22668	 22669	 0.004095	 0.011745	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22668	 22681	 0.004952	 0.014202	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22669	 22671	 0.004178	 0.012816	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22669	 22672	 0.002608	 0.009133	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22669	 22682	 0.004171	 0.015983	 0.00045	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22670	 22678	 0.003088	 0.007169	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81979	 22671	 0.004188	 0.020207	 0.00036	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22672	 82887	 0.003359	 0.008635	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22673	 22680	 0.000138	 0.001302	 0.00039	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22673	 22686	 0.000756	 0.008942	 0.00255	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22673	 82887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22673	 82887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22674	 22718	 0.002955	 0.016795	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81979	 22674	 0.002261	 0.012855	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22675	 22678	 0.003751	 0.009181	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22675	 82888	 0.001328	 0.005512	 0.00014	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22676	 22677	 0.000494	 0.003719	 0.00103	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22676	 82888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22676	 82888	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22677	 22679	 9.6e-05	 0.001481	 0.00041	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22679	 22680	 6.6e-05	 0.00096	 0.00031	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82808	 22681	 0.024424	 0.037414	 0.00053	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22682	 22683	 0.004549	 0.020272	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22682	 22684	 0.002602	 0.021644	 0.00041	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82808	 22683	 0.006663	 0.033706	 0.00059	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22684	 22685	 0.041175	 0.027659	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22684	 82889	 0.003033	 0.020594	 0.00051	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22686	 22703	 0.003476	 0.039734	 0.01212	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22686	 82889	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22686	 82889	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82887	 22687	 0.029007	 0.021341	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22688	 22717	 0.00608	 0.031618	 0.00069	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22688	 82890	 0.009533	 0.046517	 0.0008	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22689	 22701	 0.005806	 0.015072	 0.00366	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22689	 82890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22689	 82890	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22690	 22691	 0.006548	 0.0134	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22690	 22692	 0.035782	 0.025866	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82814	 22690	 0.010475	 0.04075	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22691	 22694	 0.006531	 0.015006	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22691	 22698	 0.012302	 0.054817	 0.00093	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22693	 82892	 0.014624	 0.019221	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82885	 22694	 0.018154	 0.042146	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22695	 82891	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22696	 22697	 0.020155	 0.013048	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82892	 22697	 0.004578	 0.031059	 0.00058	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22697	 82893	 0.005261	 0.020874	 0.0006	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22698	 22710	 0.023476	 0.074543	 0.00131	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22699	 22708	 0.001309	 0.014474	 0.00434	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82891	 22699	 0.001438	 0.009973	 0.00585	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22699	 82893	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22699	 82893	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82893	 22700	 0.036724	 0.071973	 0.00108	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22701	 82894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22701	 82894	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82890	 22702	 0.017082	 0.076119	 0.00129	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82894	 22702	 0.003529	 0.023942	 0.00045	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22702	 82895	 0.009213	 0.063242	 0.00115	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22703	 23065	 0.001959	 0.021695	 0.00706	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22703	 82895	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22703	 82895	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22704	 22705	 0.03493	 0.089793	 0.00139	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22704	 22720	 0.006374	 0.052403	 0.00102	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22704	 22795	 0.10661	 0.1796	 0.00256	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22704	 24233	 0.042785	 0.19067	 0.00324	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22705	 23076	 0.03469	 0.089175	 0.00138	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22706	 22711	 0.038662	 0.0877	 0.00175	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22706	 22795	 0.013555	 0.072534	 0.0022	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22706	 82897	 0.03473	 0.11586	 0.00184	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22707	 22720	 0.005776	 0.048053	 0.00091	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22707	 82896	 0.014533	 0.060662	 0.00175	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22707	 82897	 0.013075	 0.069664	 0.00122	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22708	 22709	 0.000818	 0.005672	 0.00162	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22708	 82896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22708	 82896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22709	 82897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22709	 82897	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22710	 22711	 0.029661	 0.098947	 0.00157	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82897	 22710	 0.037374	 0.086769	 0.00129	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22711	 22794	 0.043338	 0.11022	 0.00174	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22712	 22713	 0.00718	 0.01826	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81984	 22713	 0.008396	 0.02666	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22713	 82898	 0.006453	 0.017057	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81984	 22714	 0.003355	 0.010293	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82884	 22714	 0.021298	 0.021512	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81983	 22715	 0.00363	 0.009745	 0.00221	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22715	 82898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22715	 82898	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81984	 22716	 0.007319	 0.012329	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82885	 22716	 0.010893	 0.021349	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81979	 22717	 0.007019	 0.019917	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82884	 22718	 0.007996	 0.022934	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81984	 22719	 0.012808	 0.025358	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22721	 22727	 0.016309	 0.03786	 0.01154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22721	 22729	 0.003378	 0.025449	 0.00706	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81946	 22721	 0.011001	 0.045423	 0.01075	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22721	 82899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22721	 82899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22722	 22723	 0.025818	 0.020432	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22722	 83114	 0.024969	 0.083295	 0.00132	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22724	 82902	 0.080742	 0.15261	 0.00247	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22724	 83114	 0.026447	 0.12761	 0.00225	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22725	 22726	 0.033483	 0.14921	 0.00253	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82815	 22725	 0.075081	 0.1985	 0.0036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22725	 82901	 0.058166	 0.14238	 0.00243	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22725	 82903	 0.045423	 0.12008	 0.00218	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22726	 82903	 0.064877	 0.16678	 0.00258	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22726	 82967	 0.014887	 0.091525	 0.00165	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22726	 82968	 0.030865	 0.12008	 0.002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22727	 22728	 0.00954	 0.024767	 0.00601	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22727	 82900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22727	 82900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22728	 82901	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22728	 82901	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22729	 22730	 0.000902	 0.008203	 0.00207	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22730	 22731	 0.004114	 0.01647	 0.00415	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22730	 82902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22730	 82902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22731	 22946	 0.008413	 0.054198	 0.01421	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22731	 82903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22731	 82903	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22732	 22733	 0.00531	 0.015229	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82902	 22732	 0.019651	 0.046534	 0.00085	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82903	 22733	 0.027992	 0.064987	 0.00097	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22733	 83112	 0.081216	 0.19374	 0.00434	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22734	 23873	 0.050536	 0.13366	 0.03131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22734	 82904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22734	 82904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22735	 22737	 0.21546	 0.17054	 0.00215	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22735	 22738	 0.050261	 0.098505	 0.00148	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82904	 22735	 0.060337	 0.12348	 0.00304	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22736	 22737	 0.045417	 0.083186	 0.00144	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22738	 22739	 0.13067	 0.19821	 0.00284	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22739	 22740	 0.060998	 0.15514	 0.00245	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22740	 22742	 0.26761	 0.20532	 0.00276	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22740	 23869	 0.096672	 0.26416	 0.00449	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22740	 23875	 0.17337	 0.13721	 0.00173	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82743	 22740	 0.51523	 0.39073	 0.00538	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22741	 23871	 0.18598	 0.1472	 0.00185	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82904	 22742	 0.17103	 0.13408	 0.00172	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22743	 82905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22743	 82905	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22744	 22745	 0.24607	 0.19478	 0.00245	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22745	 22746	 0.14145	 0.11195	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82905	 22745	 0.33223	 0.33248	 0.00449	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22746	 22747	 0.11561	 0.22894	 0.00336	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82905	 22747	 0.35577	 0.23045	 0.00439	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22748	 22757	 0.038958	 0.11055	 0.00174	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82799	 22748	 0.02756	 0.12281	 0.00209	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22749	 22762	 0.029696	 0.10609	 0.00211	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22749	 83090	 0.0354	 0.20125	 0.00364	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22750	 22751	 0.1151	 0.10794	 0.00167	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22751	 22752	 0.025553	 0.042615	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22751	 22762	 0.017166	 0.052659	 0.00143	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22751	 82906	 0.036426	 0.06075	 0.00088	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22752	 22753	 0.005981	 0.015374	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22752	 22761	 0.00423	 0.00982	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22753	 22761	 0.009156	 0.023285	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22753	 82906	 0.007052	 0.016201	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22753	 82907	 0.019891	 0.089005	 0.00183	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22754	 22756	 0.001985	 0.019452	 0.00609	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22754	 82906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22754	 82906	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22754	 82908	 0.000802	 0.010084	 0.00312	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82906	 22755	 0.033372	 0.02641	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22756	 82907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22756	 82907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22757	 22760	 0.030991	 0.087946	 0.00138	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22758	 82909	 0.01606	 0.11024	 0.00201	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22758	 83100	 0.015291	 0.094012	 0.00169	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81929	 22759	 0.001545	 0.016962	 0.16487	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22759	 82908	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22760	 22761	 0.003682	 0.021797	 0.00042	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82909	 22760	 0.008483	 0.037799	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22763	 22764	 0.001247	 0.003295	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22763	 82910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22763	 82910	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22764	 22782	 0.003567	 0.009259	 0.00225	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22764	 82911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22764	 82911	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81980	 22765	 0.005386	 0.015285	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22765	 82918	 0.035215	 0.027869	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22765	 82921	 0.015636	 0.012374	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82910	 22766	 0.017622	 0.011409	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22767	 22800	 0.001545	 0.004084	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22767	 82912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22767	 82912	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22768	 82914	 0.041882	 0.030814	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82912	 22769	 0.0172	 0.011135	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22770	 22771	 0.011075	 0.008006	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82912	 22770	 0.01439	 0.010587	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22771	 22773	 0.009627	 0.010589	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22772	 22774	 0.002175	 0.005923	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22772	 22788	 0.013874	 0.038692	 0.00812	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22772	 82913	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22772	 82913	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82913	 22773	 0.03056	 0.024185	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22773	 82914	 0.025651	 0.018543	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22774	 22788	 0.010552	 0.031112	 0.00724	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22774	 82914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22774	 82914	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82914	 22775	 0.048079	 0.032296	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82914	 22776	 0.059216	 0.064499	 0.00088	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22777	 22778	 0.029215	 0.0229	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22777	 82916	 0.017661	 0.027055	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22779	 22780	 0.002661	 0.018824	 0.00517	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22779	 82915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22779	 82915	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22780	 82916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22780	 82916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22781	 22795	 0.011715	 0.071194	 0.00131	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22781	 82917	 0.005973	 0.026616	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22782	 82917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22782	 82917	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22783	 22796	 0.031484	 0.1039	 0.00168	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82917	 22783	 0.010053	 0.022802	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22783	 82918	 0.0039	 0.011963	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22784	 82918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22784	 82918	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81980	 22785	 0.010351	 0.06364	 0.00115	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22785	 83339	 0.082851	 0.18951	 0.00463	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22786	 22787	 0.002115	 0.013399	 0.00364	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22786	 22799	 0.002091	 0.021849	 0.00735	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22787	 22789	 0.005826	 0.019436	 0.00493	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22788	 82919	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22788	 82919	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22789	 82920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22789	 82920	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22790	 23030	 0.032733	 0.093886	 0.00144	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82919	 22790	 0.007832	 0.065156	 0.00123	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82920	 22790	 0.012544	 0.058163	 0.00121	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82915	 22791	 0.020714	 0.091268	 0.00159	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82878	 22792	 0.044203	 0.10262	 0.00153	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82915	 22792	 0.023211	 0.11327	 0.00196	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22793	 22794	 0.029614	 0.097729	 0.00158	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22796	 22797	 0.033793	 0.089333	 0.00162	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22797	 24233	 0.14379	 0.10894	 0.0015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22797	 83339	 0.051381	 0.14738	 0.00227	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22798	 24230	 0.01599	 0.079974	 0.00142	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82920	 22798	 0.012108	 0.053654	 0.00161	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22799	 24236	 0.00203	 0.025016	 0.00808	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22800	 82921	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22800	 82921	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22801	 22803	 0.021499	 0.016852	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22801	 82923	 0.01995	 0.015637	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22802	 22809	 0.026804	 0.018005	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22802	 22815	 0.012889	 0.022666	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22802	 82922	 0.006382	 0.017434	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22802	 82923	 0.022054	 0.017287	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22803	 22811	 0.030902	 0.025435	 0.00052	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22803	 82922	 0.00239	 0.012589	 0.00023	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22803	 82927	 0.069194	 0.054238	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22804	 22807	 0.002771	 0.008296	 0.00187	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22804	 22812	 0.001042	 0.006052	 0.00143	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22804	 82922	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22804	 82922	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22805	 22806	 0.019994	 0.02199	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22805	 22814	 0.020401	 0.013208	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82922	 22805	 0.004208	 0.009624	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22806	 22809	 0.016522	 0.013075	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22807	 22808	 0.001282	 0.00333	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22807	 22825	 0.0021	 0.005549	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22807	 82923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22807	 82923	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22808	 82924	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22808	 82924	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22808	 82926	 0.001428	 0.003707	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22809	 22810	 0.023343	 0.017906	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22809	 22822	 0.030774	 0.019923	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82924	 22809	 0.00769	 0.012773	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22810	 22821	 0.024544	 0.019423	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22811	 22840	 0.020928	 0.057969	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22811	 22851	 0.014627	 0.016088	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22812	 22839	 0.001374	 0.014131	 0.00401	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22812	 82925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22812	 82925	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22813	 22842	 0.008298	 0.015199	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22816	 22817	 0.019815	 0.024156	 0.00039	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22816	 22842	 0.005086	 0.013073	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22817	 22818	 0.015154	 0.011878	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22817	 22820	 0.038352	 0.030351	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22818	 22819	 0.018479	 0.014485	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22819	 22820	 0.016353	 0.012941	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22820	 22830	 0.012801	 0.018653	 0.00042	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22820	 22844	 0.009514	 0.04192	 0.00073	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22820	 82939	 0.049277	 0.054199	 0.00072	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22821	 22822	 0.022582	 0.017871	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22822	 82939	 0.009415	 0.023368	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22823	 22826	 0.000216	 0.002446	 0.02227	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22823	 82926	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82927	 22824	 0.011842	 0.021284	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22824	 82928	 0.067631	 0.053523	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22824	 82930	 0.012962	 0.036783	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82926	 22825	 0.002566	 0.006449	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22825	 82928	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22825	 82928	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22826	 22833	 0.00017	 0.001957	 0.01917	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22826	 22848	 0.000259	 0.002932	 0.02669	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22826	 82929	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82929	 22827	 0.003541	 0.009875	 0.00207	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22827	 82931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22827	 82931	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22828	 22830	 0.042579	 0.033697	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82931	 22828	 0.013853	 0.013992	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22829	 22833	 0.000106	 0.001394	 0.01261	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22829	 22847	 0.000116	 0.001616	 0.01598	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22830	 22831	 0.028753	 0.022755	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22831	 22832	 0.01627	 0.012876	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82931	 22832	 0.028548	 0.020637	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22833	 82932	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22833	 82932	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82930	 22834	 0.013077	 0.043624	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82932	 22834	 0.003192	 0.019622	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22834	 82940	 0.064238	 0.084429	 0.00116	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81973	 22835	 0.014592	 0.011548	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82927	 22835	 0.024889	 0.044908	 0.00065	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81973	 22836	 0.018974	 0.031689	 0.00054	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22836	 82933	 0.11434	 0.082659	 0.00125	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22837	 22838	 0.004487	 0.024619	 0.00651	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22838	 82933	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22838	 82933	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22839	 22841	 0.001521	 0.017039	 0.00542	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22839	 82934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22839	 82934	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82934	 22840	 0.018999	 0.048839	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22841	 82935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22841	 82935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22841	 83321	 0.014811	 0.067958	 0.01741	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22842	 22843	 0.016469	 0.045558	 0.00106	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82925	 22842	 0.063536	 0.041134	 0.00078	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22843	 22844	 0.014994	 0.050019	 0.00079	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22843	 24132	 0.057085	 0.16374	 0.00252	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22843	 24138	 0.046951	 0.10738	 0.00262	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82935	 22843	 0.022969	 0.088367	 0.00151	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82930	 22844	 0.054545	 0.11464	 0.00209	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22844	 82936	 0.006666	 0.065322	 0.00128	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22845	 82936	 0.14487	 0.11356	 0.00146	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22846	 22847	 0.000141	 0.002032	 0.01864	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22846	 24139	 0.000232	 0.00321	 0.03205	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22846	 82936	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22846	 82936	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22848	 82937	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82938	 22849	 0.1205	 0.12172	 0.00161	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22850	 22854	 0.014154	 0.03947	 0.00828	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82926	 22850	 0.004167	 0.010818	 0.00263	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82929	 22850	 0.00321	 0.008952	 0.00188	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22850	 82939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22850	 82939	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22851	 22852	 0.017691	 0.013867	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82928	 22852	 0.018018	 0.027598	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82933	 22852	 0.13146	 0.085113	 0.00162	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82932	 22853	 0.024867	 0.071323	 0.0011	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22853	 82940	 0.051662	 0.052181	 0.00069	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22854	 24084	 0.02814	 0.096568	 0.02315	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82929	 22854	 0.011765	 0.030544	 0.00741	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22854	 82940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22854	 82940	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82938	 22855	 0.14218	 0.092055	 0.00175	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82940	 22855	 0.080435	 0.081244	 0.00108	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22856	 22857	 0.004558	 0.020524	 0.00546	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82791	 22856	 0.003789	 0.015774	 0.00492	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82937	 22857	 0.00706	 0.024219	 0.0058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22860	 22862	 0.054942	 0.1424	 0.00269	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22860	 23412	 0.23482	 0.18587	 0.00234	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22860	 23413	 0.11644	 0.33051	 0.0052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22861	 22862	 0.054877	 0.14108	 0.00218	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22863	 22864	 0.011853	 0.009756	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22863	 22934	 0.016242	 0.031832	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22864	 22866	 0.020934	 0.014829	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22864	 22867	 0.018743	 0.014691	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22865	 22873	 0.019605	 0.025514	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22865	 22939	 0.04558	 0.029509	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22866	 22867	 0.019216	 0.015207	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22867	 82942	 0.023325	 0.017672	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22868	 82948	 0.012979	 0.021863	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22868	 82963	 0.029636	 0.037239	 0.00056	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22869	 82941	 0.011246	 0.014636	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22869	 82963	 0.013888	 0.027497	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22870	 22871	 0.000913	 0.00313	 0.00075	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22870	 22879	 0.001557	 0.004589	 0.00107	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22870	 82941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22870	 82941	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22870	 82962	 0.001194	 0.00686	 0.00194	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22871	 22876	 0.001138	 0.00286	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22871	 82942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22871	 82942	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82942	 22872	 0.021588	 0.015883	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22872	 82943	 0.018893	 0.014952	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22873	 22874	 0.020555	 0.016112	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22873	 22886	 0.035632	 0.026996	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22873	 82943	 0.008862	 0.025416	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22875	 82943	 0.008258	 0.01265	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22875	 82949	 0.017464	 0.013821	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22876	 82943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22876	 82943	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22877	 22878	 4.2e-05	 0.000479	 0.0042	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22877	 22889	 0.000137	 0.001547	 0.01409	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22877	 22957	 0.000448	 0.004917	 0.04777	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22877	 82944	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22878	 22935	 0.000157	 0.001754	 0.01638	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22878	 82946	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22879	 22880	 0.000635	 0.003485	 0.00092	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82946	 22879	 0.001021	 0.003099	 0.00068	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22880	 22881	 0.00079	 0.004628	 0.00126	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22881	 82948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22881	 82948	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22881	 82964	 0.002173	 0.010358	 0.003	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82947	 22882	 0.014183	 0.015599	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22883	 22884	 0.004099	 0.007747	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82941	 22883	 0.02018	 0.033995	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82945	 22883	 0.005312	 0.013656	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22884	 22892	 0.017449	 0.011296	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22885	 22887	 0.001244	 0.004267	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82944	 22885	 0.000941	 0.004729	 0.00123	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22885	 82949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22885	 82949	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22886	 22940	 0.026506	 0.040604	 0.00057	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22886	 22950	 0.030509	 0.024144	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82941	 22886	 0.021694	 0.062222	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22886	 82950	 0.003907	 0.016533	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22887	 22951	 0.0016	 0.004461	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22887	 82950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22887	 82950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22888	 22893	 0.005263	 0.008789	 0.00015	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22888	 22895	 0.006868	 0.012344	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82949	 22888	 0.005479	 0.009847	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22889	 22899	 8.8e-05	 0.000993	 0.00904	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22889	 82951	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82941	 22890	 0.050164	 0.047042	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22890	 82978	 0.010336	 0.034109	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22891	 22894	 0.007932	 0.012151	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82952	 22891	 0.007253	 0.015543	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22892	 22893	 0.008721	 0.006902	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22893	 22894	 0.003849	 0.008936	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22894	 82954	 0.006416	 0.009391	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22895	 22896	 0.005656	 0.008029	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22896	 82971	 0.009386	 0.012336	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22897	 22898	 0.019854	 0.015042	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22898	 82955	 0.004558	 0.010872	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22898	 82956	 0.056679	 0.044855	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22898	 82971	 0.031494	 0.024924	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22899	 82953	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22900	 22904	 0.001398	 0.003807	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82953	 22900	 0.000645	 0.00251	 0.00067	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22900	 82955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22900	 82955	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22901	 22902	 0.003499	 0.008994	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22901	 22903	 0.013118	 0.010381	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82952	 22902	 0.008099	 0.016036	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22902	 82977	 0.003248	 0.010834	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22904	 22970	 0.001563	 0.004018	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22905	 22906	 0.010166	 0.013857	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82955	 22905	 0.00754	 0.017104	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22906	 22908	 0.035713	 0.023121	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22907	 22951	 0.003371	 0.0094	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22907	 82956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22907	 82956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22907	 82973	 0.003599	 0.009251	 0.00229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22908	 22909	 0.01743	 0.017434	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22908	 22956	 0.023263	 0.018235	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22909	 82981	 0.003299	 0.014699	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22910	 22911	 0.023859	 0.092819	 0.00155	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22910	 23459	 0.099818	 0.10873	 0.00148	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22910	 82957	 0.025348	 0.074541	 0.00153	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22911	 22920	 0.062709	 0.1028	 0.00182	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22911	 23460	 0.082365	 0.090594	 0.00121	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22911	 83113	 0.037503	 0.096408	 0.00149	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22911	 83114	 0.043299	 0.12419	 0.00191	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22912	 22914	 0.003752	 0.01502	 0.00378	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22912	 22918	 0.010765	 0.029309	 0.00646	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22912	 82957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22912	 82957	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22913	 22914	 0.005887	 0.020599	 0.00683	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22913	 22916	 0.008268	 0.028362	 0.00679	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22913	 23517	 0.012628	 0.075245	 0.0198	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22913	 23524	 0.007119	 0.043057	 0.01099	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22913	 82958	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22913	 82958	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22915	 22916	 0.000862	 0.006722	 0.00201	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22915	 23896	 0.00316	 0.02539	 0.00714	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22915	 82959	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22915	 82959	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22916	 22918	 0.003367	 0.028874	 0.00822	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22916	 82960	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22916	 82960	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82960	 22917	 0.028096	 0.065219	 0.00124	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22917	 82961	 0.024347	 0.057655	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22918	 82961	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22918	 82961	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22919	 22920	 0.020978	 0.092432	 0.00161	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82957	 22919	 0.020824	 0.081011	 0.00135	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82961	 22919	 0.026512	 0.067425	 0.00107	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22920	 22921	 0.039465	 0.10037	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22920	 83114	 0.013623	 0.072586	 0.00127	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22921	 22922	 0.037968	 0.09656	 0.00153	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22922	 22923	 0.025946	 0.047523	 0.00082	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82961	 22922	 0.026279	 0.067554	 0.00105	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22923	 82966	 0.11597	 0.075085	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22924	 22925	 0.009526	 0.022557	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22924	 22927	 0.019078	 0.03739	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22925	 22930	 0.019992	 0.051392	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82961	 22925	 0.007742	 0.047052	 0.00087	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22926	 22927	 0.014402	 0.025724	 0.00038	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22927	 22930	 0.08342	 0.063203	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22927	 82963	 0.030226	 0.076564	 0.00152	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22928	 22929	 0.015605	 0.024908	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22928	 22934	 0.013483	 0.038671	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22929	 22930	 0.032351	 0.025602	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22930	 22939	 0.014422	 0.026415	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22931	 22932	 0.041761	 0.049992	 0.00083	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22931	 22933	 0.014903	 0.057977	 0.00097	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82960	 22931	 0.013087	 0.068052	 0.00148	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22932	 82965	 0.059652	 0.046759	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22933	 22934	 0.006388	 0.016422	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22934	 82963	 0.014227	 0.022709	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22935	 22936	 0.000189	 0.002075	 0.02016	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22935	 82962	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22936	 22957	 0.000744	 0.008117	 0.07969	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22936	 82964	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22937	 23911	 0.012672	 0.056464	 0.00096	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82948	 22937	 0.010258	 0.029421	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82965	 22937	 0.03894	 0.032051	 0.00065	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82948	 22938	 0.038011	 0.041808	 0.00056	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22939	 22940	 0.052041	 0.039919	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22940	 22943	 0.089748	 0.068844	 0.00092	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22941	 22943	 0.06706	 0.053071	 0.00067	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22941	 22950	 0.014283	 0.026161	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22941	 22955	 0.057283	 0.045333	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22942	 82966	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22942	 82966	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22943	 22947	 0.027063	 0.029766	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81988	 22943	 0.012264	 0.01787	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82966	 22943	 0.034657	 0.053091	 0.00075	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22944	 82967	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22944	 82967	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22944	 82969	 0.003397	 0.027289	 0.00767	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81988	 22945	 0.016258	 0.092421	 0.00167	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22945	 82968	 0.010629	 0.051865	 0.0009	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22946	 82968	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22946	 82968	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22946	 82969	 0.002058	 0.033122	 0.01082	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22947	 22948	 0.051734	 0.056902	 0.00076	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22947	 82970	 0.022155	 0.045338	 0.00112	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82967	 22948	 0.025694	 0.078825	 0.00214	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22948	 82970	 0.018663	 0.043323	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22949	 22957	 0.000217	 0.002378	 0.0231	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	22949	 82969	 0.000112	 0.008969	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22950	 22952	 0.025372	 0.018341	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22950	 82971	 0.008882	 0.017408	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22951	 82971	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22951	 82971	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82956	 22952	 0.017994	 0.018046	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82969	 22953	 0.003628	 0.015357	 0.00346	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22953	 82972	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22953	 82972	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22954	 22955	 0.022519	 0.016568	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22955	 82974	 0.005895	 0.022933	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22956	 22958	 0.03856	 0.027875	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22956	 82974	 0.007357	 0.022144	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22957	 82973	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22958	 22959	 0.023816	 0.018848	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22958	 22961	 0.013008	 0.021912	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22960	 22962	 0.035039	 0.027729	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22961	 22962	 0.007342	 0.013651	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22962	 82981	 0.025063	 0.024216	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22962	 82982	 0.003278	 0.014361	 0.00031	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22963	 22984	 0.007222	 0.015476	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22963	 82982	 0.006784	 0.017438	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22964	 22968	 0.000615	 0.006664	 0.00208	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22964	 23916	 0.000888	 0.011367	 0.00339	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22964	 82975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22964	 82975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22965	 22966	 0.000433	 0.00459	 0.00136	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22965	 23913	 0.000721	 0.008242	 0.00251	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22966	 22972	 0.000627	 0.005375	 0.00153	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22966	 82976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22966	 82976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22967	 22969	 0.001035	 0.004145	 0.00104	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82951	 22967	 0.001466	 0.003943	 0.00111	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22967	 82977	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22967	 82977	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22968	 22969	 0.000851	 0.005484	 0.00144	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22968	 82978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22968	 82978	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22969	 22971	 0.000999	 0.003998	 0.00101	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22970	 22971	 0.000523	 0.003937	 0.00109	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22970	 22977	 0.001481	 0.00508	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22971	 22973	 0.000622	 0.004839	 0.00126	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22971	 82979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22971	 82979	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22972	 22973	 0.000335	 0.003051	 0.00077	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22972	 82980	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22972	 82980	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22974	 22980	 0.011043	 0.030588	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82980	 22974	 0.007329	 0.018841	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22975	 22976	 0.010497	 0.015738	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82979	 22975	 0.004916	 0.016222	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	22976	 82981	 0.023436	 0.015743	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22976	 82982	 0.034226	 0.027086	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22977	 22978	 0.003426	 0.009055	 0.00212	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22977	 82981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22977	 82981	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22978	 22982	 0.002243	 0.021533	 0.00626	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22978	 82982	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22978	 82982	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22979	 22981	 0.018369	 0.029321	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82976	 22979	 0.006999	 0.025001	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82982	 22980	 0.020184	 0.026268	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	22981	 22983	 0.018065	 0.051814	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22981	 82983	 0.009224	 0.04613	 0.00082	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81943	 22982	 0.00437	 0.037638	 0.02186	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22982	 82983	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22982	 82983	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22983	 22984	 0.016803	 0.016441	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22983	 22985	 0.006493	 0.016691	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22984	 22985	 0.007216	 0.016753	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	22985	 22988	 0.004681	 0.021694	 0.00042	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22986	 22988	 0.060578	 0.047484	 0.00061	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22987	 22988	 0.00939	 0.036127	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82972	 22987	 0.012641	 0.025869	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22989	 82984	 0.068323	 0.050268	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82969	 22990	 0.007829	 0.020691	 0.00484	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	22990	 82984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22990	 82984	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	22993	 22996	 0.012255	 0.049875	 0.01215	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22993	 23367	 0.010279	 0.047941	 0.01187	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22994	 22995	 0.029011	 0.17837	 0.00322	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22994	 23884	 0.032886	 0.15466	 0.00288	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22995	 23373	 0.030099	 0.14457	 0.0028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	22995	 83227	 0.14471	 0.26117	 0.00378	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22996	 23880	 0.015013	 0.05307	 0.01196	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	22997	 23002	 0.14366	 0.1137	 0.00143	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	22998	 23001	 0.043583	 0.11204	 0.00173	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22998	 24129	 0.039157	 0.097192	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	22999	 82985	 0.063173	 0.042435	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23000	 23006	 0.00436	 0.021159	 0.00484	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23000	 24130	 0.00525	 0.027972	 0.00785	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23000	 82985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23000	 82985	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23001	 23002	 0.057228	 0.083392	 0.00188	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23001	 82987	 0.14614	 0.11456	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23002	 23003	 0.10962	 0.090232	 0.00183	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23002	 83307	 0.083349	 0.21605	 0.00409	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23003	 82986	 0.11687	 0.092493	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23004	 23005	 0.003641	 0.01249	 0.00299	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23004	 82986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23004	 82986	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23004	 82990	 0.005068	 0.017385	 0.00416	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23005	 23006	 0.002215	 0.008618	 0.0023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23005	 82987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23005	 82987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23006	 82988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23006	 82988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23007	 23009	 0.002974	 0.016595	 0.00424	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23007	 23019	 0.005214	 0.02392	 0.00613	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23008	 82989	 0.022548	 0.017844	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23009	 82989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23009	 82989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23009	 82990	 0.001252	 0.006173	 0.00167	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23010	 23527	 0.000665	 0.009409	 0.08974	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23010	 82990	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23011	 23012	 0.050294	 0.099579	 0.00146	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82989	 23011	 0.034312	 0.067246	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82991	 23011	 0.008946	 0.047124	 0.00085	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23011	 83135	 0.06508	 0.18029	 0.00298	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23012	 82992	 0.080911	 0.081725	 0.00108	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23013	 82992	 0.037512	 0.026571	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23014	 23015	 0.003931	 0.024395	 0.00591	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 23014	 0.024724	 0.084839	 0.02033	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82990	 23014	 0.012195	 0.046358	 0.01298	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23014	 82992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23014	 82992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23015	 23016	 0.000798	 0.003942	 0.00115	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23016	 23122	 0.004407	 0.01964	 0.00534	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23016	 82993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23016	 82993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23017	 23123	 0.069124	 0.13687	 0.00201	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82992	 23017	 0.047642	 0.10807	 0.00216	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23018	 23528	 0.002536	 0.020722	 0.00562	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82990	 23018	 0.003872	 0.033787	 0.00928	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23019	 23532	 0.004529	 0.018133	 0.00457	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82988	 23020	 0.046615	 0.049665	 0.00071	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23021	 23022	 0.25687	 0.20333	 0.00256	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23022	 23023	 0.10416	 0.06997	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23022	 23026	 0.086475	 0.17123	 0.00251	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82757	 23024	 0.52241	 0.40988	 0.00526	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23025	 23026	 0.075298	 0.13792	 0.00238	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82871	 23026	 0.013573	 0.092093	 0.00172	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23027	 23035	 0.034889	 0.080987	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23027	 23048	 0.028452	 0.080739	 0.00127	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23027	 83103	 0.021323	 0.084599	 0.00242	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23028	 23029	 0.038797	 0.079398	 0.00195	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23028	 23049	 0.038206	 0.098215	 0.00152	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23029	 23030	 0.035347	 0.090865	 0.00141	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82920	 23029	 0.025548	 0.09939	 0.00166	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23029	 82998	 0.099913	 0.17573	 0.0033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23030	 23031	 0.14454	 0.11439	 0.00144	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23031	 82994	 0.05904	 0.10383	 0.00195	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23031	 83000	 0.042958	 0.099734	 0.00148	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23032	 23040	 0.005114	 0.025696	 0.00669	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23032	 23043	 0.004209	 0.026656	 0.00723	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23032	 82994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23032	 82994	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23033	 23039	 0.074864	 0.059247	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23034	 23047	 0.016517	 0.043656	 0.01022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23034	 24226	 0.022289	 0.080728	 0.01733	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23034	 82995	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23034	 82995	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23034	 82996	 0.001833	 0.017911	 0.00503	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23035	 23048	 0.037261	 0.026936	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82995	 23035	 0.016166	 0.042846	 0.00109	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23036	 82997	 0.040303	 0.078989	 0.00118	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23036	 83001	 0.12131	 0.078544	 0.0015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23037	 26399	 0.001931	 0.021892	 0.19951	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23037	 82996	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82997	 23038	 0.022385	 0.017715	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23038	 82999	 0.020296	 0.014672	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82997	 23039	 0.032058	 0.02537	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23039	 82998	 0.005874	 0.013433	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23040	 23041	 0.002214	 0.007593	 0.00182	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23040	 82998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23040	 82998	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82996	 23041	 0.002749	 0.007264	 0.0017	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23041	 82999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23041	 82999	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82994	 23042	 0.034097	 0.11375	 0.0018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82999	 23042	 0.029372	 0.038604	 0.00053	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23043	 23044	 0.00736	 0.02947	 0.00742	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23043	 83000	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23043	 83000	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23044	 83957	 0.013536	 0.070525	 0.0185	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23045	 23047	 0.006136	 0.029941	 0.00827	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23045	 26074	 0.007498	 0.041297	 0.01491	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23046	 23444	 0.042309	 0.1076	 0.0017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82997	 23046	 0.098864	 0.19576	 0.00287	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23046	 83001	 0.005855	 0.035997	 0.00065	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23047	 83001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23047	 83001	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23048	 23049	 0.015085	 0.038363	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23049	 24229	 0.056704	 0.16092	 0.00253	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23049	 24230	 0.04736	 0.12045	 0.0019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23049	 24231	 0.21984	 0.174	 0.00219	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82995	 23049	 0.062684	 0.091344	 0.00206	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23050	 23052	 0.001248	 0.006208	 0.002	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82862	 23051	 0.10977	 0.080763	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23052	 23053	 0.00182	 0.009305	 0.00254	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23053	 23059	 0.002905	 0.013241	 0.0042	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82860	 23054	 0.087239	 0.071808	 0.00146	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23054	 83002	 0.13446	 0.097205	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23055	 23057	 0.00267	 0.01202	 0.0032	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23055	 23070	 0.00174	 0.007245	 0.00226	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23055	 83002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23055	 83002	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23056	 23060	 0.019418	 0.047531	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83002	 23056	 0.019348	 0.049737	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23057	 23094	 0.001798	 0.008247	 0.00211	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23058	 83004	 0.021103	 0.054249	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23058	 83012	 0.015015	 0.038598	 0.0006	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23059	 23061	 0.004999	 0.01361	 0.003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23059	 23578	 0.002657	 0.014157	 0.00397	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23059	 83003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23059	 83003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83003	 23060	 0.01927	 0.049536	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23061	 23062	 0.004786	 0.01203	 0.00312	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23062	 23082	 0.003015	 0.008406	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23062	 83004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23062	 83004	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23063	 83310	 0.17592	 0.13924	 0.00175	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23064	 23070	 0.00349	 0.021459	 0.00619	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23064	 24110	 0.002887	 0.025579	 0.00681	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23064	 83005	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23064	 83005	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23065	 23066	 0.000389	 0.004372	 0.00115	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23066	 23068	 0.00141	 0.012788	 0.00669	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23066	 24104	 0.011968	 0.096185	 0.02705	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23066	 83006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23066	 83006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23067	 23076	 0.055216	 0.083747	 0.0012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82895	 23067	 0.018513	 0.11251	 0.00208	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83006	 23067	 0.010671	 0.041512	 0.00069	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23067	 83007	 0.007091	 0.051029	 0.00167	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23068	 23072	 0.001289	 0.013262	 0.00376	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23068	 83007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23068	 83007	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83005	 23069	 0.051219	 0.074636	 0.00169	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83007	 23069	 0.028272	 0.047627	 0.00068	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23070	 83008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23070	 83008	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83002	 23071	 0.032678	 0.054578	 0.00093	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83008	 23071	 0.02124	 0.049312	 0.00073	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23071	 83009	 0.005429	 0.012415	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23072	 23074	 0.002563	 0.009743	 0.00273	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23072	 83009	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23072	 83009	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23073	 23075	 0.008703	 0.052892	 0.00098	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83007	 23073	 0.00799	 0.048556	 0.0009	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23074	 23095	 0.003088	 0.011738	 0.00329	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23075	 23080	 0.013259	 0.080583	 0.00149	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23076	 23077	 0.029852	 0.098514	 0.0016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23077	 24233	 0.03449	 0.098923	 0.00152	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23078	 23080	 0.068883	 0.048794	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23079	 23080	 0.016545	 0.033858	 0.00083	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23079	 24233	 0.040777	 0.10482	 0.00162	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23080	 23104	 0.009031	 0.040244	 0.00068	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23080	 24232	 0.086259	 0.077297	 0.00158	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23081	 23085	 0.005765	 0.025688	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23081	 23581	 0.016586	 0.047572	 0.00073	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23082	 23084	 0.00281	 0.006522	 0.00199	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23083	 23087	 0.018678	 0.030057	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23083	 23092	 0.037991	 0.029141	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23083	 83010	 0.032599	 0.025798	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23084	 83010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23084	 83010	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83010	 23085	 0.00479	 0.023375	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23086	 23089	 0.039351	 0.031142	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23087	 23089	 0.003045	 0.018722	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23087	 83011	 0.005107	 0.019648	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23088	 23091	 0.003667	 0.013937	 0.0039	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23088	 23097	 0.00189	 0.007567	 0.00191	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23088	 23105	 0.003143	 0.019502	 0.00472	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23088	 83011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23088	 83011	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23089	 23090	 0.004873	 0.011312	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23089	 83014	 0.036055	 0.055233	 0.00078	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23090	 23098	 0.041113	 0.032536	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23090	 23106	 0.019593	 0.013161	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23091	 23094	 0.002143	 0.0104	 0.00238	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83009	 23093	 0.01327	 0.051054	 0.00087	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23093	 83012	 0.005853	 0.013276	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23093	 83013	 0.030575	 0.077759	 0.00123	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23094	 83012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23094	 83012	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23095	 23096	 0.001964	 0.008111	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23096	 23097	 0.002288	 0.008994	 0.00235	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23097	 83013	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23097	 83013	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23099	 23100	 0.033786	 0.044405	 0.00061	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83013	 23099	 0.026901	 0.052722	 0.00079	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23100	 23104	 0.022529	 0.021127	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23101	 23102	 0.059357	 0.046975	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23102	 23103	 0.010728	 0.040243	 0.00072	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23102	 83015	 0.036685	 0.033098	 0.00055	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23103	 23104	 0.004397	 0.026032	 0.00051	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23103	 24242	 0.022912	 0.059382	 0.00112	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23105	 83014	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23105	 83014	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23105	 83156	 0.009749	 0.03832	 0.01003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23107	 23108	 0.003962	 0.010471	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23107	 83015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23107	 83015	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23108	 83016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23108	 83016	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83016	 23109	 0.008275	 0.028971	 0.0008	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23109	 83165	 0.004834	 0.018597	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23110	 24244	 0.017274	 0.044406	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83016	 23110	 0.007909	 0.022683	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23111	 23115	 0.025616	 0.0997	 0.02664	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82724	 23111	 0.062993	 0.16932	 0.03843	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23111	 83017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23111	 83017	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83017	 23112	 0.2444	 0.15826	 0.00301	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23113	 23117	 0.31324	 0.31652	 0.00419	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83017	 23114	 0.20994	 0.39065	 0.00915	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23115	 24101	 0.029183	 0.11691	 0.02948	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23118	 23122	 0.002489	 0.012379	 0.004	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23118	 23124	 0.002965	 0.009267	 0.00268	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23119	 24069	 0.029574	 0.078387	 0.00199	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23119	 83019	 0.03432	 0.067952	 0.001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23120	 23129	 0.000223	 0.002451	 0.02381	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23120	 83018	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23121	 23122	 0.006545	 0.01699	 0.00412	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23121	 23124	 0.009288	 0.031294	 0.00778	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 23121	 0.00948	 0.076972	 0.02452	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23121	 83020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23121	 83020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23121	 83023	 0.009918	 0.034024	 0.00815	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23122	 83021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23122	 83021	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82993	 23123	 0.046837	 0.092734	 0.00136	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83021	 23123	 0.071329	 0.046179	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23123	 83208	 0.043476	 0.098621	 0.00197	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23124	 23125	 0.003787	 0.011397	 0.00357	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23124	 23127	 0.004359	 0.014686	 0.00365	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23125	 23155	 0.003783	 0.012976	 0.00311	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23125	 83022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23125	 83022	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83022	 23126	 0.033405	 0.03374	 0.00045	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23127	 23162	 0.003582	 0.010877	 0.00238	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23128	 23142	 0.041829	 0.08282	 0.00122	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83020	 23128	 0.03019	 0.10071	 0.0016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23129	 23131	 0.000386	 0.004275	 0.0407	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23129	 83023	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23130	 23136	 0.046418	 0.034151	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23130	 24047	 0.23176	 0.25497	 0.0034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83024	 23130	 0.052946	 0.052959	 0.00072	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23130	 83025	 0.081356	 0.063772	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23131	 23132	 4.6e-05	 0.000722	 0.00753	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23131	 24057	 0.000161	 0.001893	 0.03306	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23131	 83025	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23131	 83025	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23132	 23138	 7e-05	 0.001117	 0.01129	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23132	 83026	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23132	 83026	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23133	 23141	 0.000101	 0.001163	 0.0102	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23133	 23327	 5.2e-05	 0.000868	 0.00814	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23133	 83027	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23133	 83027	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23134	 23140	 0.004396	 0.01162	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23134	 83029	 0.00704	 0.023232	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23135	 83028	 0.036682	 0.026517	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83025	 23136	 0.012912	 0.029529	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23136	 83029	 0.008405	 0.022276	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83023	 23137	 0.006448	 0.02451	 0.00686	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83027	 23137	 0.002643	 0.007415	 0.00191	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23137	 83028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23137	 83028	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23138	 23327	 0.000139	 0.002305	 0.02161	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23138	 83029	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23138	 83029	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23139	 23224	 0.027455	 0.10563	 0.0018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83025	 23139	 0.024203	 0.044329	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83026	 23139	 0.011855	 0.022043	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23140	 83077	 0.022702	 0.058357	 0.0009	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23141	 23146	 0.000122	 0.001359	 0.01281	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23142	 23143	 0.07226	 0.056641	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23142	 23144	 0.068828	 0.05447	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23143	 23144	 0.036082	 0.028283	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23143	 23148	 0.086778	 0.065748	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23144	 23145	 0.01176	 0.017836	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23144	 83032	 0.07325	 0.05797	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23145	 23149	 0.02721	 0.021534	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83028	 23145	 0.031282	 0.081075	 0.00153	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23146	 23147	 6e-05	 0.000688	 0.00621	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23147	 23179	 0.000344	 0.003778	 0.03669	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23147	 23216	 8.7e-05	 0.000984	 0.00896	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23148	 23150	 0.023378	 0.0172	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23148	 23151	 0.032186	 0.020837	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23149	 23151	 0.01777	 0.014626	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23150	 23151	 0.022252	 0.016372	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23150	 83052	 0.007583	 0.019284	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23151	 83052	 0.013054	 0.025845	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23152	 23153	 0.012721	 0.016555	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23152	 23154	 0.045489	 0.033467	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23152	 83031	 0.014099	 0.025341	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23153	 23154	 0.010762	 0.016484	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23153	 23160	 0.041431	 0.045569	 0.00061	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23154	 83030	 0.005906	 0.01676	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23155	 23836	 0.010098	 0.026688	 0.00625	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23155	 83030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23155	 83030	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83030	 23156	 0.036235	 0.028676	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23157	 23159	 0.011538	 0.019437	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23157	 23160	 0.040305	 0.029136	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23157	 23831	 0.022771	 0.018021	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23158	 23159	 0.007487	 0.014824	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23158	 23174	 0.005595	 0.018665	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23160	 23161	 0.025208	 0.027726	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23160	 83033	 0.023258	 0.056931	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23162	 23163	 0.00253	 0.006791	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23162	 23173	 0.01108	 0.028766	 0.00698	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23162	 83031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23162	 83031	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23163	 23164	 0.001621	 0.003906	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23164	 23173	 0.007431	 0.020232	 0.00446	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23164	 83032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23164	 83032	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23165	 23167	 0.036292	 0.028721	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83032	 23165	 0.023537	 0.018627	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23166	 23169	 0.026778	 0.021192	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83032	 23166	 0.044797	 0.035452	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23167	 23171	 0.02296	 0.01817	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23167	 83033	 0.02351	 0.039604	 0.00056	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23168	 83033	 0.035798	 0.02833	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23169	 23171	 0.023835	 0.018863	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23169	 83052	 0.004987	 0.016637	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23170	 23178	 0.025951	 0.020537	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23170	 23193	 0.018598	 0.014718	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23172	 83033	 0.029186	 0.022877	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23173	 83033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23173	 83033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23173	 83075	 0.001124	 0.01079	 0.00314	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23174	 83034	 0.005729	 0.032564	 0.00059	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23175	 23841	 0.01259	 0.040541	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23175	 83034	 0.002986	 0.016972	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23176	 23859	 0.003462	 0.015252	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23176	 83039	 0.003543	 0.021783	 0.00039	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23177	 83034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23177	 83034	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23177	 83075	 0.002334	 0.007614	 0.00202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23178	 23186	 0.012936	 0.036708	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23178	 23194	 0.051083	 0.033071	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83033	 23178	 0.021514	 0.023663	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23179	 23181	 6.8e-05	 0.000723	 0.00754	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23179	 83035	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23179	 83035	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23179	 83074	 0.00014	 0.001535	 0.01491	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23180	 23189	 0.002942	 0.007774	 0.00182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23180	 23198	 0.001783	 0.006301	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83035	 23180	 0.000421	 0.003543	 0.00105	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23180	 83036	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23180	 83036	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23181	 23182	 0.00012	 0.001364	 0.01232	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23181	 83037	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23181	 83037	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23182	 23183	 6.1e-05	 0.000692	 0.00625	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23182	 83038	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23183	 83040	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23183	 83074	 0.000126	 0.001459	 0.01279	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23184	 23185	 0.001044	 0.003968	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23184	 23853	 0.00119	 0.004148	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23185	 23191	 0.000542	 0.004082	 0.00113	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23185	 83075	 0.000417	 0.003152	 0.00155	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23186	 23187	 0.024378	 0.015782	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23186	 83044	 0.01824	 0.018244	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23186	 83076	 0.005331	 0.017785	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23187	 83044	 0.032307	 0.020916	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23188	 23207	 0.010217	 0.017211	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83036	 23188	 0.008727	 0.015984	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23189	 23287	 0.000659	 0.005611	 0.0014	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23189	 83042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23189	 83042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23189	 83043	 0.000729	 0.005857	 0.00165	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23190	 83043	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23190	 83074	 0.000108	 0.001245	 0.01091	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23191	 23291	 0.000929	 0.00313	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23191	 83045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23191	 83045	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23192	 23293	 0.000466	 0.003998	 0.00114	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23192	 23861	 0.001585	 0.004316	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23192	 83046	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23192	 83046	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23192	 83075	 0.000795	 0.009252	 0.00272	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23193	 23194	 0.017262	 0.013531	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23194	 23196	 0.024982	 0.019582	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23194	 83047	 0.013599	 0.014957	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23195	 23220	 0.001374	 0.005503	 0.00139	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23195	 23223	 0.001605	 0.004242	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83027	 23195	 0.002588	 0.01165	 0.0031	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23196	 83052	 0.024099	 0.019071	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23197	 23198	 0.001112	 0.003815	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23197	 23199	 0.001921	 0.004938	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23197	 23212	 0.003021	 0.007767	 0.00192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23197	 83047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23197	 83047	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23199	 23200	 0.001271	 0.003359	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23199	 83048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23199	 83048	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23200	 23201	 0.001161	 0.003236	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23201	 23204	 0.001909	 0.004955	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23202	 23205	 0.025407	 0.022766	 0.00047	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23202	 83049	 0.024249	 0.019007	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23202	 83054	 0.01728	 0.040117	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23203	 23211	 0.001851	 0.00516	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23203	 23222	 0.0012	 0.003115	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23204	 23221	 0.003353	 0.009129	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23204	 83049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23204	 83049	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23205	 23206	 0.018672	 0.014777	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23206	 23207	 0.01334	 0.014246	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23206	 83057	 0.023037	 0.017453	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83042	 23207	 0.04	 0.031655	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23208	 83057	 0.017887	 0.014155	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23209	 23257	 0.026001	 0.019699	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83049	 23209	 0.009517	 0.015895	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23210	 23211	 0.001633	 0.00424	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23210	 83050	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23210	 83050	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23210	 83056	 0.004483	 0.011848	 0.00277	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23211	 83051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23211	 83051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23212	 23214	 0.001249	 0.004209	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23212	 83052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23212	 83052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23213	 23227	 0.010478	 0.018716	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23213	 23228	 0.001418	 0.004681	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23213	 23229	 0.017861	 0.013532	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83050	 23213	 0.006677	 0.022273	 0.00035	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83051	 23213	 0.005939	 0.013788	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23214	 23215	 0.001162	 0.004106	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23215	 83053	 0.000922	 0.004153	 0.00111	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23216	 83053	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23216	 83053	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83048	 23217	 0.025696	 0.018905	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23218	 23220	 0.002416	 0.006736	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23218	 23222	 0.00091	 0.003645	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23218	 23223	 0.001141	 0.004486	 0.00117	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23218	 83054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23218	 83054	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83054	 23219	 0.020057	 0.015873	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23219	 83055	 0.005697	 0.01128	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83053	 23220	 0.000619	 0.003333	 0.00092	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23220	 83055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23220	 83055	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23220	 83056	 0.007877	 0.02045	 0.00496	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23221	 23222	 0.001241	 0.003118	 0.00081	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23223	 23331	 0.001392	 0.004852	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23224	 23226	 0.021708	 0.021926	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23224	 23227	 0.008279	 0.01774	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83054	 23224	 0.010954	 0.023023	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23225	 23227	 0.03656	 0.039043	 0.00083	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23225	 83077	 0.016936	 0.032814	 0.00071	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23226	 23228	 0.015177	 0.032524	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23226	 24054	 0.045951	 0.17878	 0.00298	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23227	 23228	 0.011028	 0.013444	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23228	 23229	 0.014279	 0.0113	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23230	 23231	 0.010841	 0.008498	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23231	 23232	 0.011264	 0.008914	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23232	 23233	 0.004472	 0.01269	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23232	 23236	 0.004108	 0.010559	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83050	 23233	 0.005316	 0.017732	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23234	 23235	 0.008883	 0.006963	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23234	 23258	 0.015362	 0.012157	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23235	 23236	 0.012003	 0.009499	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23236	 23237	 0.005281	 0.012258	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23237	 23238	 0.022532	 0.017831	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23237	 23240	 0.003195	 0.008213	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23238	 23239	 0.004451	 0.007105	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23238	 23258	 0.004452	 0.010619	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23239	 23244	 0.007965	 0.013056	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23240	 23241	 0.004453	 0.008726	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23241	 23242	 0.005642	 0.009005	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23242	 23243	 0.006785	 0.011122	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23242	 23246	 0.00384	 0.00871	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23243	 23244	 0.004289	 0.008491	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23244	 23265	 0.018653	 0.01884	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23245	 23276	 0.015764	 0.011396	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23246	 23247	 0.004831	 0.009468	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23247	 23248	 0.026833	 0.021235	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23247	 23249	 0.017631	 0.013358	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23247	 23250	 0.01539	 0.010902	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23247	 83068	 0.023636	 0.067791	 0.00104	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23248	 24554	 0.026286	 0.019339	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23249	 23251	 0.012921	 0.009789	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23250	 23252	 0.016958	 0.01342	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23252	 24553	 0.020457	 0.014788	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23253	 83056	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23253	 83074	 0.000314	 0.003555	 0.03236	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23254	 23286	 0.030239	 0.023931	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83057	 23254	 0.00893	 0.016356	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83042	 23255	 0.015316	 0.030016	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23255	 83058	 0.016622	 0.018282	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23256	 23259	 0.000397	 0.00313	 0.00092	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23256	 23287	 0.003285	 0.008682	 0.00203	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83056	 23256	 0.000352	 0.003364	 0.00123	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23256	 83058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23256	 83058	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83058	 23257	 0.026595	 0.020846	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23258	 83059	 0.002502	 0.017174	 0.00031	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23259	 24547	 0.007924	 0.027615	 0.0064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23259	 83059	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23259	 83059	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23260	 23263	 0.003197	 0.006542	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23260	 23265	 0.005102	 0.017852	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83059	 23260	 0.001797	 0.008157	 0.00018	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23261	 23262	 0.008046	 0.014046	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83057	 23261	 0.006973	 0.031652	 0.00069	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23262	 83060	 0.003781	 0.008103	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23263	 23266	 0.004617	 0.009141	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23264	 23265	 0.012678	 0.009328	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23265	 23271	 0.008712	 0.007806	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23266	 23269	 0.005518	 0.009045	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23267	 23268	 0.000835	 0.002274	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23267	 83060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23267	 83060	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23268	 23275	 0.000806	 0.002027	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23269	 23270	 0.002824	 0.008671	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23269	 23274	 0.013444	 0.010639	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83060	 23269	 0.0066	 0.012089	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23270	 23273	 0.00319	 0.0082	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23271	 23272	 0.011498	 0.009099	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23272	 23273	 0.016683	 0.0108	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23273	 23277	 0.003507	 0.009015	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23274	 23278	 0.014768	 0.010676	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23275	 23313	 0.001198	 0.003167	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23276	 23277	 0.020427	 0.016166	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23277	 23280	 0.009604	 0.009279	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23277	 23282	 0.007212	 0.017653	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23277	 83069	 0.006148	 0.028507	 0.00059	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23278	 23279	 0.013678	 0.009689	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23278	 83069	 0.008818	 0.017282	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23279	 23285	 0.006118	 0.011991	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23279	 83069	 0.004927	 0.011436	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23280	 23283	 0.019345	 0.015309	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23281	 23282	 0.011126	 0.008805	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23282	 24550	 0.025963	 0.020547	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23283	 23284	 0.011692	 0.008602	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23284	 23323	 0.010978	 0.021735	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23284	 24247	 0.015421	 0.009983	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23285	 23323	 0.006504	 0.010957	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23286	 83061	 0.012402	 0.008965	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23287	 23300	 0.000632	 0.004002	 0.00109	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23287	 83061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23287	 83061	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23288	 23289	 0.012706	 0.009959	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23288	 23290	 0.004497	 0.0173	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23288	 23297	 0.004389	 0.008602	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83061	 23288	 0.023412	 0.017225	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83044	 23290	 0.002638	 0.016219	 0.00029	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23290	 83079	 0.010049	 0.019896	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23291	 23292	 0.000653	 0.002307	 0.00052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23292	 23295	 0.000441	 0.003028	 0.00088	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23292	 83078	 0.001505	 0.0039	 0.00118	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23293	 23783	 0.000545	 0.004585	 0.00136	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83046	 23294	 0.01011	 0.033726	 0.00053	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23294	 83066	 0.009342	 0.018309	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23295	 23307	 0.000567	 0.004138	 0.00106	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23295	 83062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23295	 83062	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23296	 83063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23296	 83063	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23296	 83078	 0.001241	 0.004493	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23297	 23298	 0.004323	 0.0069	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23298	 23302	 0.002896	 0.007655	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83063	 23298	 0.012397	 0.017598	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83061	 23299	 0.01203	 0.008521	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23300	 23301	 0.000342	 0.001741	 0.00063	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23301	 23324	 0.00035	 0.002008	 0.00057	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23302	 23303	 0.004629	 0.009166	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23303	 23312	 0.006635	 0.013137	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23304	 23305	 0.001817	 0.006361	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23304	 23311	 0.003987	 0.013299	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83063	 23305	 0.002023	 0.009393	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23305	 83064	 0.014201	 0.017312	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23306	 83064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23306	 83064	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23306	 83078	 0.001404	 0.005338	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23307	 23308	 0.001056	 0.00384	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23307	 23310	 0.001294	 0.004438	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23307	 83065	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23307	 83065	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23308	 23789	 0.00164	 0.005626	 0.00135	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23308	 83066	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23308	 83066	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23309	 23317	 0.00844	 0.016541	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83066	 23309	 0.003054	 0.01545	 0.00027	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23309	 83207	 0.011802	 0.016448	 0.00028	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23310	 83067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23310	 83067	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23311	 23325	 0.003417	 0.007814	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23312	 83073	 0.028628	 0.022656	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23313	 23314	 0.001563	 0.003628	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23313	 23324	 0.000605	 0.002883	 0.00084	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23313	 83068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23313	 83068	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23314	 83069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23314	 83069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23314	 83072	 0.001558	 0.005345	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23315	 23326	 0.005663	 0.016243	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23315	 23332	 0.014104	 0.014245	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23316	 23317	 0.017897	 0.017901	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23316	 23319	 0.023829	 0.018858	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23318	 23319	 0.006371	 0.014788	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23318	 23777	 0.020471	 0.016046	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23318	 24294	 0.011044	 0.014515	 0.0002	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81977	 23319	 0.003688	 0.014349	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23320	 83070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23320	 83070	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23320	 83072	 0.002065	 0.007083	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23321	 23322	 0.011896	 0.009325	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83070	 23322	 0.012893	 0.014181	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23322	 83073	 0.004103	 0.015718	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23323	 24267	 0.005354	 0.012431	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23323	 83071	 0.001942	 0.009483	 0.0002	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23325	 23326	 0.005017	 0.009483	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83067	 23326	 0.005774	 0.016385	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23328	 24268	 0.00079	 0.003106	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23328	 83071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23328	 83071	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23328	 83072	 0.000465	 0.003664	 0.00107	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23329	 23333	 0.000205	 0.002546	 0.02558	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23329	 24310	 0.000292	 0.003373	 0.02957	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23329	 24324	 0.000453	 0.005131	 0.04671	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23329	 83072	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23329	 83074	 0.000415	 0.004792	 0.04201	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23330	 24603	 0.000113	 0.002292	 0.82871	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23330	 24882	 0.000713	 0.013447	 5.9831	 4162.0	 4370.1	 4578.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23330	 83074	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23330	 83074	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23330	 83074	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83027	 23331	 0.003253	 0.01377	 0.0031	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23331	 83077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23331	 83077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81977	 23332	 0.004408	 0.011211	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83070	 23332	 0.003477	 0.009973	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83074	 23333	 0.000187	 0.002163	 0.01896	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23333	 83078	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81995	 23334	 0.14581	 0.20325	 0.00348	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23335	 23336	 0.004306	 0.022431	 0.00588	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23336	 23337	 0.005075	 0.027848	 0.00736	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23337	 23342	 0.002578	 0.02211	 0.00629	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23337	 83080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23337	 83080	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81995	 23338	 0.032444	 0.075312	 0.00143	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23338	 83082	 0.087609	 0.2004	 0.00489	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23339	 23367	 0.020056	 0.052073	 0.01264	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23340	 24862	 0.002548	 0.028531	 0.26706	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23340	 83081	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23340	 83081	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23341	 23369	 0.10093	 0.26165	 0.00495	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23341	 83082	 0.010224	 0.023736	 0.00035	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83081	 23342	 0.001139	 0.015927	 0.0054	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23342	 83082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23342	 83082	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23343	 23344	 0.011033	 0.008117	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81994	 23343	 0.019737	 0.019742	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23343	 83083	 0.020272	 0.014915	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81961	 23344	 0.021133	 0.029999	 0.00049	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81994	 23344	 0.027469	 0.025302	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23344	 83083	 0.024688	 0.019538	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23344	 83084	 0.01561	 0.012353	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23345	 23346	 0.001132	 0.003039	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23345	 83083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23345	 83083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23346	 23347	 0.000956	 0.002565	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23346	 83084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23346	 83084	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23347	 23348	 0.001969	 0.005204	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81960	 23348	 0.000711	 0.001983	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23348	 83085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23348	 83085	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83084	 23349	 0.030998	 0.031309	 0.00041	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81994	 23350	 0.075001	 0.054219	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23351	 23362	 0.074696	 0.13343	 0.00197	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23352	 23358	 0.057435	 0.14765	 0.00229	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23352	 23364	 0.14912	 0.31352	 0.00571	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81994	 23352	 0.07913	 0.12632	 0.00291	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23353	 23354	 0.027459	 0.04586	 0.00078	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23353	 23356	 0.023959	 0.061589	 0.00095	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23353	 23365	 0.047701	 0.13682	 0.0021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81961	 23353	 0.038282	 0.14894	 0.00249	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82744	 23353	 0.54518	 0.60051	 0.00802	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23354	 23355	 0.03819	 0.038573	 0.00051	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23355	 23358	 0.060815	 0.043079	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23356	 23357	 0.055316	 0.035812	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23356	 23359	 0.047843	 0.052111	 0.00071	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23357	 23358	 0.023893	 0.023378	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23357	 23359	 0.05892	 0.046628	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23358	 23360	 0.1342	 0.1052	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23359	 23361	 0.13326	 0.20417	 0.00287	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23362	 23363	 0.10715	 0.083991	 0.00108	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23362	 23364	 0.096882	 0.20764	 0.00364	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81994	 23362	 0.094285	 0.21893	 0.00326	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81994	 23365	 0.010275	 0.023308	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83083	 23365	 0.013347	 0.026425	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81960	 23366	 0.021488	 0.083622	 0.02234	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23367	 23368	 0.004839	 0.03955	 0.01073	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23368	 23370	 0.003962	 0.03511	 0.00935	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23369	 83086	 0.017245	 0.035439	 0.00068	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23369	 83088	 0.18497	 0.1464	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23370	 83086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23370	 83086	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23370	 83087	 0.000324	 0.004331	 0.00118	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23371	 83087	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23371	 83087	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81967	 23372	 0.007783	 0.0267	 0.0064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23372	 83088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23372	 83088	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83088	 23373	 0.021275	 0.1308	 0.00236	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81938	 23374	 0.10383	 0.082175	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23375	 23376	 0.11825	 0.093582	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23376	 83090	 0.087553	 0.096301	 0.00129	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23377	 23385	 0.16661	 0.13061	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23378	 23379	 0.034305	 0.049988	 0.00113	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23379	 23380	 0.016824	 0.036052	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23380	 23385	 0.02469	 0.018165	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23380	 83089	 0.028331	 0.065774	 0.00098	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23381	 23383	 0.004226	 0.045344	 0.0118	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23381	 23514	 0.003446	 0.052667	 0.01697	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23381	 83089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23381	 83089	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23382	 23384	 0.040014	 0.17632	 0.00306	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23382	 23458	 0.047033	 0.10757	 0.00263	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83089	 23382	 0.026108	 0.10448	 0.00221	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23383	 83090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23383	 83090	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23384	 23457	 0.01814	 0.10312	 0.00187	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83090	 23384	 0.022674	 0.086875	 0.00246	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82812	 23386	 0.10397	 0.24139	 0.0046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23387	 83091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23387	 83091	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23388	 23389	 0.026454	 0.19542	 0.00408	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82813	 23388	 0.1005	 0.34345	 0.00747	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83091	 23388	 0.10283	 0.2204	 0.00386	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23389	 23390	 0.017531	 0.14585	 0.00276	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83091	 23390	 0.049984	 0.41605	 0.00788	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23390	 83092	 0.01642	 0.063879	 0.00107	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23390	 83092	 0.01642	 0.063879	 0.00107	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23391	 83092	 0.006727	 0.013319	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23392	 83092	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23392	 83092	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23393	 23395	 0.001834	 0.00476	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23393	 23405	 0.007433	 0.019644	 0.0046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81930	 23393	 0.002753	 0.00997	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23393	 83093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23393	 83093	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23394	 23400	 0.001633	 0.005603	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81930	 23394	 0.002375	 0.009335	 0.00244	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23394	 83094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23394	 83094	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23395	 23401	 0.001852	 0.004808	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83093	 23396	 0.022886	 0.030079	 0.00041	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23396	 83099	 0.014042	 0.027801	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81931	 23397	 0.035049	 0.027737	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23398	 83095	 0.000181	 0.014517	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23398	 83095	 0.000181	 0.014517	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83096	 23398	 0.000162	 0.012969	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 0	 -30.0	 30.0;
	81931	 23399	 0.066355	 0.052513	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23399	 83097	 0.027011	 0.021172	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23400	 23401	 0.002386	 0.006407	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83096	 23400	 0.003044	 0.012185	 0.00307	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23400	 83097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23400	 83097	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23401	 83098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23401	 83098	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23402	 23404	 0.004914	 0.012757	 0.0031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23402	 83099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23402	 83099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83098	 23403	 0.081522	 0.16142	 0.00237	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23404	 23411	 0.01234	 0.049391	 0.01669	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83096	 23404	 0.012886	 0.032394	 0.00839	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23405	 23408	 0.008133	 0.021114	 0.00512	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23406	 24012	 0.010979	 0.029016	 0.00679	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81930	 23406	 0.007777	 0.02019	 0.0049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23407	 23408	 0.009074	 0.023981	 0.00561	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23409	 23410	 0.053208	 0.10428	 0.00156	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82866	 23409	 0.053199	 0.13676	 0.00212	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83099	 23410	 0.054008	 0.13736	 0.00217	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23410	 83100	 0.058147	 0.11513	 0.00169	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23411	 83100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23411	 83100	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23412	 23415	 0.084372	 0.21691	 0.00336	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23412	 83496	 0.11009	 0.28004	 0.00443	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23413	 23414	 0.019382	 0.085889	 0.00258	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23413	 24861	 0.036431	 0.10449	 0.00161	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81985	 23413	 0.037795	 0.11376	 0.00222	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23414	 23415	 0.040223	 0.14084	 0.0039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81981	 23414	 0.01342	 0.073443	 0.00144	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23415	 23962	 0.03266	 0.18567	 0.00336	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23416	 23417	 0.004885	 0.01291	 0.00302	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23416	 24844	 0.003184	 0.008267	 0.00201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23417	 83101	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23417	 83101	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23418	 23427	 0.009194	 0.023112	 0.00599	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23418	 24846	 0.007001	 0.018503	 0.00433	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23418	 83102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23418	 83102	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23419	 23420	 0.095343	 0.075455	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83102	 23419	 0.053075	 0.043686	 0.00089	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23420	 23424	 0.11391	 0.090146	 0.00114	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23420	 24817	 0.085306	 0.10719	 0.00161	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23421	 24221	 0.11686	 0.091605	 0.00118	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23421	 83107	 0.28698	 0.2112	 0.00309	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23422	 24222	 0.006284	 0.016607	 0.00389	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23422	 83103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23422	 83103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23423	 23444	 0.039077	 0.092536	 0.00169	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81958	 23423	 0.19043	 0.23646	 0.00515	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83103	 23423	 0.13927	 0.11022	 0.00139	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23424	 23425	 0.081446	 0.05273	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23425	 23443	 0.12354	 0.090898	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23425	 83107	 0.066462	 0.086494	 0.00121	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23426	 23430	 0.070279	 0.055618	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23427	 23428	 0.003599	 0.009046	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23427	 83104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23427	 83104	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23428	 83105	 0.00255	 0.008886	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23429	 23438	 0.024004	 0.031548	 0.00043	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23429	 83106	 0.071647	 0.06719	 0.00104	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23430	 23431	 0.008837	 0.011246	 0.00016	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23430	 23436	 0.032473	 0.021023	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23431	 83106	 0.009839	 0.022502	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23432	 24828	 0.000973	 0.010619	 0.10427	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23432	 83105	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23433	 23434	 0.031949	 0.025284	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23433	 23440	 0.045274	 0.029311	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83106	 23433	 0.009568	 0.027442	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23434	 23435	 0.017352	 0.011234	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23435	 23436	 0.021714	 0.015975	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23435	 23437	 0.013558	 0.014913	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23436	 23437	 0.006277	 0.010019	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23437	 23438	 0.02186	 0.014152	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23437	 83107	 0.010965	 0.031115	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23438	 83107	 0.009476	 0.02244	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81957	 23439	 0.012051	 0.032353	 0.00733	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23439	 83107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23439	 83107	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23439	 83109	 0.014318	 0.035994	 0.00933	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23440	 23441	 0.027616	 0.054678	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23441	 23442	 0.077037	 0.056679	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81958	 23441	 0.018221	 0.048293	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23443	 23444	 0.10946	 0.11056	 0.00146	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23443	 23447	 0.10925	 0.086465	 0.00109	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23445	 26773	 0.028398	 0.06063	 0.00137	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23446	 23452	 0.062254	 0.049267	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23447	 23452	 0.048611	 0.040011	 0.00081	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23447	 83110	 0.021987	 0.05652	 0.00087	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23448	 84212	 0.037975	 0.04942	 0.00069	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23449	 26735	 0.003489	 0.009221	 0.00216	 144.0	 182.0	 184.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23449	 83108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23449	 83108	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23449	 83109	 0.002674	 0.011042	 0.00261	 159.0	 166.9	 174.9	 0.0	 0.0	 0	 -30.0	 30.0;
	23450	 83109	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23451	 26731	 0.006981	 0.019466	 0.00409	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81957	 23451	 0.001576	 0.004394	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83109	 23451	 0.003612	 0.009696	 0.0022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23452	 23453	 0.040023	 0.031673	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83108	 23452	 0.018523	 0.036302	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23453	 26738	 0.025205	 0.019947	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23453	 84209	 0.03473	 0.027485	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23454	 23455	 0.038376	 0.098651	 0.00153	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23455	 23456	 0.032655	 0.09366	 0.00144	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23455	 23457	 0.060458	 0.17158	 0.0027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81947	 23455	 0.10645	 0.27078	 0.00428	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23456	 23457	 0.024913	 0.088999	 0.00177	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23456	 23460	 0.045415	 0.13026	 0.002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23456	 23461	 0.045251	 0.11463	 0.00227	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23458	 23459	 0.038236	 0.097241	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23459	 23460	 0.06081	 0.15633	 0.00242	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23459	 83132	 0.066963	 0.4119	 0.00743	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23461	 23462	 0.047532	 0.10782	 0.00215	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23461	 83112	 0.048455	 0.1125	 0.00167	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23462	 83111	 0.034533	 0.070671	 0.00174	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23463	 23464	 0.004193	 0.039473	 0.01196	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81946	 23463	 0.001517	 0.019082	 0.00591	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23463	 83111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23463	 83111	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23464	 23465	 0.005347	 0.02263	 0.00509	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23464	 23466	 0.004958	 0.026695	 0.00733	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23464	 83112	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23464	 83112	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23465	 23466	 0.002795	 0.012455	 0.00338	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23465	 83113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23465	 83113	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23465	 83116	 0.013994	 0.15851	 0.06117	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23466	 83114	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23466	 83114	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23467	 83115	 0.13979	 0.27683	 0.00406	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23468	 23950	 0.049292	 0.13037	 0.03054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23468	 83115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23468	 83115	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23469	 23470	 0.072957	 0.16937	 0.00323	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23469	 23886	 0.073927	 0.18803	 0.00297	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23470	 23471	 0.12902	 0.097756	 0.00135	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23470	 83234	 0.075561	 0.19977	 0.00363	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23471	 23885	 0.052803	 0.13686	 0.00259	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23471	 83234	 0.048876	 0.11658	 0.00261	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23472	 23474	 0.027219	 0.017622	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23472	 23489	 0.009836	 0.017299	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23472	 83123	 0.056704	 0.044875	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23473	 23474	 0.008031	 0.012882	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23473	 23476	 0.006315	 0.012503	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23473	 83121	 0.060038	 0.047514	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23473	 83130	 0.007275	 0.010601	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23474	 23489	 0.009411	 0.018024	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23475	 23497	 0.000178	 0.003153	 0.03303	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23475	 83116	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23476	 83120	 0.005847	 0.015031	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23477	 23478	 0.010808	 0.018207	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23477	 83119	 0.005151	 0.013242	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23478	 23491	 0.007213	 0.01428	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23478	 23513	 0.02107	 0.034997	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23478	 83118	 0.015583	 0.044693	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23478	 83121	 0.05093	 0.036077	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23479	 23480	 0.001714	 0.005972	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23479	 23492	 0.002243	 0.006498	 0.00157	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23480	 23485	 0.003775	 0.015112	 0.00381	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23480	 23495	 0.008888	 0.023489	 0.0055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23480	 83118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23480	 83118	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23481	 23482	 0.000875	 0.003438	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23481	 83119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23481	 83119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83116	 23482	 0.000723	 0.006079	 0.0018	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23482	 83120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23482	 83120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23483	 23513	 0.015728	 0.012447	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23484	 23512	 0.002936	 0.008187	 0.00172	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23484	 83121	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23484	 83121	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23485	 23506	 0.005278	 0.017784	 0.00442	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23485	 83122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23485	 83122	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83121	 23486	 0.015871	 0.028637	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83122	 23486	 0.018729	 0.034824	 0.00082	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23487	 23505	 0.003313	 0.01171	 0.00264	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83116	 23487	 0.003789	 0.019641	 0.0048	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23487	 83123	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23487	 83123	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23487	 83126	 0.007368	 0.039021	 0.00989	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23488	 23503	 0.058655	 0.064514	 0.00086	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 23488	 0.015523	 0.051783	 0.00082	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 23489	 0.004746	 0.019398	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 23490	 0.044759	 0.032931	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83119	 23491	 0.006594	 0.013493	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23492	 83124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23492	 83124	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23492	 83126	 0.006616	 0.019162	 0.00462	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83124	 23493	 0.006839	 0.022816	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83124	 23494	 0.016133	 0.016295	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23494	 83125	 0.051343	 0.03324	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23495	 83125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23495	 83125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23495	 83126	 0.001966	 0.00787	 0.00198	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 23496	 0.00646	 0.025131	 0.00042	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83125	 23496	 0.019499	 0.055926	 0.00086	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23497	 23902	 0.000192	 0.002714	 0.02588	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23497	 83126	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23497	 83126	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83117	 23498	 0.020241	 0.032309	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23499	 23500	 0.043501	 0.10301	 0.00188	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23499	 23900	 0.02255	 0.052353	 0.00078	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 23499	 0.012723	 0.087337	 0.00159	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23499	 83237	 0.025081	 0.083668	 0.00133	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23501	 83127	 0.028558	 0.1111	 0.00185	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23501	 83133	 0.0378	 0.086451	 0.00211	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83116	 23502	 0.002045	 0.029167	 0.00974	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23502	 83127	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23502	 83127	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83127	 23504	 0.05431	 0.12421	 0.00303	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23504	 83129	 0.023953	 0.095034	 0.00271	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23504	 83132	 0.048349	 0.1613	 0.00256	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23505	 23507	 0.00433	 0.013032	 0.00408	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23506	 23508	 0.003387	 0.013561	 0.00342	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23507	 23511	 0.004751	 0.019021	 0.00479	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81937	 23508	 0.016172	 0.13882	 0.03956	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23508	 83128	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23508	 83128	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23509	 23510	 0.01339	 0.044187	 0.00072	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83122	 23509	 0.165	 0.17974	 0.00245	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83128	 23509	 0.052701	 0.051565	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23510	 83225	 0.031419	 0.12223	 0.00204	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23511	 23862	 0.006828	 0.042375	 0.01027	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23511	 83129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23511	 83129	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23512	 83130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23512	 83130	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83117	 23513	 0.005506	 0.0313	 0.00057	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83119	 23513	 0.022035	 0.017438	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83120	 23513	 0.004692	 0.011883	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23514	 23864	 0.005842	 0.05412	 0.02712	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23514	 83131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23514	 83131	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23515	 23518	 0.051655	 0.13279	 0.00206	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23515	 23865	 0.074223	 0.21065	 0.00331	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23516	 83132	 0.076372	 0.05619	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23517	 23524	 0.006212	 0.037009	 0.00974	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81937	 23517	 0.009146	 0.1399	 0.04513	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23517	 83132	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23517	 83132	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23518	 23521	 0.053058	 0.13494	 0.00213	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83131	 23519	 0.045926	 0.17868	 0.00298	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83132	 23519	 0.090761	 0.21074	 0.00313	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23521	 23523	 0.034877	 0.096481	 0.00224	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23522	 23523	 0.1412	 0.11175	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82958	 23523	 0.028676	 0.11156	 0.00186	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23523	 83133	 0.052487	 0.099202	 0.0016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23524	 23896	 0.025226	 0.06668	 0.01561	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23524	 83133	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23524	 83133	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23525	 23526	 0.070213	 0.053859	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23526	 83135	 0.039531	 0.059956	 0.00086	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23527	 23619	 0.000495	 0.006781	 0.0691	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23527	 83134	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23528	 23533	 0.004369	 0.015286	 0.00507	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23528	 83136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23528	 83136	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23529	 23564	 0.001735	 0.010778	 0.00304	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83134	 23529	 0.000912	 0.008081	 0.00215	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23529	 83137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23529	 83137	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23530	 23531	 0.003809	 0.019383	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83136	 23530	 0.005639	 0.027068	 0.00081	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83137	 23530	 0.056236	 0.036408	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23531	 23555	 0.04234	 0.033507	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23531	 23560	 0.008081	 0.021419	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23532	 23535	 0.003517	 0.010186	 0.00246	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23532	 83138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23532	 83138	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23533	 23547	 0.004674	 0.015591	 0.00395	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23533	 83139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23533	 83139	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23534	 23542	 0.023241	 0.055034	 0.00101	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83138	 23534	 0.010174	 0.057832	 0.00105	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83139	 23534	 0.053581	 0.054118	 0.00072	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23535	 23537	 0.004544	 0.012008	 0.00281	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23536	 83140	 0.11017	 0.081062	 0.00119	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23537	 23543	 0.002192	 0.01843	 0.00546	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82846	 23538	 0.012737	 0.067094	 0.0012	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23538	 83140	 0.011112	 0.029451	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23539	 23541	 0.005474	 0.020806	 0.00582	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23539	 83140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23539	 83140	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23540	 23567	 0.042748	 0.097767	 0.00239	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83140	 23540	 0.01595	 0.040562	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23541	 23576	 0.004002	 0.01373	 0.00329	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23541	 23577	 0.004812	 0.012717	 0.00298	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23542	 83141	 0.031551	 0.024969	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23542	 83142	 0.048779	 0.053652	 0.00072	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23543	 23544	 0.001669	 0.005724	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23543	 23549	 0.004877	 0.019528	 0.00492	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23543	 83141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23543	 83141	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23544	 23545	 0.002502	 0.007598	 0.00166	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23545	 23566	 0.005687	 0.014295	 0.0037	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83139	 23546	 0.070274	 0.050802	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23547	 23549	 0.003949	 0.013819	 0.00458	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23547	 83142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23547	 83142	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23548	 23551	 0.036897	 0.029199	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23548	 83143	 0.035916	 0.028423	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23549	 23642	 0.002669	 0.009155	 0.00219	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23549	 23643	 0.002193	 0.007389	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23549	 83143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23549	 83143	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23550	 23551	 0.026231	 0.027948	 0.0004	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23550	 83144	 0.024811	 0.025059	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83142	 23551	 0.009542	 0.042519	 0.00072	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23551	 83144	 0.022015	 0.039722	 0.00057	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23552	 23557	 0.049352	 0.039057	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23552	 23561	 0.014667	 0.029039	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23552	 83144	 0.01593	 0.025554	 0.00047	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23553	 23641	 0.00316	 0.008484	 0.00192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23553	 83144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23553	 83144	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23554	 83146	 0.028988	 0.022236	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23554	 83148	 0.0149	 0.016389	 0.00022	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23555	 83148	 0.035509	 0.028101	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23556	 23560	 0.013213	 0.033965	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23556	 23561	 0.010486	 0.020761	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23556	 83169	 0.10907	 0.070615	 0.00134	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23557	 23562	 0.022678	 0.017947	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23557	 83145	 0.020794	 0.038086	 0.00066	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23558	 23559	 0.003442	 0.011598	 0.00288	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23558	 23563	 0.002842	 0.007305	 0.00181	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23558	 83145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23558	 83145	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23558	 83168	 0.004639	 0.011662	 0.00302	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23559	 23564	 0.000632	 0.003361	 0.00078	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23559	 23812	 0.005285	 0.013967	 0.00327	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23559	 83146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23559	 83146	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23562	 83170	 0.041694	 0.030141	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23563	 23814	 0.002258	 0.007745	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83134	 23563	 0.005261	 0.027882	 0.00931	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23563	 83147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23563	 83147	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23564	 83148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23564	 83148	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23565	 23566	 0.002836	 0.009729	 0.00233	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23565	 23569	 0.002594	 0.008898	 0.00213	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23565	 83149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23565	 83149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23566	 83150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23566	 83150	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83150	 23567	 0.008674	 0.023994	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23567	 83152	 0.025642	 0.05077	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23568	 23570	 0.036588	 0.023687	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23568	 23598	 0.010756	 0.02305	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83003	 23568	 0.048063	 0.15262	 0.00268	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23569	 23572	 0.002442	 0.006454	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23569	 23644	 0.00421	 0.011127	 0.0026	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23570	 23587	 0.019304	 0.044816	 0.00067	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83149	 23570	 0.087005	 0.068856	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83150	 23570	 0.030809	 0.051382	 0.00075	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23571	 23587	 0.035007	 0.022664	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23571	 83151	 0.02864	 0.022449	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23572	 23589	 0.004703	 0.012209	 0.00296	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23572	 83151	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23572	 83151	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23573	 23575	 0.001448	 0.00406	 0.00105	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23573	 23576	 0.002054	 0.00642	 0.00186	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23574	 23575	 0.003155	 0.00847	 0.00192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23574	 23578	 0.001541	 0.009249	 0.0028	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23574	 23579	 0.005829	 0.019013	 0.00505	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23574	 23582	 0.003402	 0.011669	 0.0028	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23575	 83152	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23575	 83152	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23577	 23578	 0.003379	 0.009072	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23579	 23582	 0.00335	 0.00842	 0.00218	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23579	 23595	 0.002201	 0.007703	 0.00255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23579	 83153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23579	 83153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23579	 83156	 0.007177	 0.019268	 0.00437	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23580	 83154	 0.006629	 0.013125	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23580	 83160	 0.038033	 0.058263	 0.00082	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83153	 23581	 0.054442	 0.054989	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23582	 83154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23582	 83154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23583	 83157	 0.012483	 0.035803	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23583	 83160	 0.009244	 0.021461	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23584	 23595	 0.001248	 0.004369	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23584	 83155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23584	 83155	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23585	 23601	 0.004779	 0.021297	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83155	 23585	 0.003711	 0.016353	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23586	 83156	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23586	 83412	 0.000645	 0.008017	 0.08054	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83151	 23587	 0.03923	 0.028359	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23587	 83158	 0.016101	 0.028759	 0.00042	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23588	 23591	 0.032131	 0.025428	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23588	 23596	 0.046879	 0.037099	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23588	 83159	 0.046644	 0.036914	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23589	 23590	 0.002862	 0.007563	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23589	 83158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23589	 83158	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83156	 23590	 0.003563	 0.022113	 0.00536	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23590	 83159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23590	 83159	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23591	 23597	 0.030965	 0.020047	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23592	 23594	 0.005665	 0.013414	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83157	 23592	 0.025088	 0.064491	 0.001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83159	 23592	 0.023648	 0.023717	 0.00038	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23593	 23606	 0.012774	 0.025291	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81948	 23593	 0.002864	 0.012298	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23594	 23606	 0.012487	 0.02899	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23595	 83160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23595	 83160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23596	 23597	 0.069779	 0.055223	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23596	 23598	 0.012972	 0.027263	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83155	 23597	 0.003639	 0.016216	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23597	 83161	 0.008516	 0.038105	 0.00078	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23599	 23606	 0.010841	 0.025168	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23599	 83162	 0.018286	 0.022698	 0.00049	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23600	 23604	 0.003491	 0.009736	 0.00204	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23600	 83161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23600	 83161	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83161	 23601	 0.005674	 0.020271	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23602	 23605	 0.02664	 0.026907	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23602	 23609	 0.019533	 0.015458	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23602	 83162	 0.010817	 0.021417	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23603	 23605	 0.026057	 0.020621	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23603	 83197	 0.023468	 0.015193	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23604	 83162	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23604	 83162	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23604	 83413	 0.013662	 0.037197	 0.0082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23605	 24614	 0.01611	 0.014436	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23606	 23745	 0.029216	 0.018915	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23607	 23608	 0.007782	 0.029938	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83157	 23607	 0.006499	 0.032873	 0.00057	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23608	 23610	 0.01574	 0.030847	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23608	 24613	 0.021967	 0.039483	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23609	 23610	 0.018729	 0.013539	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23609	 24613	 0.028917	 0.022884	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23610	 24613	 0.018887	 0.014488	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23611	 23616	 0.021856	 0.040031	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23611	 24617	 0.031061	 0.072113	 0.00107	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23611	 83164	 0.029066	 0.053238	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23612	 83163	 0.033477	 0.02463	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23613	 23614	 0.002684	 0.009487	 0.00214	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23613	 23615	 0.004343	 0.011275	 0.00274	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23613	 83163	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23613	 83163	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83156	 23614	 0.002037	 0.01097	 0.00301	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23614	 83164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23614	 83164	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23615	 83165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23615	 83165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83163	 23616	 0.048139	 0.038096	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83165	 23616	 0.005811	 0.010804	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23617	 23619	 0.000111	 0.001773	 0.01775	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23617	 23768	 0.000864	 0.009626	 0.09079	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83074	 23617	 0.000714	 0.007837	 0.07613	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23617	 83166	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83167	 23618	 0.014656	 0.029018	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23618	 83169	 0.010251	 0.020296	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23619	 83168	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83168	 23620	 0.002289	 0.009162	 0.00231	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23620	 83170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23620	 83170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23621	 83171	 0.010064	 0.017976	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23621	 83175	 0.019755	 0.015633	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23622	 83171	 0.013607	 0.012277	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23623	 23660	 0.001298	 0.004701	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23623	 23838	 0.002993	 0.007911	 0.00185	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83166	 23623	 0.001828	 0.009338	 0.00235	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23623	 83171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23623	 83171	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23624	 23629	 0.00242	 0.008155	 0.00203	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23624	 23654	 0.003182	 0.008411	 0.00197	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23624	 83172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23624	 83172	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83170	 23625	 0.006911	 0.017574	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23625	 83173	 0.019634	 0.01616	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23626	 23628	 0.006946	 0.009039	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83170	 23626	 0.013518	 0.026492	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23627	 23628	 0.016644	 0.013171	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23627	 83177	 0.044653	 0.035338	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23628	 83173	 0.026816	 0.021221	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23629	 23631	 0.001555	 0.00542	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83168	 23629	 0.001456	 0.011351	 0.00339	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23629	 83173	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23629	 83173	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83167	 23630	 0.012174	 0.021409	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83173	 23630	 0.029872	 0.021595	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23631	 23635	 0.000866	 0.003136	 0.00067	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83172	 23632	 0.018504	 0.013107	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23632	 83174	 0.032408	 0.025647	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23633	 23634	 0.016497	 0.013055	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23633	 23639	 0.011054	 0.012157	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83172	 23633	 0.00987	 0.019343	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23635	 83174	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23635	 83174	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23636	 23671	 0.00408	 0.013997	 0.00335	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83166	 23636	 0.002374	 0.01069	 0.00284	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23636	 83175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23636	 83175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83174	 23637	 0.001868	 0.010619	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23637	 83176	 0.00374	 0.009912	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23638	 23639	 0.019346	 0.014234	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23638	 83176	 0.024432	 0.017975	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23639	 23679	 0.017321	 0.019051	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23639	 83182	 0.009903	 0.019607	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23640	 23661	 0.001286	 0.003399	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23640	 83176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23640	 83176	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23641	 83177	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23641	 83177	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23642	 23658	 0.005215	 0.013783	 0.00323	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23643	 23644	 0.001484	 0.005001	 0.00124	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23643	 83178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23643	 83178	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23644	 23645	 0.00214	 0.0062	 0.0015	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23644	 83179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23644	 83179	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23645	 23658	 0.004053	 0.010522	 0.00255	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23645	 83180	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23645	 83180	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83144	 23646	 0.030664	 0.046973	 0.00066	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83172	 23646	 0.055897	 0.044236	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83177	 23646	 0.011395	 0.018679	 0.00033	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23646	 83183	 0.03099	 0.024525	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23647	 83181	 0.035249	 0.02282	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23647	 83183	 0.024595	 0.019464	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23648	 23659	 0.022881	 0.018108	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23648	 83183	 0.01425	 0.015674	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23649	 23658	 0.002487	 0.006573	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23649	 83181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23649	 83181	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23650	 23651	 0.021617	 0.017107	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23650	 23657	 0.0349	 0.027619	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83180	 23650	 0.021001	 0.022427	 0.00047	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83181	 23651	 0.028172	 0.018239	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23652	 23653	 0.006835	 0.013532	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23652	 23683	 0.012587	 0.019639	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83181	 23653	 0.005176	 0.017082	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23654	 23658	 0.003086	 0.007933	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23654	 83182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23654	 83182	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23655	 23656	 0.02758	 0.021827	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23656	 23680	 0.037944	 0.029742	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83181	 23656	 0.040569	 0.033392	 0.00068	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83179	 23657	 0.011336	 0.022216	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83168	 23658	 0.007454	 0.024868	 0.00631	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23658	 83183	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23658	 83183	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83182	 23659	 0.016534	 0.016582	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83183	 23659	 0.019959	 0.020159	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23660	 23664	 0.001201	 0.004186	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23661	 83184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23661	 83184	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23662	 23666	 0.007351	 0.021084	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23662	 23684	 0.019474	 0.029832	 0.00042	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83184	 23662	 0.008023	 0.016419	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83175	 23663	 0.022977	 0.038165	 0.00081	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23663	 83187	 0.033857	 0.026539	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23664	 23665	 0.002138	 0.007556	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23665	 23847	 0.001724	 0.004809	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23665	 83185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23665	 83185	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23666	 23668	 0.016009	 0.031696	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23667	 23668	 0.021923	 0.01735	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23667	 23691	 0.025377	 0.020083	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23668	 23669	 0.023135	 0.018308	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23668	 23704	 0.018186	 0.035642	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23669	 83186	 0.010436	 0.015207	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23670	 23671	 0.002708	 0.009289	 0.00223	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23670	 23673	 0.001319	 0.004443	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23670	 83186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23670	 83186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23671	 83187	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23671	 83187	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23672	 23676	 0.023689	 0.015336	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83186	 23672	 0.030353	 0.021942	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23673	 23702	 0.001435	 0.004156	 0.001	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23674	 23675	 0.005249	 0.012429	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23674	 23676	 0.012372	 0.017242	 0.00029	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23674	 23678	 0.002456	 0.011991	 0.00025	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23674	 83224	 0.010068	 0.019933	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23675	 83223	 0.003704	 0.007579	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83185	 23676	 0.007354	 0.024534	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23677	 23678	 0.011729	 0.009282	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23678	 23703	 0.004721	 0.011179	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23679	 23681	 0.018861	 0.01429	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23680	 23685	 0.018929	 0.01498	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23681	 23684	 0.00474	 0.012284	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83182	 23681	 0.009599	 0.02753	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23682	 23683	 0.018115	 0.021686	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23682	 23687	 0.030805	 0.023339	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23682	 23689	 0.048367	 0.038277	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23684	 23687	 0.012805	 0.022519	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83158	 23685	 0.018315	 0.035075	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83158	 23686	 0.008702	 0.015939	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23686	 83188	 0.036819	 0.029138	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23687	 23688	 0.011827	 0.017937	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23688	 23700	 0.037226	 0.02946	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23689	 23699	 0.018683	 0.035309	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23689	 83190	 0.005827	 0.015403	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23690	 23691	 0.024465	 0.019177	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23690	 23699	 0.009692	 0.016699	 0.00027	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23692	 23700	 0.022151	 0.014341	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23693	 23695	 0.002048	 0.007237	 0.00163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23693	 23696	 0.000912	 0.00365	 0.00092	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23693	 83188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23693	 83188	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23694	 23745	 0.00583	 0.013904	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81948	 23694	 0.005376	 0.01881	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23695	 83189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23695	 83189	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23696	 23697	 0.001328	 0.004429	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23697	 83190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23697	 83190	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23698	 23734	 0.005848	 0.016772	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83189	 23698	 0.005794	 0.015316	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83190	 23698	 0.018655	 0.018659	 0.00025	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23699	 23700	 0.022779	 0.018027	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23699	 23732	 0.01582	 0.031321	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23699	 23733	 0.00885	 0.016209	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23699	 23751	 0.09472	 0.072658	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83190	 23699	 0.003742	 0.019458	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23701	 23703	 0.052897	 0.041862	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23701	 23711	 0.040887	 0.031363	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23702	 23709	 0.001627	 0.004223	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23703	 23794	 0.019191	 0.012424	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23704	 23712	 0.026411	 0.020702	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23705	 23715	 0.021533	 0.021538	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23705	 23716	 0.021369	 0.016911	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23706	 23707	 0.018648	 0.014758	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23706	 23711	 0.034606	 0.027387	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23706	 23712	 0.021539	 0.013945	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23706	 23713	 0.017301	 0.013692	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23706	 23739	 0.013875	 0.02747	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23706	 23743	 0.026746	 0.048074	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23707	 23738	 0.018386	 0.015133	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23708	 23795	 0.024951	 0.018357	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23708	 83191	 0.023136	 0.01831	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23709	 23719	 0.003604	 0.009356	 0.00227	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23709	 83191	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23709	 83191	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23710	 23715	 0.017395	 0.012574	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23711	 23714	 0.02757	 0.021819	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23711	 23715	 0.026666	 0.017264	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23713	 23714	 0.033657	 0.026635	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23713	 23720	 0.023414	 0.015728	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23715	 83192	 0.007504	 0.017422	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23716	 23757	 0.02093	 0.016563	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23717	 23723	 0.022047	 0.016911	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23717	 23759	 0.010364	 0.017459	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23718	 23723	 0.023172	 0.016414	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23719	 23728	 0.005096	 0.011829	 0.0036	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23719	 83192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23719	 83192	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23720	 83194	 0.008762	 0.017173	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23721	 23728	 0.00248	 0.006374	 0.00158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23721	 83193	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23721	 83193	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23722	 23727	 0.022733	 0.017819	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83192	 23722	 0.025663	 0.020116	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83193	 23722	 0.030777	 0.024357	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23723	 23725	 0.027955	 0.022123	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23723	 23726	 0.029565	 0.023397	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23724	 23725	 0.013972	 0.010952	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23725	 23726	 0.021703	 0.017176	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23725	 24480	 0.021091	 0.016691	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23725	 83198	 0.01381	 0.027343	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23726	 24487	 0.006427	 0.010258	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23727	 24488	 0.017462	 0.013819	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23728	 24568	 0.001035	 0.003487	 0.00087	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23728	 83194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23728	 83194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23729	 23730	 0.008667	 0.013145	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23729	 23741	 0.03578	 0.028315	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23730	 23750	 0.008829	 0.016416	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23730	 83195	 0.030339	 0.02401	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23731	 23749	 0.00891	 0.008999	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23731	 23753	 0.009337	 0.009365	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23731	 83197	 0.032069	 0.025379	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23732	 23737	 0.029337	 0.023217	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23733	 23736	 0.013782	 0.018114	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23734	 23735	 0.007373	 0.017118	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23735	 23741	 0.013822	 0.022063	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23736	 23737	 0.023945	 0.018769	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23737	 23738	 0.008781	 0.017386	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23737	 23740	 0.035144	 0.027812	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23737	 23741	 0.047937	 0.037576	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23739	 83196	 0.00787	 0.018268	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23740	 83196	 0.024061	 0.026207	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23741	 83197	 0.041424	 0.054444	 0.00075	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23742	 23744	 0.002072	 0.006206	 0.0014	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23742	 83195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23742	 83195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23742	 83413	 0.003673	 0.020157	 0.00533	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23743	 24582	 0.019497	 0.021444	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83195	 23743	 0.00997	 0.01954	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23743	 83196	 0.021145	 0.016575	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23744	 83196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23744	 83196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23745	 23747	 0.008148	 0.021116	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23746	 23747	 0.008878	 0.01417	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83189	 23746	 0.006466	 0.013233	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23747	 23751	 0.007043	 0.020201	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23747	 23752	 0.01213	 0.021886	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23748	 83197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23748	 83197	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23748	 83413	 0.007724	 0.025768	 0.00654	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23749	 23750	 0.018975	 0.015016	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23750	 24585	 0.008771	 0.016066	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23750	 83404	 0.018592	 0.029676	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83197	 23751	 0.058031	 0.038981	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23752	 23753	 0.011656	 0.017283	 0.00026	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23754	 23758	 0.005654	 0.011884	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23754	 23796	 0.004214	 0.010832	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23755	 23756	 0.002531	 0.008442	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23755	 23795	 0.001825	 0.008133	 0.00014	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23756	 23757	 0.002889	 0.007893	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23757	 23759	 0.006304	 0.012482	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23758	 23759	 0.011707	 0.021124	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23759	 23766	 0.011501	 0.008147	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23759	 23810	 0.015962	 0.012632	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23759	 83198	 0.050157	 0.036902	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23760	 23761	 0.01148	 0.008299	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23760	 23762	 0.016592	 0.013131	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23760	 23809	 0.005712	 0.01326	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23760	 83198	 0.031919	 0.023074	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23763	 83198	 0.016925	 0.020261	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23764	 24474	 0.018291	 0.014337	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23764	 83198	 0.007146	 0.011464	 0.00021	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23765	 83198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23765	 83198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23765	 83400	 0.009558	 0.028768	 0.009	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23767	 23771	 0.004058	 0.010319	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23767	 24472	 0.017656	 0.01299	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23767	 24473	 0.004961	 0.009723	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83198	 23767	 0.017758	 0.014054	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23768	 23774	 6.1e-05	 0.000706	 0.00619	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23768	 83199	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83200	 23769	 0.014614	 0.011565	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23770	 23772	 0.015233	 0.015386	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23770	 23808	 0.008566	 0.007676	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23771	 23772	 0.003959	 0.011234	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23772	 83202	 0.002555	 0.016632	 0.00034	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23773	 83202	 0.011467	 0.008988	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23774	 24396	 0.000485	 0.005324	 0.05172	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23774	 83201	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23774	 83412	 0.00085	 0.009812	 0.08603	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23775	 23776	 0.011952	 0.009168	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23776	 23777	 0.004919	 0.012209	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83202	 23777	 0.006231	 0.017238	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23777	 83203	 0.004611	 0.010593	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83201	 23778	 0.000341	 0.002434	 0.00075	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23778	 83203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23778	 83203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23779	 23780	 0.003306	 0.007498	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23779	 83222	 0.003065	 0.01095	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23780	 23781	 0.003318	 0.014786	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23780	 23782	 0.002376	 0.006297	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23780	 23790	 0.00556	 0.015946	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23781	 23791	 0.016328	 0.012922	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23781	 83221	 0.002672	 0.017392	 0.00035	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23782	 23792	 0.003474	 0.008835	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23783	 23784	 0.00141	 0.004836	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23783	 23785	 0.001635	 0.004244	 0.00103	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23783	 83204	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23783	 83204	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23784	 23854	 0.001788	 0.008202	 0.0021	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23784	 24451	 0.013202	 0.03824	 0.00922	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23784	 83205	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23784	 83205	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23785	 83206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23785	 83206	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23786	 23788	 0.021383	 0.020052	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83066	 23786	 0.0061	 0.01493	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23787	 23788	 0.02208	 0.017307	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23787	 23803	 0.01588	 0.010281	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83206	 23787	 0.010095	 0.019784	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23788	 23803	 0.01625	 0.01286	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23788	 23807	 0.012778	 0.010112	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83200	 23788	 0.029269	 0.018949	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23788	 83207	 0.013176	 0.013308	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83199	 23789	 0.00276	 0.007409	 0.00168	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23789	 83207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23789	 83207	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23790	 23793	 0.004472	 0.011589	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23790	 23795	 0.014366	 0.026313	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23790	 83224	 0.002116	 0.014354	 0.00027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23792	 23797	 0.006581	 0.013029	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23793	 23795	 0.008587	 0.013774	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23794	 23795	 0.016591	 0.012206	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23795	 23796	 0.02478	 0.018232	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83200	 23795	 0.041968	 0.083094	 0.00122	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23796	 23797	 0.005536	 0.011328	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23797	 23798	 0.006642	 0.015417	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23797	 23800	 0.00821	 0.01281	 0.00021	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23798	 23799	 0.006686	 0.013238	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83205	 23798	 0.00222	 0.012222	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23799	 23802	 0.012419	 0.009828	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23800	 23801	 0.012328	 0.008733	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23801	 23805	 0.018589	 0.014711	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23802	 23806	 0.023814	 0.018667	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23804	 23806	 0.011912	 0.009138	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23805	 23806	 0.004665	 0.013379	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23805	 23809	 0.004685	 0.011914	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23806	 23808	 0.008755	 0.010868	 0.00024	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83200	 23806	 0.002165	 0.012969	 0.00031	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83200	 23807	 0.018133	 0.012845	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23811	 23812	 0.004969	 0.013528	 0.00298	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23811	 83208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23811	 83208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23813	 23820	 0.009518	 0.025226	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83208	 23813	 0.009987	 0.038854	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23813	 83209	 0.072044	 0.052081	 0.00079	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23814	 23815	 0.001969	 0.00696	 0.00157	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23815	 23821	 0.001352	 0.004409	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23816	 23817	 0.010471	 0.011517	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23816	 83211	 0.009427	 0.016838	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23817	 23818	 0.024534	 0.019416	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23817	 23820	 0.027784	 0.019681	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23818	 23819	 0.010715	 0.019138	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23818	 23820	 0.031032	 0.024558	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83169	 23818	 0.054415	 0.10774	 0.00158	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23818	 83212	 0.033939	 0.024534	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83030	 23819	 0.009171	 0.016128	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23821	 23822	 0.001237	 0.004311	 0.001	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23822	 23827	 0.001538	 0.005275	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23822	 83209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23822	 83209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23823	 23824	 0.023743	 0.018611	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83169	 23824	 0.013407	 0.034096	 0.00054	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23824	 83210	 0.013551	 0.022599	 0.00033	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23825	 23836	 0.001403	 0.005938	 0.00134	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83168	 23825	 0.002086	 0.010665	 0.00291	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23825	 83210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23825	 83210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83210	 23826	 0.01103	 0.017606	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23826	 83211	 0.016497	 0.021681	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23827	 83211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23827	 83211	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23828	 23843	 0.067717	 0.055738	 0.00113	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83211	 23828	 0.004871	 0.017042	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23828	 83212	 0.00864	 0.017107	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23829	 23833	 0.00213	 0.00563	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23829	 83212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23829	 83212	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83212	 23830	 0.02323	 0.018209	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23831	 83213	 0.023384	 0.018506	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23832	 23840	 0.016921	 0.025918	 0.00045	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23832	 83213	 0.026398	 0.020891	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23833	 83213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23833	 83213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23834	 23839	 0.024255	 0.019195	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83211	 23835	 0.013353	 0.022269	 0.00032	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23835	 83215	 0.041365	 0.02678	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23836	 23838	 0.000957	 0.003639	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23836	 83214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23836	 83214	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23837	 23838	 0.001274	 0.003366	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23837	 23844	 0.00163	 0.003783	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23838	 83215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23838	 83215	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23839	 23843	 0.037427	 0.02423	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83213	 23839	 0.044555	 0.028845	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83215	 23839	 0.016667	 0.033	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23840	 23841	 0.023269	 0.016821	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23840	 23859	 0.013867	 0.027456	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23841	 23842	 0.009785	 0.017655	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23842	 23843	 0.022382	 0.017713	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23843	 83216	 0.0366	 0.028965	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23843	 83218	 0.057374	 0.045405	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23844	 23845	 0.001759	 0.004421	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23845	 23848	 0.002485	 0.00645	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23845	 83216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23845	 83216	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83185	 23846	 0.026998	 0.021366	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23847	 23857	 0.001118	 0.003767	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23847	 83217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23847	 83217	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23848	 23849	 0.001231	 0.004015	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23848	 83218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23848	 83218	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23849	 23850	 0.00103	 0.004046	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23850	 23852	 0.001376	 0.004487	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23850	 83219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23850	 83219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23851	 23859	 0.023233	 0.015041	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83219	 23851	 0.018688	 0.020555	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23851	 83220	 0.023614	 0.015288	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23852	 23860	 0.00045	 0.00374	 0.00113	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23852	 83220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23852	 83220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23853	 23860	 0.001228	 0.004211	 0.00101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23853	 23861	 0.000564	 0.003868	 0.00113	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23854	 23856	 0.001159	 0.007343	 0.00199	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23854	 23861	 0.000636	 0.005109	 0.00144	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83075	 23854	 0.001667	 0.012615	 0.0062	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23854	 83221	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23854	 83221	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83221	 23855	 0.023582	 0.018484	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23856	 23858	 0.001476	 0.004813	 0.00128	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23856	 83222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23856	 83222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23857	 23858	 0.001412	 0.003629	 0.0009	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23857	 83223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23857	 83223	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23858	 83224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23858	 83224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83040	 23860	 0.00035	 0.003774	 0.00108	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81937	 23862	 0.009186	 0.064694	 0.0368	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23862	 83225	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23862	 83225	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23863	 23866	 0.003359	 0.023055	 0.00672	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23863	 83226	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23863	 83226	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81937	 23864	 0.004741	 0.048515	 0.02884	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23864	 83227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23864	 83227	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83225	 23865	 0.031575	 0.1407	 0.00239	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81937	 23866	 0.004514	 0.034334	 0.01079	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23867	 23868	 0.045556	 0.13067	 0.00201	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83225	 23867	 0.051728	 0.10242	 0.0015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83226	 23868	 0.029177	 0.077333	 0.00196	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23869	 23870	 0.2334	 0.23351	 0.00315	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23869	 23887	 0.066167	 0.1701	 0.00263	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23869	 23889	 0.074234	 0.16979	 0.00415	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23870	 23874	 0.073442	 0.21067	 0.00324	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23870	 23956	 0.033955	 0.093931	 0.00218	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23870	 83228	 0.027859	 0.12275	 0.00213	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23870	 83234	 0.2288	 0.52396	 0.01281	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23871	 23872	 0.14813	 0.11724	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23872	 23875	 0.15013	 0.11882	 0.0015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23872	 83228	 0.078516	 0.15037	 0.00237	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81951	 23873	 0.068282	 0.19619	 0.04838	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23873	 83228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23873	 83228	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83228	 23874	 0.036539	 0.093929	 0.00145	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23876	 83230	 0.13423	 0.18301	 0.00406	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81959	 23877	 0.005278	 0.061252	 0.5414	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23877	 83229	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83230	 23878	 0.12987	 0.27838	 0.00488	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23879	 23882	 0.049387	 0.14166	 0.00218	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23880	 24863	 0.013888	 0.046797	 0.01163	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23880	 83231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23880	 83231	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83231	 23881	 0.053314	 0.13706	 0.00212	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83231	 23882	 0.041181	 0.18352	 0.00312	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23885	 23888	 0.047712	 0.12134	 0.00192	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23886	 23887	 0.27971	 0.21461	 0.00288	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23887	 23888	 0.080555	 0.18701	 0.00356	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23888	 23889	 0.11284	 0.11086	 0.00187	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23890	 83232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23890	 83232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23892	 83233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23892	 83233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23893	 83234	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23893	 83234	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23894	 23895	 0.0869	 0.05626	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83233	 23894	 0.034076	 0.069734	 0.00172	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23896	 23897	 0.003788	 0.021531	 0.00623	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23897	 23936	 0.000468	 0.006677	 0.00223	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23897	 23941	 0.004545	 0.029717	 0.00756	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23897	 83235	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23897	 83235	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23898	 23899	 0.000943	 0.014096	 0.00417	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23898	 23936	 0.001712	 0.021539	 0.00667	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23898	 83236	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23898	 83236	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23899	 23905	 0.000563	 0.003905	 0.00229	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23899	 83237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23899	 83237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23900	 83239	 0.018153	 0.042144	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23901	 83238	 0.010677	 0.027447	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23902	 83238	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23902	 83238	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23903	 23905	 0.001553	 0.006216	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81969	 23903	 0.000417	 0.003093	 0.00158	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23903	 83240	 0.001098	 0.008025	 0.00237	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81970	 23904	 0.00755	 0.024914	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83126	 23905	 0.00128	 0.014087	 0.00837	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23905	 83239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23905	 83239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23905	 83240	 0.001733	 0.008187	 0.00262	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23906	 83240	 0.001226	 0.007606	 0.00184	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23906	 83241	 0.001974	 0.010516	 0.00295	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23907	 23910	 0.000152	 0.002817	 0.02706	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23907	 83240	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23907	 83240	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23908	 23909	 0.039317	 0.06023	 0.00085	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83236	 23908	 0.034868	 0.069037	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23909	 83242	 0.017233	 0.066027	 0.00187	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23909	 83246	 0.030948	 0.14351	 0.00298	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23910	 83241	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23911	 83250	 0.010353	 0.052371	 0.00091	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82975	 23912	 0.01542	 0.055086	 0.00109	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23912	 83243	 0.005554	 0.034143	 0.00062	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23913	 23916	 0.000216	 0.002661	 0.00086	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23914	 23916	 0.000377	 0.005639	 0.0019	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23914	 23917	 0.001213	 0.005007	 0.00118	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23914	 23921	 0.002712	 0.025917	 0.00854	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23914	 83243	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23914	 83243	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23915	 23916	 0.000498	 0.005282	 0.00157	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23915	 23942	 0.000711	 0.008893	 0.00389	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23917	 23919	 0.001225	 0.006259	 0.00157	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23918	 23919	 0.001002	 0.00489	 0.00135	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23918	 23921	 0.002672	 0.019531	 0.00576	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23918	 83244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23918	 83244	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23919	 83245	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23919	 83245	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23920	 23937	 0.014294	 0.05842	 0.00118	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23920	 83249	 0.009754	 0.043202	 0.00098	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81943	 23921	 0.000662	 0.007285	 0.00433	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23921	 83246	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23921	 83246	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23922	 23940	 0.001807	 0.026312	 0.00842	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81939	 23922	 0.001608	 0.016455	 0.00978	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23922	 83251	 0.005649	 0.028384	 0.00739	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23923	 23926	 0.013883	 0.055652	 0.00143	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81940	 23923	 0.005522	 0.027934	 0.00049	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23924	 23926	 0.036371	 0.025764	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23925	 23926	 0.00599	 0.026692	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23925	 83252	 0.008914	 0.031189	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23927	 23928	 0.031261	 0.023	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82726	 23927	 0.051167	 0.040107	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23928	 83254	 0.056939	 0.060666	 0.00086	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23929	 23930	 0.012631	 0.032736	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23929	 83252	 0.003005	 0.015629	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23930	 83247	 0.03895	 0.035142	 0.00059	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23931	 83254	 0.038436	 0.030418	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23932	 23934	 0.000366	 0.004148	 0.03776	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23932	 23944	 0.000269	 0.003343	 0.03097	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23932	 83247	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23932	 83247	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83244	 23933	 0.042714	 0.04127	 0.0006	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23934	 83248	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23934	 83248	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81943	 23935	 0.003858	 0.017994	 0.00446	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23935	 83251	 0.00148	 0.011659	 0.00341	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23937	 23938	 0.050942	 0.039931	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83243	 23937	 0.01335	 0.03829	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83245	 23937	 0.049109	 0.032988	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83244	 23938	 0.037419	 0.029613	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83235	 23939	 0.030831	 0.079905	 0.00151	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23939	 83249	 0.016147	 0.037097	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23940	 23941	 0.001303	 0.012511	 0.00364	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23940	 83249	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23940	 83249	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23941	 23942	 0.00076	 0.009561	 0.00296	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23941	 83250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23941	 83250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23943	 23947	 0.001758	 0.004237	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23944	 83251	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23947	 83253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23947	 83253	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82740	 23948	 0.001401	 0.011256	 0.00316	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83241	 23948	 0.007785	 0.054017	 0.01542	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23948	 83254	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23948	 83254	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23950	 83255	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23950	 83255	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23951	 23952	 0.073755	 0.13715	 0.00321	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83255	 23951	 0.076788	 0.17829	 0.00265	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23953	 23954	 0.24066	 0.15584	 0.00297	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83255	 23953	 0.21069	 0.15504	 0.00227	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23955	 23956	 0.026379	 0.084945	 0.00145	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23955	 23957	 0.030064	 0.092328	 0.00173	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23957	 23961	 0.037576	 0.080525	 0.00141	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82809	 23957	 0.050845	 0.156	 0.00423	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23958	 23959	 0.12443	 0.09848	 0.00124	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23958	 23961	 0.028446	 0.087357	 0.00164	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82809	 23958	 0.029273	 0.10458	 0.00208	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23959	 23960	 0.08307	 0.065115	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23960	 23964	 0.18721	 0.14676	 0.00188	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23961	 23963	 0.071358	 0.18496	 0.0035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23962	 23963	 0.082419	 0.16869	 0.00415	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23962	 23964	 0.091933	 0.075672	 0.00153	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23965	 23983	 0.000124	 0.002176	 0.02328	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23965	 23996	 0.000137	 0.001535	 0.01434	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23965	 23999	 0.000313	 0.005381	 0.05313	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23965	 83256	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83257	 23966	 0.013152	 0.010409	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23967	 23969	 0.000595	 0.003277	 0.00077	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23967	 23980	 0.000807	 0.004807	 0.00126	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83256	 23967	 0.002005	 0.005298	 0.00124	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23968	 23972	 0.000307	 0.004436	 0.00141	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23968	 23975	 0.000381	 0.005189	 0.00186	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23968	 23979	 0.000458	 0.003676	 0.00103	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23968	 83258	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23968	 83258	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23969	 23971	 0.000793	 0.003475	 0.0012	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23969	 83259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23969	 83259	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83259	 23970	 0.00478	 0.012288	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23970	 83274	 0.008094	 0.023215	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23971	 23972	 0.001505	 0.00468	 0.00098	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23971	 83273	 0.000848	 0.004704	 0.00143	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23972	 24001	 0.000617	 0.006758	 0.00187	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23972	 83260	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23972	 83260	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23973	 23974	 0.002972	 0.020403	 0.00037	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23973	 24005	 0.092115	 0.070659	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83260	 23973	 0.004981	 0.016617	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23973	 83279	 0.013717	 0.036262	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23974	 23994	 0.003751	 0.018006	 0.00054	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23974	 83261	 0.006948	 0.014218	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23975	 23976	 0.000181	 0.002562	 0.00085	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23975	 83261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23975	 83261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23976	 23992	 0.000327	 0.002363	 0.00127	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23977	 23978	 0.00022	 0.002333	 0.00069	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23977	 83264	 0.00028	 0.002876	 0.00082	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23978	 23979	 0.000234	 0.001903	 0.00061	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23978	 23980	 0.000581	 0.003336	 0.00094	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23978	 23982	 0.000644	 0.003422	 0.00079	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23980	 83262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23980	 83262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83259	 23981	 0.010251	 0.027098	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23981	 83263	 0.005292	 0.012532	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23982	 83263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23982	 83263	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23982	 83264	 0.000539	 0.003938	 0.00101	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23983	 23990	 4.5e-05	 0.000447	 0.00766	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23983	 23990	 4.5e-05	 0.000447	 0.00766	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23983	 23997	 0.000142	 0.002494	 0.04141	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23983	 83264	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23983	 83264	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23984	 23986	 0.00025	 0.002521	 0.04149	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23984	 23986	 0.00025	 0.002521	 0.04149	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81929	 23984	 0.000144	 0.003506	 0.06047	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83095	 23984	 0.000127	 0.003016	 0.05391	 1921.0	 2017.0	 2113.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23984	 83265	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23984	 83265	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23985	 23987	 0.015542	 0.044103	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23985	 83272	 0.041805	 0.075141	 0.00135	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23986	 23991	 9.4e-05	 0.000974	 0.0153	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23986	 23991	 9.4e-05	 0.000974	 0.0153	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23987	 83266	 0.015449	 0.023161	 0.00042	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23987	 83268	 0.009262	 0.027877	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23988	 23993	 0.002332	 0.014922	 0.00502	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23988	 23995	 0.000868	 0.006346	 0.00187	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	23988	 83266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23988	 83266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23988	 83267	 0.001893	 0.009513	 0.00248	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83263	 23989	 0.002232	 0.011161	 0.0002	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83266	 23989	 0.003369	 0.014927	 0.00045	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23990	 23991	 6.9e-05	 0.000735	 0.0108	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23990	 23991	 6.9e-05	 0.000735	 0.0108	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23990	 83267	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23991	 83269	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23991	 83269	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23992	 23993	 0.000319	 0.004877	 0.00157	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23992	 83270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23992	 83270	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23993	 24008	 0.000744	 0.005702	 0.00153	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83269	 23993	 0.000279	 0.004558	 0.00225	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83270	 23994	 0.007353	 0.018902	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23994	 83283	 0.00724	 0.040678	 0.00075	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23995	 83271	 0.001768	 0.008795	 0.00284	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23996	 23997	 0.000287	 0.003308	 0.029	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23996	 83271	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23997	 24002	 8.3e-05	 0.0015	 0.0285	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23997	 83273	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83272	 23998	 0.010505	 0.042935	 0.00087	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83274	 23998	 0.039962	 0.072106	 0.00104	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23998	 83276	 0.041342	 0.081854	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23999	 24000	 0.000357	 0.003923	 0.0381	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23999	 83275	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24000	 24002	 0.000426	 0.004745	 0.04474	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24000	 83277	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24001	 83279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24001	 83279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24001	 83280	 0.000548	 0.005937	 0.00186	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24002	 83280	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83279	 24003	 0.083606	 0.056162	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83281	 24004	 0.016512	 0.042445	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24004	 83289	 0.025378	 0.072017	 0.00113	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24006	 24007	 0.00167	 0.010754	 0.00282	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24006	 24008	 0.002615	 0.01625	 0.00459	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24007	 24009	 0.002672	 0.027013	 0.00794	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24007	 24016	 0.003322	 0.023699	 0.00735	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24007	 83282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24007	 83282	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24008	 83283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24008	 83283	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83265	 24009	 0.001536	 0.01423	 0.00713	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24009	 83284	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24009	 83284	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83282	 24010	 0.037359	 0.073969	 0.00109	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83283	 24010	 0.004638	 0.044907	 0.0009	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83284	 24010	 0.004318	 0.041809	 0.00084	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24011	 24013	 0.006628	 0.026536	 0.00669	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83265	 24011	 0.010508	 0.038051	 0.00816	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24011	 83285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24011	 83285	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24013	 24014	 0.006545	 0.025726	 0.00673	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24014	 24015	 0.006412	 0.021997	 0.00527	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24015	 24103	 0.011536	 0.039576	 0.00948	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24015	 83286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24015	 83286	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24016	 24017	 0.003328	 0.022841	 0.00666	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24017	 24116	 0.005266	 0.042748	 0.01361	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24017	 83287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24017	 83287	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24018	 83289	 0.15587	 0.10092	 0.00192	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24019	 83288	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83277	 24020	 0.001847	 0.016744	 0.00875	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24020	 83290	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24020	 83290	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24021	 24041	 0.001944	 0.006667	 0.0016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24021	 83291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24021	 83291	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24022	 24023	 0.001967	 0.008803	 0.00018	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83291	 24022	 0.002788	 0.015849	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24023	 24024	 0.003417	 0.011275	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24024	 24027	 0.008111	 0.016059	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24025	 24026	 0.015473	 0.010017	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83291	 24025	 0.011704	 0.027716	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24027	 24028	 0.023805	 0.015991	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24027	 24029	 0.013266	 0.01555	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24027	 83292	 0.01077	 0.047993	 0.00082	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24029	 24030	 0.021821	 0.017104	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24029	 24034	 0.021147	 0.038732	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24031	 24032	 0.026875	 0.026881	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24031	 24033	 0.010876	 0.022256	 0.00055	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24031	 24034	 0.008433	 0.027155	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24032	 24036	 0.018803	 0.047818	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24032	 24040	 0.03331	 0.031237	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24033	 24035	 0.022982	 0.063659	 0.00105	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24035	 24093	 0.12425	 0.083466	 0.00147	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81965	 24035	 0.028427	 0.14218	 0.00253	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24036	 24037	 0.013718	 0.039345	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24037	 83299	 0.022357	 0.079866	 0.00159	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24038	 24039	 0.026046	 0.051569	 0.00076	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24038	 24047	 0.080462	 0.082162	 0.00128	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24039	 83292	 0.010581	 0.032461	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24040	 83292	 0.033706	 0.035995	 0.00076	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 24041	 0.009347	 0.057471	 0.01658	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24041	 83292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24041	 83292	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81971	 24042	 0.007188	 0.017841	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83291	 24042	 0.017501	 0.040207	 0.00061	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24042	 83293	 0.027544	 0.040319	 0.00062	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81971	 24043	 0.015536	 0.02591	 0.00038	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24044	 24045	 0.00236	 0.00945	 0.00238	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24044	 83293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24044	 83293	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24044	 83294	 0.014661	 0.038063	 0.00924	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24045	 24049	 0.002527	 0.010116	 0.00255	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24046	 24047	 0.020149	 0.042349	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24046	 83295	 0.020239	 0.046987	 0.0007	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83293	 24047	 0.051098	 0.08608	 0.00123	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24048	 24057	 0.000294	 0.003618	 0.05796	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24048	 83294	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24048	 83294	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81936	 24049	 0.003442	 0.013778	 0.00347	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24049	 83295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24049	 83295	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24050	 24052	 0.099495	 0.10944	 0.00146	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81963	 24050	 0.002481	 0.006576	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83295	 24050	 0.072534	 0.073263	 0.00097	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24050	 83296	 0.042363	 0.064251	 0.00092	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24051	 24053	 0.008389	 0.024734	 0.00575	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81962	 24051	 0.004981	 0.017088	 0.00409	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24051	 83296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24051	 83296	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83296	 24052	 0.050607	 0.050756	 0.00082	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24052	 83297	 0.025436	 0.059053	 0.00088	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24053	 83297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24053	 83297	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24054	 24058	 0.034698	 0.048357	 0.00083	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83297	 24054	 0.008542	 0.038775	 0.00084	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83297	 24055	 0.091811	 0.07266	 0.00091	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83297	 24056	 0.038102	 0.038906	 0.00061	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24057	 83298	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24057	 83298	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83298	 24058	 0.024433	 0.032112	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24059	 24060	 0.00297	 0.011891	 0.003	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83294	 24059	 0.005271	 0.020715	 0.00542	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83018	 24060	 0.003961	 0.014343	 0.00308	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 24061	 0.010793	 0.066371	 0.01915	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83018	 24061	 0.003685	 0.020219	 0.00534	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 24062	 0.003713	 0.020376	 0.00539	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24062	 83299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24062	 83299	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83299	 24063	 0.14172	 0.11216	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24064	 24068	 0.15786	 0.12494	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24064	 24098	 0.10521	 0.1595	 0.00332	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81965	 24065	 0.059699	 0.047245	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24066	 24067	 0.011183	 0.025576	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24066	 24068	 0.02932	 0.096758	 0.00157	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82992	 24067	 0.18512	 0.14652	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82993	 24067	 0.063116	 0.1237	 0.00185	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83299	 24068	 0.029183	 0.077351	 0.00196	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81965	 24069	 0.073309	 0.21028	 0.00323	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83020	 24069	 0.050175	 0.13004	 0.00246	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83299	 24069	 0.02713	 0.1324	 0.00229	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24070	 24073	 0.043424	 0.034365	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24070	 24078	 0.087307	 0.068437	 0.00088	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24070	 83300	 0.013981	 0.062297	 0.00106	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24071	 83300	 0.011959	 0.023678	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24072	 24081	 0.003549	 0.012912	 0.00395	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24072	 83300	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24072	 83300	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24072	 83303	 0.006746	 0.018367	 0.00405	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24074	 24077	 0.01522	 0.027356	 0.00049	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24074	 83301	 0.00636	 0.021217	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24075	 24076	 0.002291	 0.007641	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24075	 83301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24075	 83301	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24076	 83302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24076	 83302	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24076	 83305	 0.000671	 0.008443	 0.00262	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83302	 24077	 0.011373	 0.029237	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82940	 24078	 0.12629	 0.10395	 0.00211	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24079	 24083	 0.053468	 0.10586	 0.00155	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82940	 24079	 0.046314	 0.14914	 0.00254	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83300	 24080	 0.026109	 0.080181	 0.0015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24080	 83304	 0.098732	 0.09876	 0.00133	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24082	 24085	 0.000391	 0.004288	 0.04166	 736.0	 772.8	 809.6	 0.0	 0.0	 0	 -30.0	 30.0;
	24082	 83303	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 0	 -30.0	 30.0;
	24082	 83303	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 0	 -30.0	 30.0;
	24083	 24086	 0.13702	 0.14926	 0.00203	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24084	 83304	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24084	 83304	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24085	 83305	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24085	 83305	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83302	 24086	 0.019311	 0.059242	 0.0016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24087	 24090	 0.00831	 0.038127	 0.00977	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24088	 24089	 0.20946	 0.15413	 0.00225	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81974	 24088	 0.045661	 0.097488	 0.0022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24088	 83306	 0.12819	 0.25385	 0.00373	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 24090	 0.040493	 0.11297	 0.02373	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24090	 83306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24090	 83306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24091	 24092	 0.049909	 0.11586	 0.00221	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83306	 24091	 0.034345	 0.11457	 0.00182	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24092	 24094	 0.037708	 0.07466	 0.0011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81965	 24094	 0.11762	 0.16035	 0.00356	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24095	 24098	 0.089602	 0.19204	 0.00336	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82883	 24095	 0.087261	 0.35679	 0.00722	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83306	 24095	 0.049654	 0.11408	 0.00173	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24096	 83307	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24096	 83307	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83307	 24097	 0.10062	 0.15262	 0.00219	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81965	 24098	 0.24356	 0.19279	 0.00243	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82725	 24099	 0.033238	 0.11874	 0.00236	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83017	 24099	 0.5956	 0.49122	 0.00995	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24100	 83308	 0.28624	 0.22443	 0.00288	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24101	 83308	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24101	 83308	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24102	 83309	 0.063589	 0.16482	 0.00312	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24103	 24104	 0.002452	 0.018652	 0.00586	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81946	 24104	 0.008507	 0.12039	 0.03992	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24104	 83309	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24104	 83309	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24105	 24106	 0.010083	 0.018193	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24105	 24107	 0.005137	 0.010556	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24106	 24107	 0.005009	 0.01025	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24106	 83312	 0.05251	 0.13919	 0.00353	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24107	 24108	 0.009288	 0.01549	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24107	 24109	 0.005107	 0.012988	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83309	 24107	 0.005579	 0.040307	 0.00076	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24108	 24109	 0.026796	 0.021004	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24109	 83311	 0.009506	 0.024636	 0.00047	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24110	 24117	 0.003164	 0.02195	 0.00626	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24110	 83310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24110	 83310	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83310	 24111	 0.037626	 0.10792	 0.00166	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24111	 83311	 0.042436	 0.10909	 0.00169	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24112	 24113	 0.043704	 0.10145	 0.00193	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24112	 24114	 0.038388	 0.1101	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83309	 24112	 0.062623	 0.113	 0.00163	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24113	 24114	 0.030018	 0.086096	 0.00132	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82807	 24113	 0.015391	 0.075019	 0.00141	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83005	 24114	 0.055146	 0.1884	 0.0041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24114	 83311	 0.20464	 0.20673	 0.00274	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24115	 24116	 0.001443	 0.012293	 0.00307	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24115	 24117	 0.003309	 0.023935	 0.01288	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24115	 83311	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24115	 83311	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24117	 83312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24117	 83312	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83312	 24118	 0.01711	 0.043513	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24119	 24122	 0.15909	 0.12591	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24120	 83313	 0.12441	 0.16353	 0.00224	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24121	 24125	 0.002772	 0.029373	 0.00872	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24121	 83313	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24121	 83313	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24122	 24123	 0.14732	 0.11549	 0.00148	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24123	 24129	 0.041943	 0.10782	 0.00167	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24123	 83314	 0.044285	 0.14774	 0.00234	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24124	 24125	 0.008837	 0.023354	 0.00547	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81951	 24124	 0.01584	 0.095834	 0.02447	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24124	 83314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24124	 83314	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24125	 24128	 0.002251	 0.025732	 0.00785	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83276	 24126	 0.14124	 0.10211	 0.00155	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24127	 24131	 0.1768	 0.13993	 0.00176	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83274	 24127	 0.047427	 0.26654	 0.00494	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24127	 83315	 0.1486	 0.14865	 0.00201	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24128	 24130	 0.001889	 0.021603	 0.00605	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24130	 83315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24130	 83315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24132	 24138	 0.062921	 0.09818	 0.00164	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82733	 24132	 0.020187	 0.13697	 0.00256	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24133	 24141	 0.017679	 0.044445	 0.01152	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24133	 83316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24133	 83316	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24134	 24135	 0.001828	 0.00637	 0.00148	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81941	 24135	 0.002227	 0.018968	 0.00473	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24135	 83317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24135	 83317	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83316	 24136	 0.072547	 0.125	 0.00199	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83317	 24136	 0.011397	 0.027896	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81934	 24137	 0.020593	 0.052936	 0.00082	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24138	 83322	 0.038801	 0.11129	 0.00171	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24139	 24144	 0.000248	 0.0039	 0.04064	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24139	 83318	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24139	 83318	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24140	 24142	 0.006909	 0.024079	 0.00558	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24140	 24146	 0.008084	 0.028176	 0.00653	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24140	 83319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24140	 83319	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82768	 24141	 0.005493	 0.017916	 0.00476	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24141	 83320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24141	 83320	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24143	 83321	 0.011056	 0.02922	 0.00684	 132.0	 132.0	 132.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24144	 83321	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83318	 24145	 0.026485	 0.052437	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81941	 24146	 0.009957	 0.042143	 0.00948	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24146	 83323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24146	 83323	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24147	 24240	 0.00391	 0.024293	 0.00686	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24147	 83324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24147	 83324	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24148	 24156	 0.006134	 0.012553	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24148	 24176	 0.011087	 0.025149	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81982	 24148	 0.000357	 0.001656	 3e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24149	 24150	 0.011114	 0.012225	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24149	 24151	 0.015213	 0.011925	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81982	 24149	 0.004449	 0.007996	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24150	 24151	 0.011475	 0.012499	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24150	 24175	 0.010822	 0.021427	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24151	 24152	 0.00473	 0.007549	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24152	 24168	 0.015439	 0.012218	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24152	 24172	 0.028579	 0.026324	 0.00042	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83324	 24152	 0.005926	 0.011733	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24152	 83341	 0.020236	 0.051463	 0.00081	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24153	 24162	 0.019294	 0.01296	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83324	 24153	 0.010621	 0.007678	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81982	 24154	 0.003517	 0.005387	 9e-05	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83324	 24154	 0.004014	 0.007947	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24155	 24167	 0.009446	 0.018702	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81982	 24155	 0.005761	 0.013374	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24156	 83325	 0.007584	 0.013891	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24157	 24176	 0.026454	 0.020936	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24157	 24208	 0.027792	 0.029679	 0.00063	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24157	 83325	 0.019011	 0.020255	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24158	 83325	 0.016673	 0.010794	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24159	 24181	 0.008007	 0.022329	 0.00469	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24159	 83325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24159	 83325	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24160	 24166	 0.021668	 0.017148	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83325	 24160	 0.029132	 0.022346	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24161	 24162	 0.022108	 0.01675	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24162	 24164	 0.017373	 0.012782	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24162	 83326	 0.010288	 0.024362	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24163	 24241	 0.001639	 0.006563	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24163	 83326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24163	 83326	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24164	 24165	 0.012544	 0.009927	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24165	 24168	 0.004877	 0.010452	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83326	 24165	 0.003984	 0.014731	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24166	 24167	 0.013222	 0.011847	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24168	 24169	 0.013954	 0.011485	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24168	 24170	 0.006531	 0.011665	 0.00017	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24169	 24172	 0.01833	 0.029257	 0.00067	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83326	 24169	 0.007368	 0.019097	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24170	 24171	 0.009565	 0.0089	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24171	 24172	 0.019455	 0.014314	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24172	 24173	 0.005624	 0.014457	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24172	 24212	 0.022544	 0.017841	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24173	 24175	 0.023039	 0.018233	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24174	 24178	 0.001472	 0.003821	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24174	 24226	 0.008938	 0.024925	 0.00523	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24174	 83327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24174	 83327	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24175	 24177	 0.019197	 0.015801	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83327	 24175	 0.02084	 0.016493	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24176	 24177	 0.031465	 0.024901	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83327	 24176	 0.045159	 0.029236	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24177	 24209	 0.008652	 0.01657	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83327	 24177	 0.025996	 0.01994	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24177	 83328	 0.021765	 0.015734	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24178	 24210	 0.001281	 0.003387	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24178	 83328	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24178	 83328	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24179	 24215	 0.035392	 0.027742	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83327	 24179	 0.006892	 0.011001	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83325	 24180	 0.013247	 0.026229	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24181	 24185	 0.006672	 0.017321	 0.0042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24181	 83329	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24181	 83329	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24181	 83428	 0.007169	 0.018947	 0.00443	 118.0	 123.9	 129.8	 0.0	 0.0	 0	 -30.0	 30.0;
	24182	 24197	 0.033119	 0.02621	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24182	 24199	 0.021392	 0.016768	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24182	 24646	 0.019485	 0.038578	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24183	 24199	 0.029428	 0.023289	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24184	 24208	 0.003345	 0.013013	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81978	 24184	 0.003285	 0.014637	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24184	 83330	 0.005508	 0.012357	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24185	 83330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24185	 83330	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24186	 24191	 0.023371	 0.019237	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24186	 24194	 0.005218	 0.010332	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24187	 24188	 0.004821	 0.012394	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83330	 24187	 0.009123	 0.017878	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24187	 83334	 0.007362	 0.018925	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24188	 24189	 0.008311	 0.015222	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24189	 24190	 0.010998	 0.01103	 0.00018	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24190	 24191	 0.014564	 0.011526	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24191	 24192	 0.019128	 0.015138	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24191	 24198	 0.02985	 0.023623	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24191	 24246	 0.059504	 0.046642	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24193	 24194	 0.01095	 0.007089	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24194	 24195	 0.012254	 0.009697	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83330	 24194	 0.004788	 0.012308	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24196	 24198	 0.00615	 0.01764	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24196	 24202	 0.005701	 0.015772	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24197	 24198	 0.005775	 0.011433	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24197	 24199	 0.012933	 0.00992	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24198	 24246	 0.01577	 0.019575	 0.00043	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24200	 24246	 0.017777	 0.013079	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24201	 24203	 0.009065	 0.005869	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24202	 24205	 0.026551	 0.019193	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24202	 83331	 0.009851	 0.037898	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24203	 24246	 0.017988	 0.019165	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24204	 24812	 0.005255	 0.018575	 0.00419	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24204	 83331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24204	 83331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24205	 24206	 0.010611	 0.015909	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24206	 24220	 0.013747	 0.027218	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83331	 24206	 0.010367	 0.031838	 0.0006	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24206	 83332	 0.038585	 0.037904	 0.00064	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24207	 24218	 0.002915	 0.007568	 0.00184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24207	 83332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24207	 83332	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24208	 24209	 0.003478	 0.008074	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24209	 83333	 0.01529	 0.009898	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24210	 24211	 0.001005	 0.002525	 0.00065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24210	 83333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24210	 83333	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24211	 83334	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24211	 83334	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24212	 24213	 0.015814	 0.017224	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24212	 83335	 0.049509	 0.03751	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24213	 24217	 0.04659	 0.036871	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83326	 24213	 0.031447	 0.054181	 0.00086	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83334	 24214	 0.014405	 0.014549	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24214	 83336	 0.007092	 0.01299	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24215	 83335	 0.007628	 0.029674	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24216	 24226	 0.003914	 0.010508	 0.00238	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24216	 83335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24216	 83335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24217	 24228	 0.021048	 0.035457	 0.00051	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83335	 24217	 0.027395	 0.021473	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24218	 83336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24218	 83336	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24219	 24225	 0.029619	 0.023216	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83336	 24219	 0.036138	 0.039747	 0.00053	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24220	 24221	 0.055127	 0.045374	 0.00092	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24221	 24223	 0.090501	 0.066586	 0.00097	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24222	 83337	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24222	 83337	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83337	 24223	 0.017059	 0.0135	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24224	 24225	 0.071741	 0.050819	 0.0008	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24224	 24227	 0.034069	 0.062401	 0.00108	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83337	 24224	 0.072214	 0.056605	 0.00073	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24226	 83338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24226	 83338	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83338	 24227	 0.007665	 0.019704	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83335	 24228	 0.043368	 0.046313	 0.00098	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24228	 83340	 0.029799	 0.084561	 0.00133	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83338	 24229	 0.033658	 0.053724	 0.00124	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24230	 24231	 0.037631	 0.096737	 0.0015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24232	 24233	 0.024047	 0.09355	 0.00156	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24232	 24235	 0.12896	 0.10207	 0.00129	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24232	 24239	 0.025845	 0.099432	 0.0017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24234	 24236	 0.002082	 0.011787	 0.00292	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24234	 24240	 0.005352	 0.032119	 0.00973	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24234	 83339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24234	 83339	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24235	 24237	 0.01859	 0.053318	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83339	 24235	 0.005084	 0.012928	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24237	 24239	 0.014441	 0.07305	 0.00127	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83339	 24237	 0.014041	 0.060301	 0.0011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83326	 24238	 0.033517	 0.044052	 0.0006	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24239	 24242	 0.10864	 0.079931	 0.00117	 32.0	 32.0	 32.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83326	 24239	 0.023165	 0.077277	 0.00122	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24239	 83340	 0.040788	 0.051252	 0.00077	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24240	 24241	 0.001003	 0.010984	 0.00305	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24240	 83340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24240	 83340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24241	 83341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24241	 83341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24242	 24244	 0.02678	 0.070793	 0.00129	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24243	 24245	 0.07429	 0.088934	 0.00148	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24244	 24245	 0.033501	 0.041586	 0.00091	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81966	 24246	 0.011717	 0.065934	 0.00142	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24246	 83481	 0.017936	 0.035512	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24247	 24248	 0.015038	 0.010652	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24248	 24249	 0.008489	 0.008339	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24248	 24267	 0.00652	 0.012909	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24249	 24252	 0.003265	 0.008393	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24249	 83345	 0.00916	 0.021848	 0.00049	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24250	 83346	 0.017481	 0.013702	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24251	 24252	 0.007241	 0.009423	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24251	 24275	 0.008259	 0.010855	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24252	 24253	 0.008074	 0.015986	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24253	 24255	 0.00902	 0.009111	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24253	 24552	 0.011218	 0.008793	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24254	 24255	 0.015248	 0.012067	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24255	 24256	 0.007538	 0.005908	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24255	 24257	 0.012557	 0.016503	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24257	 24258	 0.004837	 0.007409	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24257	 24275	 0.010191	 0.007721	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24258	 83342	 0.004905	 0.009612	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24259	 24266	 0.001156	 0.003103	 0.0007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24259	 83342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24259	 83342	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83342	 24260	 0.017128	 0.013555	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24260	 83343	 0.022052	 0.017286	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24261	 83343	 0.011135	 0.008812	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24262	 24547	 0.002842	 0.007379	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24262	 83343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24262	 83343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24263	 24264	 0.006484	 0.011699	 0.00017	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83343	 24263	 0.006283	 0.010584	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24264	 24265	 0.011221	 0.007265	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24264	 83395	 0.00972	 0.018616	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24265	 83344	 0.008789	 0.006889	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24266	 24318	 0.000793	 0.002058	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24266	 83344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24266	 83344	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24267	 24270	 0.011853	 0.009092	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24268	 24272	 0.00228	 0.006207	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24268	 83345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24268	 83345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24269	 24270	 0.017792	 0.013946	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83345	 24269	 0.004357	 0.006954	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24269	 83346	 0.011884	 0.008743	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24271	 24272	 0.000788	 0.002083	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24271	 83346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24271	 83346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24272	 24285	 0.000745	 0.002001	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24273	 24274	 0.012867	 0.010183	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24273	 24277	 0.00572	 0.011211	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24273	 83348	 0.003121	 0.007079	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24275	 24277	 0.01529	 0.016654	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24276	 24277	 0.011028	 0.007139	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24277	 24278	 0.011405	 0.00894	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24277	 24316	 0.005321	 0.011403	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24277	 83349	 0.028739	 0.022527	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24279	 24335	 0.007491	 0.013517	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24279	 83347	 0.024397	 0.019307	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24279	 83353	 0.008636	 0.013228	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24280	 24284	 0.00097	 0.002641	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24280	 83347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24280	 83347	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24280	 83352	 0.00168	 0.004511	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24281	 24282	 0.016362	 0.016526	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83347	 24281	 0.028071	 0.021267	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24282	 24283	 0.005535	 0.008395	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83345	 24282	 0.019044	 0.014928	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24283	 83350	 0.003805	 0.010085	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24284	 24285	 0.000962	 0.002583	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24285	 83348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24285	 83348	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24286	 83349	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24286	 83349	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24286	 83352	 0.002429	 0.006306	 0.00153	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83078	 24287	 0.005252	 0.021686	 0.00513	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24287	 83350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24287	 83350	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24287	 83352	 0.004379	 0.013618	 0.00284	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24288	 24289	 0.004837	 0.010972	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83350	 24288	 0.003148	 0.008092	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24289	 83351	 0.015114	 0.017717	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24290	 83351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24290	 83351	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24290	 83352	 0.002998	 0.008161	 0.0018	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24291	 24292	 0.00329	 0.008054	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83351	 24291	 0.005245	 0.010279	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24292	 24293	 0.003232	 0.006901	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81977	 24293	 0.003792	 0.008978	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24294	 24295	 0.011386	 0.008231	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24295	 24296	 0.012944	 0.009169	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83351	 24296	 0.016442	 0.012612	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24297	 24298	 0.011463	 0.008287	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24297	 24300	 0.017596	 0.012946	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24298	 24302	 0.028326	 0.022417	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24298	 24306	 0.010365	 0.008203	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24299	 24300	 0.016277	 0.012759	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24299	 24302	 0.011496	 0.009098	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24300	 24301	 0.01176	 0.009218	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24300	 24305	 0.005591	 0.014373	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24302	 24303	 0.00445	 0.00881	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24302	 24561	 0.007846	 0.015535	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83203	 24302	 0.012952	 0.030065	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24303	 24465	 0.007025	 0.011515	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24304	 24305	 0.00393	 0.008043	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24304	 24463	 0.006107	 0.015697	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83203	 24305	 0.002749	 0.012043	 0.00026	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24306	 24307	 0.01304	 0.01032	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24307	 24556	 0.00561	 0.008592	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24308	 24312	 0.007919	 0.010305	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24308	 24559	 0.013585	 0.009995	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24309	 24559	 0.011634	 0.00841	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24310	 24379	 0.000444	 0.005027	 0.04577	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24310	 83352	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24311	 24314	 0.008562	 0.006776	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24311	 24848	 0.027971	 0.02022	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83351	 24312	 0.004484	 0.008059	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24313	 24418	 0.01679	 0.012137	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24313	 24556	 0.021043	 0.016653	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24314	 83389	 0.005183	 0.007686	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24315	 24328	 0.038782	 0.026051	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83342	 24315	 0.017486	 0.01132	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24316	 24317	 0.005275	 0.012119	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24317	 24849	 0.013011	 0.011739	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24317	 83354	 0.012923	 0.009508	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24318	 24320	 0.001348	 0.004214	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24318	 83354	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24318	 83354	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24319	 83355	 0.012485	 0.00988	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24320	 83355	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24320	 83355	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24320	 83357	 0.001215	 0.004093	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24321	 24322	 0.000606	 0.002465	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24321	 24538	 0.000681	 0.002725	 0.00069	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81952	 24322	 0.00082	 0.003191	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24323	 83356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24323	 83356	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24323	 83357	 0.001241	 0.004258	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24324	 83357	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24325	 24326	 0.004363	 0.010024	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24325	 24849	 0.006716	 0.012071	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83356	 24325	 0.004255	 0.006792	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24326	 24328	 0.015359	 0.012155	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24326	 24329	 0.004519	 0.009287	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83356	 24326	 0.011337	 0.018482	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24327	 24329	 0.004518	 0.010489	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24327	 24335	 0.003225	 0.005997	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83349	 24328	 0.016372	 0.012404	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24330	 24331	 0.007356	 0.011269	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24330	 24339	 0.006955	 0.008852	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24331	 24332	 0.003672	 0.009441	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24331	 24340	 0.008136	 0.008861	 0.00012	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24332	 24333	 0.00201	 0.005167	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83356	 24333	 0.003868	 0.009942	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24334	 24340	 0.006583	 0.017448	 0.00044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24334	 24852	 0.007996	 0.006328	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81953	 24334	 0.00496	 0.019369	 0.00043	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24335	 83359	 0.011235	 0.010068	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24336	 83359	 0.020842	 0.015334	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24337	 24353	 0.000763	 0.002047	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83352	 24337	 0.002157	 0.007035	 0.00187	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24337	 83359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24337	 83359	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83359	 24338	 0.017431	 0.011285	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24339	 24344	 0.00792	 0.010409	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24340	 24341	 0.005269	 0.015112	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24341	 24342	 0.00619	 0.004384	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24341	 24343	 0.016579	 0.01312	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24341	 24348	 0.032168	 0.025215	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24342	 24345	 0.013136	 0.010076	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24344	 24355	 0.010771	 0.011846	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24345	 24346	 0.009357	 0.007405	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24346	 24347	 0.008841	 0.00693	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24346	 24348	 0.012169	 0.00922	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24348	 83363	 0.005603	 0.01098	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24348	 83378	 0.031739	 0.050661	 0.00117	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24349	 83368	 0.014173	 0.01004	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24350	 24352	 0.001999	 0.005367	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24350	 24358	 0.000728	 0.001925	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24350	 83360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24350	 83360	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24351	 24357	 0.004151	 0.008895	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24351	 24855	 0.002525	 0.008424	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83360	 24351	 0.014926	 0.009663	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24352	 24353	 0.000871	 0.002239	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24352	 83361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24352	 83361	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24354	 24355	 0.012346	 0.009771	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83361	 24355	 0.006869	 0.010964	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83360	 24356	 0.015212	 0.011924	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24357	 24367	 0.008312	 0.012734	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24357	 83362	 0.014903	 0.011794	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24358	 24359	 0.000438	 0.001125	 0.00028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24358	 24373	 0.000975	 0.002349	 0.00066	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24359	 24365	 0.001446	 0.003636	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24359	 83362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24359	 83362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24360	 24361	 0.000722	 0.001937	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24360	 24373	 0.000832	 0.002138	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24360	 83363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24360	 83363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24361	 83377	 0.003474	 0.011917	 0.00285	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24362	 24365	 0.00174	 0.004474	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24362	 83364	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24362	 83364	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24362	 83377	 0.001922	 0.00696	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24363	 24368	 0.001137	 0.003097	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24363	 24374	 0.000912	 0.003301	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24363	 83365	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24363	 83365	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83364	 24364	 0.012564	 0.013685	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83365	 24364	 0.02449	 0.019381	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24364	 83368	 0.022536	 0.017664	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83362	 24366	 0.005469	 0.003541	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24367	 24372	 0.007813	 0.01303	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83365	 24367	 0.030195	 0.023896	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24367	 83366	 0.013878	 0.010983	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24368	 24371	 0.001617	 0.004273	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24368	 83366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24368	 83366	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24369	 24370	 0.013751	 0.010882	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24369	 24389	 0.01804	 0.01414	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24370	 24399	 0.01441	 0.011404	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24370	 83367	 0.010443	 0.011374	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24371	 24422	 0.001001	 0.002727	 0.0006	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24371	 83367	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24371	 83367	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24372	 83386	 0.014286	 0.011306	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24372	 83389	 0.014077	 0.01114	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24373	 83368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24373	 83368	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24374	 24390	 0.000797	 0.002223	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24374	 83377	 0.002608	 0.006771	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24375	 24376	 0.003449	 0.00676	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24375	 24378	 0.007812	 0.011967	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24375	 83378	 0.010085	 0.015296	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24376	 24377	 0.006645	 0.006711	 9e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83364	 24377	 0.011594	 0.009175	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83365	 24377	 0.023493	 0.018592	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24378	 83371	 0.013957	 0.013961	 0.00019	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24378	 83376	 0.017775	 0.023362	 0.00032	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24379	 24381	 5e-05	 0.000569	 0.00518	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24379	 83369	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24379	 83369	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24380	 83450	 0.007503	 0.013486	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24381	 24387	 9.6e-05	 0.001057	 0.01027	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24381	 24393	 9e-05	 0.001034	 0.00906	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24381	 83370	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81944	 24382	 0.001695	 0.00448	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83370	 24382	 0.000874	 0.002345	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24382	 83372	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24382	 83372	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24383	 24756	 8.3e-05	 0.000922	 0.0087	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24383	 83373	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24384	 24385	 0.020563	 0.014566	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24384	 83463	 0.009101	 0.01001	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24385	 83464	 0.015856	 0.010651	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24386	 24853	 6.5e-05	 0.000755	 0.00662	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24386	 83375	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24387	 83377	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24388	 24389	 0.010045	 0.007874	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24389	 83379	 0.003626	 0.006642	 0.00011	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83369	 24390	 0.001286	 0.003792	 0.00088	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24390	 83379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24390	 83379	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24391	 24392	 0.000735	 0.001942	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83369	 24391	 0.001207	 0.00324	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24392	 24397	 0.000839	 0.002108	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24393	 24396	 5.6e-05	 0.000625	 0.00595	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24393	 24716	 6e-05	 0.000691	 0.00605	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24393	 83380	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24393	 83380	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24394	 24395	 0.010133	 0.008019	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83380	 24394	 0.016345	 0.012935	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24394	 83382	 0.018598	 0.014718	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83380	 24395	 0.018409	 0.014569	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24395	 83382	 0.008644	 0.006841	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24396	 83381	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24397	 24847	 0.000446	 0.001529	 0.00037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83381	 24397	 0.000487	 0.001669	 0.0004	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24398	 24436	 0.000656	 0.002249	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83381	 24398	 0.000782	 0.002682	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24399	 24428	 0.008549	 0.006766	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24399	 83492	 0.01072	 0.011791	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24400	 83492	 0.011533	 0.008485	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24401	 24403	 0.013797	 0.011356	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24401	 24563	 0.008302	 0.00657	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24402	 24403	 0.017201	 0.013613	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24402	 24467	 0.025088	 0.019855	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24403	 24413	 0.004169	 0.008254	 0.00012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24403	 24414	 0.016744	 0.011248	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24403	 83393	 0.007984	 0.021162	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24404	 24413	 0.01068	 0.008192	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24404	 24450	 0.010811	 0.008556	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24405	 24450	 0.014127	 0.010007	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24406	 24407	 0.000746	 0.001938	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24406	 83383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24406	 83383	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24407	 24411	 0.000822	 0.002239	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24407	 83384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24407	 83384	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24408	 24423	 0.016639	 0.013168	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83384	 24408	 0.013158	 0.009512	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24409	 24421	 0.006172	 0.009454	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24409	 83385	 0.006878	 0.008385	 0.00013	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24410	 24411	 0.000819	 0.002165	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24410	 83385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24410	 83385	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24412	 24413	 0.005701	 0.008547	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24412	 24415	 0.011843	 0.007667	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24412	 24450	 0.025118	 0.01848	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83385	 24412	 0.004819	 0.012387	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24415	 24416	 0.010024	 0.007246	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24416	 24564	 0.01118	 0.00751	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24417	 24418	 0.005326	 0.006692	 0.0001	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24417	 24567	 0.005078	 0.008435	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83385	 24417	 0.020624	 0.014909	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24418	 24419	 0.0045	 0.00812	 0.00012	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24419	 83386	 0.006101	 0.011956	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24420	 24422	 0.000838	 0.002214	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24420	 24430	 0.000913	 0.002414	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24420	 83386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24420	 83386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24421	 24423	 0.012204	 0.009658	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83386	 24421	 0.004707	 0.007861	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24422	 83387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24422	 83387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24423	 24424	 0.012127	 0.007851	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24424	 24425	 0.011772	 0.009228	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24424	 24426	 0.012856	 0.010174	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83387	 24424	 0.016877	 0.013356	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83384	 24426	 0.01625	 0.016254	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24426	 83388	 0.00628	 0.014089	 0.00022	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83383	 24427	 0.003763	 0.010679	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24427	 83388	 0.00198	 0.005247	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24428	 83388	 0.01416	 0.009512	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24429	 24847	 0.00136	 0.003704	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24429	 83388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24429	 83388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83352	 24430	 0.004014	 0.014189	 0.0032	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24430	 83389	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24430	 83389	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24431	 24432	 0.010513	 0.012585	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83383	 24431	 0.006673	 0.00877	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24432	 24433	 0.011427	 0.008095	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24432	 83393	 0.016635	 0.013164	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24433	 24434	 0.005054	 0.007494	 0.00011	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24433	 24440	 0.007934	 0.012154	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24434	 24439	 0.019714	 0.015601	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24434	 24445	 0.004552	 0.007265	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24435	 24436	 0.000832	 0.003011	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24435	 24451	 0.002959	 0.00782	 0.00183	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24435	 83390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24435	 83390	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83390	 24437	 0.014313	 0.011219	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24437	 83392	 0.017604	 0.013932	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24438	 24444	 0.000704	 0.002415	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24438	 24451	 0.00357	 0.009956	 0.00209	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24438	 24720	 0.001804	 0.005031	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24438	 83391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24438	 83391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24439	 24440	 0.005349	 0.010484	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83391	 24439	 0.004042	 0.009168	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24440	 24441	 0.019589	 0.015503	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24440	 24457	 0.00496	 0.011394	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24441	 24442	 0.00866	 0.012293	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24441	 83394	 0.04671	 0.036965	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24442	 24521	 0.020476	 0.016205	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83391	 24442	 0.005083	 0.009848	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24442	 83453	 0.015868	 0.020855	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24443	 24522	 0.015811	 0.01597	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24443	 83392	 0.026153	 0.020697	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24443	 83453	 0.015782	 0.010218	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24444	 83392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24444	 83392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24444	 83451	 0.000764	 0.003865	 0.00108	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83392	 24445	 0.004076	 0.009363	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24446	 24447	 0.01638	 0.011841	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24446	 24448	 0.004395	 0.007015	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24446	 24466	 0.02455	 0.019428	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24446	 24467	 0.011712	 0.007582	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24447	 24453	 0.010265	 0.008124	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24448	 24449	 0.003215	 0.008266	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24449	 83393	 0.003185	 0.012254	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24450	 83393	 0.003637	 0.010947	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24451	 83393	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24451	 83393	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24451	 83400	 0.008547	 0.028798	 0.00716	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83393	 24452	 0.015707	 0.012048	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24453	 24455	 0.013471	 0.010559	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24454	 24455	 0.011632	 0.008922	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24455	 24456	 0.004718	 0.009035	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24456	 24457	 0.015902	 0.012585	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24456	 24462	 0.016593	 0.013131	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24456	 24477	 0.037595	 0.029469	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83393	 24456	 0.004327	 0.016649	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24458	 24462	 0.012432	 0.009536	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24458	 24502	 0.007974	 0.013071	 0.00023	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24459	 24461	 0.011728	 0.009193	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24459	 24499	 0.019763	 0.012795	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24460	 24477	 0.012915	 0.009336	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24460	 24497	 0.02023	 0.016009	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24461	 24462	 0.010987	 0.007783	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24463	 24464	 0.011683	 0.009246	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24463	 24472	 0.009003	 0.017824	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24465	 24466	 0.018764	 0.014708	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24467	 24468	 0.011614	 0.007519	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24468	 24469	 0.018344	 0.014517	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24468	 24471	 0.008216	 0.008644	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24469	 24474	 0.037199	 0.026891	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24470	 24471	 0.017389	 0.013761	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24470	 24473	 0.008205	 0.008229	 0.00013	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24470	 24475	 0.017872	 0.013709	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24471	 24472	 0.004418	 0.008747	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24474	 24475	 0.0125	 0.009892	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24474	 24479	 0.017032	 0.01335	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83198	 24474	 0.009128	 0.015377	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24475	 24476	 0.015723	 0.012443	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24476	 24477	 0.016802	 0.01317	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24477	 24478	 0.012141	 0.009608	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24478	 24479	 0.013871	 0.00898	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24478	 24482	 0.021756	 0.017054	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24480	 24481	 0.011438	 0.009052	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24481	 24482	 0.005239	 0.008825	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24482	 24483	 0.011709	 0.008464	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24482	 24484	 0.008405	 0.014159	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24482	 24499	 0.045825	 0.03592	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24483	 24497	 0.011667	 0.008434	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24484	 24485	 0.00438	 0.008023	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24485	 24486	 0.003897	 0.01033	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24485	 24490	 0.004931	 0.008898	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24485	 24507	 0.0172	 0.013482	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24485	 24508	 0.002789	 0.015856	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24486	 24487	 0.00435	 0.007819	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24488	 24489	 0.011576	 0.009161	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24488	 24508	 0.035884	 0.030669	 0.00057	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24489	 24491	 0.018647	 0.014303	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24490	 24491	 0.004365	 0.008642	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24491	 24493	 0.003495	 0.010278	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24492	 24493	 0.002608	 0.010435	 0.00022	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24492	 24518	 0.005578	 0.015998	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24492	 24571	 0.004825	 0.008619	 0.00013	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24493	 24494	 0.023734	 0.018783	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24494	 24495	 0.011718	 0.009274	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24495	 24496	 0.006769	 0.008809	 0.00012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83193	 24495	 0.035206	 0.027861	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24496	 83397	 0.007074	 0.014006	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24497	 24499	 0.022617	 0.017729	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24497	 24506	 0.008158	 0.016153	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24498	 24499	 0.011229	 0.008886	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24499	 24500	 0.012331	 0.009759	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24499	 83394	 0.008989	 0.024558	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24500	 24502	 0.008014	 0.010533	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24501	 24504	 0.013901	 0.011001	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24502	 24519	 0.011727	 0.008306	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24502	 83394	 0.004785	 0.015193	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24503	 24720	 0.005349	 0.013446	 0.00348	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24503	 83394	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24503	 83394	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24503	 83400	 0.002532	 0.013891	 0.00367	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83394	 24504	 0.012753	 0.010092	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24505	 24506	 0.003193	 0.009158	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24505	 24509	 0.005367	 0.00983	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83394	 24505	 0.011862	 0.019983	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24506	 24507	 0.009981	 0.007899	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24508	 24510	 0.012039	 0.009528	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24508	 24517	 0.005025	 0.012779	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24508	 83398	 0.008529	 0.029842	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24509	 24510	 0.005752	 0.011389	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24510	 24511	 0.002917	 0.00756	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24511	 24513	 0.012485	 0.008083	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24511	 24516	 0.004575	 0.015262	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83394	 24512	 0.018072	 0.013296	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24513	 24514	 0.013295	 0.010421	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24514	 24515	 0.005855	 0.015051	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24514	 24532	 0.004421	 0.010263	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24515	 24579	 0.024171	 0.015648	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24515	 83399	 0.010261	 0.020316	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24516	 83399	 0.003559	 0.013844	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24517	 83399	 0.007761	 0.02589	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24518	 83398	 0.002791	 0.009971	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24519	 24520	 0.011157	 0.007494	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24520	 24521	 0.011666	 0.009144	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24520	 24536	 0.027343	 0.021639	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24521	 24522	 0.011696	 0.008455	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24522	 24523	 0.011694	 0.007571	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24523	 24524	 0.009008	 0.009011	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24523	 24526	 0.027283	 0.021591	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24524	 24525	 0.024578	 0.018083	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24524	 24725	 0.020349	 0.020354	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24524	 83454	 0.011863	 0.015591	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24525	 24526	 0.011391	 0.009015	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24525	 83466	 0.016111	 0.021174	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24526	 24527	 0.011784	 0.00867	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24526	 24536	 0.048845	 0.038656	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24527	 24528	 0.011682	 0.009156	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24527	 24529	 0.018651	 0.01476	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24528	 24535	 0.011652	 0.009221	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24529	 24531	 0.033815	 0.026506	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24529	 24534	 0.016522	 0.013076	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24529	 24698	 0.028083	 0.022225	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24530	 24534	 0.024817	 0.019639	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24530	 24700	 0.01694	 0.013279	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24531	 24536	 0.018629	 0.024484	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24531	 83403	 0.005215	 0.023238	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24532	 24533	 0.011622	 0.008402	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83394	 24532	 0.020741	 0.013428	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24533	 24534	 0.011635	 0.008411	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24535	 24536	 0.014297	 0.011314	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24536	 24537	 0.010673	 0.008446	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83394	 24536	 0.020837	 0.01649	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83394	 24537	 0.014595	 0.009449	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24538	 24539	 0.000905	 0.003559	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83357	 24539	 0.001845	 0.007178	 0.00192	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24539	 83395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24539	 83395	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83395	 24540	 0.016373	 0.012046	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24541	 24542	 0.003647	 0.005821	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83395	 24541	 0.007686	 0.019758	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24542	 24544	 0.016801	 0.014359	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24543	 24544	 0.018108	 0.01309	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24544	 24545	 0.018823	 0.013849	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83343	 24544	 0.022158	 0.016302	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24546	 83396	 0.020565	 0.016275	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24547	 83396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24547	 83396	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24548	 24549	 0.005	 0.006507	 9e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83396	 24548	 0.00695	 0.01376	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24549	 24550	 0.021279	 0.016839	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24550	 24551	 0.014246	 0.011274	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24551	 24552	 0.009956	 0.006687	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24553	 24554	 0.018703	 0.014801	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83396	 24553	 0.00939	 0.016877	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24555	 24558	 0.011392	 0.007653	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24556	 24557	 0.004332	 0.008576	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24556	 24566	 0.008381	 0.015123	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83353	 24556	 0.012222	 0.031419	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24557	 24558	 0.003315	 0.008523	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24558	 24559	 0.002597	 0.006675	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83353	 24559	 0.002372	 0.012637	 0.00022	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24560	 24848	 0.004117	 0.010583	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24561	 24565	 0.014769	 0.009561	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24562	 24563	 0.008482	 0.006132	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24563	 24565	 0.006761	 0.013386	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24564	 24567	 0.010578	 0.007647	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24565	 24567	 0.007184	 0.010771	 0.0002	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24566	 24567	 0.015605	 0.012349	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24568	 24569	 0.000711	 0.00244	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24568	 83397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24568	 83397	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24569	 24591	 0.00129	 0.00525	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24570	 24571	 0.006471	 0.012813	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24570	 83405	 0.004868	 0.012903	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24572	 83398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24572	 83398	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24572	 83400	 0.002106	 0.007097	 0.00176	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24573	 24574	 0.017838	 0.015246	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83398	 24573	 0.006703	 0.015561	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24573	 83406	 0.008655	 0.016961	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24574	 83401	 0.014866	 0.015641	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24575	 83399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24575	 83399	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24575	 83400	 0.000919	 0.00368	 0.00093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24576	 24790	 0.000567	 0.006589	 0.05696	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24576	 83400	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24576	 83412	 0.000237	 0.002691	 0.02431	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24577	 24705	 0.003119	 0.010869	 0.00252	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83400	 24577	 0.001116	 0.00364	 0.00097	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24577	 83402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24577	 83402	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24578	 24611	 0.002421	 0.008766	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24578	 24765	 0.005337	 0.017408	 0.00462	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83400	 24578	 0.000771	 0.003538	 0.00091	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24578	 83403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24578	 83403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83403	 24579	 0.006737	 0.013339	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24580	 24701	 0.003233	 0.009173	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83403	 24580	 0.003059	 0.010926	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83402	 24581	 0.017565	 0.013901	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24582	 24583	 0.013654	 0.017946	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24582	 83405	 0.023384	 0.018329	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24583	 24590	 0.006429	 0.015956	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83195	 24583	 0.022809	 0.018051	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24584	 24589	 0.005799	 0.016455	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83195	 24584	 0.02711	 0.021455	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24585	 24587	 0.00646	 0.018527	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24586	 83404	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24586	 83404	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24586	 83413	 0.005294	 0.018162	 0.00435	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24587	 83408	 0.004114	 0.015826	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24588	 24589	 0.005773	 0.01526	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24588	 24595	 0.004848	 0.014592	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24590	 83407	 0.004912	 0.016209	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24591	 24592	 0.000521	 0.003926	 0.00109	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24591	 83405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24591	 83405	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24592	 24593	 0.000451	 0.003789	 0.00112	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24592	 83406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24592	 83406	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24593	 83407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24593	 83407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24593	 83410	 0.000505	 0.005355	 0.00159	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24594	 24595	 0.009476	 0.017097	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24594	 83411	 0.008808	 0.014059	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24595	 83409	 0.009973	 0.017926	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24596	 24599	 0.001772	 0.004942	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24596	 83408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24596	 83408	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24597	 24598	 0.022557	 0.017851	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83408	 24597	 0.023625	 0.018696	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83408	 24598	 0.031938	 0.025276	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24598	 83409	 0.034089	 0.026977	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24598	 83432	 0.076347	 0.060421	 0.00076	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24599	 83409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24599	 83409	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24599	 83413	 0.001775	 0.00609	 0.00146	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24600	 83410	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24600	 83412	 6.4e-05	 0.000742	 0.00651	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24601	 24602	 0.004084	 0.012528	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83407	 24601	 0.007325	 0.01362	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83411	 24601	 0.003089	 0.012255	 0.00035	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83401	 24602	 0.01449	 0.025482	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83406	 24602	 0.009707	 0.017515	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24603	 25669	 0.000417	 0.010617	 4.6849	 5108.0	 5363.4	 5618.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24603	 83412	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24603	 83412	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24603	 83412	 0.00014	 0.011199	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24604	 24627	 0.001948	 0.004694	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24604	 83415	 0.001648	 0.004859	 0.00113	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24605	 24632	 0.000322	 0.00372	 0.03261	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83412	 24605	 0.000106	 0.001219	 0.01068	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24605	 83415	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24606	 24607	 0.02125	 0.015361	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24607	 24608	 0.002042	 0.007854	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24607	 24670	 0.035407	 0.027754	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83414	 24607	 0.002235	 0.013743	 0.00025	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24608	 83437	 0.003564	 0.01048	 0.00021	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24609	 24611	 0.000556	 0.003934	 0.00108	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83413	 24609	 0.000618	 0.006628	 0.00173	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24609	 83417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24609	 83417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83417	 24610	 0.011667	 0.009145	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24611	 83418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24611	 83418	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24612	 24666	 0.003099	 0.009508	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83418	 24612	 0.001546	 0.007167	 0.00015	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24613	 24614	 0.016778	 0.028264	 0.0004	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24613	 24618	 0.031507	 0.024934	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24614	 24615	 0.021774	 0.014096	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83404	 24614	 0.013976	 0.027671	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24615	 24616	 0.01656	 0.018214	 0.00024	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24616	 83419	 0.00891	 0.020469	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24617	 83420	 0.015833	 0.02944	 0.00069	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24618	 83420	 0.0179	 0.03383	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24619	 24624	 0.001418	 0.003416	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83413	 24619	 0.004859	 0.016209	 0.00411	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24619	 83419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24619	 83419	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83413	 24620	 0.011634	 0.030748	 0.0072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24620	 83420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24620	 83420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83420	 24621	 0.03974	 0.03115	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24621	 83429	 0.04623	 0.036586	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24622	 24625	 0.011911	 0.021492	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83420	 24622	 0.009545	 0.017483	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24623	 24626	 0.028067	 0.018171	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24624	 83421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24624	 83421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24624	 83423	 0.003495	 0.009237	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83421	 24625	 0.009484	 0.013217	 0.00023	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83421	 24626	 0.023471	 0.015195	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24626	 83422	 0.016677	 0.016725	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24626	 83424	 0.037546	 0.02943	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24627	 24628	 0.001421	 0.003868	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24628	 83422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24628	 83422	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24628	 83423	 0.001242	 0.003381	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24629	 24653	 0.018641	 0.014612	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83421	 24629	 0.054641	 0.0395	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24629	 83424	 0.02361	 0.01737	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24630	 24662	 0.000338	 0.003711	 0.03605	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83412	 24630	 0.000287	 0.003315	 0.02906	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24630	 83423	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83423	 24631	 0.002012	 0.005223	 0.00127	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24631	 83425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24631	 83425	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24631	 83426	 0.001808	 0.004921	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24632	 24641	 8.9e-05	 0.000989	 0.00942	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24632	 83426	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24633	 24639	 0.0079	 0.015642	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83425	 24633	 0.009094	 0.016346	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24634	 24635	 0.011692	 0.009164	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24634	 24639	 0.01009	 0.010192	 0.00013	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24636	 24637	 0.02022	 0.014877	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24636	 24638	 0.008421	 0.015135	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83424	 24636	 0.005067	 0.014901	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24637	 83431	 0.021684	 0.01716	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24638	 24639	 0.027454	 0.021727	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24638	 24648	 0.023293	 0.018258	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24639	 24640	 0.011706	 0.009264	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24639	 24647	 0.012216	 0.022041	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83424	 24639	 0.012941	 0.03004	 0.00057	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24641	 83428	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24642	 24643	 0.006435	 0.013169	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24642	 24644	 0.018254	 0.027963	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83427	 24642	 0.013146	 0.027629	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83429	 24642	 0.010176	 0.023083	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24643	 24644	 0.035577	 0.023032	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24643	 24646	 0.013147	 0.025765	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24644	 24645	 0.034933	 0.027645	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24644	 24647	 0.029785	 0.023571	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24645	 24646	 0.035612	 0.023055	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24645	 83430	 0.040602	 0.026286	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24645	 83481	 0.059693	 0.047241	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24647	 24649	 0.026733	 0.019668	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24647	 83430	 0.049998	 0.035416	 0.00056	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24648	 24651	 0.029111	 0.022818	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24649	 83430	 0.023333	 0.018466	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24650	 24661	 0.004298	 0.011359	 0.00266	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24650	 24812	 0.00543	 0.013958	 0.00346	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24650	 83430	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24650	 83430	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24651	 83433	 0.035135	 0.022747	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24651	 83434	 0.027189	 0.021312	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24652	 24655	 0.001856	 0.004904	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83413	 24652	 0.005456	 0.018717	 0.00448	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24652	 83431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24652	 83431	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24653	 83432	 0.018577	 0.020432	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83415	 24654	 0.001281	 0.004637	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24654	 83432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24654	 83432	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24655	 24661	 0.002446	 0.006465	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24655	 83433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24655	 83433	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24656	 24674	 0.026606	 0.020855	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83433	 24656	 0.017443	 0.013804	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24656	 83434	 0.018421	 0.014578	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24657	 24658	 0.006466	 0.010892	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24657	 24677	 0.011452	 0.015051	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24657	 24678	 0.017215	 0.012665	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24657	 83441	 0.015331	 0.021366	 0.00037	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24657	 83444	 0.027375	 0.017723	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24658	 24676	 0.014313	 0.011327	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24658	 24686	 0.018516	 0.014653	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24659	 24677	 0.012077	 0.008555	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24660	 24675	 0.015205	 0.010771	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24660	 83436	 0.009027	 0.017872	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24661	 83434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24661	 83434	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24662	 24807	 0.000365	 0.004245	 0.0367	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83412	 24662	 0.000441	 0.004835	 0.04696	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24662	 83435	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24663	 24664	 0.012668	 0.013933	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24663	 24677	 0.031255	 0.024734	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24663	 24803	 0.022703	 0.017966	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83436	 24663	 0.010715	 0.024305	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24664	 24678	 0.039039	 0.030895	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24664	 24803	 0.029682	 0.021457	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24665	 24694	 0.005818	 0.008824	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24665	 24695	 0.02135	 0.013822	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24665	 24802	 0.031654	 0.02505	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24666	 24681	 0.006619	 0.012124	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24666	 24702	 0.008698	 0.017046	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24666	 83437	 0.00595	 0.028999	 0.00054	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24666	 83438	 0.010983	 0.021745	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24667	 24668	 0.005412	 0.010365	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83417	 24667	 0.005801	 0.016639	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83418	 24667	 0.033032	 0.026141	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24668	 83439	 0.012879	 0.013009	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24669	 24684	 0.000834	 0.004321	 0.00105	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83413	 24669	 0.000931	 0.007553	 0.0024	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24669	 83437	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24669	 83437	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83432	 24670	 0.025305	 0.017925	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24671	 24672	 0.025015	 0.018404	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24671	 24685	 0.008189	 0.014999	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83416	 24671	 0.011371	 0.034224	 0.00067	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24671	 83440	 0.021586	 0.01692	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24672	 24673	 0.019544	 0.015467	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24673	 24674	 0.016552	 0.016902	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24673	 24680	 0.005469	 0.014058	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24674	 24675	 0.018482	 0.013598	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24674	 24676	 0.007829	 0.01434	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83431	 24674	 0.019575	 0.029987	 0.00042	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83434	 24675	 0.027689	 0.017926	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24678	 83444	 0.011656	 0.009225	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83432	 24679	 0.017704	 0.011461	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83431	 24680	 0.025596	 0.020256	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83432	 24680	 0.00359	 0.017519	 0.0003	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24681	 83438	 0.004364	 0.00864	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24682	 24688	 0.000904	 0.002461	 0.00054	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24682	 83438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24682	 83438	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24683	 24684	 0.001133	 0.003817	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24683	 24687	 0.00114	 0.003719	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24683	 24693	 0.003305	 0.009745	 0.00227	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24683	 83439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24683	 83439	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24684	 83440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24684	 83440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24685	 24686	 0.005313	 0.00829	 0.00014	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24687	 24693	 0.001983	 0.005743	 0.00139	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24687	 83441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24687	 83441	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24688	 83442	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24688	 83442	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24689	 24691	 0.027128	 0.021468	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83442	 24689	 0.008984	 0.009074	 0.00012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24690	 24696	 0.00223	 0.005986	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24690	 24713	 0.001454	 0.003738	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24690	 83443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24690	 83443	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24691	 24692	 0.008817	 0.013372	 0.00019	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83443	 24691	 0.011838	 0.008709	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24691	 83445	 0.029237	 0.021135	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24692	 24695	 0.029213	 0.018913	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24692	 83444	 0.00477	 0.011295	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24693	 24784	 0.005229	 0.01382	 0.00323	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24693	 83444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24693	 83444	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24694	 24802	 0.030656	 0.033718	 0.00045	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83444	 24694	 0.007973	 0.017022	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24695	 83445	 0.017268	 0.013665	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24696	 24707	 0.001354	 0.003634	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24696	 83445	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24696	 83445	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83445	 24697	 0.011738	 0.008636	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24698	 24699	 0.020934	 0.013552	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24698	 83466	 0.028367	 0.022449	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24699	 24700	 0.017778	 0.014633	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24699	 24726	 0.025126	 0.018163	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24700	 24701	 0.004736	 0.012044	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24701	 24702	 0.01012	 0.01826	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24701	 24703	 0.00861	 0.008635	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24703	 24704	 0.017395	 0.012798	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24704	 24726	 0.01165	 0.018595	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24704	 83446	 0.008756	 0.016549	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24705	 24712	 0.001224	 0.003236	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24705	 83446	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24705	 83446	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24706	 24726	 0.04589	 0.036317	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24706	 24732	 0.017468	 0.011734	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83443	 24706	 0.003634	 0.008605	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24707	 24784	 0.000898	 0.003174	 0.00072	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24708	 24732	 0.013032	 0.015887	 0.00025	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24708	 83471	 0.00764	 0.019429	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24709	 24733	 0.017511	 0.013858	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24709	 83470	 0.020648	 0.01634	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24710	 24711	 0.00122	 0.003277	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24710	 24783	 0.001691	 0.004604	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24711	 83447	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24711	 83447	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24712	 24713	 0.000806	 0.001871	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24713	 83448	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24713	 83448	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24714	 83454	 0.012166	 0.009537	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24714	 83455	 0.009468	 0.009668	 0.00015	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24715	 24725	 0.017404	 0.013773	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24715	 83455	 0.008282	 0.011542	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24716	 24717	 0.000123	 0.001347	 0.01308	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24716	 83449	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24717	 83451	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83392	 24718	 0.011486	 0.00909	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24718	 83454	 0.026696	 0.020925	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83452	 24719	 0.016599	 0.013136	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24720	 24721	 0.000837	 0.002173	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24720	 24722	 0.002296	 0.005329	 0.00162	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24720	 83453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24720	 83453	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24721	 24722	 0.001743	 0.004481	 0.00111	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24721	 83454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24721	 83454	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83449	 24722	 0.001357	 0.006045	 0.00164	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24722	 83455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24722	 83455	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24723	 24724	 0.018252	 0.018435	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83452	 24723	 0.045014	 0.032541	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83455	 24723	 0.011867	 0.009391	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24724	 83458	 0.03637	 0.028783	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24724	 83495	 0.007355	 0.021094	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24725	 83458	 0.05173	 0.03349	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24725	 83495	 0.018017	 0.041829	 0.00062	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24726	 24727	 0.016727	 0.013112	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24726	 24728	 0.022713	 0.017422	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24728	 24729	 0.021165	 0.016749	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24729	 24730	 0.012358	 0.009092	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24729	 24731	 0.016715	 0.013228	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24729	 83456	 0.017814	 0.024827	 0.00042	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24730	 24731	 0.016844	 0.012392	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24730	 83466	 0.027593	 0.0276	 0.00037	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24731	 24732	 0.008304	 0.013612	 0.00024	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24731	 24733	 0.012831	 0.010057	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24734	 24737	 0.002287	 0.006559	 0.00161	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24734	 24765	 0.002529	 0.006566	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24734	 83456	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24734	 83456	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24735	 24736	 0.001133	 0.002629	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24735	 83457	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24735	 83457	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24736	 83458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24736	 83458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24737	 24782	 0.010249	 0.027087	 0.00634	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24737	 83459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24737	 83459	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24737	 83461	 0.001325	 0.005036	 0.00141	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24738	 24739	 0.026346	 0.017057	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24738	 83462	 0.006031	 0.022623	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24739	 24740	 0.017939	 0.011614	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24739	 24787	 0.02156	 0.013958	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83447	 24739	 0.022198	 0.016332	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24740	 24741	 0.011346	 0.008979	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24740	 24788	 0.019604	 0.015514	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24741	 24748	 0.02511	 0.019872	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24742	 24748	 0.012803	 0.008289	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24743	 24744	 0.018004	 0.013015	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24743	 24753	 0.020687	 0.016371	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24743	 24778	 0.024354	 0.017918	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24745	 83465	 0.020256	 0.013114	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24746	 24747	 0.012661	 0.008197	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24746	 83465	 0.026416	 0.026681	 0.00035	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24747	 24749	 0.027296	 0.021396	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24747	 83462	 0.00753	 0.017481	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24748	 24749	 0.003324	 0.008454	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24749	 24750	 0.00447	 0.010377	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24749	 24753	 0.01828	 0.014329	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24750	 83460	 0.003301	 0.008555	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24751	 24763	 0.001006	 0.002658	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24751	 24774	 0.005135	 0.013786	 0.00312	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24751	 83460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24751	 83460	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24752	 24755	 0.010768	 0.007784	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83460	 24752	 0.015348	 0.012147	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24753	 24754	 0.015003	 0.01176	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24753	 24780	 0.044735	 0.033893	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24754	 24777	 0.004734	 0.009374	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24755	 24768	 0.012542	 0.012579	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24755	 24769	 0.012479	 0.008079	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24756	 24854	 7.1e-05	 0.000825	 0.00723	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24756	 83461	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24756	 83461	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81944	 24757	 0.003555	 0.009395	 0.0022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83373	 24757	 0.002437	 0.006327	 0.00154	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83461	 24757	 0.001356	 0.003584	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24757	 83462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24757	 83462	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24757	 83487	 0.016738	 0.038858	 0.01184	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24758	 24759	 0.00545	 0.0087	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24758	 83494	 0.002813	 0.008628	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24759	 83463	 0.011636	 0.009209	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24760	 24762	 0.001577	 0.004399	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24760	 83463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24760	 83463	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24761	 24764	 0.001428	 0.003981	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24761	 83493	 0.002023	 0.006818	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24762	 24763	 0.001501	 0.003966	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24762	 83464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24762	 83464	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24763	 24764	 0.000805	 0.002191	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24763	 83465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24763	 83465	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24765	 83466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24765	 83466	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24766	 83467	 0.000905	 0.048849	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24766	 83467	 0.000905	 0.048849	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83460	 24767	 0.005544	 0.012872	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83467	 24767	 0.00469	 0.012055	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24768	 24769	 0.005481	 0.010852	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24768	 24771	 0.019075	 0.013511	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83467	 24768	 0.001913	 0.01019	 0.00018	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24769	 24777	 0.005958	 0.00951	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24770	 24771	 0.007121	 0.008524	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24770	 24780	 0.013433	 0.010631	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24771	 24772	 0.014079	 0.011035	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24772	 24773	 0.022547	 0.017843	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83467	 24772	 0.005957	 0.015439	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24772	 83468	 0.031055	 0.020105	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24773	 83468	 0.017154	 0.013575	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24774	 24837	 0.001607	 0.004374	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24774	 83468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24774	 83468	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24775	 24778	 0.021043	 0.016653	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24775	 24779	 0.007333	 0.014519	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24776	 83469	 0.021386	 0.016925	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24777	 24780	 0.017503	 0.012878	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24778	 83476	 0.047816	 0.037481	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24779	 24780	 0.015335	 0.012021	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24779	 83469	 0.005415	 0.012569	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24779	 83489	 0.025261	 0.032874	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83468	 24780	 0.028289	 0.0217	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83468	 24781	 0.016664	 0.013188	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24781	 83469	 0.006486	 0.010353	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24782	 24838	 0.001616	 0.004195	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24782	 24839	 0.003213	 0.008626	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24782	 83469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24782	 83469	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24783	 83470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24783	 83470	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24784	 83471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24784	 83471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24784	 83473	 0.001518	 0.005208	 0.00125	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24785	 83472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24785	 83472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24785	 83473	 0.000859	 0.002946	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24786	 24789	 0.012763	 0.010101	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83470	 24786	 0.019225	 0.015214	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24787	 24793	 0.03374	 0.025563	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24788	 24793	 0.017805	 0.013099	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24789	 24795	 0.041213	 0.026681	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24790	 24796	 0.000111	 0.001239	 0.01168	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24790	 83473	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83474	 24791	 0.020046	 0.015187	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24791	 83475	 0.01647	 0.014758	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24792	 24793	 0.023358	 0.017917	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24792	 24795	 0.023451	 0.018559	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24793	 24794	 0.016589	 0.016638	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24793	 83476	 0.017937	 0.035513	 0.00052	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24794	 83476	 0.009405	 0.018621	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24795	 24799	 0.018301	 0.032893	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24796	 24807	 9.3e-05	 0.001076	 0.00943	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24796	 24828	 0.0004	 0.004531	 0.04126	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24796	 83475	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24796	 83475	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24797	 24800	 0.02577	 0.018629	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83475	 24797	 0.008758	 0.015403	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83473	 24798	 0.005415	 0.014311	 0.00335	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24798	 83476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24798	 83476	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24798	 83484	 0.008196	 0.021661	 0.00507	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83476	 24799	 0.023202	 0.018362	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24799	 83482	 0.007089	 0.027275	 0.00047	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24800	 24821	 0.034374	 0.027203	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24801	 24823	 0.037549	 0.027626	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24801	 83478	 0.025733	 0.033821	 0.00046	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83445	 24802	 0.055441	 0.035893	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24802	 83478	 0.017285	 0.049049	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24803	 24804	 0.029917	 0.021192	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24804	 24851	 0.047708	 0.0351	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24804	 83477	 0.027802	 0.035383	 0.00052	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24805	 24806	 0.002736	 0.007925	 0.00191	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83435	 24805	 0.001305	 0.006176	 0.00148	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24806	 83477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24806	 83477	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24807	 24822	 0.000307	 0.003538	 0.03102	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24807	 83478	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24807	 83478	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24808	 24815	 0.012589	 0.033278	 0.0006	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24808	 24819	 0.089773	 0.071047	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83477	 24808	 0.007385	 0.028411	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83478	 24808	 0.046321	 0.083581	 0.00121	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24809	 24810	 0.004235	 0.014968	 0.00337	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24809	 83479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24809	 83479	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24810	 24812	 0.005133	 0.013564	 0.00317	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83413	 24810	 0.015833	 0.043111	 0.0095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24810	 83480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24810	 83480	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83479	 24811	 0.017337	 0.031754	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83480	 24811	 0.034459	 0.02727	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24812	 83481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24812	 83481	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24813	 24814	 0.01145	 0.029434	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83481	 24813	 0.010137	 0.023182	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81966	 24814	 0.010445	 0.029958	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83479	 24815	 0.010895	 0.028006	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83480	 24815	 0.061902	 0.062523	 0.00083	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24816	 24817	 0.026763	 0.048103	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81966	 24817	 0.011231	 0.043692	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24818	 24819	 0.074001	 0.05242	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24818	 24820	 0.028241	 0.047573	 0.00068	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83102	 24819	 0.10201	 0.13276	 0.00186	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24820	 24824	 0.020283	 0.038333	 0.00062	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24821	 83482	 0.01061	 0.01702	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24822	 24828	 0.000144	 0.001667	 0.01461	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24822	 83482	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24822	 83482	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83482	 24823	 0.028361	 0.043447	 0.00061	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24824	 83483	 0.005786	 0.019301	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24825	 83483	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24825	 83483	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24825	 83484	 0.002907	 0.007915	 0.00174	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24826	 24830	 0.047634	 0.037697	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83101	 24826	 0.16197	 0.12697	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24826	 83491	 0.015979	 0.022269	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24827	 83491	 0.057029	 0.043745	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24828	 24836	 6.9e-05	 0.000758	 0.00736	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24828	 83484	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83483	 24829	 0.028246	 0.020782	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83485	 24829	 0.032157	 0.025448	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83483	 24830	 0.022867	 0.01653	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83485	 24830	 0.029446	 0.023303	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24831	 24842	 0.019511	 0.02146	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83468	 24831	 0.033636	 0.03592	 0.00076	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83485	 24831	 0.072145	 0.05534	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24831	 83486	 0.006427	 0.014699	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24831	 83490	 0.030058	 0.023561	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24832	 24839	 0.001288	 0.004338	 0.00108	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24832	 83486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24832	 83486	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24832	 83487	 0.001252	 0.006523	 0.00171	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83486	 24833	 0.017143	 0.013567	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83486	 24834	 0.016055	 0.016216	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24834	 83488	 0.007789	 0.01135	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24835	 24836	 5.4e-05	 0.000625	 0.00547	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24835	 83487	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 -1.0	 1	 -30.0	 30.0;
	24835	 83487	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 -1.0	 1	 -30.0	 30.0;
	24836	 83488	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24836	 83488	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81955	 24837	 0.003034	 0.016067	 0.00407	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24838	 24839	 0.001609	 0.004177	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24838	 83489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24838	 83489	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83484	 24839	 0.003963	 0.010473	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24839	 83490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24839	 83490	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81956	 24840	 0.014637	 0.024656	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24840	 83491	 0.056572	 0.044344	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24841	 24842	 0.011946	 0.021554	 0.00031	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81956	 24841	 0.019762	 0.031544	 0.00073	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24843	 24844	 0.004238	 0.011201	 0.00262	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81955	 24843	 0.002622	 0.008551	 0.00227	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24843	 83491	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24843	 83491	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24845	 24846	 0.001733	 0.004456	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83484	 24845	 0.003681	 0.012629	 0.00303	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24847	 83492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24847	 83492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83353	 24848	 0.00974	 0.025038	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83359	 24848	 0.005566	 0.015794	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83358	 24849	 0.00486	 0.018907	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83364	 24850	 0.014659	 0.010785	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83478	 24851	 0.007979	 0.025586	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24853	 83493	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24854	 83495	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24854	 83495	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81975	 24855	 0.000446	 0.001986	 3e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82869	 24856	 0.0281	 0.099361	 0.0224	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24856	 83496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24856	 83496	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24856	 83497	 0.011318	 0.043023	 0.01204	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82758	 24857	 0.15248	 0.36123	 0.00661	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83496	 24857	 0.20836	 0.20845	 0.00282	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24858	 24859	 0.009499	 0.037335	 0.00977	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24860	 83497	 0.000491	 0.006288	 0.00188	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24861	 83498	 0.00694	 0.023151	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24862	 83497	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83497	 24863	 0.00089	 0.003113	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24864	 24865	 0.000645	 0.007079	 0.06877	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24864	 27296	 0.001844	 0.021301	 0.18691	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24864	 83499	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24864	 83499	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24865	 26413	 0.000486	 0.005333	 0.05181	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24865	 83500	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24865	 83500	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24866	 83501	 0.22993	 0.18026	 0.00231	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24866	 83555	 0.25739	 0.16668	 0.00317	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82004	 24867	 0.10733	 0.10544	 0.00178	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82004	 24868	 0.021818	 0.12259	 0.00227	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24868	 84442	 0.043437	 0.19032	 0.00409	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24869	 27337	 0.001962	 0.021958	 0.20537	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81996	 24869	 0.002209	 0.025519	 0.22402	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82006	 24869	 0.000212	 0.003826	 0.06038	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24869	 83501	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24869	 83501	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24870	 24878	 0.002574	 0.038523	 0.01295	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24870	 26386	 0.00302	 0.025127	 0.00761	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24870	 27257	 0.009528	 0.031077	 0.00825	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24871	 83506	 0.040508	 0.10302	 0.00163	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24872	 24876	 0.084693	 0.054832	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24873	 83502	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24873	 83502	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24873	 83508	 0.00043	 0.00585	 0.06027	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24874	 24900	 0.057232	 0.091356	 0.0021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24874	 24901	 0.057582	 0.10127	 0.0019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24874	 83510	 0.030174	 0.070052	 0.00104	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24875	 24892	 0.001418	 0.005135	 0.0011	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24875	 83503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24875	 83503	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24875	 83509	 0.0021	 0.008407	 0.00212	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24876	 83513	 0.012254	 0.031164	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24877	 83504	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24877	 83508	 0.000307	 0.003432	 0.03206	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24878	 26376	 0.016094	 0.10198	 0.0277	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83504	 24878	 0.000827	 0.007325	 0.00402	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24878	 83506	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24878	 83506	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24878	 83514	 0.00134	 0.010505	 0.0048	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83506	 24879	 0.1244	 0.098451	 0.00124	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24880	 24899	 0.000505	 0.005624	 0.05304	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24880	 25119	 0.002953	 0.034138	 0.30002	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24880	 83507	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24880	 83507	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24881	 24954	 0.002601	 0.023707	 0.00861	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24881	 83520	 0.001106	 0.011934	 0.00342	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24882	 83508	 0.000129	 0.010315	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24882	 83508	 0.000129	 0.010315	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24882	 83508	 0.000129	 0.010315	 0.0	 1900.0	 1900.0	 1900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24883	 27128	 0.004396	 0.049133	 0.46596	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83508	 24883	 0.00015	 0.001729	 0.01516	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24883	 83511	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83510	 24884	 0.040138	 0.031764	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24885	 24957	 0.13802	 0.11362	 0.0023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83510	 24885	 0.031337	 0.056325	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24886	 83513	 0.018197	 0.014401	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24887	 24891	 0.000656	 0.002626	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24887	 24902	 0.001618	 0.004201	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83504	 24887	 0.002991	 0.01083	 0.00232	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24887	 83513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24887	 83513	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24888	 24902	 0.001323	 0.003832	 0.00092	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83504	 24888	 0.002846	 0.00775	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24889	 24896	 9.7e-05	 0.00112	 0.00982	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24889	 24897	 5.1e-05	 0.000565	 0.00528	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24889	 83514	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24889	 83514	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24890	 83516	 0.008225	 0.016284	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24890	 83518	 0.005875	 0.008561	 0.00019	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24891	 24892	 0.001329	 0.004132	 0.00086	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24891	 83515	 0.001795	 0.004513	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24893	 24894	 0.014285	 0.011305	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83503	 24893	 0.020801	 0.016304	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24894	 24895	 0.004267	 0.007934	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83510	 24894	 0.008142	 0.020931	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83513	 24895	 0.010665	 0.020902	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24895	 83516	 0.011681	 0.011798	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83508	 24896	 0.0001	 0.0011	 0.01068	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24896	 83515	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24897	 24899	 7.4e-05	 0.000851	 0.00746	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24897	 83517	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83517	 24898	 0.000762	 0.002014	 0.00047	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24898	 83519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24898	 83519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83508	 24899	 0.000147	 0.001696	 0.01487	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24899	 83520	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24900	 24901	 0.079026	 0.057129	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24900	 84578	 0.020065	 0.051579	 0.0008	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24901	 84578	 0.024265	 0.06629	 0.00113	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83515	 24902	 0.001528	 0.005243	 0.00126	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24903	 26920	 0.073865	 0.1353	 0.00234	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24903	 83523	 0.042295	 0.10873	 0.00168	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24903	 84422	 0.12965	 0.25414	 0.00381	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24903	 84616	 0.059811	 0.095474	 0.0022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24904	 26442	 0.016032	 0.043653	 0.00962	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24904	 83522	 0.01229	 0.033461	 0.00737	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24905	 24908	 0.022102	 0.039726	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24905	 83523	 0.099352	 0.078628	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24906	 27277	 0.000977	 0.010725	 0.1042	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24906	 27739	 0.001102	 0.012099	 0.11756	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24906	 83522	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24907	 24909	 0.071961	 0.056949	 0.00072	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83523	 24907	 0.047507	 0.03644	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24907	 83524	 0.069033	 0.054633	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24908	 24909	 0.06778	 0.053641	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24908	 84417	 0.023887	 0.076601	 0.0019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24909	 83524	 0.093829	 0.074257	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24909	 84417	 0.033507	 0.088578	 0.00161	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24910	 24911	 0.010901	 0.028024	 0.00694	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83522	 24910	 0.005484	 0.014723	 0.00334	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24910	 83524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24910	 83524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24911	 27750	 0.013071	 0.034545	 0.00809	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24912	 26425	 0.016617	 0.054205	 0.01439	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24912	 27276	 0.010521	 0.027315	 0.00663	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24912	 83525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24912	 83525	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24913	 84097	 0.053612	 0.10972	 0.0027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24913	 84117	 0.068059	 0.19522	 0.003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24914	 83526	 0.001396	 0.003963	 6e-05	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24915	 83526	 0.010875	 0.019621	 0.00028	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24916	 83526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24916	 83526	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24916	 83527	 0.008216	 0.036993	 0.00984	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24917	 24935	 0.063668	 0.12034	 0.00195	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83526	 24917	 0.021175	 0.06496	 0.00176	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24917	 83528	 0.011157	 0.05802	 0.00126	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24918	 83527	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24919	 24921	 0.000136	 0.002417	 0.00122	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24919	 24924	 0.000412	 0.006434	 0.0042	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24920	 24926	 0.005843	 0.033215	 0.0006	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24920	 24927	 0.007124	 0.027713	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24920	 24927	 0.007124	 0.027713	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82061	 24920	 0.006161	 0.023702	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82061	 24920	 0.006161	 0.023702	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24920	 83531	 0.01182	 0.027032	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82010	 24921	 0.000363	 0.006441	 0.00324	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24921	 83529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24921	 83529	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83529	 24922	 0.010454	 0.016014	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24923	 24928	 0.001315	 0.01394	 0.00414	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24923	 83530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24923	 83530	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24924	 24934	 0.010781	 0.031785	 0.00739	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81999	 24924	 0.002867	 0.046773	 0.02792	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24924	 83531	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24924	 83531	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24925	 24929	 0.000917	 0.014078	 0.00394	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24925	 83532	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24925	 83532	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83531	 24926	 0.002833	 0.011023	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83531	 24926	 0.002833	 0.011023	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83532	 24926	 0.015223	 0.058565	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83532	 24926	 0.015223	 0.058565	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83532	 24927	 0.022731	 0.081204	 0.00161	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83532	 24927	 0.022731	 0.081204	 0.00161	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24927	 83535	 0.04576	 0.10624	 0.00158	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24928	 24930	 0.001147	 0.012907	 0.00339	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24929	 24930	 0.001733	 0.010977	 0.00298	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24929	 24932	 0.005963	 0.01576	 0.00369	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81999	 24929	 0.002683	 0.041753	 0.01295	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24930	 83533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24930	 83533	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24930	 84142	 0.001294	 0.011882	 0.0102	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24931	 24938	 0.056317	 0.13075	 0.00194	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24931	 83534	 0.038228	 0.098271	 0.00152	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24932	 83534	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24932	 83534	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24933	 83535	 0.15629	 0.12252	 0.00157	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24934	 83535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24934	 83535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24936	 24937	 0.020671	 0.11313	 0.00221	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24936	 27604	 0.029129	 0.11161	 0.00316	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83535	 24937	 0.023315	 0.14641	 0.0032	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24938	 83969	 0.082531	 0.19546	 0.00357	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24939	 24940	 0.000303	 0.003496	 0.03065	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24939	 83536	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24939	 83536	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24940	 24942	 0.00035	 0.003965	 0.0361	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24941	 24945	 0.002459	 0.021181	 0.0123	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24941	 26421	 0.002734	 0.019776	 0.01064	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24942	 83537	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24942	 83537	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24943	 24953	 0.017657	 0.012508	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24944	 24952	 0.001119	 0.003397	 0.00074	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83537	 24944	 0.005189	 0.015299	 0.00356	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24945	 24951	 0.004549	 0.018212	 0.00459	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82001	 24945	 0.006976	 0.059543	 0.05117	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83537	 24945	 0.003785	 0.013189	 0.00306	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24945	 83538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24945	 83538	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24946	 24948	 0.005458	 0.032513	 0.00855	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24946	 24950	 0.002059	 0.017969	 0.00494	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24946	 24952	 0.00431	 0.011733	 0.00258	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24947	 24953	 0.013021	 0.048146	 0.00089	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24947	 27135	 0.081785	 0.27288	 0.00433	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24948	 27734	 0.008127	 0.043303	 0.01215	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24949	 27721	 0.00062	 0.006903	 0.0651	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	24949	 83539	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24949	 83539	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24950	 83540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24950	 83540	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24950	 84268	 0.002915	 0.029205	 0.00972	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24951	 84581	 0.012685	 0.044841	 0.0101	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24952	 83541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24952	 83541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83538	 24953	 0.02771	 0.05824	 0.00106	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83541	 24953	 0.001866	 0.007403	 0.00021	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24954	 26594	 0.003243	 0.027818	 0.00792	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24955	 24956	 0.004904	 0.01296	 0.00303	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24955	 24962	 0.007991	 0.027414	 0.00657	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83511	 24955	 0.006225	 0.020303	 0.00539	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24956	 24959	 0.007448	 0.047179	 0.01281	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24956	 24962	 0.003284	 0.014787	 0.00393	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83511	 24956	 0.009968	 0.034195	 0.00819	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24956	 83542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24956	 83542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83542	 24957	 0.031742	 0.02055	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24958	 24964	 0.010342	 0.026587	 0.00658	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83502	 24958	 0.012622	 0.033359	 0.00781	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24959	 24960	 0.004813	 0.016512	 0.00396	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24959	 24961	 0.011459	 0.029457	 0.00729	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24959	 24964	 0.002808	 0.011882	 0.00267	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24960	 26952	 0.007019	 0.028091	 0.00949	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24960	 83543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24960	 83543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24961	 27359	 0.00747	 0.019743	 0.00462	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24961	 83544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24961	 83544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24962	 27358	 0.00874	 0.031648	 0.00679	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24962	 27361	 0.01847	 0.065296	 0.01472	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24962	 83545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24962	 83545	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83543	 24963	 0.13408	 0.086809	 0.00165	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24963	 83546	 0.008476	 0.019674	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24963	 84274	 0.035071	 0.080209	 0.00196	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24964	 26948	 0.006088	 0.027929	 0.00715	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24964	 83546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24964	 83546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24965	 83553	 0.013726	 0.036283	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24966	 83547	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24967	 26470	 0.016925	 0.081664	 0.00144	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83548	 24967	 0.013443	 0.067236	 0.0012	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24968	 24969	 0.004963	 0.023146	 0.00573	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24968	 24982	 0.003052	 0.03418	 0.01087	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24968	 26397	 0.008217	 0.0329	 0.00829	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24968	 83549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24968	 83549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24969	 24971	 0.004504	 0.025129	 0.00642	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24970	 24983	 0.025802	 0.13053	 0.00227	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24970	 83550	 0.010073	 0.069143	 0.00126	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24971	 83550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24971	 83550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24971	 84365	 0.010219	 0.10144	 0.0276	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83550	 24972	 0.19114	 0.12377	 0.00236	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24973	 26976	 0.38152	 0.30207	 0.0038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24973	 83551	 0.16392	 0.12974	 0.00163	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24974	 24975	 0.000875	 0.012015	 0.00433	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82035	 24974	 0.001039	 0.015136	 0.00484	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24974	 83551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24974	 83551	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83547	 24975	 0.001487	 0.014732	 0.00451	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	24975	 83552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24975	 83552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24976	 24977	 0.002336	 0.009546	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83552	 24976	 0.006324	 0.02423	 0.00068	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24977	 24978	 0.023506	 0.016651	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24979	 24981	 0.000576	 0.004595	 0.00113	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83547	 24979	 0.001766	 0.013533	 0.00363	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24980	 24981	 0.000745	 0.003528	 0.00085	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24980	 26472	 0.004209	 0.018321	 0.00522	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24981	 83553	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24981	 83553	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83547	 24982	 0.002466	 0.02775	 0.00729	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24983	 24984	 0.00793	 0.045078	 0.00082	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83548	 24984	 0.008901	 0.054721	 0.00099	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24985	 24986	 0.07402	 0.1247	 0.00178	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24985	 25182	 0.061816	 0.14352	 0.00213	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24985	 83617	 0.03948	 0.10041	 0.00159	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24986	 83554	 0.069139	 0.17774	 0.00275	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24986	 84091	 0.10608	 0.3011	 0.00473	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24987	 83629	 0.022989	 0.060932	 0.00155	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24988	 24989	 0.002904	 0.022878	 0.00669	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24988	 24992	 0.005884	 0.036516	 0.00885	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24988	 26414	 0.004189	 0.029046	 0.01703	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24988	 83554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24988	 83554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24989	 24990	 0.014135	 0.048493	 0.01162	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82007	 24989	 0.019509	 0.076695	 0.02007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24990	 24992	 0.017382	 0.045942	 0.01075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82007	 24990	 0.004041	 0.032257	 0.00795	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	24990	 83555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24990	 83555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83555	 24991	 0.048774	 0.077855	 0.00179	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	24991	 83556	 0.12967	 0.10164	 0.0013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82007	 24992	 0.018256	 0.071768	 0.01878	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82032	 24992	 0.029154	 0.10309	 0.02324	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	24992	 83556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24992	 83556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83554	 24993	 0.14597	 0.16057	 0.00214	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83556	 24993	 0.034954	 0.089855	 0.00139	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24994	 24995	 0.020149	 0.015455	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24994	 24997	 0.009545	 0.027375	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24994	 83564	 0.006346	 0.016313	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	24996	 24997	 0.017182	 0.013598	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24997	 24998	 0.014139	 0.010221	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24997	 83557	 0.01056	 0.022629	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	24997	 83570	 0.048159	 0.035432	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	24999	 25025	 0.000624	 0.006994	 0.00222	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	24999	 83557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	24999	 83557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25000	 25001	 0.006795	 0.01761	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25000	 25013	 0.003461	 0.019445	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82058	 25000	 0.010907	 0.022414	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25001	 25070	 0.013619	 0.022325	 0.00039	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25001	 25072	 0.031311	 0.061994	 0.00091	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25001	 83560	 0.061501	 0.15811	 0.00245	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25001	 83595	 0.02234	 0.027234	 0.00044	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25002	 25003	 0.000321	 0.003609	 0.00095	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25002	 25069	 0.000287	 0.002484	 0.00089	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25003	 25071	 0.000404	 0.005174	 0.00154	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25003	 83558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25003	 83558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25004	 25005	 0.010915	 0.027091	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25004	 83560	 0.011954	 0.00946	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82233	 25005	 0.031836	 0.16106	 0.0028	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25005	 83559	 0.049312	 0.039025	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25006	 83559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25006	 83559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25006	 83561	 0.002037	 0.005289	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25007	 83560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25007	 83560	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25007	 83561	 0.003258	 0.011798	 0.00253	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25008	 25012	 0.10153	 0.079588	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25008	 25072	 0.035098	 0.080269	 0.00196	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83560	 25008	 0.003351	 0.008615	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25009	 25010	 0.000525	 0.006098	 0.05272	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25009	 27252	 0.000449	 0.007884	 0.08436	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25009	 83561	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25009	 83561	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25010	 26358	 0.000364	 0.004127	 0.03757	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25010	 83562	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25010	 83562	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25011	 83584	 0.10622	 0.084065	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25013	 25014	 0.006602	 0.029417	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82041	 25014	 0.022361	 0.052951	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25015	 25071	 0.000907	 0.013203	 0.00423	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25015	 84070	 0.001658	 0.024376	 0.00745	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25016	 83564	 0.016196	 0.02481	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25017	 25018	 0.000974	 0.006168	 0.00167	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25017	 25023	 0.000535	 0.004167	 0.00125	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25017	 83563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25017	 83563	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25018	 25019	 0.001184	 0.003861	 0.00102	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25018	 83564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25018	 83564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25019	 83565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25019	 83565	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25020	 25021	 0.000528	 0.004799	 0.00121	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25020	 26293	 0.001026	 0.00758	 0.00219	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25020	 83566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25020	 83566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25021	 25022	 0.000781	 0.005852	 0.00143	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25021	 83567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25021	 83567	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25022	 25027	 0.004488	 0.011652	 0.00283	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25022	 83576	 0.00286	 0.007559	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25023	 26290	 0.001289	 0.006355	 0.00172	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25023	 83568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25023	 83568	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83568	 25024	 0.032349	 0.0238	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82040	 25025	 0.001334	 0.012213	 0.00489	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25025	 83569	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25025	 83569	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83569	 25026	 0.023442	 0.037418	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25026	 83570	 0.007186	 0.023715	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25026	 83572	 0.051789	 0.039237	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25027	 83570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25027	 83570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25028	 25030	 0.013453	 0.023659	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25028	 25039	 0.025867	 0.020276	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25028	 83578	 0.008086	 0.022945	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25029	 25030	 0.005289	 0.016225	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25029	 83580	 0.004769	 0.02626	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25030	 25044	 0.046193	 0.032721	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25030	 84594	 0.008421	 0.028092	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25031	 25033	 0.000165	 0.002096	 0.01843	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25031	 25038	 0.000207	 0.002406	 0.0208	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25031	 26309	 0.0004	 0.005041	 0.04914	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25031	 83571	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83572	 25032	 0.00374	 0.014607	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25032	 83578	 0.01677	 0.038352	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25032	 83579	 0.042655	 0.033435	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25033	 25050	 0.000319	 0.005395	 0.06221	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25033	 83573	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25033	 83573	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25034	 83574	 0.015259	 0.030211	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25034	 84593	 0.029068	 0.028555	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25035	 25040	 0.000836	 0.010879	 0.00314	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25035	 83574	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25035	 83574	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25035	 83575	 0.000488	 0.007449	 0.0024	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25036	 25046	 0.000132	 0.00149	 0.01356	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25036	 27712	 0.000522	 0.005813	 0.05482	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25036	 83575	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25036	 83575	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83571	 25037	 0.001763	 0.005751	 0.00153	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25037	 83576	 0.002683	 0.009714	 0.00208	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25038	 83576	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83576	 25040	 0.001445	 0.010708	 0.00549	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25040	 83578	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25040	 83578	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83574	 25041	 0.011536	 0.027516	 0.00062	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83578	 25041	 0.015857	 0.02084	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25041	 83579	 0.009842	 0.028229	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25042	 25043	 0.002419	 0.006587	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25042	 25045	 0.00183	 0.008398	 0.00215	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83576	 25042	 0.000785	 0.006731	 0.00192	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83571	 25043	 0.001604	 0.004729	 0.0011	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25043	 83579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25043	 83579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25044	 26307	 0.02532	 0.027849	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25045	 26313	 0.00276	 0.007295	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25045	 27705	 0.002903	 0.024895	 0.00708	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83576	 25045	 0.001282	 0.011663	 0.00294	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25045	 83580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25045	 83580	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25046	 25063	 0.000184	 0.002124	 0.01862	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25046	 83581	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25047	 25050	 0.000346	 0.00399	 0.03498	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25047	 83583	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25047	 83583	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25048	 25064	 0.002385	 0.007958	 0.00202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25048	 25066	 0.002513	 0.014285	 0.00414	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25048	 83584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25048	 83584	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25048	 83596	 0.000725	 0.007944	 0.0022	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25049	 25066	 0.001641	 0.013183	 0.00371	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25049	 83585	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25049	 83585	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25049	 84582	 0.000888	 0.008064	 0.00263	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25050	 25057	 0.000115	 0.001328	 0.01164	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25050	 25073	 0.000289	 0.004163	 0.0382	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25050	 27128	 0.00043	 0.004717	 0.04582	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25050	 83586	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25050	 83586	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25051	 25054	 0.000362	 0.00405	 0.00129	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25051	 83587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25051	 83587	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25051	 84582	 0.000891	 0.008516	 0.00281	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25052	 25053	 0.000614	 0.005893	 0.00171	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25052	 27718	 0.000859	 0.009104	 0.0027	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25052	 83588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25052	 83588	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25053	 25062	 0.000463	 0.004963	 0.00129	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25054	 25055	 0.000232	 0.002831	 0.00094	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25055	 25059	 0.001327	 0.004806	 0.00103	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25055	 83593	 0.000503	 0.00411	 0.00112	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25056	 25064	 0.002083	 0.007018	 0.00174	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25056	 83589	 0.00076	 0.002608	 0.00062	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25057	 25067	 4.6e-05	 0.0005	 0.00491	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25057	 83589	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25057	 83589	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25058	 83590	 0.019118	 0.01513	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25058	 83594	 0.020035	 0.015856	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25059	 25060	 0.00073	 0.002197	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25060	 25061	 0.000688	 0.002433	 0.00055	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25060	 83590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25060	 83590	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25061	 25062	 0.001357	 0.004653	 0.00111	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25061	 83591	 0.001641	 0.006571	 0.00166	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25061	 83592	 0.000992	 0.003402	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25062	 83592	 0.001066	 0.006039	 0.0015	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25063	 25067	 0.000145	 0.001596	 0.0155	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25063	 83591	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25063	 83591	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25065	 83592	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25065	 83592	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25066	 27253	 0.011033	 0.027735	 0.00719	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25067	 83593	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82058	 25068	 0.000643	 0.002867	 5e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83557	 25068	 0.002859	 0.011121	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25068	 83595	 0.003632	 0.010306	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25069	 83595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25069	 83595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83558	 25070	 0.007786	 0.023909	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25073	 83596	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25073	 83596	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25074	 25078	 0.005782	 0.028059	 0.00641	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25074	 25195	 0.001931	 0.020201	 0.01331	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25074	 83597	 0.001371	 0.02028	 0.00698	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25075	 27427	 0.000273	 0.002996	 0.0291	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25075	 83597	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25075	 83597	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25076	 25077	 0.006142	 0.025359	 0.006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25076	 27451	 0.002888	 0.012867	 0.0035	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83597	 25076	 0.00793	 0.028714	 0.00616	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25077	 25078	 0.005913	 0.03184	 0.00875	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25077	 83598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25077	 83598	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25078	 25079	 0.006586	 0.025886	 0.00677	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25078	 26463	 0.022438	 0.08822	 0.02309	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25078	 83599	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25078	 83599	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25079	 26460	 0.007192	 0.028797	 0.00726	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25080	 26395	 0.025569	 0.11441	 0.00236	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83599	 25080	 0.029109	 0.10192	 0.00282	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25081	 25090	 0.10701	 0.084693	 0.00107	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25081	 84166	 0.21206	 0.16785	 0.00211	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25082	 25086	 0.07772	 0.13093	 0.00187	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25082	 84278	 0.075742	 0.19472	 0.00301	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25083	 25085	 0.005133	 0.013567	 0.00318	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25083	 25087	 0.007106	 0.018268	 0.00452	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25083	 83600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25083	 83600	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83600	 25084	 0.069828	 0.055261	 0.0007	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25084	 83601	 0.02988	 0.0216	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25085	 25088	 0.003319	 0.013289	 0.00335	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25085	 26600	 0.016354	 0.064288	 0.01682	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25085	 83601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25085	 83601	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25086	 25117	 0.025753	 0.13028	 0.00227	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25086	 25118	 0.10819	 0.10822	 0.00146	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83600	 25086	 0.022897	 0.089076	 0.00149	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25087	 26601	 0.011746	 0.031536	 0.00715	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25088	 83602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25088	 83602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25088	 83611	 0.001869	 0.021364	 0.00652	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25089	 25112	 0.14215	 0.10277	 0.00156	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25089	 83612	 0.068519	 0.1463	 0.0033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83602	 25090	 0.027412	 0.15583	 0.00282	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25090	 84574	 0.056895	 0.15041	 0.00273	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25091	 25092	 0.00211	 0.010552	 0.00019	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25091	 25100	 0.00102	 0.0058	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25092	 25093	 0.004707	 0.013499	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25092	 25102	 0.012665	 0.014052	 0.00027	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25093	 25104	 0.005678	 0.016286	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25094	 25095	 0.000527	 0.003188	 0.00081	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25094	 83603	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25094	 83603	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25095	 25096	 0.00062	 0.002624	 0.00059	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25095	 25103	 0.003668	 0.009523	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25096	 25133	 0.000688	 0.003341	 0.00076	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25097	 25133	 0.00025	 0.001335	 0.00037	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25097	 83604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25097	 83604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25098	 25099	 0.002683	 0.014132	 0.00025	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83604	 25098	 0.001953	 0.009878	 0.00017	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25099	 83608	 0.001843	 0.010087	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25100	 83605	 0.001654	 0.009402	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25101	 25110	 0.000705	 0.005868	 0.00178	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25101	 83605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25101	 83605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25102	 83606	 0.009515	 0.015187	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25103	 25130	 0.002304	 0.020103	 0.00552	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25103	 83606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25103	 83606	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25104	 25105	 0.005034	 0.01294	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25104	 25106	 0.008526	 0.018871	 0.00031	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25104	 83609	 0.014997	 0.042556	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25105	 25106	 0.006961	 0.018401	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83603	 25105	 0.003014	 0.011726	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25106	 83609	 0.00596	 0.029808	 0.00053	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25107	 25113	 0.003435	 0.012026	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83603	 25107	 0.002098	 0.014231	 0.00027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25108	 25110	 0.000758	 0.01122	 0.00386	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25108	 25134	 0.000549	 0.005648	 0.0016	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25108	 83607	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25108	 83607	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25109	 25123	 0.026943	 0.077277	 0.00119	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82060	 25109	 0.009318	 0.022807	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25110	 25127	 0.001533	 0.010938	 0.00339	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25110	 83608	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25110	 83608	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25110	 83977	 0.003234	 0.032581	 0.01998	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25111	 25119	 0.000373	 0.004095	 0.03978	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25111	 26141	 0.000745	 0.01182	 0.12416	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25111	 26805	 0.000617	 0.010766	 0.11651	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25111	 27196	 0.001063	 0.018657	 0.19978	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25111	 83609	 0.001096	 0.056989	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25111	 83609	 0.001096	 0.056989	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25112	 25131	 0.028022	 0.084342	 0.00165	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25112	 26804	 0.031818	 0.09126	 0.0014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25113	 25115	 0.010979	 0.017996	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25113	 25120	 0.012857	 0.035612	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25114	 25134	 0.000661	 0.004109	 0.00116	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25114	 83610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25114	 83610	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25114	 83611	 0.003941	 0.015779	 0.00398	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25115	 25120	 0.004374	 0.021874	 0.00039	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83610	 25115	 0.002911	 0.016549	 0.0003	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25116	 25118	 0.016465	 0.038225	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83607	 25116	 0.008125	 0.029026	 0.00058	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25117	 25121	 0.009806	 0.060288	 0.00109	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25119	 83611	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83601	 25120	 0.043611	 0.11529	 0.00209	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83612	 25120	 0.032545	 0.032553	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25121	 25122	 0.026822	 0.028643	 0.00061	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25121	 84286	 0.02162	 0.057302	 0.00145	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25122	 83613	 0.027238	 0.063237	 0.00094	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25123	 83613	 0.028396	 0.058111	 0.00143	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25124	 83613	 0.013119	 0.025975	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25125	 26110	 0.003623	 0.012085	 0.00306	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25125	 83613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25125	 83613	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25126	 25128	 0.000701	 0.006727	 0.00196	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25126	 26110	 0.00086	 0.009112	 0.0027	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25126	 83614	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25126	 83614	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25127	 25129	 0.00103	 0.008775	 0.00219	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25128	 25129	 0.000573	 0.004819	 0.00143	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25129	 83615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25129	 83615	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25130	 26133	 0.005424	 0.031107	 0.01034	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25130	 26135	 0.002884	 0.024732	 0.00704	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25130	 26809	 0.011441	 0.07483	 0.01904	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25131	 25132	 0.034027	 0.086191	 0.00171	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83609	 25131	 0.037894	 0.083871	 0.00138	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25132	 26136	 0.051977	 0.13219	 0.00209	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25133	 83616	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25133	 83616	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25135	 25136	 0.004819	 0.012938	 0.00293	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25135	 25152	 0.009088	 0.038466	 0.00866	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25135	 83617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25135	 83617	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25136	 25137	 0.005692	 0.015042	 0.00352	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25137	 83618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25137	 83618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25137	 83619	 0.006331	 0.015915	 0.00412	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25138	 25142	 0.000151	 0.001739	 0.01525	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25138	 27714	 0.000203	 0.002226	 0.02162	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25138	 83619	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25138	 83619	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83618	 25139	 0.025582	 0.059393	 0.00088	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25139	 83627	 0.029131	 0.059615	 0.00147	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25140	 25141	 0.001929	 0.005252	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25140	 26335	 0.002268	 0.005993	 0.0014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25141	 83620	 0.003193	 0.008439	 0.00198	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25142	 25149	 0.00017	 0.001926	 0.01753	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25142	 83620	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25142	 83620	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25143	 25148	 0.000254	 0.002815	 0.0268	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25143	 26315	 0.000524	 0.005724	 0.0562	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25143	 83621	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25144	 25149	 7.5e-05	 0.000819	 0.00804	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25144	 83623	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83622	 25145	 0.007753	 0.01535	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83624	 25145	 0.012754	 0.019538	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83622	 25146	 0.010875	 0.027956	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83624	 25146	 0.071	 0.056189	 0.00071	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25146	 84055	 0.028981	 0.053081	 0.00092	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25147	 25166	 0.001265	 0.007652	 0.00195	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83623	 25147	 0.004121	 0.013885	 0.00345	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25147	 83625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25147	 83625	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25147	 83626	 0.005026	 0.014016	 0.00294	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25148	 25149	 0.00011	 0.001234	 0.01153	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25148	 83626	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25149	 83628	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25149	 83628	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83628	 25150	 0.043935	 0.033287	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25151	 25154	 0.04302	 0.085177	 0.00125	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83627	 25151	 0.10168	 0.080474	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81997	 25152	 0.007071	 0.060654	 0.01726	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25152	 83629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25152	 83629	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25153	 25154	 0.014542	 0.029759	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83629	 25153	 0.088425	 0.079782	 0.00134	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25154	 83630	 0.007044	 0.04004	 0.00072	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25155	 25156	 0.000641	 0.007331	 0.00224	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25155	 25158	 0.00189	 0.010371	 0.00274	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25155	 83630	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25155	 83630	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25156	 25168	 0.000415	 0.005219	 0.00162	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25157	 26341	 0.000341	 0.004233	 0.03922	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25157	 26346	 0.000223	 0.002529	 0.02303	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25157	 83631	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25158	 25161	 0.001113	 0.00652	 0.00178	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25158	 25162	 0.000489	 0.007186	 0.0022	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83627	 25159	 0.016832	 0.041777	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25159	 83633	 0.007049	 0.016364	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83632	 25160	 0.006909	 0.016037	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25160	 83634	 0.021739	 0.022198	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25161	 25165	 0.001108	 0.009055	 0.00246	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83631	 25161	 0.000496	 0.004389	 0.00241	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83626	 25162	 0.000829	 0.008383	 0.00246	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25162	 83633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25162	 83633	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25163	 26345	 0.030708	 0.024302	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25163	 83634	 0.01268	 0.025106	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83631	 25164	 0.002817	 0.009663	 0.00231	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25164	 83634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25164	 83634	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25164	 84063	 0.002275	 0.006013	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25165	 25166	 0.000971	 0.006865	 0.00188	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82033	 25167	 0.023887	 0.037272	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82032	 25168	 0.001677	 0.011628	 0.00682	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25169	 25171	 0.000238	 0.002641	 0.02515	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25169	 83635	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25169	 83635	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83635	 25170	 0.085275	 0.067487	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81996	 25171	 0.000247	 0.002796	 0.02546	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25172	 25173	 0.010346	 0.024016	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83629	 25172	 0.048191	 0.084752	 0.00159	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81998	 25173	 0.045158	 0.13869	 0.0026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81998	 25174	 0.073922	 0.096205	 0.00135	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25175	 83639	 0.10054	 0.19907	 0.00292	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25176	 25177	 0.000186	 0.002152	 0.01887	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25176	 26127	 0.000592	 0.006835	 0.05992	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25176	 83636	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25176	 83636	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25177	 25179	 0.000158	 0.001821	 0.01596	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25177	 83637	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25177	 83637	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25178	 83639	 0.00851	 0.021877	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25178	 83976	 0.086986	 0.17224	 0.00253	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25179	 83638	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25180	 25181	 0.009934	 0.026256	 0.00615	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25180	 27697	 0.011186	 0.029565	 0.00692	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25181	 26409	 0.01668	 0.056208	 0.01397	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83631	 25181	 0.011373	 0.087165	 0.02336	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25181	 83640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25181	 83640	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83639	 25182	 0.050988	 0.14625	 0.00225	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83640	 25182	 0.049862	 0.092716	 0.00217	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25183	 26409	 0.018143	 0.047954	 0.01123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83638	 25183	 0.011165	 0.026906	 0.0076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25184	 25198	 0.004934	 0.017197	 0.00399	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25184	 26878	 0.006366	 0.021839	 0.00523	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25185	 25186	 0.000148	 0.001629	 0.01583	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25185	 83641	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25185	 83641	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25186	 25190	 0.0005	 0.005482	 0.05325	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25186	 83642	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25187	 26459	 0.11336	 0.2939	 0.00556	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83643	 25187	 0.008579	 0.043399	 0.00076	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25187	 83644	 0.033605	 0.07802	 0.00116	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25187	 83648	 0.053751	 0.11897	 0.00195	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25188	 25194	 0.006307	 0.025251	 0.00636	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25188	 83644	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25188	 83644	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25188	 83645	 0.002795	 0.010873	 0.0029	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83644	 25189	 0.014338	 0.037903	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25189	 83646	 0.01368	 0.03176	 0.00047	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25190	 25205	 0.001549	 0.017885	 0.15689	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25190	 26862	 0.000606	 0.006714	 0.06393	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25190	 27385	 0.000452	 0.007926	 0.08481	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25190	 83645	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25191	 26874	 0.006471	 0.02739	 0.00616	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83645	 25191	 0.001307	 0.01545	 0.0044	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25191	 83647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25191	 83647	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83647	 25192	 0.010444	 0.074376	 0.00167	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25192	 84477	 0.01347	 0.097555	 0.00245	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83646	 25193	 0.12854	 0.1659	 0.00333	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25194	 25195	 0.006796	 0.027211	 0.00686	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25195	 83651	 0.009006	 0.043953	 0.01214	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25196	 83652	 0.11327	 0.089647	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83642	 25197	 0.007727	 0.028112	 0.00861	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25197	 83648	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25197	 83648	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25197	 83653	 0.00298	 0.042026	 0.01437	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25198	 25199	 0.001964	 0.024209	 0.00782	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25198	 83649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25198	 83649	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25199	 83650	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25199	 83650	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25199	 83651	 0.001498	 0.018093	 0.01026	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25200	 25201	 0.000217	 0.002517	 0.02176	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25200	 83651	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25201	 25202	 0.000188	 0.001985	 0.02969	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25201	 25202	 0.000188	 0.001985	 0.02969	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25201	 83653	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25201	 83653	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25202	 25203	 7.4e-05	 0.000748	 0.01217	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25202	 25203	 7.4e-05	 0.000748	 0.01217	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25203	 25206	 8.5e-05	 0.000841	 0.01439	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25203	 25206	 8.5e-05	 0.000841	 0.01439	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83652	 25204	 0.023518	 0.077611	 0.00126	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25204	 83655	 0.003326	 0.00954	 0.00015	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25205	 25206	 6.4e-05	 0.000661	 0.01038	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25205	 25206	 6.4e-05	 0.000661	 0.01038	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25205	 26848	 0.001549	 0.017255	 0.16282	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25205	 83654	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25205	 83654	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25206	 83655	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25206	 83655	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83650	 25207	 0.009323	 0.062303	 0.00138	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83654	 25207	 0.005181	 0.036898	 0.00083	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25208	 25216	 0.000287	 0.003929	 0.05877	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25208	 27648	 0.000679	 0.012102	 0.12556	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25208	 83656	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25208	 83656	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25209	 26426	 0.004086	 0.043841	 0.01141	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25209	 83659	 0.002035	 0.021141	 0.00654	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25210	 25212	 0.000674	 0.007777	 0.06818	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25210	 26473	 0.000715	 0.008252	 0.07235	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25210	 83657	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25210	 83657	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25211	 25215	 0.000101	 0.001822	 0.02875	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25211	 83658	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25211	 83658	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25212	 25213	 0.000101	 0.00125	 0.01255	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25212	 83659	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25212	 83659	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25213	 25214	 8.2e-05	 0.001017	 0.01022	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25213	 26483	 0.001973	 0.02237	 0.20388	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25213	 27739	 0.001299	 0.018808	 0.28929	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25213	 83660	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25213	 83660	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25214	 25215	 6.6e-05	 0.000997	 0.01787	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25214	 25216	 0.000121	 0.001292	 0.01897	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25215	 83661	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25215	 83661	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25216	 83662	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25216	 83662	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83662	 25217	 0.001194	 0.018807	 0.00641	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25217	 83663	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25217	 83663	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25217	 83979	 0.002549	 0.028844	 0.0162	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25218	 26438	 0.065362	 0.12942	 0.0019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25218	 83665	 0.047024	 0.12188	 0.0023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25219	 25220	 0.011852	 0.048438	 0.00098	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25219	 84639	 0.033125	 0.17451	 0.00313	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25220	 83664	 0.008832	 0.038693	 0.00083	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25221	 25222	 0.026945	 0.021324	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25221	 83664	 0.008024	 0.045084	 0.00083	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25221	 83665	 0.050639	 0.084576	 0.00144	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25223	 25224	 0.002873	 0.021527	 0.00525	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25223	 26897	 0.008417	 0.0645	 0.01728	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25223	 83664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25223	 83664	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25224	 25225	 0.003439	 0.022013	 0.00741	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25224	 26436	 0.049716	 0.12507	 0.03243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25224	 83665	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25224	 83665	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25225	 25226	 0.00392	 0.013446	 0.00322	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25225	 83666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25225	 83666	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25226	 25230	 0.004227	 0.014942	 0.00337	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25227	 84420	 0.039669	 0.11257	 0.00177	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25228	 25229	 0.049338	 0.039045	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25228	 83667	 0.016668	 0.033001	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25230	 27136	 0.004815	 0.016517	 0.00396	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25230	 83667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25230	 83667	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25231	 83669	 0.010001	 0.007915	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25232	 25233	 0.001759	 0.004721	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25232	 25234	 0.000756	 0.0019	 0.00049	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25233	 25254	 0.001933	 0.005698	 0.00133	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25233	 83670	 0.000732	 0.0031	 0.0007	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25234	 25520	 0.000657	 0.001737	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25235	 25236	 0.000734	 0.00177	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25235	 83668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25235	 83668	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25235	 83719	 0.000553	 0.003169	 0.00105	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25236	 25237	 0.000459	 0.001213	 0.00028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25237	 25238	 0.000658	 0.001765	 0.0004	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25237	 25246	 0.000919	 0.002428	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25238	 83669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25238	 83669	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25238	 83670	 0.001168	 0.002936	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83669	 25239	 0.009355	 0.007333	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25239	 83671	 0.004489	 0.0059	 8e-05	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25240	 25253	 4e-05	 0.000453	 0.00413	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25240	 25388	 0.000153	 0.001676	 0.01628	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25240	 83670	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83668	 25241	 0.006343	 0.0114	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25241	 83673	 0.007701	 0.007778	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25242	 25243	 0.000952	 0.002517	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25242	 83672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25242	 83672	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25243	 25244	 0.000617	 0.00163	 0.00038	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25243	 83673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25243	 83673	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25244	 25245	 0.000538	 0.001465	 0.00032	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25245	 25246	 0.0007	 0.001849	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25246	 25247	 0.001291	 0.003466	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25247	 25248	 0.000822	 0.002558	 0.00053	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25247	 25265	 0.001353	 0.003401	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25247	 83674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25247	 83674	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25248	 83675	 0.000503	 0.00182	 0.00039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25249	 25253	 6.3e-05	 0.000692	 0.00672	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25249	 25261	 2.6e-05	 0.000291	 0.00274	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25249	 25262	 7.6e-05	 0.000846	 0.00805	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25249	 83675	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83671	 25250	 0.005081	 0.014572	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25250	 83679	 0.006637	 0.011068	 0.00016	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25251	 25281	 0.00596	 0.014216	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25251	 83679	 0.002595	 0.006599	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82054	 25252	 0.017174	 0.011536	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83671	 25252	 0.003015	 0.006926	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25252	 83678	 0.003482	 0.00528	 8e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25253	 83677	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25254	 83679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25254	 83679	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25254	 83680	 0.0022	 0.005814	 0.00136	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25255	 25256	 0.000699	 0.001797	 0.00045	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25256	 25257	 0.000549	 0.001276	 0.00039	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25257	 83684	 0.001894	 0.005007	 0.00117	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25258	 25262	 8.3e-05	 0.000957	 0.00838	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25258	 83680	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25259	 25260	 0.000296	 0.001699	 0.00048	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83680	 25259	 0.000256	 0.00143	 0.00037	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25259	 83682	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25259	 83682	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25260	 83684	 0.000398	 0.002667	 0.00064	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25261	 83683	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25261	 83683	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25262	 25388	 0.000294	 0.003221	 0.03129	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25262	 83684	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25262	 83807	 0.000124	 0.001591	 0.01496	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83676	 25263	 0.003155	 0.006761	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83685	 25263	 0.026126	 0.020676	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25263	 83686	 0.004528	 0.01164	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83674	 25264	 0.00804	 0.015919	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83685	 25264	 0.028961	 0.040362	 0.00069	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25265	 25266	 0.00094	 0.002485	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25266	 25268	 0.001297	 0.003335	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25266	 83686	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25266	 83686	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83686	 25267	 0.007918	 0.005724	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83684	 25268	 0.001748	 0.004537	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25269	 25279	 0.001446	 0.004032	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25269	 83687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25269	 83687	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25270	 25276	 0.000756	 0.002467	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25270	 25278	 0.000518	 0.002515	 0.00057	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25270	 83688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25270	 83688	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25271	 25272	 0.014446	 0.011323	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25272	 25277	 0.009782	 0.019367	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25273	 25274	 0.006343	 0.009717	 0.00014	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25273	 25277	 0.005584	 0.008913	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83686	 25273	 0.002632	 0.010126	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25274	 25277	 0.008033	 0.008578	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25274	 83689	 0.004654	 0.010805	 0.00016	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25275	 83689	 0.012362	 0.009095	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25276	 25432	 0.002327	 0.006527	 0.00168	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25276	 83689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25276	 83689	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83687	 25277	 0.001833	 0.009769	 0.00017	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83688	 25277	 0.013455	 0.01359	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25278	 25279	 0.00052	 0.002853	 0.00075	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25279	 25567	 0.000485	 0.00429	 0.00236	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25279	 83808	 0.000273	 0.003302	 0.00187	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25280	 83690	 0.003535	 0.008775	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83681	 25281	 0.002767	 0.013504	 0.00023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25281	 83690	 0.002698	 0.011585	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25282	 25283	 0.000713	 0.005271	 0.00152	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83680	 25282	 0.000736	 0.006018	 0.00163	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25282	 83690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25282	 83690	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25283	 83691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25283	 83691	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25284	 25285	 0.002601	 0.00515	 8e-05	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25284	 25286	 0.002498	 0.009608	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25284	 25286	 0.002498	 0.009608	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25284	 25302	 0.001421	 0.009845	 0.0002	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83691	 25284	 0.00504	 0.013959	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25286	 25287	 0.002421	 0.00942	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25286	 25287	 0.002421	 0.00942	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25287	 25288	 0.002148	 0.007338	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25287	 83809	 0.003695	 0.012927	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25287	 83809	 0.003695	 0.012927	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25288	 83692	 0.001749	 0.006467	 0.00012	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25289	 25290	 0.000494	 0.002659	 0.00073	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25289	 83692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25289	 83692	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25290	 25291	 0.000217	 0.002273	 0.00076	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25290	 83693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25290	 83693	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25291	 25292	 0.000253	 0.002807	 0.00091	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25292	 83808	 0.000411	 0.006049	 0.00185	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25293	 25297	 0.000212	 0.001996	 0.0006	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25293	 83694	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25293	 83694	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25294	 25324	 0.002036	 0.007921	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25294	 25324	 0.002036	 0.007921	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25294	 25327	 0.000758	 0.006306	 0.00012	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82011	 25294	 0.003141	 0.009634	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82011	 25294	 0.003141	 0.009634	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25295	 25300	 0.002691	 0.005003	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25295	 83695	 0.004122	 0.008833	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25296	 83695	 0.007317	 0.005289	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25297	 83695	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25297	 83695	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25298	 25299	 0.00106	 0.004723	 8e-05	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25298	 25301	 0.00116	 0.004059	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83695	 25298	 0.001119	 0.00546	 9e-05	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25299	 25344	 0.001663	 0.006469	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25299	 25344	 0.001663	 0.006469	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83695	 25299	 0.001109	 0.006238	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25300	 25301	 0.003526	 0.011763	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25300	 25303	 0.000937	 0.005758	 0.0001	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25301	 25304	 0.00168	 0.005153	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25301	 25349	 0.001266	 0.007785	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83694	 25301	 0.004061	 0.016253	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25302	 25303	 0.001157	 0.007029	 0.00013	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25304	 25305	 0.000485	 0.003664	 0.00012	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25304	 25306	 0.002004	 0.007711	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25304	 25306	 0.002004	 0.007711	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25305	 25349	 0.00148	 0.004938	 8e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25305	 25352	 0.001102	 0.006777	 0.00012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25306	 25307	 0.001556	 0.005986	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25306	 25307	 0.001556	 0.005986	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25307	 25673	 0.001238	 0.004228	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25307	 25673	 0.001238	 0.004228	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83691	 25307	 0.010687	 0.027696	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25308	 25309	 0.000961	 0.005463	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25308	 25311	 0.00138	 0.007843	 0.00014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25309	 83709	 0.002113	 0.010688	 0.00019	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25310	 25311	 0.002712	 0.010549	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25310	 25311	 0.002712	 0.010549	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83692	 25310	 0.001166	 0.006241	 0.00019	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25310	 83697	 0.004785	 0.018615	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25310	 83697	 0.004785	 0.018615	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25311	 25673	 0.001986	 0.006093	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25311	 25673	 0.001986	 0.006093	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25312	 25315	 0.00795	 0.006023	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25312	 83696	 0.012485	 0.008082	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25313	 25355	 0.000291	 0.004205	 0.00133	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25313	 83696	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25313	 83696	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25313	 83808	 0.000961	 0.008716	 0.00456	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25314	 25316	 0.000257	 0.001896	 0.00055	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25314	 83697	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25314	 83697	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25316	 25318	 0.000174	 0.001929	 0.00058	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25317	 83698	 0.008649	 0.006845	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25318	 25320	 0.000175	 0.002055	 0.00054	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83697	 25319	 0.008171	 0.015192	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25319	 83698	 0.002908	 0.011189	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25319	 83725	 0.006416	 0.016494	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25320	 25321	 0.000163	 0.001478	 0.00077	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25320	 83698	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25320	 83698	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25321	 83699	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25321	 83699	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25321	 83808	 0.000192	 0.00284	 0.00098	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25322	 25323	 0.00378	 0.012608	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83699	 25322	 0.001553	 0.009548	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25323	 25489	 0.002579	 0.006818	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25324	 25325	 0.00067	 0.00556	 0.00014	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25324	 25326	 0.001351	 0.011239	 0.00021	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25324	 25328	 0.001433	 0.008483	 0.00017	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25325	 25326	 0.000617	 0.005131	 0.0001	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25326	 83700	 0.002135	 0.007472	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25326	 83700	 0.002135	 0.007472	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25327	 25344	 0.00131	 0.007064	 0.00014	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83694	 25327	 0.002454	 0.015086	 0.00027	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25328	 25329	 0.001058	 0.006263	 0.00012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25329	 25331	 0.000669	 0.00599	 0.00013	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25329	 25347	 0.001081	 0.008889	 0.00017	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25330	 25337	 0.000299	 0.003021	 0.00089	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25330	 83700	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25330	 83700	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25331	 25459	 0.001599	 0.005999	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83700	 25331	 0.001879	 0.011421	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25332	 25458	 0.001808	 0.005545	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25332	 25458	 0.001808	 0.005545	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25332	 83702	 0.001562	 0.006078	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25332	 83702	 0.001562	 0.006078	 0.0001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25333	 25334	 0.000237	 0.001668	 0.00095	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25333	 25336	 0.00023	 0.002896	 0.0009	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25334	 25337	 0.000144	 0.002155	 0.00064	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25335	 83701	 0.001859	 0.009299	 0.00017	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25335	 83704	 0.00239	 0.00854	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25336	 83701	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25336	 83701	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25336	 83706	 0.000228	 0.002814	 0.00091	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25337	 83702	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25337	 83702	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83701	 25338	 0.001554	 0.00871	 0.00024	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83702	 25338	 0.001688	 0.012341	 0.00023	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25339	 25461	 0.00129	 0.010728	 0.0002	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83702	 25339	 0.004481	 0.011846	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25339	 83708	 0.001322	 0.006344	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25340	 25341	 3.7e-05	 0.000414	 0.00394	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25340	 83703	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25341	 25478	 7.8e-05	 0.000901	 0.0079	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25341	 83705	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25341	 83705	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25342	 25478	 0.00012	 0.001357	 0.01236	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25342	 83706	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25343	 25462	 0.000197	 0.003107	 0.00106	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83706	 25343	 0.000287	 0.002932	 0.00174	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25343	 83708	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25343	 83708	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25344	 25345	 0.002033	 0.00782	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25344	 25345	 0.002033	 0.00782	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25345	 25346	 0.000799	 0.005749	 0.00019	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25345	 25347	 0.001901	 0.005832	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25345	 25347	 0.001901	 0.005832	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25346	 25349	 0.000715	 0.007009	 0.00014	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25347	 25348	 0.000697	 0.006489	 0.00013	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25347	 25458	 0.006009	 0.023378	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25347	 25458	 0.006009	 0.023378	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25347	 25468	 0.000694	 0.005346	 0.0001	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25348	 25350	 0.001053	 0.010322	 0.0002	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25350	 25351	 0.001225	 0.008314	 0.00016	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25350	 25352	 0.00251	 0.010733	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25350	 25353	 0.001029	 0.009581	 0.00019	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83694	 25350	 0.0108	 0.032507	 0.00064	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25351	 25449	 0.001973	 0.01199	 0.00022	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25353	 25354	 0.002124	 0.007589	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25353	 25354	 0.002124	 0.007589	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25354	 83709	 0.002653	 0.010207	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25354	 83709	 0.002653	 0.010207	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25355	 83709	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25355	 83709	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25356	 25359	 0.000926	 0.005605	 0.00018	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25356	 25452	 0.002362	 0.00919	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25356	 25452	 0.002362	 0.00919	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83709	 25356	 0.002373	 0.008302	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83709	 25356	 0.002373	 0.008302	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25357	 25359	 0.001299	 0.004545	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25357	 25359	 0.001299	 0.004545	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25357	 25362	 0.0016	 0.006155	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25357	 25362	 0.0016	 0.006155	 0.00011	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25358	 25359	 0.001121	 0.004359	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25358	 25359	 0.001121	 0.004359	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25358	 25602	 0.002094	 0.007481	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25358	 25602	 0.002094	 0.007481	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83709	 25359	 0.002265	 0.012875	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25360	 25362	 0.002308	 0.008978	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25360	 25362	 0.002308	 0.008978	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83696	 25360	 0.003531	 0.013736	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83696	 25360	 0.003531	 0.013736	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25361	 25362	 0.011026	 0.007138	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25362	 25367	 0.002786	 0.015834	 0.00029	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25363	 83712	 0.008939	 0.007074	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25364	 25606	 0.000121	 0.00095	 0.00028	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25364	 83711	 0.000337	 0.00271	 0.00076	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83696	 25365	 0.010907	 0.007726	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25366	 83710	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25366	 83710	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25366	 83724	 0.000281	 0.003018	 0.00079	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83710	 25367	 0.000936	 0.005257	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25368	 25373	 0.002206	 0.009665	 0.00021	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83710	 25368	 0.00197	 0.011199	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25369	 25403	 8.7e-05	 0.000957	 0.0093	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25369	 83711	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25370	 25373	 0.000796	 0.006271	 0.00013	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25370	 25374	 0.001015	 0.006469	 0.00016	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83712	 25370	 0.001077	 0.004191	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83712	 25370	 0.001077	 0.004191	 7e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25371	 25372	 0.00725	 0.005737	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25372	 25609	 0.001093	 0.010177	 0.0002	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83712	 25372	 0.002194	 0.00844	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83712	 25372	 0.002194	 0.00844	 0.00014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25373	 83714	 0.001587	 0.007743	 0.00013	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25374	 83714	 0.000803	 0.006262	 0.00012	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25375	 25377	 0.000365	 0.004171	 0.00127	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25375	 83713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25375	 83713	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25375	 83724	 0.000164	 0.00206	 0.00064	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25376	 25377	 0.000135	 0.001319	 0.00037	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25376	 25378	 0.000206	 0.002638	 0.00079	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25376	 83714	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25376	 83714	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25378	 25381	 0.000215	 0.002132	 0.00058	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25379	 25380	 0.002194	 0.008705	 0.00025	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25379	 25610	 0.002774	 0.009252	 0.00015	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83712	 25379	 0.002444	 0.023658	 0.00047	 147.0	 154.3	 161.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25380	 25639	 0.001871	 0.009129	 0.00016	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25381	 25383	 0.000861	 0.002955	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25381	 83715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25381	 83715	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25382	 25639	 0.00374	 0.011473	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25382	 25639	 0.00374	 0.011473	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25382	 25640	 0.004278	 0.016643	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83715	 25382	 0.002586	 0.009948	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83715	 25382	 0.002586	 0.009948	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25383	 25384	 0.000577	 0.003058	 0.00078	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25383	 83716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25383	 83716	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25384	 83717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25384	 83717	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25385	 25386	 0.015486	 0.012138	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25386	 83721	 0.004761	 0.007599	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25387	 25389	 0.001796	 0.004664	 0.00113	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25387	 83718	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25387	 83718	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25388	 26604	 0.000501	 0.009094	 0.09092	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25388	 83719	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83719	 25389	 0.001027	 0.004347	 0.00098	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25389	 83721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25389	 83721	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25390	 25392	 0.00525	 0.010395	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25390	 25398	 0.007396	 0.01154	 0.00019	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25391	 25394	 0.007651	 0.014226	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25391	 25488	 0.004247	 0.010057	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25392	 25597	 0.022571	 0.033469	 0.0005	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83720	 25392	 0.006429	 0.031375	 0.00054	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25393	 83722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25393	 83722	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25393	 83776	 0.006028	 0.015494	 0.00384	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25394	 25435	 0.012465	 0.020999	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83722	 25394	 0.005211	 0.014944	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25394	 83723	 0.007142	 0.016408	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25395	 25397	 0.002889	 0.011809	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25395	 25399	 0.009387	 0.013326	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83720	 25395	 0.002289	 0.011648	 0.00026	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83721	 25395	 0.005841	 0.011565	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83720	 25396	 0.016606	 0.013142	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25397	 25398	 0.003144	 0.010489	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25398	 83723	 0.003695	 0.010598	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25399	 25672	 0.014508	 0.010674	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25400	 25401	 0.002097	 0.005709	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25400	 83723	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25400	 83723	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25401	 83776	 0.001654	 0.005673	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25402	 25439	 0.001734	 0.009755	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25402	 25482	 0.001367	 0.010655	 0.0002	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83708	 25402	 0.004191	 0.00973	 0.00014	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25403	 25495	 9.4e-05	 0.00157	 0.0145	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25403	 83724	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25403	 83807	 9.1e-05	 0.001207	 0.01933	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25404	 25405	 0.000299	 0.004646	 0.00144	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25404	 25648	 0.000418	 0.00559	 0.00153	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25404	 26674	 0.000346	 0.003862	 0.00257	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25405	 25406	 0.000364	 0.00458	 0.00142	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25406	 25644	 0.000356	 0.004564	 0.00136	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25407	 25594	 0.007675	 0.029526	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25407	 83800	 0.002658	 0.014001	 0.00025	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25408	 25641	 0.000638	 0.007178	 0.00208	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25408	 83726	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25408	 83726	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25408	 83745	 0.002347	 0.028926	 0.00934	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25409	 25410	 0.002412	 0.010012	 0.00026	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25409	 25638	 0.002236	 0.012711	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25410	 25589	 0.006957	 0.017884	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25410	 83760	 0.003103	 0.0213	 0.00039	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25411	 25526	 0.000399	 0.003424	 0.00097	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25411	 83727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25411	 83727	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25411	 83792	 0.002174	 0.013047	 0.00395	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25412	 25414	 0.000522	 0.002998	 0.00085	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25412	 25664	 0.0006	 0.003449	 0.00098	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25413	 25414	 0.000644	 0.00562	 0.00154	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25413	 25532	 0.000672	 0.004301	 0.00145	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25414	 25659	 0.001699	 0.006801	 0.00171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25414	 83728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25414	 83728	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25414	 83808	 0.001974	 0.027913	 0.00925	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25415	 25528	 0.005173	 0.016589	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83727	 25415	 0.003112	 0.018913	 0.00035	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25415	 83729	 0.001968	 0.014383	 0.00027	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25416	 25643	 0.001496	 0.005131	 0.00123	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25416	 83729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25416	 83729	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25417	 25433	 0.002285	 0.00604	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25417	 25539	 0.003104	 0.008203	 0.00192	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25417	 83730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25417	 83730	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25418	 25419	 0.003129	 0.013707	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25418	 83775	 0.003601	 0.01832	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25419	 25422	 0.005441	 0.012343	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83730	 25419	 0.01046	 0.015681	 0.00028	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25420	 25421	 0.005529	 0.013092	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25420	 25560	 0.00775	 0.019709	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25421	 25422	 0.025731	 0.018931	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25421	 25627	 0.007655	 0.018126	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25422	 25542	 0.005438	 0.017267	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25423	 83731	 0.009414	 0.021855	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25423	 83735	 0.008363	 0.019413	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25424	 25502	 0.001927	 0.00968	 0.00252	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25424	 83731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25424	 83731	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25425	 25429	 0.000157	 0.001808	 0.01585	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25425	 27506	 0.000581	 0.010197	 0.10912	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25425	 83732	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25426	 27572	 0.023173	 0.052996	 0.00129	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25426	 27574	 0.040225	 0.037721	 0.00058	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83731	 25426	 0.011186	 0.043036	 0.00073	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83733	 25426	 0.017924	 0.034727	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25426	 83805	 0.094686	 0.077938	 0.00158	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25427	 83773	 0.039425	 0.031201	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25427	 83782	 0.021981	 0.02889	 0.0004	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83733	 25428	 0.010298	 0.031624	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25428	 83774	 0.011881	 0.030542	 0.00047	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25429	 25598	 0.000181	 0.003181	 0.03403	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25429	 83734	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25430	 25431	 0.001037	 0.00274	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25430	 83736	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25430	 83736	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25431	 25432	 0.0011	 0.002553	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25433	 25552	 0.000868	 0.004989	 0.00141	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25433	 25675	 0.000986	 0.003323	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25434	 25436	 0.020196	 0.01583	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25434	 83766	 0.024297	 0.019228	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25434	 83810	 0.008786	 0.013456	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25435	 25436	 0.024793	 0.017922	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25435	 83738	 0.00746	 0.01477	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25436	 83739	 0.023239	 0.018391	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25437	 25561	 7.4e-05	 0.000821	 0.00782	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25437	 83737	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25438	 83739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25438	 83739	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25438	 83776	 0.001654	 0.005847	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25439	 25441	 0.009527	 0.014594	 0.0002	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25439	 83740	 0.002052	 0.009144	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25440	 25441	 0.003604	 0.008367	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25440	 83740	 0.003765	 0.008448	 0.00013	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25441	 25442	 0.003333	 0.007737	 0.00012	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25442	 25443	 0.001104	 0.007972	 0.00015	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25442	 25447	 0.001698	 0.010431	 0.00024	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25443	 25618	 0.00603	 0.01088	 0.00016	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25443	 25619	 0.002576	 0.009525	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25443	 25620	 0.00588	 0.011392	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25444	 25446	 0.000755	 0.005818	 0.00011	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25444	 25450	 0.001603	 0.01191	 0.00028	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25445	 25448	 0.004326	 0.011436	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25445	 25668	 0.00305	 0.010066	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25446	 25448	 0.00228	 0.008869	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25446	 25448	 0.00228	 0.008869	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25446	 25456	 0.001925	 0.00749	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25446	 25456	 0.001925	 0.00749	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25446	 25668	 0.00303	 0.018417	 0.00034	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25447	 25448	 0.0013	 0.008287	 0.0002	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25448	 25622	 0.002016	 0.007054	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25448	 25622	 0.002016	 0.007054	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25448	 25635	 0.001915	 0.008104	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25449	 25450	 0.000901	 0.004685	 0.0001	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25449	 25466	 0.010012	 0.007924	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25449	 83740	 0.008957	 0.034461	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25449	 83740	 0.008957	 0.034461	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25450	 25451	 0.000984	 0.00492	 9e-05	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25450	 25452	 0.001572	 0.012719	 0.00033	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25451	 25453	 0.001448	 0.006415	 0.00019	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25452	 25453	 0.001645	 0.009242	 0.00017	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25454	 25455	 0.001436	 0.005755	 0.00015	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25454	 25456	 0.002412	 0.007399	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25454	 25456	 0.002412	 0.007399	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25454	 25602	 0.003145	 0.012236	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25454	 25602	 0.003145	 0.012236	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25455	 25457	 0.001395	 0.006148	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25456	 25457	 0.002362	 0.010409	 0.00018	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25458	 25461	 0.002035	 0.007798	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25459	 25460	 0.001579	 0.004186	 0.00011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25460	 25464	 0.001707	 0.005633	 9e-05	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25461	 25464	 0.002959	 0.011513	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25461	 25464	 0.002959	 0.011513	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25461	 83740	 0.001124	 0.006907	 0.00012	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25462	 83740	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25462	 83740	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25463	 25464	 0.010705	 0.008472	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25464	 25465	 0.00168	 0.009021	 0.00021	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25465	 25468	 0.001042	 0.007072	 0.00013	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25467	 25468	 0.010535	 0.007615	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25469	 83741	 0.009049	 0.005858	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25470	 25472	 3.8e-05	 0.000668	 0.00723	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25470	 25477	 3.6e-05	 0.000385	 0.00576	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25470	 83741	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25470	 83741	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83741	 25471	 0.007448	 0.015241	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25471	 83742	 0.005997	 0.008738	 0.0002	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25472	 25475	 2.9e-05	 0.000549	 0.0052	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25472	 83742	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25472	 83742	 0.011027	 0.34182	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25473	 25474	 0.010283	 0.008138	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25474	 83744	 0.01559	 0.042589	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25474	 84125	 0.008462	 0.020037	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25475	 26493	 3.3e-05	 0.000585	 0.00626	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83704	 25476	 0.005185	 0.015607	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25476	 83744	 0.003462	 0.007917	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25477	 25478	 2.5e-05	 0.00026	 0.00389	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25477	 83743	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25478	 25479	 4.2e-05	 0.000467	 0.0044	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25478	 25614	 0.000647	 0.008992	 0.0889	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25479	 83745	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25480	 25483	 0.001798	 0.004896	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83745	 25480	 0.000683	 0.001832	 0.00042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25481	 25482	 0.00531	 0.012327	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83707	 25481	 0.004434	 0.007919	 0.00012	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25482	 83747	 0.00222	 0.011105	 0.0002	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25483	 83747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25483	 83747	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25484	 25487	 0.019053	 0.013774	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83722	 25484	 0.014711	 0.022535	 0.00032	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25484	 83771	 0.009829	 0.018002	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25485	 25487	 0.004285	 0.009844	 0.00015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25485	 25488	 0.011	 0.023572	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25485	 25547	 0.003382	 0.013533	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25486	 25597	 0.019442	 0.015386	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83718	 25488	 0.006222	 0.020531	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25489	 25490	 0.006817	 0.012252	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25489	 25492	 0.011135	 0.010758	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25490	 25491	 0.004338	 0.009118	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25490	 83748	 0.016396	 0.013495	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83713	 25491	 0.006145	 0.014117	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25492	 83748	 0.019668	 0.015416	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25493	 25497	 0.000423	 0.006316	 0.00187	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25493	 83748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25493	 83748	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25493	 83808	 0.000964	 0.006784	 0.00386	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25494	 25656	 0.009652	 0.020685	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25494	 83751	 0.005391	 0.008954	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25495	 25614	 0.000219	 0.003572	 0.05574	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25495	 83749	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25495	 83807	 0.000119	 0.001602	 0.02823	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83750	 25496	 0.002666	 0.009523	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25496	 83751	 0.003981	 0.009105	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25496	 83762	 0.004329	 0.011219	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25497	 25529	 0.000819	 0.003217	 0.00084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25497	 25532	 0.000621	 0.00454	 0.00134	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25497	 83751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25497	 83751	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83714	 25498	 0.00411	 0.01983	 0.00035	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83716	 25498	 0.002089	 0.009204	 0.00016	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83750	 25498	 0.001703	 0.014163	 0.00027	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25499	 25591	 0.001309	 0.008046	 0.00232	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25499	 26494	 0.000683	 0.007029	 0.00199	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25499	 83752	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25499	 83752	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83752	 25500	 0.02359	 0.023826	 0.00032	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25501	 25502	 0.000742	 0.008311	 0.00264	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25501	 25601	 0.001458	 0.010584	 0.00366	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25501	 83753	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25501	 83753	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25501	 83808	 0.00072	 0.007365	 0.00438	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25502	 83754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25502	 83754	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25503	 25504	 0.009773	 0.00719	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25504	 25505	 0.010072	 0.007971	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25504	 25511	 0.014309	 0.010344	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25504	 25513	 0.005268	 0.007478	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25505	 25506	 0.010103	 0.006787	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25506	 25507	 0.009814	 0.009843	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25507	 25509	 0.008189	 0.012544	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25507	 83757	 0.007629	 0.014952	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25508	 25509	 0.007522	 0.00487	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25509	 83759	 0.003178	 0.00817	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25510	 25511	 0.0033	 0.004502	 8e-05	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25510	 25596	 0.005976	 0.009981	 0.00017	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25511	 83755	 0.01485	 0.014999	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25512	 83755	 0.016488	 0.013048	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25513	 83755	 0.009332	 0.007158	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25513	 83756	 0.015217	 0.011927	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25514	 25515	 0.000472	 0.001247	 0.00029	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25514	 83755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25514	 83755	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25515	 25516	 0.000454	 0.0012	 0.00028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25515	 83756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25515	 83756	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25516	 25517	 0.000385	 0.001363	 0.00031	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25517	 25518	 0.000384	 0.001561	 0.00038	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25517	 83757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25517	 83757	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25518	 25519	 0.000641	 0.001648	 0.00041	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83719	 25518	 0.000372	 0.003571	 0.00104	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25518	 83758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25518	 83758	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25519	 25520	 0.000537	 0.001418	 0.00033	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25520	 83759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25520	 83759	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83758	 25521	 0.01207	 0.009461	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83759	 25521	 0.010827	 0.008568	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25522	 25523	 0.001612	 0.011784	 0.00022	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25522	 25621	 0.001513	 0.009891	 0.00023	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25523	 25533	 0.005791	 0.01604	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25523	 25537	 0.041932	 0.038624	 0.00062	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83752	 25523	 0.019728	 0.03906	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25524	 25525	 0.000306	 0.00385	 0.00119	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25524	 25624	 0.001066	 0.004337	 0.00106	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25524	 83760	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25524	 83760	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25525	 25536	 0.000316	 0.003678	 0.00108	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25526	 25527	 0.000372	 0.003729	 0.00124	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25526	 83761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25526	 83761	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25527	 25529	 0.000368	 0.003651	 0.00112	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25528	 25640	 0.005413	 0.014029	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83761	 25528	 0.002127	 0.008526	 0.00022	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83749	 25529	 0.000271	 0.004136	 0.00133	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25529	 83762	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25529	 83762	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25530	 25531	 0.004002	 0.009796	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83762	 25530	 0.002926	 0.008977	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25531	 83763	 0.004713	 0.008762	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25532	 83763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25532	 83763	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25533	 83764	 0.005633	 0.013079	 0.00019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25534	 25536	 0.000319	 0.003124	 0.00098	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25534	 25660	 0.001456	 0.007713	 0.00195	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25534	 83764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25534	 83764	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25535	 25661	 0.007561	 0.02495	 0.0004	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83752	 25535	 0.02135	 0.041841	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83764	 25535	 0.004742	 0.01219	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25536	 83765	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25536	 83765	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83765	 25537	 0.006563	 0.012994	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83739	 25538	 0.008711	 0.02022	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25538	 83783	 0.032016	 0.025337	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25539	 83766	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25539	 83766	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25539	 83776	 0.005225	 0.013808	 0.00323	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25540	 25541	 0.01832	 0.014498	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25540	 25578	 0.021496	 0.017011	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25541	 25542	 0.020325	 0.020529	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25542	 25626	 0.036528	 0.028632	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25542	 25628	 0.020208	 0.036322	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83766	 25542	 0.003642	 0.0207	 0.00037	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25543	 25549	 0.000541	 0.00432	 0.00106	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25543	 26656	 0.001643	 0.006684	 0.00163	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25543	 83767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25543	 83767	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25544	 25545	 0.000738	 0.003388	 0.00087	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25544	 25647	 0.000573	 0.002493	 0.00071	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25545	 25551	 0.001039	 0.003949	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25545	 83768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25545	 83768	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25546	 25650	 0.006329	 0.016095	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83722	 25546	 0.016939	 0.048584	 0.00075	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83768	 25546	 0.009178	 0.017987	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25546	 83770	 0.00694	 0.01374	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25547	 83801	 0.003527	 0.017842	 0.00031	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83767	 25548	 0.014609	 0.019201	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25548	 83769	 0.005384	 0.019233	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25548	 84187	 0.00924	 0.02449	 0.00062	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25549	 25559	 0.00203	 0.009314	 0.00239	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25549	 83769	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25549	 83769	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83769	 25550	 0.005346	 0.020565	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25550	 83770	 0.009556	 0.018728	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25551	 25552	 0.000287	 0.002613	 0.00066	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25551	 83770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25551	 83770	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25552	 83771	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25552	 83771	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25553	 25580	 0.003418	 0.009033	 0.00211	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25553	 83772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25553	 83772	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83772	 25554	 0.011106	 0.021988	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25554	 83773	 0.024374	 0.024618	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25554	 83774	 0.052629	 0.051495	 0.00073	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25555	 25556	 0.001859	 0.00478	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25555	 25558	 0.003626	 0.009871	 0.00217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25555	 83773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25555	 83773	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25556	 25576	 0.001925	 0.005241	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25557	 25558	 0.003341	 0.008831	 0.00207	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25557	 25630	 0.003831	 0.012779	 0.00324	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25558	 83774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25558	 83774	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25559	 25653	 0.002144	 0.008724	 0.00213	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25559	 83775	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25559	 83775	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25559	 83797	 0.007858	 0.026216	 0.00665	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83775	 25560	 0.008546	 0.02197	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25561	 25598	 0.000298	 0.003439	 0.03015	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25561	 83776	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25561	 83807	 0.000358	 0.004249	 0.03901	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25562	 25563	 0.016706	 0.013221	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25562	 25584	 0.010228	 0.017987	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25563	 25565	 0.01165	 0.014638	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25564	 25565	 0.010375	 0.00854	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25564	 25572	 0.01148	 0.007432	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25565	 83780	 0.008046	 0.018679	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25566	 25568	 0.0006	 0.002859	 0.00083	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25566	 25574	 0.001825	 0.006608	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25566	 83778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25566	 83778	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25567	 25581	 0.001775	 0.010576	 0.00278	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25567	 83779	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25567	 83779	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25568	 83780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25568	 83780	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25568	 83804	 0.00163	 0.006634	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25569	 25571	 0.01757	 0.013311	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25570	 25571	 0.008165	 0.010731	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25570	 83787	 0.010876	 0.011962	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25571	 25572	 0.005307	 0.012321	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25571	 83786	 0.021515	 0.017027	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83779	 25572	 0.003863	 0.021961	 0.0004	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83778	 25573	 0.004846	 0.01125	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83780	 25573	 0.008748	 0.017145	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25574	 25576	 0.001805	 0.006536	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25574	 83781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25574	 83781	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83781	 25575	 0.017978	 0.012996	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25575	 83786	 0.008443	 0.015176	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25576	 25601	 0.002543	 0.006827	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25576	 83782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25576	 83782	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25577	 25588	 0.001121	 0.002882	 0.00071	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25577	 83783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25577	 83783	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83772	 25578	 0.014763	 0.02923	 0.00043	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83783	 25578	 0.002651	 0.010311	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25579	 25580	 0.001295	 0.003898	 0.00122	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25579	 25581	 0.001603	 0.005402	 0.00134	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25579	 83784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25579	 83784	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25580	 83785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25580	 83785	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25581	 83786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25581	 83786	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83785	 25582	 0.025031	 0.01962	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83786	 25582	 0.016793	 0.025725	 0.00036	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25583	 25587	 0.005309	 0.010511	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83739	 25583	 0.005607	 0.014413	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83777	 25584	 0.005629	 0.011519	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25585	 25588	 0.002483	 0.005763	 0.00176	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83776	 25585	 0.001196	 0.006229	 0.00163	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25585	 83787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25585	 83787	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25586	 25587	 0.015334	 0.014379	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83784	 25586	 0.003511	 0.009964	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83787	 25586	 0.004673	 0.012386	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83783	 25587	 0.027966	 0.021921	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25589	 25590	 0.028967	 0.020519	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25589	 25662	 0.008704	 0.024965	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83745	 25591	 0.002096	 0.009613	 0.00246	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25591	 83788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25591	 83788	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25592	 25593	 0.013292	 0.013572	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83746	 25592	 0.022312	 0.020552	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83747	 25592	 0.007271	 0.01688	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25594	 25597	 0.009437	 0.021909	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25595	 25597	 0.003364	 0.017721	 0.00032	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25595	 83800	 0.004629	 0.02222	 0.00066	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25596	 25597	 0.004147	 0.013685	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83756	 25596	 0.041759	 0.027035	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25598	 25654	 5.8e-05	 0.000652	 0.00594	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25598	 83789	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25598	 83789	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25599	 25600	 0.000666	 0.004135	 0.00117	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83789	 25599	 0.000821	 0.003767	 0.00096	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25599	 83790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25599	 83790	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25600	 25601	 0.000776	 0.004308	 0.00131	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83734	 25601	 0.000608	 0.005386	 0.00296	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25602	 83791	 0.003658	 0.01423	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25602	 83791	 0.003658	 0.01423	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25603	 25608	 0.004864	 0.011124	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25603	 25636	 0.003591	 0.013278	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25603	 25636	 0.003591	 0.013278	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25603	 83791	 0.005181	 0.018507	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25603	 83791	 0.005181	 0.018507	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25604	 25638	 0.023086	 0.016985	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25605	 25606	 0.000116	 0.001158	 0.00039	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25605	 83791	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25605	 83791	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25607	 25611	 0.001099	 0.00709	 0.00023	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25607	 25638	 0.003691	 0.028768	 0.00054	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25608	 25610	 0.003037	 0.010132	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25609	 25610	 0.000748	 0.006959	 0.00013	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25610	 25612	 0.001036	 0.005545	 0.00017	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25611	 25612	 0.001214	 0.008025	 0.00016	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25611	 25639	 0.003498	 0.009272	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25613	 25666	 0.043887	 0.034401	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25613	 83793	 0.014026	 0.023425	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25614	 27570	 0.000386	 0.004234	 0.04112	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25614	 83792	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25615	 25616	 0.019257	 0.018917	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25615	 27531	 0.041867	 0.032817	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83793	 25616	 0.004332	 0.026631	 0.00048	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25616	 83794	 0.01139	 0.024409	 0.00043	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25617	 27210	 0.004536	 0.016503	 0.00505	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83792	 25617	 0.00147	 0.01302	 0.00347	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25617	 83794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25617	 83794	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83708	 25618	 0.010865	 0.024961	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25618	 83795	 0.025659	 0.038917	 0.00056	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25619	 25621	 0.002539	 0.009877	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25620	 25621	 0.002376	 0.014607	 0.00026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25620	 25623	 0.002773	 0.011002	 0.00031	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83788	 25621	 0.00302	 0.014432	 0.00032	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25622	 25623	 0.002601	 0.010118	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25622	 25623	 0.002601	 0.010118	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25623	 83795	 0.00201	 0.009451	 0.00018	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25624	 83795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25624	 83795	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25625	 25627	 0.012364	 0.024479	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25625	 83798	 0.010631	 0.034234	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25628	 25629	 0.030206	 0.021835	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83772	 25629	 0.014854	 0.026532	 0.00039	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25630	 83796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25630	 83796	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25630	 83797	 0.001564	 0.008139	 0.0024	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25631	 26933	 0.017099	 0.013532	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25631	 26934	 0.009001	 0.016736	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83796	 25631	 0.007466	 0.017074	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83796	 25632	 0.016176	 0.022544	 0.00039	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83796	 25633	 0.010783	 0.02135	 0.00031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25633	 83798	 0.006995	 0.014316	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25634	 83797	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25634	 83807	 0.000883	 0.010007	 0.09112	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25635	 25637	 0.002638	 0.010108	 0.00029	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25636	 25637	 0.002514	 0.008798	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25636	 25637	 0.002514	 0.008798	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25637	 25638	 0.001265	 0.006964	 0.00016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83788	 25638	 0.01012	 0.057525	 0.00104	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83726	 25639	 0.008477	 0.032612	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83726	 25639	 0.008477	 0.032612	 0.00056	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25640	 25657	 0.002896	 0.011141	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25640	 25657	 0.002896	 0.011141	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83717	 25640	 0.001937	 0.0133	 0.00024	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83725	 25640	 0.009019	 0.061905	 0.00113	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25641	 25642	 0.00013	 0.001683	 0.00067	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25642	 25643	 0.001174	 0.003049	 0.00074	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25642	 83799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25642	 83799	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25644	 25645	 0.001	 0.003639	 0.00111	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25644	 83800	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25644	 83800	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25645	 83801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25645	 83801	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25646	 25647	 0.000585	 0.002683	 0.00069	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25646	 25649	 0.001015	 0.004658	 0.00119	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25648	 25649	 0.000947	 0.004908	 0.0012	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25648	 83802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25648	 83802	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83801	 25650	 0.008206	 0.01905	 0.00028	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25650	 84168	 0.021757	 0.071799	 0.00116	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83775	 25651	 0.025694	 0.0182	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83769	 25652	 0.00658	 0.015276	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83775	 25652	 0.008586	 0.024364	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25652	 83803	 0.040999	 0.029638	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25653	 26660	 0.00244	 0.01155	 0.00278	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25653	 83803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25653	 83803	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25654	 83804	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25654	 83804	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83700	 25655	 0.014409	 0.009328	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83753	 25656	 0.009249	 0.028374	 0.00077	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83754	 25656	 0.02147	 0.029292	 0.00052	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83799	 25657	 0.003906	 0.015196	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83799	 25657	 0.003906	 0.015196	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83726	 25658	 0.027411	 0.021026	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25659	 83805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25659	 83805	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25660	 26494	 0.003107	 0.010133	 0.00269	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25660	 83806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25660	 83806	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83806	 25661	 0.012144	 0.029725	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25661	 83962	 0.008201	 0.035222	 0.00064	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83726	 25662	 0.008602	 0.022113	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25663	 25671	 0.009738	 0.047518	 0.00082	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83726	 25663	 0.00606	 0.034445	 0.00062	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83792	 25664	 0.001375	 0.007164	 0.00188	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83793	 25665	 0.005843	 0.032175	 0.00073	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25665	 84539	 0.017635	 0.032791	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25667	 25671	 0.008533	 0.034873	 0.00071	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25667	 83965	 0.016884	 0.056325	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25667	 83966	 0.014124	 0.037337	 0.00068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83740	 25668	 0.00398	 0.019905	 0.00035	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25669	 83807	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25669	 83807	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25669	 83807	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83808	 25669	 0.000162	 0.012969	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 0	 -30.0	 30.0;
	83808	 25669	 0.000162	 0.012969	 0.0	 1650.0	 1650.0	 1650.0	 1.0	 0.0	 0	 -30.0	 30.0;
	25670	 84128	 0.016552	 0.016718	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83672	 25672	 0.013912	 0.011451	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83680	 25674	 0.000875	 0.00305	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25674	 83809	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25674	 83809	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25675	 25676	 0.002018	 0.005334	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83737	 25676	 0.0028	 0.0074	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25676	 83810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25676	 83810	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25677	 25679	 0.004163	 0.0248	 0.00652	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25677	 26952	 0.005911	 0.030754	 0.00906	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25678	 25682	 0.01253	 0.06705	 0.00203	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82593	 25678	 0.007481	 0.058306	 0.00109	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25679	 25683	 0.004027	 0.027646	 0.00806	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25680	 25681	 0.005566	 0.024804	 0.00674	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25680	 27359	 0.013205	 0.043072	 0.01144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25681	 25685	 0.001587	 0.025003	 0.00853	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25681	 26959	 0.001449	 0.022925	 0.00688	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82050	 25682	 0.019293	 0.075055	 0.00125	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25682	 83811	 0.02081	 0.052922	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25683	 25685	 0.001093	 0.008119	 0.0031	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25684	 83811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25684	 83811	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25686	 27243	 0.02941	 0.14191	 0.00251	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82050	 25686	 0.1326	 0.13394	 0.00177	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25687	 25688	 0.007399	 0.025383	 0.00608	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25687	 83812	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25687	 83812	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25688	 27244	 0.007721	 0.027958	 0.006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25689	 83813	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25689	 83813	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25690	 25692	 0.10183	 0.11201	 0.00149	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25691	 27178	 0.010786	 0.028957	 0.00656	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25692	 83814	 0.077521	 0.14847	 0.00234	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25692	 84373	 0.041254	 0.13615	 0.00221	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82009	 25693	 0.012341	 0.019699	 0.00045	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25693	 83815	 0.038604	 0.029248	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25694	 27180	 0.007745	 0.047622	 0.01374	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82008	 25694	 0.003292	 0.019282	 0.00525	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25694	 83814	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25694	 83814	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25695	 27177	 0.030133	 0.11304	 0.00203	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82009	 25695	 0.032365	 0.06408	 0.00094	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83814	 25695	 0.012068	 0.034246	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25695	 83815	 0.007433	 0.03312	 0.00056	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82008	 25696	 0.003094	 0.008033	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25696	 83815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25696	 83815	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83815	 25697	 0.098925	 0.07829	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25698	 25699	 0.00205	 0.005154	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25698	 25704	 0.00144	 0.005215	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25699	 83816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25699	 83816	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25700	 83817	 0.029277	 0.02317	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25701	 83817	 0.006151	 0.014281	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25701	 83819	 0.009745	 0.022625	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25702	 83817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25702	 83817	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25702	 83818	 0.002633	 0.008588	 0.00228	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25703	 25729	 0.000298	 0.003377	 0.03074	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25703	 26887	 0.001164	 0.012707	 0.12479	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25703	 83818	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25704	 25730	 0.001852	 0.004463	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25704	 83820	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25704	 83820	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25705	 27139	 0.025069	 0.12682	 0.00221	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83816	 25705	 0.013843	 0.066449	 0.00199	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25706	 83823	 0.013361	 0.075952	 0.00137	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25706	 84355	 0.023224	 0.081314	 0.00225	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25707	 26901	 0.097716	 0.11913	 0.00191	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83817	 25707	 0.039723	 0.078649	 0.00115	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25708	 83885	 0.033716	 0.026682	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25709	 26064	 0.06359	 0.042715	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25710	 25712	 0.007735	 0.020765	 0.00471	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83818	 25710	 0.007266	 0.020262	 0.00425	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25710	 83827	 0.003214	 0.009674	 0.00303	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25711	 83821	 0.014127	 0.032307	 0.00079	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25711	 83890	 0.006013	 0.029342	 0.00051	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25712	 25714	 0.003259	 0.008612	 0.00202	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25713	 25877	 0.003116	 0.00869	 0.00182	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25713	 83825	 0.002196	 0.005978	 0.00132	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25714	 25719	 0.002083	 0.005355	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25714	 83821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25714	 83821	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83821	 25715	 0.010884	 0.018079	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25715	 83828	 0.027329	 0.032716	 0.00054	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25716	 25724	 0.008886	 0.022842	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25716	 83828	 0.009983	 0.025661	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25717	 25730	 0.00631	 0.016941	 0.00384	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25717	 83822	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25717	 83822	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25717	 83827	 0.003105	 0.015067	 0.00344	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83822	 25718	 0.009286	 0.018386	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25719	 25893	 0.005205	 0.014513	 0.00305	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25720	 25722	 0.007139	 0.025233	 0.00569	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25720	 83823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25720	 83823	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25721	 25723	 0.015176	 0.030047	 0.00044	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25721	 83900	 0.004847	 0.018856	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25722	 25726	 0.00122	 0.005597	 0.00143	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25722	 83824	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25722	 83824	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83824	 25723	 0.021002	 0.021213	 0.00028	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83824	 25724	 0.025188	 0.027704	 0.00037	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25725	 83904	 0.11069	 0.071662	 0.00136	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25726	 25910	 0.001543	 0.00803	 0.00236	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25727	 25729	 0.000226	 0.002508	 0.02388	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25727	 25865	 0.000432	 0.004892	 0.04454	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25727	 83825	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25728	 26901	 0.18994	 0.19001	 0.00257	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83819	 25728	 0.052337	 0.083541	 0.00192	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25729	 26483	 0.001157	 0.020316	 0.21759	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25729	 27672	 0.000335	 0.005488	 0.06742	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25729	 83827	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25729	 83827	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83824	 25731	 0.020146	 0.10477	 0.00227	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25731	 84355	 0.042159	 0.16221	 0.00277	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25732	 25915	 0.002225	 0.008056	 0.00173	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25732	 83828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25732	 83828	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25733	 25734	 0.002983	 0.011943	 0.00301	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82044	 25733	 0.005617	 0.023774	 0.00535	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25734	 25735	 0.003844	 0.017634	 0.00452	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25735	 26431	 0.005396	 0.033486	 0.00811	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25735	 83829	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25735	 83829	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25736	 25747	 0.000157	 0.002847	 0.02846	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25736	 26887	 0.003804	 0.041859	 0.40832	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25736	 83830	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25736	 83830	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83830	 25737	 0.007716	 0.023225	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25738	 25740	 0.067014	 0.1587	 0.0029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25738	 84368	 0.076729	 0.2201	 0.00339	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25739	 25740	 0.007998	 0.02456	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83830	 25739	 0.013283	 0.097093	 0.00179	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25739	 83833	 0.003578	 0.013766	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25740	 83832	 0.003543	 0.011691	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25741	 25745	 0.000141	 0.001797	 0.02689	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25741	 27167	 0.000234	 0.003327	 0.05316	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25741	 83831	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25741	 83831	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25742	 25743	 0.000313	 0.001844	 0.0015	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83831	 25742	 0.000531	 0.004166	 0.0019	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25743	 25744	 0.000246	 0.003026	 0.00098	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25743	 83832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25743	 83832	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25744	 83833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25744	 83833	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25744	 83834	 0.000252	 0.002787	 0.00084	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25745	 25747	 6.8e-05	 0.001228	 0.01227	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25745	 83834	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25745	 83834	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25746	 25748	 0.000904	 0.009291	 0.00294	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83834	 25746	 0.000158	 0.002361	 0.00079	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25748	 25750	 0.00407	 0.018981	 0.0047	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83831	 25749	 0.00538	 0.015002	 0.00315	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25749	 83835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25749	 83835	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25750	 26431	 0.006226	 0.02592	 0.00808	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25750	 27275	 0.046849	 0.15802	 0.03933	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82044	 25750	 0.014615	 0.087748	 0.02659	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83831	 25750	 0.005335	 0.033151	 0.00936	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25750	 83836	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25750	 83836	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25751	 25753	 0.000469	 0.005315	 0.04839	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25751	 26586	 0.000157	 0.001749	 0.0165	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25751	 27183	 0.000824	 0.009047	 0.08789	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25751	 83837	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25751	 83837	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25752	 25754	 0.000385	 0.004446	 0.03898	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25752	 25759	 0.000355	 0.004016	 0.03656	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25752	 83838	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25752	 83838	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25753	 25754	 0.000171	 0.001969	 0.01726	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25753	 83839	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25753	 83839	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25754	 25999	 0.000965	 0.010939	 0.09961	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25754	 83840	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25754	 83840	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25755	 25777	 0.001766	 0.008709	 0.00235	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25755	 25778	 0.001771	 0.006172	 0.00143	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25755	 83841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25755	 83841	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25756	 25757	 0.003634	 0.013159	 0.00282	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25756	 26046	 0.004085	 0.014012	 0.00336	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25757	 25758	 0.006531	 0.023087	 0.0052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25757	 25777	 0.003468	 0.020313	 0.00553	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25757	 27193	 0.002902	 0.035255	 0.0095	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25758	 25764	 0.00154	 0.013211	 0.00376	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83839	 25758	 0.001744	 0.018223	 0.00613	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25758	 83843	 0.007319	 0.029305	 0.00738	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25759	 25762	 0.00022	 0.002639	 0.0261	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25760	 83844	 0.041801	 0.10746	 0.00166	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25761	 25762	 0.000216	 0.002737	 0.02441	 792.0	 831.6	 871.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25761	 25771	 0.000403	 0.004394	 0.04314	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25761	 26419	 0.00037	 0.005869	 0.06163	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25761	 83842	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25761	 83842	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25762	 83843	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25763	 25767	 0.015727	 0.028268	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25763	 25768	 0.018365	 0.024137	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83844	 25763	 0.059619	 0.047182	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25763	 84356	 0.22425	 0.63712	 0.01003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25764	 25766	 0.000434	 0.004168	 0.00121	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25765	 83845	 0.022666	 0.023144	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25766	 25770	 0.000563	 0.006305	 0.002	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83843	 25766	 0.005712	 0.015095	 0.00353	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25766	 83845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25766	 83845	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25767	 25768	 0.008182	 0.014986	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25767	 25769	 0.010081	 0.019757	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83845	 25767	 0.013881	 0.010881	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25767	 83848	 0.036605	 0.09487	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83844	 25768	 0.048219	 0.03816	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25769	 83846	 0.005098	 0.019126	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83842	 25770	 0.004347	 0.017085	 0.00447	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25770	 83846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25770	 83846	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25770	 83847	 0.002004	 0.020415	 0.00526	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25771	 27200	 0.000815	 0.009235	 0.08409	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25771	 83847	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25772	 27190	 0.15029	 0.15181	 0.00201	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83848	 25772	 0.037523	 0.096458	 0.00149	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25772	 84427	 0.1313	 0.34044	 0.00644	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25773	 25775	 0.023364	 0.015126	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25773	 83849	 0.010318	 0.01565	 0.00022	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25774	 25776	 0.002934	 0.014989	 0.00377	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25774	 26039	 0.001546	 0.005302	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25774	 83849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25774	 83849	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25775	 26579	 0.048461	 0.037986	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83849	 25775	 0.025341	 0.025595	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25776	 25778	 0.002852	 0.008868	 0.00185	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83840	 25776	 0.006301	 0.02102	 0.00533	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25779	 25783	 0.002349	 0.027341	 0.00804	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25779	 26812	 0.003394	 0.035463	 0.00974	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25780	 26813	 0.008321	 0.045662	 0.01207	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83637	 25780	 0.005054	 0.06359	 0.0197	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25780	 83850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25780	 83850	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25781	 83851	 0.034276	 0.067865	 0.001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25782	 83851	 0.069696	 0.055157	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25783	 25784	 0.00063	 0.008887	 0.00304	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25783	 83851	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25783	 83851	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25784	 83852	 0.000771	 0.012629	 0.00397	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25785	 26406	 0.0005	 0.005563	 0.05246	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25785	 27199	 0.000656	 0.011449	 0.1239	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25785	 83852	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25785	 83852	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25786	 25895	 0.013309	 0.014213	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25786	 26068	 0.01297	 0.009376	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25787	 83916	 0.012185	 0.009551	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25788	 25789	 0.012486	 0.008845	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25789	 25793	 0.007329	 0.012346	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25789	 83853	 0.014636	 0.009831	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25789	 83916	 0.034798	 0.027538	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25790	 25791	 0.000667	 0.002358	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25790	 25794	 0.001089	 0.003734	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25791	 25792	 0.001161	 0.003237	 0.00068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25791	 25957	 0.000857	 0.003368	 0.00088	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25792	 25800	 0.000836	 0.002171	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25793	 25960	 0.005561	 0.011011	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25794	 25795	 0.000641	 0.001931	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25794	 83853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25794	 83853	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25795	 25796	 0.000511	 0.001667	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25796	 25804	 0.000538	 0.001845	 0.00044	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25796	 83854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25796	 83854	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25797	 25798	 0.018314	 0.014494	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83854	 25797	 0.021166	 0.016751	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25798	 25810	 0.020679	 0.016365	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25798	 83856	 0.014604	 0.016062	 0.00021	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25798	 83859	 0.007231	 0.014317	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25799	 25802	 0.000927	 0.003179	 0.00076	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25799	 25811	 0.001175	 0.003959	 0.00098	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25800	 25802	 0.001184	 0.003302	 0.00069	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25800	 83855	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25800	 83855	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25801	 25803	 0.015094	 0.011945	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83855	 25801	 0.015297	 0.011058	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25801	 83856	 0.020065	 0.015202	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25801	 83913	 0.014427	 0.013017	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25802	 83856	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25802	 83856	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83856	 25803	 0.014252	 0.011279	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25804	 25808	 0.000507	 0.001766	 0.00041	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25804	 83857	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25804	 83857	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25805	 25806	 0.00535	 0.009799	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83854	 25805	 0.01519	 0.011176	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25806	 25816	 0.005563	 0.017067	 0.00046	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83857	 25806	 0.013224	 0.014545	 0.00019	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25806	 83869	 0.01448	 0.033613	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25807	 25959	 0.003471	 0.012567	 0.0027	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25807	 83858	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25807	 83858	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25807	 83873	 0.002078	 0.010246	 0.00277	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25808	 25809	 0.000468	 0.00156	 0.0004	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25808	 83859	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25808	 83859	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25809	 25812	 0.00063	 0.002122	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25810	 83860	 0.009056	 0.008426	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25811	 25821	 0.000821	 0.002903	 0.00065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25811	 83860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25811	 83860	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25812	 83861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25812	 83861	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25812	 83868	 0.001457	 0.005832	 0.00147	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83859	 25813	 0.00809	 0.014817	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83861	 25813	 0.006899	 0.00546	 7e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25813	 83863	 0.002039	 0.009085	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25814	 25815	 0.007911	 0.006201	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25815	 25818	 0.00349	 0.006909	 0.0001	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25815	 25961	 0.014322	 0.02194	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83861	 25815	 0.021201	 0.016618	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25816	 83930	 0.001583	 0.009941	 0.00022	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25817	 25890	 0.001309	 0.003291	 0.00085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25817	 25995	 0.000788	 0.002655	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25817	 83862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25817	 83862	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25818	 25819	 0.010954	 0.008669	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25818	 83870	 0.004156	 0.011919	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25819	 83863	 0.010449	 0.008269	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25820	 83863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25820	 83863	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25820	 83868	 0.001382	 0.003552	 0.00088	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25821	 25833	 0.00058	 0.002102	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25822	 25823	 0.001477	 0.005065	 0.00121	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25822	 25944	 0.00174	 0.004599	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25822	 83864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25822	 83864	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25823	 25837	 0.000959	 0.003342	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25824	 25945	 0.001595	 0.006205	 0.00166	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25824	 83865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25824	 83865	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25824	 83940	 0.00058	 0.005751	 0.00156	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25825	 25827	 0.017541	 0.013881	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25826	 25828	 0.004893	 0.008128	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25826	 83941	 0.00633	 0.016273	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25827	 83941	 0.012563	 0.009636	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25828	 26010	 0.00271	 0.007024	 0.00013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25828	 83866	 0.020028	 0.01585	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25829	 26006	 0.000466	 0.002953	 0.0008	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25829	 26011	 0.001748	 0.006999	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25829	 83866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25829	 83866	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25830	 26021	 0.012713	 0.01006	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83866	 25830	 0.012683	 0.010037	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25831	 26022	 0.014595	 0.01155	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25831	 83939	 0.015415	 0.012199	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25832	 83867	 0.013516	 0.008751	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25832	 83871	 0.021263	 0.016827	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25833	 25836	 0.000611	 0.002096	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25833	 83867	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25833	 83867	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25834	 25841	 0.000183	 0.002072	 0.01886	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25834	 25955	 0.000326	 0.003632	 0.03425	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25834	 25999	 0.000235	 0.002582	 0.02508	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25834	 83868	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25835	 25996	 0.001457	 0.004295	 0.001	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83868	 25835	 0.001818	 0.004805	 0.00112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25835	 83870	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25835	 83870	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25836	 25838	 0.000496	 0.001653	 0.00042	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25837	 25853	 0.000637	 0.002305	 0.00049	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25837	 83871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25837	 83871	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25838	 25852	 0.000639	 0.002193	 0.00053	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25839	 25851	 0.000815	 0.002154	 0.0005	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83868	 25839	 0.001465	 0.003766	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25839	 83872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25839	 83872	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25840	 25849	 0.017561	 0.017737	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83870	 25840	 0.012462	 0.013308	 0.00028	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83872	 25840	 0.02355	 0.017327	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25841	 25888	 0.000173	 0.001924	 0.01814	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25841	 25981	 0.00017	 0.001897	 0.01788	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25841	 83873	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25841	 83873	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25842	 25845	 0.007071	 0.010038	 0.00017	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25842	 25848	 0.011683	 0.02108	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25842	 25983	 0.01564	 0.021337	 0.00038	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25843	 25846	 0.000981	 0.003366	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25843	 83874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25843	 83874	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25843	 83925	 0.001653	 0.005669	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25844	 25845	 0.004715	 0.009336	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83874	 25844	 0.003229	 0.00926	 0.00014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25845	 83927	 0.026213	 0.020547	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25846	 25847	 0.001059	 0.00275	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25846	 83875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25846	 83875	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25847	 25988	 0.000905	 0.002274	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25848	 25989	 0.019058	 0.015082	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25849	 25850	 0.008558	 0.016389	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25850	 25859	 0.036933	 0.026699	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25850	 83928	 0.007046	 0.016114	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25851	 25856	 0.001278	 0.003564	 0.00075	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25851	 25858	 0.000753	 0.002099	 0.00044	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25852	 25856	 0.000723	 0.002481	 0.00059	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25852	 83876	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25852	 83876	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25853	 25854	 0.000362	 0.00124	 0.0003	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25853	 83877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25853	 83877	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25854	 25855	 0.000527	 0.001835	 0.00043	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25855	 25997	 0.000761	 0.002563	 0.00064	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25855	 83878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25855	 83878	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25856	 25857	 0.000628	 0.002219	 0.0005	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25857	 25861	 0.000822	 0.002291	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25857	 25862	 0.000705	 0.002418	 0.00058	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25858	 25860	 0.001279	 0.00431	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25859	 83879	 0.00921	 0.00722	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25860	 25863	 0.000569	 0.00201	 0.00045	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25860	 83879	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25860	 83879	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25861	 83880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25861	 83880	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25861	 83931	 0.002413	 0.005815	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25862	 25998	 0.000798	 0.002737	 0.00066	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25863	 26000	 0.001763	 0.006142	 0.00142	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25863	 83881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25863	 83881	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25864	 25963	 0.002603	 0.011944	 0.00306	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25864	 83882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25864	 83882	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25865	 25970	 0.000381	 0.004321	 0.03934	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25865	 83883	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25866	 26065	 0.001789	 0.006136	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25866	 83885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25866	 83885	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25867	 25871	 0.001241	 0.004492	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25867	 83886	 0.001361	 0.00454	 0.00115	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25868	 25958	 0.021363	 0.016745	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25869	 83895	 0.019318	 0.013684	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25870	 25888	 8e-05	 0.000876	 0.00851	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25870	 83886	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25870	 83886	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25871	 25885	 0.001163	 0.003634	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25872	 25873	 0.009727	 0.014901	 0.00021	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25872	 25874	 0.023235	 0.018213	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25873	 83916	 0.006848	 0.012733	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25874	 83893	 0.034851	 0.02758	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25875	 25876	 0.001318	 0.004397	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25875	 25879	 0.001675	 0.005747	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25875	 83887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25875	 83887	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25876	 25885	 0.000932	 0.003295	 0.00074	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25876	 83888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25876	 83888	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25877	 25878	 0.001814	 0.004869	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25877	 25883	 0.001634	 0.004319	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25877	 83889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25877	 83889	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25878	 25879	 0.001811	 0.00545	 0.0017	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25878	 83890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25878	 83890	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25880	 25881	 0.003403	 0.008993	 0.0021	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25880	 25886	 0.001617	 0.005636	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25880	 83891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25880	 83891	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25881	 25884	 0.001827	 0.004744	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25881	 83892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25881	 83892	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25882	 25892	 0.005882	 0.016871	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83891	 25882	 0.004729	 0.016893	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25883	 25884	 0.001228	 0.003246	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25886	 25968	 0.004093	 0.016089	 0.00421	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25886	 83893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25886	 83893	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25887	 83919	 0.03144	 0.024881	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25888	 83894	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25889	 25890	 0.000989	 0.002757	 0.00058	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83894	 25889	 0.001333	 0.00346	 0.00084	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25891	 25894	 0.013853	 0.010014	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25891	 25895	 0.012803	 0.025349	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25891	 25897	 0.01698	 0.013438	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25891	 83896	 0.0089	 0.017621	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25892	 83896	 0.008967	 0.016117	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25893	 25898	 0.002216	 0.007724	 0.00179	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25893	 25915	 0.001463	 0.007212	 0.00195	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83873	 25893	 0.006746	 0.037021	 0.00979	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25893	 83896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25893	 83896	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25894	 25896	 0.00633	 0.00832	 0.00011	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25895	 25908	 0.022432	 0.017752	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25895	 83916	 0.005118	 0.024972	 0.00043	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25896	 26068	 0.004854	 0.007956	 0.00014	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25898	 25899	 0.000868	 0.002977	 0.00071	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25899	 25900	 0.001171	 0.004082	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25900	 25956	 0.000697	 0.002391	 0.00057	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25900	 83897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25900	 83897	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25901	 25902	 0.000233	 0.002733	 0.00072	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25901	 25907	 0.000301	 0.00315	 0.00087	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25902	 25903	 0.0002	 0.00229	 0.0007	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25903	 83898	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25903	 83898	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25903	 83914	 0.000135	 0.002065	 0.00067	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25904	 25905	 0.017134	 0.01356	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25904	 25906	 0.01362	 0.008818	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25905	 26059	 0.011861	 0.013045	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25906	 25909	 0.013583	 0.018515	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25906	 83899	 0.002104	 0.009216	 0.0002	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25906	 83903	 0.015285	 0.019724	 0.0004	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25907	 25919	 0.000818	 0.004947	 0.00126	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25907	 83899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25907	 83899	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25909	 83901	 0.020566	 0.016927	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25910	 25919	 0.001025	 0.006108	 0.00161	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25911	 25923	 0.001533	 0.004115	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25911	 83900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25911	 83900	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25912	 25914	 0.00738	 0.016739	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83892	 25912	 0.006721	 0.019276	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83896	 25913	 0.029777	 0.023565	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25914	 25916	 0.00638	 0.0164	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25915	 83901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25915	 83901	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83828	 25916	 0.014728	 0.026306	 0.00039	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83901	 25916	 0.010582	 0.009547	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25917	 25918	 0.000977	 0.003351	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25917	 25920	 0.001242	 0.004497	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25918	 25948	 0.000758	 0.003872	 0.00097	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25918	 83902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25918	 83902	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25919	 25920	 0.001179	 0.003973	 0.00099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25919	 25924	 0.001584	 0.005338	 0.00133	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25919	 83903	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25919	 83903	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25921	 25925	 0.022412	 0.015055	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83903	 25921	 0.012099	 0.019832	 0.00035	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25922	 25926	 0.0116	 0.032918	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25922	 25928	 0.007404	 0.018122	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25922	 25932	 0.021052	 0.023155	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25922	 25934	 0.057235	 0.045295	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25922	 26060	 0.015666	 0.040272	 0.00062	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25923	 25924	 0.001242	 0.004049	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25925	 25928	 0.031691	 0.02508	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25926	 25928	 0.002493	 0.010405	 0.0003	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83902	 25926	 0.005143	 0.01322	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25926	 83912	 0.014192	 0.047343	 0.00075	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25927	 25930	 0.030016	 0.019432	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25929	 25933	 0.003131	 0.011066	 0.00249	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25929	 83904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25929	 83904	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25930	 25931	 0.024311	 0.021784	 0.00045	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83904	 25930	 0.01567	 0.036381	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25930	 83905	 0.025413	 0.042382	 0.00062	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25931	 26060	 0.011295	 0.022136	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25933	 25935	 0.00308	 0.010565	 0.00253	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25933	 83905	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25933	 83905	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25934	 25940	 0.010882	 0.03591	 0.00058	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25934	 25941	 0.036707	 0.0392	 0.00083	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83905	 25934	 0.007752	 0.041303	 0.00072	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25935	 25937	 0.00203	 0.006963	 0.00167	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25936	 25937	 0.000438	 0.005341	 0.00177	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25936	 26041	 0.001676	 0.005749	 0.00138	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25936	 26580	 0.003685	 0.011458	 0.00239	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25936	 83906	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25936	 83906	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25936	 83933	 0.00416	 0.034613	 0.01048	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25937	 26578	 0.004604	 0.01284	 0.00269	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25937	 83907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25937	 83907	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25938	 26061	 0.002921	 0.00772	 0.00181	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25938	 26069	 0.00277	 0.007769	 0.002	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25938	 83908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25938	 83908	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25939	 25940	 0.00722	 0.013645	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25939	 83912	 0.04878	 0.036957	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25939	 83954	 0.008525	 0.021159	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25940	 83954	 0.007508	 0.02627	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83907	 25941	 0.014787	 0.033816	 0.00083	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25941	 83954	 0.006606	 0.031874	 0.00056	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25942	 25943	 0.022549	 0.014598	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83908	 25942	 0.016628	 0.032923	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25944	 25953	 0.003457	 0.00833	 0.00235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25945	 25946	 0.001145	 0.004145	 0.00089	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25945	 83909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25945	 83909	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25946	 25950	 0.001085	 0.003655	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25947	 25948	 0.000854	 0.003321	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25947	 25949	 0.000827	 0.002787	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25947	 83910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25947	 83910	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25948	 26061	 0.001806	 0.004641	 0.00115	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25949	 25950	 0.00105	 0.003602	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25950	 83911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25950	 83911	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83909	 25951	 0.006454	 0.016591	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25951	 83912	 0.008333	 0.02142	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25952	 26069	 0.004572	 0.01275	 0.00268	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25952	 83912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25952	 83912	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25953	 83913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25953	 83913	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25953	 83915	 0.001049	 0.002925	 0.00061	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25954	 25955	 3.8e-05	 0.000428	 0.00387	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25954	 83914	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25954	 83914	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25955	 83915	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25955	 83915	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25956	 25957	 0.000657	 0.002254	 0.00054	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83895	 25958	 0.010984	 0.02601	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25958	 83916	 0.006793	 0.015771	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25959	 83916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25959	 83916	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83858	 25960	 0.007046	 0.018112	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83858	 25961	 0.007011	 0.01284	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83862	 25961	 0.002701	 0.009457	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25962	 26067	 0.021895	 0.036516	 0.00053	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25962	 26803	 0.081754	 0.076075	 0.00144	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83884	 25962	 0.027972	 0.04285	 0.0006	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25962	 83918	 0.019551	 0.050257	 0.00078	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25963	 83917	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25963	 83917	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25963	 83920	 0.002036	 0.014126	 0.00403	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83917	 25964	 0.01304	 0.023885	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25964	 83918	 0.005704	 0.014663	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25965	 83918	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25965	 83918	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25965	 83920	 0.000617	 0.005614	 0.00142	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25966	 25968	 0.001508	 0.008416	 0.00215	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25966	 83919	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25966	 83919	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25966	 83925	 0.001231	 0.011194	 0.00283	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83888	 25967	 0.009121	 0.021598	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83917	 25967	 0.004564	 0.023735	 0.00051	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25969	 25971	 0.064055	 0.050693	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25969	 83921	 0.009855	 0.025333	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25970	 25977	 0.000213	 0.003806	 0.03909	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25970	 25981	 0.000174	 0.001942	 0.01814	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25970	 83920	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25972	 25973	 0.017189	 0.013473	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25973	 25979	 0.009212	 0.010034	 0.00014	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25973	 25980	 0.021716	 0.014059	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25973	 25982	 0.017187	 0.013602	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25973	 83926	 0.008581	 0.028626	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25974	 25975	 0.038408	 0.027765	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25974	 25979	 0.019203	 0.015197	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25975	 83922	 0.009989	 0.028345	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83920	 25976	 0.002217	 0.005698	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25976	 83922	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25976	 83922	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25976	 83925	 0.003486	 0.008091	 0.00246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25977	 26058	 0.000251	 0.002808	 0.02623	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25977	 27195	 0.000279	 0.005067	 0.05065	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25977	 83923	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25978	 26806	 0.059869	 0.095566	 0.0022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25978	 26807	 0.042713	 0.0818	 0.00129	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83924	 25978	 0.022255	 0.051669	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25981	 26052	 0.00032	 0.003636	 0.03284	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25981	 27672	 0.001162	 0.013162	 0.11987	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25981	 83925	 0.0001	 0.007999	 0.0	 1850.0	 1850.0	 1850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25982	 25985	 0.008307	 0.012962	 0.00022	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83926	 25983	 0.008747	 0.029181	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83926	 25984	 0.0165	 0.021685	 0.0003	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25985	 25986	 0.014045	 0.011115	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83926	 25985	 0.006806	 0.022458	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25986	 25987	 0.015324	 0.012011	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83875	 25987	 0.012076	 0.008112	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25988	 25990	 0.002298	 0.007184	 0.00208	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25988	 25992	 0.001742	 0.004603	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25988	 83927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25988	 83927	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25989	 83928	 0.025455	 0.018031	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25990	 26003	 0.003003	 0.007549	 0.00196	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25990	 83928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25990	 83928	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83924	 25991	 0.011252	 0.037535	 0.00059	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83926	 25991	 0.021798	 0.043158	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25991	 83929	 0.00641	 0.034154	 0.0006	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25992	 25993	 0.001143	 0.004041	 0.00091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25993	 83929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25993	 83929	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25993	 83948	 0.002042	 0.007116	 0.00165	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25994	 26003	 0.002806	 0.007212	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25994	 26054	 0.002428	 0.008329	 0.002	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83873	 25995	 0.000855	 0.002979	 0.00069	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83873	 25996	 0.000721	 0.004024	 0.00103	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25996	 83930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25996	 83930	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25997	 83931	 0.000893	 0.003575	 0.0009	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25998	 26000	 0.001605	 0.005354	 0.00136	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25999	 26001	 6.5e-05	 0.001027	 0.0107	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25999	 26008	 0.000165	 0.001882	 0.01699	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25999	 83931	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26000	 83933	 0.002516	 0.007417	 0.00173	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26000	 83936	 0.000876	 0.007641	 0.0021	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26001	 26005	 0.000142	 0.001613	 0.01468	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26001	 27200	 0.000775	 0.01365	 0.22681	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26001	 83933	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26002	 26049	 0.02219	 0.022412	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83934	 26002	 0.005849	 0.015034	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26002	 83938	 0.005961	 0.023191	 0.00039	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83933	 26003	 0.004754	 0.012563	 0.00294	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26003	 83935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26003	 83935	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26004	 26005	 7.2e-05	 0.000826	 0.00725	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26004	 26055	 0.000232	 0.002633	 0.02397	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26004	 83936	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26004	 83936	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26005	 83937	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83931	 26006	 0.000835	 0.00546	 0.00202	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26006	 83939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26006	 83939	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83871	 26007	 0.009191	 0.01535	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26007	 83941	 0.004071	 0.00757	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26008	 83940	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26009	 26012	 0.00066	 0.003144	 0.00091	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26009	 26069	 0.00147	 0.005195	 0.00117	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26010	 26021	 0.010964	 0.01847	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26010	 83942	 0.002035	 0.00783	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26011	 26012	 0.000477	 0.002484	 0.00065	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26011	 83942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26011	 83942	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83942	 26013	 0.014094	 0.011154	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26014	 26015	 0.016715	 0.013102	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26014	 26027	 0.01639	 0.010611	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26015	 26031	 0.006946	 0.017665	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26015	 83943	 0.003897	 0.023072	 0.00045	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26016	 26018	 0.010985	 0.011095	 0.00015	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26016	 26021	 0.007588	 0.009656	 0.00014	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26017	 26018	 0.013764	 0.010892	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26018	 83943	 0.010164	 0.017122	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83933	 26019	 0.002189	 0.014098	 0.0037	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26019	 83943	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26019	 83943	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83943	 26020	 0.018287	 0.01322	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26021	 26023	 0.003566	 0.005692	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26022	 26024	 0.006668	 0.013646	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26022	 26025	 0.002625	 0.011747	 0.00024	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26023	 26024	 0.003101	 0.007125	 0.00011	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26025	 26026	 0.021627	 0.017116	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83932	 26025	 0.018622	 0.017463	 0.00027	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83934	 26025	 0.009523	 0.027023	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26026	 83946	 0.035498	 0.027825	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26027	 26028	 0.012106	 0.009286	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83942	 26027	 0.019256	 0.021179	 0.00028	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26029	 26031	 0.038926	 0.025201	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26030	 26035	 0.006814	 0.013491	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83906	 26030	 0.046267	 0.036615	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26031	 26033	 0.00848	 0.032991	 0.00055	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26031	 26037	 0.003424	 0.01332	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26032	 26033	 0.019294	 0.015124	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26033	 83945	 0.002944	 0.016508	 0.00045	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26034	 26062	 0.057475	 0.045485	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83849	 26034	 0.012725	 0.029542	 0.00044	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83943	 26034	 0.01181	 0.04219	 0.00084	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26035	 26038	 0.005981	 0.017587	 0.00036	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26035	 83944	 0.01061	 0.013945	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26036	 26039	 0.001494	 0.00528	 0.00119	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26036	 26041	 0.001	 0.003011	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26036	 83944	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26036	 83944	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26037	 26038	 0.002906	 0.010383	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26037	 26040	 0.017495	 0.013845	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26042	 83945	 0.018034	 0.013037	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26043	 26044	 0.002279	 0.007122	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26043	 83945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26043	 83945	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26044	 26047	 0.003809	 0.010066	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83931	 26044	 0.004501	 0.011895	 0.00278	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83933	 26044	 0.001597	 0.008585	 0.00211	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26044	 83946	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26044	 83946	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26045	 26063	 0.019033	 0.05459	 0.00084	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26045	 83947	 0.011118	 0.025543	 0.00039	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26046	 26048	 0.003295	 0.010993	 0.00279	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26047	 26048	 0.006126	 0.017084	 0.00359	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26047	 83947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26047	 83947	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83937	 26050	 0.001003	 0.011779	 0.00312	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26051	 26057	 0.018383	 0.015131	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83929	 26051	 0.041867	 0.033133	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26051	 83949	 0.00408	 0.01361	 0.00022	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26051	 83950	 0.041822	 0.03077	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26052	 26053	 4.1e-05	 0.000474	 0.00416	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26052	 83948	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26053	 26055	 0.000184	 0.002123	 0.01861	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83948	 26054	 0.000666	 0.003826	 0.00108	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26054	 83950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26054	 83950	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26055	 83951	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26055	 83951	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83951	 26056	 0.00109	 0.009048	 0.00354	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26056	 84382	 0.001582	 0.013819	 0.00547	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26058	 83952	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26058	 83952	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83896	 26059	 0.005644	 0.01155	 0.00028	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83841	 26062	 0.033862	 0.066363	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83947	 26062	 0.02776	 0.071359	 0.0011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82034	 26063	 0.01242	 0.0706	 0.00128	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83884	 26064	 0.028509	 0.045505	 0.00105	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83885	 26064	 0.036181	 0.023424	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26064	 83953	 0.033388	 0.026422	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83883	 26065	 0.003197	 0.010967	 0.00263	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26065	 83953	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26065	 83953	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26066	 26067	 0.016111	 0.01043	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83918	 26067	 0.008309	 0.020624	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83897	 26068	 0.017441	 0.022923	 0.00031	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83931	 26069	 0.003661	 0.022718	 0.0055	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26069	 83954	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26069	 83954	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26070	 26071	 0.036145	 0.085592	 0.00156	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26070	 83955	 0.041411	 0.11471	 0.00189	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26071	 26072	 0.025702	 0.066071	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26071	 26790	 0.014627	 0.064819	 0.00195	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26071	 26791	 0.055606	 0.045769	 0.00093	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26071	 84087	 0.043214	 0.16813	 0.00281	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26072	 26073	 0.030853	 0.066117	 0.00116	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26072	 84087	 0.023395	 0.10308	 0.00179	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26072	 84225	 0.047469	 0.11021	 0.00164	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26073	 83955	 0.017602	 0.058088	 0.00094	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26074	 26076	 0.001438	 0.020757	 0.00659	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26074	 83955	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26074	 83955	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83955	 26075	 0.034846	 0.092117	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26075	 83956	 0.019231	 0.063464	 0.00103	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26076	 26400	 0.005627	 0.035639	 0.00967	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26076	 83956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26076	 83956	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26076	 83957	 0.003482	 0.033429	 0.00972	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26077	 83958	 0.15637	 0.11506	 0.00168	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26077	 84623	 0.078353	 0.20144	 0.00312	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26078	 26399	 0.000635	 0.011321	 0.11745	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26078	 83957	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26079	 26941	 0.013171	 0.045905	 0.01065	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82013	 26079	 0.001278	 0.014388	 0.00416	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26079	 83959	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26079	 83959	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26080	 26448	 0.041844	 0.11091	 0.00281	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83959	 26080	 0.043595	 0.14544	 0.00231	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26081	 26083	 0.022253	 0.1265	 0.00229	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26081	 26548	 0.023905	 0.12164	 0.00276	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26082	 26084	 0.00223	 0.036258	 0.01029	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26082	 83960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26082	 83960	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83959	 26083	 0.019057	 0.14681	 0.00281	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26083	 83961	 0.015691	 0.061044	 0.00102	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26083	 83961	 0.015691	 0.061044	 0.00102	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26084	 26085	 0.000595	 0.009707	 0.00579	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26084	 83961	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26084	 83961	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82001	 26085	 0.001184	 0.016592	 0.01348	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26086	 26087	 0.005058	 0.02025	 0.0051	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26086	 26529	 0.004758	 0.016649	 0.00552	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26087	 26092	 0.004877	 0.019525	 0.00492	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26088	 26095	 0.005642	 0.019011	 0.00472	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26088	 83962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26088	 83962	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26088	 84129	 0.00755	 0.031953	 0.00719	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26089	 26090	 0.009488	 0.045545	 0.00136	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83962	 26089	 0.0075	 0.037512	 0.00067	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26089	 83965	 0.03058	 0.062581	 0.00154	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26090	 83968	 0.008675	 0.054472	 0.00119	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26091	 83963	 0.016016	 0.070168	 0.00151	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26091	 83968	 0.022381	 0.07466	 0.00118	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26092	 26105	 0.00537	 0.021853	 0.00532	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26092	 83963	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26092	 83963	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26093	 26100	 0.038706	 0.074993	 0.00161	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26093	 83964	 0.016496	 0.079593	 0.00141	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26093	 83969	 0.017521	 0.057819	 0.00094	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26094	 83964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26094	 83964	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26094	 83967	 0.013685	 0.034403	 0.00891	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26095	 26096	 0.004296	 0.011354	 0.00266	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26095	 83965	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26095	 83965	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26096	 26097	 0.002925	 0.010338	 0.00233	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26097	 83966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26097	 83966	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26098	 26099	 0.015093	 0.073653	 0.00127	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83966	 26098	 0.005182	 0.032542	 0.00071	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26099	 27209	 0.013086	 0.08045	 0.00145	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83964	 26099	 0.038248	 0.078602	 0.0015	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26099	 83968	 0.15882	 0.24334	 0.00342	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26100	 27207	 0.037886	 0.087958	 0.00131	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26101	 83969	 0.129	 0.08352	 0.00159	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26102	 26524	 0.000729	 0.008259	 0.07519	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26102	 83967	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26103	 26516	 0.001429	 0.015807	 0.00474	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83967	 26103	 0.001073	 0.00937	 0.00371	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83968	 26104	 0.083403	 0.065376	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26105	 27609	 0.007694	 0.059975	 0.01794	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83967	 26105	 0.00552	 0.04294	 0.01115	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26105	 83969	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26105	 83969	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83969	 26106	 0.058216	 0.042085	 0.00064	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26107	 26108	 0.01426	 0.010101	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26107	 26114	 0.003513	 0.00931	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26107	 83978	 0.008975	 0.027533	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26109	 27096	 0.002231	 0.006221	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26109	 27097	 0.001785	 0.011499	 0.00301	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26109	 83977	 0.000706	 0.007138	 0.0021	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26110	 83977	 0.000765	 0.011253	 0.00344	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83613	 26111	 0.020725	 0.058812	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26111	 83970	 0.005027	 0.016768	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26112	 26115	 0.001014	 0.008147	 0.00229	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26112	 83970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26112	 83970	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26112	 83977	 0.000892	 0.006607	 0.00339	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26113	 26114	 0.006156	 0.017655	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83970	 26113	 0.008437	 0.019587	 0.00029	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26115	 26135	 0.002829	 0.014994	 0.005	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26116	 26121	 0.005925	 0.020731	 0.00687	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26116	 26123	 0.005125	 0.015937	 0.00333	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26116	 27102	 0.002374	 0.008595	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26116	 83977	 0.001639	 0.013957	 0.00348	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26117	 26118	 0.000615	 0.006011	 0.00169	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26117	 26122	 0.001451	 0.009016	 0.00254	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26118	 26120	 0.000365	 0.004669	 0.00139	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26118	 26123	 0.001606	 0.008649	 0.00238	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26118	 83971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26118	 83971	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26119	 26120	 0.000417	 0.003268	 0.00149	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26119	 27042	 0.000582	 0.006081	 0.00167	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26121	 26131	 0.003095	 0.020764	 0.00501	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26122	 83977	 0.002783	 0.015442	 0.00469	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26123	 26124	 0.004352	 0.011849	 0.00261	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26124	 26128	 0.004547	 0.010554	 0.00322	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26125	 26126	 0.002597	 0.006675	 0.00165	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26125	 83972	 0.007312	 0.019326	 0.00452	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26126	 84317	 0.004754	 0.012943	 0.00285	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26127	 27055	 0.000453	 0.005231	 0.04586	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26127	 27714	 0.000894	 0.015685	 0.16792	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26127	 83972	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26127	 83972	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26128	 26129	 0.000507	 0.005603	 0.00168	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26128	 26133	 0.002283	 0.014705	 0.00385	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26128	 83973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26128	 83973	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26129	 26130	 0.00071	 0.007043	 0.00192	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26130	 26131	 0.000578	 0.00752	 0.00217	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83972	 26131	 0.001038	 0.010916	 0.00613	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83973	 26132	 0.010314	 0.022021	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26132	 83974	 0.013421	 0.034499	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26133	 26134	 0.002254	 0.019973	 0.00532	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26133	 83974	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26133	 83974	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26133	 83977	 0.017209	 0.045484	 0.01065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26134	 26138	 0.004672	 0.016025	 0.00384	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83972	 26134	 0.003868	 0.024916	 0.00653	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26135	 83975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26135	 83975	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26136	 26137	 0.036544	 0.096607	 0.00175	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83850	 26137	 0.049987	 0.1023	 0.00252	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26137	 83976	 0.014538	 0.082643	 0.0015	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26138	 26139	 0.005885	 0.02051	 0.00476	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83636	 26139	 0.003281	 0.025141	 0.00673	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26139	 83976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26139	 83976	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83975	 26140	 0.030852	 0.024416	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26141	 26967	 0.001234	 0.013739	 0.12961	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26141	 26996	 0.000245	 0.004533	 0.04356	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	81996	 26141	 0.003281	 0.033209	 0.54901	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81996	 26141	 0.003281	 0.033209	 0.54901	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26141	 83977	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26141	 83977	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26142	 26148	 0.005114	 0.031445	 0.00907	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26142	 27661	 0.009709	 0.057846	 0.01522	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26143	 26145	 0.000273	 0.003149	 0.0276	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26143	 26147	 0.000462	 0.00533	 0.04673	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26143	 83979	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26143	 83979	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26144	 83982	 0.015704	 0.037187	 0.00068	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26144	 84359	 0.23725	 0.3308	 0.00566	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26145	 83980	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26145	 83980	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26146	 83982	 0.024939	 0.019737	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26147	 26150	 0.00027	 0.003055	 0.02781	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26147	 83981	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26147	 83984	 0.000456	 0.005263	 0.04614	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26148	 26149	 0.006142	 0.024138	 0.00631	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83981	 26148	 0.002138	 0.014822	 0.00869	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26149	 27161	 0.007815	 0.031803	 0.00775	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82012	 26150	 0.001083	 0.012751	 0.22286	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26150	 83983	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26150	 83983	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26150	 84364	 0.000728	 0.008398	 0.07363	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26151	 27162	 6e-05	 0.001231	 0.43517	 3601.0	 3781.1	 3961.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26151	 83984	 0.000181	 0.014517	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26151	 83984	 0.000181	 0.014517	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83985	 26151	 0.000184	 0.014757	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26152	 26363	 0.000684	 0.004696	 9e-05	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26152	 84002	 0.004736	 0.032508	 0.00059	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26153	 26364	 0.005983	 0.006043	 8e-05	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26153	 84076	 0.008632	 0.022189	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26154	 26155	 0.001084	 0.003872	 8e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26154	 26363	 0.001358	 0.005284	 9e-05	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26155	 26156	 0.002332	 0.005994	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26155	 26158	 0.002302	 0.005855	 9e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26155	 26367	 0.017598	 0.013498	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26156	 26159	 0.00237	 0.006027	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26157	 26163	 0.002273	 0.007953	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26157	 26363	 0.00227	 0.008734	 0.00015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26158	 26163	 0.002854	 0.007336	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26159	 26163	 0.00466	 0.007439	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26160	 26161	 0.014465	 0.010642	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26161	 26173	 0.010294	 0.007573	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26161	 26177	 0.006681	 0.014264	 0.00032	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26161	 26366	 0.002659	 0.009833	 0.00018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26162	 26163	 0.00138	 0.005639	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26162	 26366	 0.001793	 0.007176	 0.00015	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26163	 26164	 0.008003	 0.006334	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26163	 26165	 0.014163	 0.009169	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26165	 26166	 0.008955	 0.007087	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26167	 26241	 0.001012	 0.01443	 0.00482	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26167	 26354	 0.002607	 0.014354	 0.00518	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26167	 83986	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26167	 83986	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83986	 26168	 0.003175	 0.012353	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26169	 26170	 0.002195	 0.00704	 0.00017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26169	 84076	 0.003824	 0.021738	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26170	 26207	 0.006503	 0.012744	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26170	 26369	 0.001512	 0.006698	 0.0002	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26170	 84068	 0.009764	 0.037986	 0.00063	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26172	 26173	 0.010747	 0.007907	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26172	 26175	 0.004485	 0.01153	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26172	 26369	 0.00328	 0.008431	 0.00013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26174	 26177	 0.016368	 0.012042	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26175	 26177	 0.002027	 0.005211	 8e-05	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26176	 26177	 0.003653	 0.012187	 0.00019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26176	 84066	 0.003389	 0.011307	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26177	 26178	 0.009637	 0.00709	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26177	 83993	 0.04392	 0.034758	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26179	 83987	 0.042849	 0.033911	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26179	 84062	 0.040521	 0.029813	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26180	 26181	 0.00092	 0.002431	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26180	 26183	 0.00123	 0.004012	 0.00107	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26180	 83987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26180	 83987	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26180	 84061	 0.001987	 0.006925	 0.00161	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26181	 26344	 0.001657	 0.004449	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83987	 26182	 0.009849	 0.019501	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26182	 84057	 0.047682	 0.052444	 0.0007	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26183	 26185	 0.00165	 0.005011	 0.0011	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26184	 26186	 0.026042	 0.01686	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26184	 84075	 0.006343	 0.010593	 0.00018	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26185	 26365	 0.002216	 0.005857	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26186	 26189	 0.015927	 0.012605	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26187	 26188	 0.001307	 0.003558	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26187	 26365	 0.001931	 0.005256	 0.00116	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26188	 26351	 0.001774	 0.005515	 0.00115	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26189	 83988	 0.009206	 0.011716	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26189	 84057	 0.033791	 0.024427	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26190	 26352	 0.003478	 0.009869	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26190	 83988	 0.004601	 0.008696	 0.00014	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26191	 26192	 0.001228	 0.003244	 0.00076	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26191	 26193	 0.001259	 0.003268	 0.00079	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26191	 83988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26191	 83988	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26192	 26339	 0.001527	 0.004258	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26193	 26248	 0.001383	 0.003654	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26193	 26350	 0.000739	 0.004292	 0.00101	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26194	 26248	 0.001026	 0.003025	 0.0007	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26194	 26330	 0.005334	 0.014321	 0.00325	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26194	 83989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26194	 83989	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26194	 84059	 0.003836	 0.015357	 0.00387	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26195	 84057	 0.021031	 0.015934	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26195	 84058	 0.020499	 0.015081	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26196	 83990	 0.016947	 0.012839	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26196	 84014	 0.027965	 0.036393	 0.00051	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26197	 26198	 0.000835	 0.00366	 0.00126	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26197	 26248	 0.001577	 0.004169	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26197	 26350	 0.000557	 0.004065	 0.00104	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26197	 83990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26197	 83990	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26198	 26327	 0.000806	 0.003228	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26199	 26350	 0.001488	 0.004052	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26199	 83991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26199	 83991	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26200	 26201	 0.001333	 0.004446	 0.00113	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26200	 83992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26200	 83992	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26201	 26355	 0.000663	 0.0037	 0.00095	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26201	 26373	 0.001866	 0.010284	 0.0024	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26201	 84067	 0.00132	 0.007732	 0.00211	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26202	 26203	 0.000776	 0.003108	 0.00078	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26202	 26349	 0.000728	 0.002498	 0.0006	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26203	 26370	 0.001147	 0.004593	 0.00116	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26203	 84067	 0.000323	 0.004134	 0.00123	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26204	 83993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26204	 83993	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26204	 84067	 0.001938	 0.004981	 0.00123	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26205	 26369	 0.004499	 0.013542	 0.00026	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83993	 26205	 0.003295	 0.01153	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26206	 26207	 0.004052	 0.010306	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83993	 26206	 0.006009	 0.015282	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26207	 26208	 0.003599	 0.008522	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26208	 26209	 0.004484	 0.010172	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26209	 26210	 0.005189	 0.012046	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26209	 83996	 0.003714	 0.012257	 0.0002	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83986	 26210	 0.004336	 0.009834	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26211	 26268	 0.000164	 0.002875	 0.03076	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26211	 26356	 7.1e-05	 0.000999	 0.00953	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26211	 83994	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26212	 26215	 0.000197	 0.002089	 0.00062	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83994	 26212	 0.000417	 0.004001	 0.00116	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26212	 83996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26212	 83996	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26213	 26216	 0.00239	 0.009298	 0.00016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83995	 26213	 0.003445	 0.012737	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26213	 84000	 0.014955	 0.027807	 0.00065	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26214	 83997	 0.004448	 0.01484	 0.00024	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26214	 84004	 0.005688	 0.020319	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26215	 26224	 0.000229	 0.002883	 0.00089	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26215	 83997	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26215	 83997	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83997	 26216	 0.00249	 0.008719	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26217	 26304	 0.003808	 0.010223	 0.00232	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26217	 83998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26217	 83998	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26217	 84067	 0.002413	 0.006478	 0.00147	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26218	 26219	 0.001649	 0.004358	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83994	 26218	 0.002237	 0.005808	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26218	 83999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26218	 83999	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26219	 26299	 0.001729	 0.004568	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26219	 84000	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26219	 84000	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84000	 26220	 0.010384	 0.006975	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26221	 26301	 0.000795	 0.003185	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26221	 84026	 0.001127	 0.004285	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83999	 26222	 0.001795	 0.010911	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26222	 84027	 0.00438	 0.026622	 0.00049	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83997	 26223	 0.005122	 0.017933	 0.0005	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26223	 84008	 0.005989	 0.023966	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26224	 26236	 0.000359	 0.004372	 0.00145	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26225	 26226	 0.020355	 0.013178	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26226	 84004	 0.014611	 0.011563	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26227	 26371	 0.01303	 0.009587	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83986	 26227	 0.005283	 0.026724	 0.00046	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26227	 84001	 0.001794	 0.011028	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26228	 26229	 0.000702	 0.002809	 0.00071	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26228	 26368	 0.001673	 0.007081	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26229	 26230	 0.000241	 0.001213	 0.00032	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26229	 84001	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26229	 84001	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26230	 26231	 0.000947	 0.002502	 0.00059	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26230	 26285	 0.001335	 0.006514	 0.0018	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26231	 26243	 0.000418	 0.003645	 0.001	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26231	 84002	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26231	 84002	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26232	 84003	 0.008217	 0.012184	 0.00018	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26232	 84010	 0.031437	 0.020352	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26233	 26239	 0.003119	 0.011141	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84001	 26233	 0.003922	 0.01085	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26234	 26247	 0.003825	 0.01045	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26234	 84003	 0.003979	 0.009236	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26235	 26238	 0.001111	 0.005678	 0.00155	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26235	 26283	 0.000517	 0.00268	 0.00065	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26235	 84003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26235	 84003	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26236	 26237	 0.000832	 0.004061	 0.00112	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26236	 84004	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26236	 84004	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26236	 84007	 0.000213	 0.003038	 0.00101	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26237	 26238	 0.000466	 0.002343	 0.00061	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26237	 84005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26237	 84005	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26238	 26241	 0.00174	 0.006965	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26238	 84006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26238	 84006	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26239	 26247	 0.002959	 0.008905	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84006	 26239	 0.01142	 0.009038	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26240	 26272	 6.5e-05	 0.000724	 0.00683	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26240	 84007	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26241	 26277	 0.001847	 0.011476	 0.00324	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26241	 84009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26241	 84009	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26241	 84030	 0.000431	 0.004134	 0.0012	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84005	 26242	 0.007981	 0.01274	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26242	 84013	 0.005141	 0.013591	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26242	 84028	 0.020624	 0.020684	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26243	 84010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26243	 84010	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26243	 84011	 0.000588	 0.006912	 0.00183	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26244	 26275	 0.000144	 0.002598	 0.04099	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26244	 84011	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26245	 26246	 0.003986	 0.012229	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26245	 26280	 0.009745	 0.022623	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26245	 84032	 0.013167	 0.033486	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26246	 84018	 0.007602	 0.029688	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26247	 84013	 0.014786	 0.01159	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26247	 84033	 0.00719	 0.016694	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26249	 26279	 0.001325	 0.00344	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26249	 84013	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26249	 84013	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26250	 26316	 0.001936	 0.007009	 0.0015	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26250	 26370	 0.001104	 0.003681	 0.00093	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26250	 84014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26250	 84014	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26251	 26305	 0.009419	 0.024212	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84000	 26251	 0.004817	 0.009858	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26252	 26253	 5.8e-05	 0.000974	 0.01895	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26252	 26254	 4.3e-05	 0.000658	 0.01494	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26252	 84015	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26252	 84015	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26253	 26358	 0.000481	 0.005354	 0.05049	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26253	 84016	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26253	 84016	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26254	 26274	 9.5e-05	 0.0016	 0.02901	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26254	 84017	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26255	 84020	 0.016086	 0.041352	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26255	 84071	 0.016842	 0.048306	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26256	 26257	 0.002133	 0.009602	 0.00255	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26256	 84070	 0.004016	 0.018081	 0.00481	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26257	 26290	 0.002018	 0.007931	 0.00207	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26257	 84019	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26257	 84019	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26258	 26265	 0.00062	 0.004163	 0.001	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26258	 26291	 0.001102	 0.006665	 0.0017	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26259	 26260	 0.000426	 0.005362	 0.00166	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26259	 26263	 0.000545	 0.007283	 0.00199	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26259	 84020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26259	 84020	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26260	 26276	 0.000471	 0.005385	 0.00164	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26260	 84021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26260	 84021	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26261	 26263	 0.000696	 0.005857	 0.00173	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26261	 26265	 0.000675	 0.006284	 0.00195	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26261	 84022	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26261	 84022	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26262	 84037	 0.018169	 0.014379	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26263	 84023	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26263	 84023	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26264	 84024	 0.013172	 0.010325	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26265	 26296	 0.001902	 0.005914	 0.00123	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26265	 84024	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26265	 84024	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84023	 26266	 0.005173	 0.022791	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26266	 84025	 0.005237	 0.013461	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26267	 26296	 0.001031	 0.005753	 0.00147	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26267	 84025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26267	 84025	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26267	 84026	 0.001942	 0.006794	 0.00225	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26268	 26269	 6.7e-05	 0.000945	 0.00901	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26268	 26273	 4.4e-05	 0.000801	 0.01476	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26269	 26297	 0.000135	 0.002467	 0.02445	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26269	 84026	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84021	 26270	 0.013092	 0.033931	 0.00064	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84023	 26270	 0.003475	 0.019756	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26270	 84029	 0.009829	 0.03511	 0.0007	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26271	 26272	 3.7e-05	 0.000405	 0.00393	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26271	 26273	 4.2e-05	 0.000497	 0.00844	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26271	 26275	 2.4e-05	 0.000378	 0.00621	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26272	 84028	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26272	 84028	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26273	 26274	 3e-05	 0.000458	 0.0082	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26273	 84029	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26273	 84029	 0.002922	 0.11396	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26274	 26275	 2.3e-05	 0.000358	 0.00373	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26275	 84030	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26275	 84030	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84017	 26276	 0.000734	 0.006224	 0.00373	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26276	 84031	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26276	 84031	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84015	 26277	 0.000916	 0.013467	 0.00412	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84030	 26277	 0.001419	 0.008309	 0.00226	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26277	 84032	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26277	 84032	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84032	 26278	 0.007466	 0.024907	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26278	 84033	 0.005984	 0.016982	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26279	 84033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26279	 84033	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26280	 26282	 0.021575	 0.031991	 0.00048	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26281	 26282	 0.029001	 0.022951	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84012	 26282	 0.011474	 0.029495	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84011	 26283	 0.001124	 0.005853	 0.00154	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84003	 26284	 0.008936	 0.020436	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84012	 26284	 0.003613	 0.008557	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84011	 26285	 0.000806	 0.004049	 0.00105	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26286	 26289	 0.009626	 0.019058	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26286	 84044	 0.035566	 0.028146	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26287	 26302	 0.007408	 0.019198	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26287	 84046	 0.013661	 0.027048	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26288	 26289	 0.005358	 0.015205	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26288	 26302	 0.006064	 0.020228	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26290	 26292	 0.000848	 0.002202	 0.00053	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26291	 26293	 0.000862	 0.00546	 0.00148	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26291	 84034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26291	 84034	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26291	 84036	 0.001861	 0.005189	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26292	 26293	 0.001548	 0.003891	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26292	 84035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26292	 84035	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26294	 26302	 0.005595	 0.0273	 0.00047	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26294	 84040	 0.002078	 0.011813	 0.00021	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26295	 26297	 6.9e-05	 0.000758	 0.00736	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26295	 26309	 0.000166	 0.002895	 0.03132	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26295	 84036	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26295	 84036	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26296	 84037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26296	 84037	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26296	 84038	 0.000385	 0.002623	 0.00089	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26297	 84038	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26298	 26299	 0.001599	 0.004458	 0.00094	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84036	 26298	 0.002554	 0.006857	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26298	 84040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26298	 84040	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26299	 84041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26299	 84041	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26300	 26301	 0.000522	 0.002123	 0.00052	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26300	 84042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26300	 84042	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26302	 26303	 0.015397	 0.025715	 0.00044	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26303	 84043	 0.010649	 0.024465	 0.00037	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26304	 84043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26304	 84043	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83998	 26305	 0.015063	 0.022048	 0.00034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26306	 26308	 0.001753	 0.006014	 0.00144	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83576	 26306	 0.003146	 0.008446	 0.00191	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26306	 84044	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26306	 84044	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26307	 26334	 0.009571	 0.027451	 0.00042	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26307	 27708	 0.020567	 0.037109	 0.00054	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26307	 84047	 0.021234	 0.054584	 0.00084	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26307	 84052	 0.009951	 0.02558	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26308	 84045	 0.000315	 0.004546	 0.00144	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26308	 84048	 0.001357	 0.008344	 0.00241	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26309	 26356	 0.000366	 0.004055	 0.0386	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26309	 84045	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26310	 26311	 0.016738	 0.016742	 0.00023	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83992	 26310	 0.006844	 0.022585	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26311	 84077	 0.016678	 0.013199	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84046	 26312	 0.004091	 0.020694	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26312	 84049	 0.009874	 0.028321	 0.00044	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26312	 84077	 0.029035	 0.019504	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26313	 26314	 0.002472	 0.006417	 0.00156	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26313	 84047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26313	 84047	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26313	 84048	 0.001726	 0.009473	 0.0025	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26314	 26321	 0.002002	 0.005375	 0.00122	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26315	 26356	 0.0004	 0.004526	 0.0412	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26315	 84048	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26316	 26317	 0.000862	 0.0049	 0.00142	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26316	 26373	 0.000799	 0.002665	 0.00068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26316	 84050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26316	 84050	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26317	 26321	 0.001803	 0.008274	 0.00212	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84014	 26318	 0.014674	 0.023422	 0.00054	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84050	 26318	 0.01317	 0.00969	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26319	 26320	 0.023111	 0.02542	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83991	 26320	 0.002705	 0.007169	 0.00018	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83621	 26321	 0.011245	 0.028907	 0.00716	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26321	 84051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26321	 84051	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84048	 26322	 0.001208	 0.012422	 0.00352	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26322	 84052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26322	 84052	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26323	 26324	 0.001785	 0.006124	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26323	 84053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26323	 84053	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26324	 26325	 0.000853	 0.002566	 0.0008	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26325	 26326	 0.000412	 0.001601	 0.00043	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26326	 26327	 0.001003	 0.003631	 0.00078	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26326	 26330	 0.001596	 0.004219	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26328	 26329	 0.018735	 0.024623	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84052	 26328	 0.02893	 0.022895	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84052	 26329	 0.04397	 0.033728	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84053	 26329	 0.004805	 0.02141	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26330	 84054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26330	 84054	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26331	 26332	 0.028499	 0.01845	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84054	 26331	 0.007332	 0.012351	 0.00018	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26332	 26333	 0.013512	 0.026482	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26332	 84056	 0.036253	 0.02869	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83989	 26333	 0.007571	 0.020013	 0.00036	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26334	 84055	 0.022019	 0.022024	 0.0003	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26334	 84596	 0.019098	 0.034459	 0.0005	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26335	 26336	 0.00242	 0.006395	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26336	 26337	 0.001707	 0.007107	 0.00222	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26336	 27710	 0.001744	 0.00698	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26336	 84055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26336	 84055	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26337	 26338	 0.003048	 0.017854	 0.00486	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26338	 84056	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26338	 84056	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26338	 84059	 0.002431	 0.0154	 0.00418	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26339	 26340	 0.001743	 0.004525	 0.0011	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26339	 84057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26339	 84057	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26340	 84058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26340	 84058	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26340	 84059	 0.002421	 0.008765	 0.00188	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26341	 26346	 0.000206	 0.002393	 0.02298	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26341	 27712	 0.000669	 0.011734	 0.12558	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26341	 84059	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26342	 26345	 0.016346	 0.032035	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84060	 26342	 0.033626	 0.02177	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26343	 26346	 9.3e-05	 0.001023	 0.00993	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26343	 84061	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26343	 84061	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26344	 84062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26344	 84062	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26344	 84063	 0.005001	 0.013215	 0.00309	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26345	 84064	 0.011395	 0.022561	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26346	 84063	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26347	 26348	 0.007118	 0.018867	 0.00048	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84064	 26347	 0.007331	 0.015003	 0.00037	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82033	 26348	 0.024033	 0.072337	 0.00141	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26349	 26350	 0.000825	 0.002832	 0.00068	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26350	 26351	 0.000316	 0.002067	 0.00077	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26350	 84067	 0.001053	 0.010646	 0.00313	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26351	 26354	 0.0007	 0.003576	 0.00097	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26351	 84065	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26351	 84065	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84065	 26352	 0.003394	 0.008038	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83991	 26353	 0.009192	 0.026084	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83993	 26353	 0.002354	 0.011975	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84065	 26353	 0.004223	 0.012112	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26353	 84066	 0.004912	 0.011403	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26354	 84066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26354	 84066	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26355	 84067	 0.00071	 0.004159	 0.00113	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26356	 84067	 0.000119	 0.009548	 0.0	 1550.0	 1550.0	 1550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26357	 26359	 0.000479	 0.006983	 0.00224	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83562	 26357	 0.001918	 0.013873	 0.00746	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26357	 84069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26357	 84069	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26358	 84070	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26359	 26360	 0.003144	 0.011439	 0.0035	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82156	 26359	 0.002833	 0.024167	 0.02076	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83562	 26359	 0.004293	 0.027193	 0.00738	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26359	 84072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26359	 84072	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84016	 26360	 0.003748	 0.014579	 0.00389	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26360	 84073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26360	 84073	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84016	 26361	 0.001036	 0.00494	 0.00143	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26361	 84074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26361	 84074	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83986	 26362	 0.009975	 0.031672	 0.00056	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84002	 26362	 0.004273	 0.024287	 0.00044	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26363	 84076	 0.002784	 0.008927	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26365	 84075	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26365	 84075	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26368	 84076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26368	 84076	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83622	 26372	 0.054778	 0.039599	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83625	 26372	 0.012072	 0.015866	 0.00022	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26373	 84077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26373	 84077	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26374	 26379	 0.000524	 0.005838	 0.05505	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26374	 84078	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26375	 84081	 0.026846	 0.064033	 0.00143	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26376	 26383	 0.005371	 0.026987	 0.00702	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26376	 27257	 0.013314	 0.045677	 0.01094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26376	 84214	 0.042101	 0.14686	 0.03409	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26377	 26378	 0.013765	 0.026976	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26378	 84081	 0.004781	 0.021303	 0.00036	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83508	 26379	 0.002185	 0.025241	 0.22157	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26379	 84080	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84081	 26380	 0.007964	 0.026568	 0.00042	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26380	 84083	 0.016158	 0.040105	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26380	 84084	 0.10012	 0.14192	 0.0029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26381	 26382	 0.013757	 0.021959	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84081	 26382	 0.010379	 0.04625	 0.00079	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26383	 84082	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26383	 84082	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26384	 26385	 0.012078	 0.031923	 0.00747	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26384	 84083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26384	 84083	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26385	 26386	 0.005194	 0.039125	 0.01086	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26385	 84084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26385	 84084	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26387	 26388	 0.002185	 0.017133	 0.00783	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26387	 27806	 0.002608	 0.03178	 0.01051	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26388	 26392	 0.000482	 0.007015	 0.00225	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26389	 26390	 0.12168	 0.13385	 0.00179	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83506	 26390	 0.0506	 0.16699	 0.00271	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26391	 26392	 0.002158	 0.035087	 0.00995	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83507	 26391	 0.002498	 0.023986	 0.01117	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26392	 84085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26392	 84085	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26393	 26591	 0.20573	 0.13322	 0.00254	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26393	 26899	 0.044658	 0.1772	 0.00506	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83521	 26393	 0.071786	 0.4416	 0.00797	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84085	 26393	 0.016785	 0.073536	 0.00158	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26394	 26398	 0.03371	 0.13115	 0.00219	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26394	 84109	 0.074766	 0.20428	 0.00347	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26395	 84572	 0.027121	 0.16675	 0.00301	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26396	 26397	 0.006592	 0.027216	 0.00644	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26396	 27663	 0.006504	 0.025563	 0.00669	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83549	 26398	 0.024265	 0.092973	 0.00263	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26399	 26754	 0.00093	 0.00939	 0.15458	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83508	 26399	 0.001946	 0.025169	 0.42353	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26399	 84086	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26400	 26401	 0.000924	 0.014329	 0.00404	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83813	 26400	 0.00296	 0.020525	 0.01203	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26402	 26403	 0.068238	 0.13511	 0.00198	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82053	 26402	 0.002894	 0.012826	 0.00039	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84087	 26402	 0.03779	 0.10839	 0.00167	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26404	 26405	 0.009501	 0.036116	 0.01011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26404	 27254	 0.009719	 0.025232	 0.00612	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26404	 27791	 0.004364	 0.034218	 0.01564	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82008	 26405	 0.003933	 0.037766	 0.01099	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26405	 84088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26405	 84088	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26406	 26412	 0.000375	 0.00681	 0.06807	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26406	 84089	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84089	 26407	 0.004436	 0.019767	 0.00537	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26407	 84092	 0.003973	 0.023076	 0.00543	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26408	 26410	 0.003614	 0.024808	 0.00724	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84089	 26408	 0.003057	 0.026216	 0.00746	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26409	 26410	 0.00659	 0.025902	 0.00678	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26409	 26414	 0.003325	 0.024053	 0.01294	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83500	 26410	 0.026175	 0.073006	 0.01533	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26410	 84091	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26410	 84091	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84091	 26411	 0.016458	 0.042307	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26411	 84428	 0.10594	 0.30394	 0.00468	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26412	 26413	 0.000598	 0.00656	 0.06372	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26412	 84092	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26412	 84092	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26413	 27324	 0.002004	 0.023144	 0.20312	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83842	 26415	 0.006177	 0.021191	 0.00508	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26415	 84093	 0.005912	 0.020281	 0.00486	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26416	 27683	 0.019508	 0.052379	 0.01187	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26416	 84426	 0.015665	 0.041402	 0.00969	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26417	 26418	 0.003492	 0.023427	 0.00566	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26417	 27684	 0.007872	 0.062853	 0.0155	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83842	 26418	 0.010427	 0.044133	 0.00993	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26418	 84093	 0.003519	 0.012802	 0.00392	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26418	 84094	 0.004391	 0.020146	 0.00516	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26419	 26420	 0.000235	 0.002734	 0.02363	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26419	 84093	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26419	 84093	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26420	 27132	 0.002101	 0.024271	 0.21303	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26420	 27685	 0.000976	 0.015859	 0.15465	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26420	 84094	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26420	 84094	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84094	 26421	 0.002085	 0.014677	 0.00834	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26422	 26428	 0.002002	 0.024838	 0.01076	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26422	 27748	 0.002147	 0.024538	 0.00748	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26422	 84095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26422	 84095	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84095	 26423	 0.022935	 0.059441	 0.00112	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26423	 84489	 0.046699	 0.12104	 0.00229	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26423	 84566	 0.032409	 0.12608	 0.0021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26424	 26427	 0.001405	 0.017681	 0.00548	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26424	 27749	 0.005017	 0.025205	 0.00656	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26424	 27750	 0.014689	 0.040963	 0.0086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26424	 84096	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26424	 84096	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26425	 26426	 0.006103	 0.034558	 0.00857	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26425	 27750	 0.005691	 0.029643	 0.00777	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83659	 26425	 0.011144	 0.098784	 0.02631	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26425	 84097	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26425	 84097	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26426	 84098	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26426	 84098	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83659	 26427	 0.007445	 0.072755	 0.02042	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26427	 84099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26427	 84099	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26428	 27655	 0.007012	 0.018205	 0.00442	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83659	 26428	 0.00397	 0.060668	 0.01955	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26428	 84100	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26428	 84100	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84098	 26429	 0.060915	 0.16643	 0.00283	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84099	 26429	 0.14127	 0.11181	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84100	 26429	 0.036681	 0.075066	 0.00185	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83829	 26430	 0.094544	 0.084721	 0.00173	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26431	 26433	 0.004537	 0.016429	 0.00352	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26431	 84101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26431	 84101	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26432	 26441	 0.039635	 0.11248	 0.00177	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84101	 26432	 0.026256	 0.035821	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26432	 84102	 0.006872	 0.036614	 0.00064	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26432	 84103	 0.017284	 0.047219	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26433	 26434	 0.003315	 0.008521	 0.00211	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26433	 26436	 0.006322	 0.037032	 0.01009	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26433	 84102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26433	 84102	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26434	 84103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26434	 84103	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26435	 26437	 0.038004	 0.11439	 0.00224	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84102	 26435	 0.097733	 0.091654	 0.00142	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26435	 84104	 0.028222	 0.094147	 0.00149	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26436	 84104	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26436	 84104	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26436	 84435	 0.004786	 0.053865	 0.01415	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26437	 26438	 0.093782	 0.11433	 0.00183	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26437	 26439	 0.08561	 0.09325	 0.00127	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26437	 26440	 0.052475	 0.1349	 0.00209	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26438	 26439	 0.011809	 0.055536	 0.00103	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26438	 27343	 0.056677	 0.15023	 0.00381	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26439	 27286	 0.15484	 0.10025	 0.00191	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26439	 84422	 0.041341	 0.2178	 0.00391	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26440	 84422	 0.043125	 0.14232	 0.00231	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26441	 84105	 0.041009	 0.11762	 0.00181	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26442	 26671	 0.009553	 0.027401	 0.00674	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26442	 84105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26442	 84105	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82017	 26443	 0.012357	 0.042393	 0.01016	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26443	 84106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26443	 84106	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84106	 26444	 0.078248	 0.079034	 0.00105	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26445	 26446	 0.035762	 0.060244	 0.00086	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26446	 26447	 0.022255	 0.052699	 0.00096	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26446	 26449	 0.020938	 0.11531	 0.0026	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84106	 26446	 0.070295	 0.14775	 0.00269	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26448	 26449	 0.048382	 0.13218	 0.00225	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82018	 26448	 0.21462	 0.19773	 0.00317	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26449	 27328	 0.035566	 0.13342	 0.0024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26449	 27328	 0.035566	 0.13342	 0.0024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26450	 26462	 0.000216	 0.003873	 0.03978	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26450	 26467	 0.000132	 0.001537	 0.02724	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26450	 84107	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26450	 84107	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26451	 26458	 0.001456	 0.009143	 0.0002	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84107	 26451	 0.001657	 0.010068	 0.00019	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26452	 26457	 0.007495	 0.011481	 0.00016	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26452	 26458	 0.016219	 0.027048	 0.00039	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26453	 26456	 0.006312	 0.014436	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26453	 26458	 0.004903	 0.011212	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26453	 84111	 0.007889	 0.030692	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26453	 84111	 0.007889	 0.030692	 0.00051	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26454	 26456	 0.011581	 0.032078	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26454	 26457	 0.007074	 0.022778	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26454	 84109	 0.010548	 0.027882	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26454	 84113	 0.030126	 0.079849	 0.00203	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26455	 26466	 0.000159	 0.001806	 0.0163	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26455	 26467	 0.000326	 0.003579	 0.03476	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26455	 84108	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26456	 26458	 0.007084	 0.015678	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82020	 26457	 0.061811	 0.17542	 0.00276	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82020	 26459	 0.091238	 0.11874	 0.00166	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84109	 26459	 0.078443	 0.22263	 0.0035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26460	 26463	 0.009454	 0.037852	 0.00954	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26461	 26462	 4e-05	 0.000751	 0.00711	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26463	 26464	 0.001095	 0.016097	 0.00492	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82019	 26463	 0.000953	 0.008748	 0.00751	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84108	 26464	 0.000992	 0.013625	 0.00491	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84109	 26465	 0.10209	 0.092115	 0.00154	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26466	 84110	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26466	 84110	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26467	 84111	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26467	 84111	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26468	 84112	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26469	 26470	 0.017414	 0.066995	 0.00114	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84113	 26469	 0.042383	 0.10895	 0.00169	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26471	 84114	 0.059788	 0.047316	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82005	 26472	 0.00733	 0.025145	 0.00602	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26472	 84114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26472	 84114	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26473	 26483	 0.000858	 0.009903	 0.08683	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26473	 84115	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26474	 26475	 0.001738	 0.010885	 0.00784	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84115	 26474	 0.001182	 0.017657	 0.00522	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26474	 84117	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26474	 84117	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26475	 26478	 0.004568	 0.02893	 0.00785	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26475	 84424	 0.00159	 0.025584	 0.00836	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26476	 27288	 0.002144	 0.022029	 0.00697	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26476	 84118	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26476	 84118	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26476	 84121	 0.004453	 0.032994	 0.01691	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84118	 26477	 0.041	 0.11635	 0.00183	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26477	 84119	 0.059233	 0.070909	 0.00118	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26477	 84123	 0.046589	 0.11033	 0.00202	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26478	 84119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26478	 84119	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26478	 84121	 0.00475	 0.019018	 0.00479	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84119	 26479	 0.022343	 0.024574	 0.00033	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84116	 26480	 0.20193	 0.15982	 0.00201	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84117	 26480	 0.01639	 0.072214	 0.00125	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26480	 84120	 0.007982	 0.039922	 0.00071	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26480	 84122	 0.036231	 0.093138	 0.00144	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26481	 26482	 0.008814	 0.031918	 0.00685	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26481	 26574	 0.012526	 0.040858	 0.01085	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26482	 84120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26482	 84120	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26482	 84121	 0.004961	 0.013112	 0.00307	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26483	 84121	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26484	 26575	 0.009699	 0.028595	 0.00665	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26484	 84123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26484	 84123	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26485	 84124	 0.010605	 0.011766	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26485	 84125	 0.0055	 0.009173	 0.00013	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26486	 84124	 0.013015	 0.009575	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26486	 84149	 0.016427	 0.013	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26487	 26489	 0.001508	 0.003985	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26487	 26542	 0.002014	 0.005063	 0.00131	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26487	 84124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26487	 84124	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84124	 26488	 0.006458	 0.010727	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26488	 84127	 0.011166	 0.015234	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26489	 84125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26489	 84125	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26489	 84126	 0.001419	 0.003683	 0.00089	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26490	 26493	 4.5e-05	 0.000757	 0.00799	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26490	 26496	 6e-05	 0.000921	 0.01042	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26490	 84126	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26491	 26492	 0.007178	 0.01649	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26491	 84130	 0.005971	 0.013718	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26492	 26497	 0.012565	 0.036038	 0.00055	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83747	 26492	 0.014629	 0.065188	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84127	 26492	 0.002528	 0.019702	 0.00037	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26492	 84131	 0.012149	 0.069058	 0.00125	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26493	 84128	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26493	 84128	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26494	 26495	 0.000854	 0.007817	 0.00313	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26494	 84129	 0.004713	 0.012115	 0.003	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26495	 26498	 0.001185	 0.011378	 0.00331	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26496	 26505	 4.8e-05	 0.000687	 0.00631	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26496	 84129	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26497	 26513	 0.010442	 0.058669	 0.00109	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84130	 26497	 0.005789	 0.013709	 0.00025	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26498	 26499	 0.00036	 0.003392	 0.00103	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26499	 84131	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26499	 84131	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26499	 84147	 0.002072	 0.015304	 0.00442	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26500	 26512	 0.009407	 0.02698	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84131	 26500	 0.010541	 0.024961	 0.00046	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26500	 84132	 0.002853	 0.015199	 0.00027	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26501	 26502	 0.000175	 0.002119	 0.00192	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26501	 26511	 0.000232	 0.003487	 0.00204	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26502	 26503	 0.000164	 0.002393	 0.00149	 614.0	 644.7	 675.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26503	 84132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26503	 84132	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26503	 84133	 0.000174	 0.002289	 0.00212	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26504	 26505	 7.6e-05	 0.001081	 0.01031	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26504	 26541	 0.000166	 0.002694	 0.04205	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26504	 84133	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26504	 84133	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26506	 26507	 0.005907	 0.013712	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26506	 84136	 0.007434	 0.019111	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26507	 84135	 0.010515	 0.01926	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26508	 84134	 0.02568	 0.020323	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26509	 26510	 0.000509	 0.007548	 0.00233	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26509	 26538	 0.000678	 0.0075	 0.00225	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26509	 84134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26509	 84134	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26510	 26511	 0.000328	 0.00432	 0.00264	 567.0	 595.3	 623.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26510	 84135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26510	 84135	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26510	 84147	 0.000543	 0.006007	 0.0018	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26511	 84136	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26511	 84136	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84136	 26512	 0.007864	 0.018254	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84131	 26513	 0.01012	 0.026014	 0.0004	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26513	 84137	 0.004166	 0.030174	 0.00076	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26514	 26516	 0.000914	 0.010119	 0.00329	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26514	 84137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26514	 84137	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26514	 84147	 0.000351	 0.003641	 0.00113	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26515	 26526	 0.004614	 0.020558	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84137	 26515	 0.003987	 0.019431	 0.00036	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26515	 84139	 0.012115	 0.034378	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26515	 84148	 0.004781	 0.0222	 0.00061	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26517	 26518	 0.00085	 0.00483	 0.0014	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26517	 26538	 0.000539	 0.00406	 0.00113	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26518	 84138	 0.002324	 0.006143	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26518	 84140	 0.00078	 0.00837	 0.00218	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84134	 26519	 0.010184	 0.029208	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26519	 84144	 0.010205	 0.024165	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26520	 26527	 0.031127	 0.034236	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82051	 26520	 0.009103	 0.015684	 0.00025	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26520	 84139	 0.009684	 0.026454	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26521	 26525	 4.7e-05	 0.000738	 0.00769	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26521	 26541	 0.000221	 0.004081	 0.03921	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26521	 84138	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26521	 84138	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84138	 26522	 0.000617	 0.002549	 0.0006	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26523	 84139	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26523	 84139	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26523	 84147	 0.002004	 0.013102	 0.00333	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26524	 26525	 0.000149	 0.001581	 0.01649	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26524	 26541	 0.000331	 0.005477	 0.05134	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26524	 84140	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26525	 26530	 0.000209	 0.002322	 0.0219	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84139	 26526	 0.018523	 0.033422	 0.00048	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84139	 26528	 0.01561	 0.060729	 0.00101	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26529	 84145	 0.0067	 0.026823	 0.00676	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26530	 26539	 0.000171	 0.001873	 0.0182	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84141	 26531	 0.02296	 0.065852	 0.00101	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26531	 84146	 0.007804	 0.015969	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26532	 84142	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84143	 26533	 0.041955	 0.029719	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26534	 26537	 0.053591	 0.042411	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26535	 26537	 0.052327	 0.041411	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83533	 26536	 0.010475	 0.040749	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84143	 26536	 0.008626	 0.045961	 0.00081	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84143	 26537	 0.0167	 0.042928	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26538	 84144	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26538	 84144	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26539	 84145	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84131	 26540	 0.033928	 0.062143	 0.00107	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26541	 84147	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82031	 26542	 0.000586	 0.004926	 0.00146	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26542	 84149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26542	 84149	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26543	 26554	 0.001332	 0.022278	 0.01263	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82026	 26543	 0.001279	 0.02028	 0.01283	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26543	 84150	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26543	 84150	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26544	 26545	 0.003346	 0.010264	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26544	 26545	 0.003346	 0.010264	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26544	 26546	 0.009137	 0.03121	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26544	 26546	 0.009137	 0.03121	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26544	 26551	 0.00987	 0.037024	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26544	 26551	 0.00987	 0.037024	 0.00067	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84150	 26544	 0.004199	 0.01288	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84150	 26544	 0.004199	 0.01288	 0.00035	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26545	 26550	 0.009317	 0.032601	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26545	 26550	 0.009317	 0.032601	 0.00068	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26546	 26550	 0.010382	 0.036328	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26546	 26550	 0.010382	 0.036328	 0.00075	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82027	 26546	 0.019598	 0.076241	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82027	 26546	 0.019598	 0.076241	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26547	 26558	 0.037882	 0.14007	 0.00259	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26547	 26558	 0.037882	 0.14007	 0.00259	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83960	 26547	 0.038877	 0.18973	 0.00328	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26547	 84151	 0.047426	 0.16596	 0.00344	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26547	 84151	 0.047426	 0.16596	 0.00344	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26548	 27329	 0.025533	 0.14515	 0.00263	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82026	 26549	 0.003791	 0.022753	 0.00689	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26549	 84151	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26549	 84151	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26549	 84445	 0.002687	 0.036601	 0.01309	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84151	 26550	 0.020007	 0.076971	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84151	 26550	 0.020007	 0.076971	 0.00131	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26551	 26553	 0.004414	 0.040603	 0.00081	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84150	 26551	 0.005912	 0.022178	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84150	 26551	 0.005912	 0.022178	 0.0004	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26552	 84152	 0.064645	 0.063253	 0.00089	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84150	 26553	 0.007549	 0.062798	 0.00119	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26554	 84152	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26554	 84152	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26555	 26556	 0.005707	 0.036821	 0.00117	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26555	 26557	 0.024544	 0.075296	 0.00204	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84152	 26555	 0.013546	 0.052697	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84152	 26555	 0.013546	 0.052697	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26556	 26558	 0.010195	 0.077458	 0.00176	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26557	 26558	 0.020385	 0.079304	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26557	 26558	 0.020385	 0.079304	 0.00132	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83960	 26558	 0.028201	 0.15435	 0.00302	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26559	 26560	 0.016307	 0.011788	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26559	 26561	 0.0113	 0.022374	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26559	 26589	 0.012185	 0.020526	 0.00029	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26559	 84154	 0.008385	 0.03262	 0.00054	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26560	 26569	 0.017964	 0.014216	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26560	 26589	 0.027033	 0.021393	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26561	 26562	 0.019682	 0.01988	 0.00026	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26562	 26570	 0.055795	 0.036122	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26562	 84153	 0.028662	 0.021088	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26563	 26564	 0.003853	 0.010002	 0.00243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26563	 26568	 0.00586	 0.020712	 0.00467	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26563	 26574	 0.01032	 0.026793	 0.0065	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26563	 84153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26563	 84153	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26564	 26565	 0.002717	 0.006831	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26565	 26588	 0.007954	 0.021022	 0.00492	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26566	 26567	 0.005249	 0.013628	 0.00331	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26566	 26587	 0.006173	 0.022351	 0.0048	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26566	 84154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26566	 84154	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26567	 26568	 0.000713	 0.00788	 0.00236	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26567	 26590	 0.001285	 0.009297	 0.005	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26567	 27182	 0.015466	 0.056006	 0.01202	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82028	 26567	 0.053875	 0.14477	 0.03284	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26568	 26571	 0.004095	 0.013356	 0.00355	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26568	 84155	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26568	 84155	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84155	 26569	 0.047936	 0.037936	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84155	 26570	 0.013773	 0.026377	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26571	 26572	 0.002674	 0.009171	 0.0022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26572	 26574	 0.005912	 0.017954	 0.00393	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26573	 27144	 0.23363	 0.18493	 0.00233	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26573	 84156	 0.22025	 0.14262	 0.00271	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26573	 84356	 0.33282	 0.21557	 0.0041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26574	 84156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26574	 84156	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26575	 26576	 0.007841	 0.026897	 0.00644	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26576	 84157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26576	 84157	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26577	 84159	 0.05134	 0.085623	 0.00125	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26578	 26581	 0.003965	 0.01048	 0.00245	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26579	 84158	 0.040303	 0.031895	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26579	 84160	 0.079219	 0.087134	 0.00116	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26580	 26584	 0.006752	 0.02353	 0.00546	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26580	 84158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26580	 84158	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26581	 26582	 0.004795	 0.013056	 0.00288	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26582	 26590	 0.009962	 0.023126	 0.00705	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26582	 84159	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26582	 84159	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84159	 26583	 0.023605	 0.043236	 0.00075	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26583	 84160	 0.026835	 0.068983	 0.00107	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26583	 84162	 0.034199	 0.067711	 0.00099	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83840	 26584	 0.002829	 0.018954	 0.00581	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26584	 84160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26584	 84160	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84155	 26585	 0.025145	 0.051458	 0.00127	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84156	 26585	 0.15892	 0.11693	 0.00171	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26586	 84161	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26586	 84161	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26587	 27182	 0.005446	 0.025398	 0.00629	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26588	 27143	 0.021164	 0.053208	 0.01379	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26588	 27145	 0.008447	 0.033201	 0.00869	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26589	 27144	 0.24716	 0.22155	 0.00453	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84161	 26590	 0.001648	 0.011925	 0.00642	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26590	 84162	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26590	 84162	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26591	 84166	 0.059766	 0.152	 0.0024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26592	 26595	 0.002466	 0.023678	 0.00689	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26592	 26598	 0.00281	 0.022809	 0.00726	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26593	 84163	 0.015053	 0.050214	 0.0008	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26593	 84164	 0.016709	 0.055141	 0.00089	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26594	 26595	 0.001063	 0.011469	 0.00328	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26594	 84163	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26594	 84163	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26595	 84164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26595	 84164	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84164	 26596	 0.051161	 0.1013	 0.00149	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26596	 84165	 0.052909	 0.13403	 0.00265	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26596	 84457	 0.042158	 0.21328	 0.00371	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26597	 26598	 0.002349	 0.006099	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26597	 26601	 0.005958	 0.015746	 0.00369	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26597	 84165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26597	 84165	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26598	 26599	 0.000663	 0.005789	 0.00159	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26599	 26600	 0.002247	 0.022261	 0.00682	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26600	 27666	 0.007561	 0.034688	 0.00889	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26600	 84166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26600	 84166	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26602	 26603	 0.000295	 0.004407	 0.00148	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26602	 26674	 0.000297	 0.004443	 0.00149	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82042	 26603	 0.000268	 0.004593	 0.00132	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26604	 26606	 0.00017	 0.001888	 0.0178	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26604	 26646	 0.000597	 0.006759	 0.06154	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26604	 84167	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26604	 84167	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26605	 26660	 0.00215	 0.017163	 0.00423	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84167	 26605	 0.000963	 0.013226	 0.00477	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26605	 84168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26605	 84168	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26606	 26631	 0.000328	 0.005726	 0.06196	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26606	 84169	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26606	 84169	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82043	 26607	 0.002907	 0.022085	 0.0005	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26607	 84170	 0.037848	 0.029667	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26608	 26609	 0.002542	 0.00639	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26608	 84170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26608	 84170	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26609	 26615	 0.001647	 0.004594	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26610	 26615	 0.001019	 0.004078	 0.00103	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26611	 26673	 0.008977	 0.010746	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82056	 26611	 0.002194	 0.006227	 0.0001	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82056	 26612	 0.004543	 0.013029	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26612	 84171	 0.005514	 0.018393	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26613	 84171	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26613	 84171	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26613	 84191	 0.00242	 0.009992	 0.00236	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26614	 26618	 0.005805	 0.014762	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82056	 26614	 0.033189	 0.021486	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84171	 26614	 0.002653	 0.015079	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26615	 26621	 0.002501	 0.007529	 0.00236	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26615	 84172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26615	 84172	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26616	 26617	 0.001116	 0.005609	 0.00146	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26616	 26621	 0.0009	 0.003664	 0.00089	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82042	 26616	 0.001272	 0.020841	 0.00655	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26616	 84173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26616	 84173	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26617	 26620	 0.000702	 0.003731	 0.00087	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26618	 26673	 0.01357	 0.012243	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26618	 84174	 0.002543	 0.008484	 0.00013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26619	 26620	 0.000818	 0.003813	 0.00094	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26619	 26627	 0.000853	 0.00361	 0.00081	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26620	 84174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26620	 84174	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26621	 26623	 0.00124	 0.004713	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26621	 26628	 0.002243	 0.007696	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26621	 84175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26621	 84175	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26622	 26624	 0.026812	 0.027378	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84175	 26622	 0.016125	 0.012217	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26623	 26639	 0.00113	 0.004091	 0.00088	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26624	 26625	 0.002594	 0.009077	 0.00019	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84173	 26624	 0.033857	 0.026794	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84175	 26624	 0.014703	 0.023586	 0.00044	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26625	 26626	 0.003545	 0.015003	 0.00028	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84174	 26626	 0.008443	 0.018941	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26626	 84177	 0.00473	 0.032471	 0.00059	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26627	 84176	 0.001092	 0.005092	 0.00126	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84167	 26628	 0.00525	 0.014094	 0.00319	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26629	 26666	 0.046635	 0.092335	 0.00136	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82045	 26629	 0.044363	 0.053107	 0.00088	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83829	 26629	 0.050236	 0.14409	 0.00222	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26630	 26633	 0.009785	 0.020025	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26630	 84177	 0.010441	 0.029946	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26630	 84180	 0.009697	 0.038804	 0.00082	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26631	 26672	 8.8e-05	 0.001267	 0.01162	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26631	 84176	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26632	 26633	 0.011256	 0.032285	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82045	 26632	 0.013732	 0.041331	 0.00081	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26633	 26666	 0.12518	 0.10304	 0.00209	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84177	 26633	 0.009261	 0.018336	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26634	 26646	 0.00025	 0.003153	 0.03073	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26634	 26672	 0.000358	 0.004054	 0.03691	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26634	 84178	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26634	 84178	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26635	 26669	 0.005663	 0.035868	 0.00974	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26635	 26670	 0.014207	 0.03755	 0.00879	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84178	 26635	 0.001276	 0.013253	 0.0041	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26635	 84179	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26635	 84179	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26636	 26666	 0.012367	 0.064308	 0.00139	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26636	 26667	 0.080411	 0.054016	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84179	 26636	 0.016287	 0.036944	 0.00074	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26637	 26638	 0.002335	 0.013273	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26637	 84180	 0.005332	 0.031565	 0.00061	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26638	 84186	 0.005374	 0.027186	 0.00047	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26639	 26640	 0.00118	 0.004172	 0.00094	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26640	 26641	 0.000387	 0.003915	 0.00115	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84176	 26640	 0.001706	 0.013375	 0.00611	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26640	 84180	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26640	 84180	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26641	 26642	 0.000536	 0.004564	 0.00114	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26641	 84181	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26641	 84181	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26642	 26645	 0.000494	 0.003037	 0.00088	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26643	 26644	 0.001915	 0.009198	 0.00018	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84180	 26643	 0.005915	 0.036364	 0.00066	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26644	 26651	 0.016154	 0.024746	 0.00035	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84168	 26644	 0.12424	 0.10227	 0.00207	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26645	 26649	 0.000934	 0.003739	 0.00094	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26645	 26650	 0.00086	 0.005289	 0.00153	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26645	 84182	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26645	 84182	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26646	 84183	 0.000905	 0.048849	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26646	 84183	 0.000905	 0.048849	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84181	 26647	 0.030092	 0.03166	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84183	 26647	 0.013381	 0.024509	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26648	 26653	 0.020945	 0.015141	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84182	 26648	 0.003482	 0.00895	 0.00014	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84183	 26648	 0.005503	 0.018359	 0.00029	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26649	 26650	 0.000662	 0.002734	 0.00065	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26650	 26665	 0.003883	 0.025393	 0.00646	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26650	 84184	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26650	 84184	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84184	 26651	 0.00123	 0.008439	 0.00015	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26651	 84188	 0.007459	 0.039911	 0.00121	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26652	 26653	 0.011394	 0.022559	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26652	 26655	 0.068613	 0.049601	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84182	 26653	 0.008307	 0.018998	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84183	 26653	 0.008465	 0.024021	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84179	 26654	 0.049101	 0.0639	 0.00089	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84183	 26654	 0.01984	 0.031826	 0.00059	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26656	 26658	 0.000803	 0.003897	 0.00089	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26656	 84185	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26656	 84185	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26657	 26658	 0.000612	 0.003128	 0.00079	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26657	 26659	 0.001305	 0.007014	 0.00173	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84169	 26659	 0.001595	 0.013417	 0.00397	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26659	 84186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26659	 84186	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26660	 26661	 0.003736	 0.009873	 0.00231	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26660	 84187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26660	 84187	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26661	 26664	 0.003404	 0.008751	 0.00217	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26662	 26663	 0.01407	 0.036465	 0.00069	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83798	 26662	 0.013502	 0.035691	 0.00065	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83803	 26663	 0.086843	 0.068728	 0.00087	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26663	 84189	 0.021223	 0.060869	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26664	 84188	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26664	 84188	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26665	 26669	 0.004373	 0.014735	 0.00366	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83797	 26665	 0.007752	 0.031036	 0.00782	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26665	 84189	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26665	 84189	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84101	 26666	 0.072911	 0.21444	 0.0044	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84179	 26668	 0.024987	 0.10212	 0.00207	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84189	 26668	 0.15008	 0.1516	 0.00201	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26669	 26904	 0.008268	 0.02185	 0.00511	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26670	 26671	 0.006774	 0.017587	 0.00427	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26671	 84190	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26671	 84190	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26672	 84191	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26672	 84191	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84167	 26674	 0.001115	 0.008438	 0.00414	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26675	 26745	 0.028363	 0.022446	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26675	 84192	 0.005168	 0.009465	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26676	 26677	 0.001097	 0.002945	 0.00067	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26676	 26766	 0.005465	 0.015239	 0.0032	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26676	 84192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26676	 84192	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26677	 26737	 0.000937	 0.002517	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26677	 84193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26677	 84193	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26678	 26680	 0.017474	 0.013697	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26679	 26688	 0.019115	 0.015127	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26679	 26745	 0.01329	 0.008604	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26680	 26690	 0.020314	 0.015923	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26680	 26744	 0.049573	 0.039232	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84193	 26680	 0.012217	 0.018529	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26680	 84201	 0.021017	 0.041613	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26681	 84194	 0.002177	 0.011013	 0.00019	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26681	 84208	 0.015187	 0.036224	 0.00081	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26681	 84211	 0.021934	 0.017359	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26682	 26683	 0.001976	 0.005131	 0.00125	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26682	 26685	 0.002609	 0.007005	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26682	 26707	 0.00684	 0.018078	 0.00423	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26682	 84194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26682	 84194	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26683	 26693	 0.002836	 0.007909	 0.00166	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26683	 84195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26683	 84195	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26684	 26685	 0.001166	 0.004669	 0.00118	 175.0	 175.0	 175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26684	 84207	 0.000689	 0.003071	 0.00083	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26685	 26706	 0.002251	 0.005844	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26685	 84196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26685	 84196	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26686	 26687	 0.010029	 0.007936	 0.0001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26686	 26747	 0.01451	 0.014198	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26686	 26801	 0.015301	 0.015454	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26687	 26746	 0.02173	 0.021948	 0.00029	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26687	 84202	 0.015084	 0.032325	 0.00057	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26687	 84220	 0.014699	 0.024761	 0.00035	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26688	 26689	 0.01422	 0.011254	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26688	 84199	 0.008859	 0.01813	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26689	 26690	 0.019764	 0.015641	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26689	 26699	 0.005203	 0.013375	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26691	 84198	 0.013867	 0.010025	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26692	 26693	 0.000524	 0.001462	 0.00031	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26692	 26697	 0.000796	 0.002166	 0.00048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26693	 84197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26693	 84197	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26694	 84201	 0.012814	 0.009077	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26695	 26721	 0.010227	 0.019016	 0.00045	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84196	 26695	 0.005924	 0.011015	 0.00026	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26695	 84201	 0.016011	 0.01267	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26696	 84198	 0.016087	 0.012731	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26696	 84200	 0.013694	 0.010075	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26697	 26702	 0.001708	 0.004514	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26697	 84198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26697	 84198	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26698	 26703	 0.007916	 0.005997	 8e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84198	 26698	 0.008736	 0.006914	 9e-05	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26699	 26700	 0.015936	 0.012612	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26699	 84202	 0.003691	 0.014413	 0.00032	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26700	 26708	 0.015128	 0.01113	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26700	 84199	 0.010996	 0.008702	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26701	 26702	 0.001037	 0.00274	 0.00064	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26701	 84199	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26701	 84199	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26702	 84200	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26702	 84200	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84198	 26703	 0.01572	 0.01244	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84200	 26703	 0.018331	 0.014368	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26703	 84230	 0.008213	 0.021711	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26704	 26705	 0.013255	 0.009752	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26704	 26710	 0.015469	 0.012242	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26705	 84201	 0.005747	 0.010527	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26706	 26722	 0.001334	 0.004496	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26706	 84201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26706	 84201	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26707	 84202	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26707	 84202	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26707	 84214	 0.002227	 0.022902	 0.0065	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26708	 26711	 0.012672	 0.010029	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26708	 26712	 0.015377	 0.015381	 0.00021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84199	 26708	 0.014338	 0.009282	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26709	 26712	 0.011255	 0.008907	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84200	 26709	 0.010563	 0.008003	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26710	 26713	 0.007434	 0.007435	 0.0001	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84202	 26711	 0.007193	 0.014241	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26712	 26713	 0.007838	 0.012511	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26713	 84230	 0.001706	 0.007562	 0.00023	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26714	 26717	 0.017292	 0.013554	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26714	 26799	 0.008434	 0.01594	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84202	 26714	 0.017994	 0.014104	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26715	 26730	 0.018801	 0.014421	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26716	 84230	 0.016174	 0.0128	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26717	 26730	 0.025903	 0.020304	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26718	 26799	 0.01896	 0.013949	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26719	 26751	 0.004818	 0.012253	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26719	 26752	 0.005852	 0.017971	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26719	 26756	 0.010374	 0.026667	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26719	 84203	 0.005332	 0.01238	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26720	 26783	 0.010321	 0.042001	 0.01023	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26720	 27778	 0.002042	 0.007003	 0.00168	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26720	 84203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26720	 84203	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26721	 84226	 0.009358	 0.024802	 0.00063	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26722	 84204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26722	 84204	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26722	 84228	 0.002634	 0.009037	 0.00216	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26723	 26726	 0.013099	 0.01323	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84204	 26723	 0.005746	 0.010859	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26723	 84227	 0.005928	 0.013558	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26724	 84205	 0.012751	 0.010091	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26725	 26726	 0.011839	 0.008969	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26725	 84205	 0.014598	 0.009451	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26727	 84205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26727	 84205	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26727	 84228	 0.002244	 0.007698	 0.00184	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84205	 26728	 0.007906	 0.015652	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26728	 84230	 0.029207	 0.021488	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84205	 26729	 0.017763	 0.013069	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26730	 84230	 0.010285	 0.020364	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26731	 84206	 0.001717	 0.004789	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26732	 26733	 4.7e-05	 0.000537	 0.00471	 736.0	 772.8	 809.6	 0.0	 0.0	 0	 -30.0	 30.0;
	26732	 84206	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 0	 -30.0	 30.0;
	26732	 84206	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 0	 -30.0	 30.0;
	26733	 26798	 0.000331	 0.003817	 0.03346	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26733	 84207	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26733	 84207	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84207	 26734	 0.000893	 0.00463	 0.00113	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26734	 84208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26734	 84208	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26735	 26736	 0.001498	 0.003958	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26735	 26739	 0.00285	 0.007758	 0.00171	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26735	 84209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26735	 84209	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26736	 26737	 0.001347	 0.003462	 0.00086	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26736	 84210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26736	 84210	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26737	 84211	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26737	 84211	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26738	 84212	 0.017619	 0.012963	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26739	 26741	 0.00159	 0.004128	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26739	 84212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26739	 84212	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26740	 26768	 0.022923	 0.017968	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26740	 84213	 0.01377	 0.012913	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26741	 26778	 0.00614	 0.018482	 0.00578	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26741	 84213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26741	 84213	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26742	 26743	 0.005788	 0.008866	 0.00012	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26742	 84220	 0.012665	 0.025076	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26743	 26744	 0.016005	 0.01157	 0.00018	 45.0	 45.0	 45.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26743	 26746	 0.018334	 0.014509	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84212	 26744	 0.008239	 0.016312	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26745	 26746	 0.013892	 0.010994	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26746	 26747	 0.01115	 0.008824	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26748	 26750	 0.008931	 0.025615	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26748	 26775	 0.10967	 0.077688	 0.00123	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84202	 26748	 0.027009	 0.021374	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26748	 84219	 0.044662	 0.030001	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26749	 26801	 0.008615	 0.015779	 0.00027	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84202	 26749	 0.002022	 0.007865	 0.00013	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26750	 26757	 0.012304	 0.02436	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26750	 26799	 0.003717	 0.013744	 0.00025	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84203	 26750	 0.008682	 0.028963	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26750	 84215	 0.010895	 0.048277	 0.00145	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26750	 84218	 0.029887	 0.032872	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26751	 26757	 0.005155	 0.013111	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26752	 26753	 0.015438	 0.012217	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26752	 84215	 0.005928	 0.026526	 0.00055	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26754	 26759	 9.4e-05	 0.001066	 0.00971	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26754	 26781	 0.000162	 0.001872	 0.01641	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26754	 84214	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26755	 26784	 0.099449	 0.070447	 0.00111	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26755	 27781	 0.011801	 0.033848	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84215	 26755	 0.008338	 0.019744	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26756	 84217	 0.005253	 0.013504	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26758	 84217	 0.005185	 0.014871	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26758	 84223	 0.009161	 0.019631	 0.00034	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26759	 27785	 0.000524	 0.005752	 0.05587	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26759	 84216	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26760	 26779	 0.000626	 0.00493	 0.00144	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84216	 26760	 0.000862	 0.007524	 0.00207	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26761	 26762	 0.000286	 0.00303	 0.0009	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26761	 26763	 0.00055	 0.003483	 0.00095	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26761	 84218	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26761	 84218	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84216	 26762	 0.000559	 0.006393	 0.00195	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26763	 26764	 0.000603	 0.003533	 0.00096	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26764	 26765	 0.000582	 0.002643	 0.00092	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26764	 84219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26764	 84219	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26765	 26766	 0.001075	 0.004305	 0.00108	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26766	 84220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26766	 84220	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26767	 26769	 0.023537	 0.018449	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84220	 26767	 0.010506	 0.01745	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26768	 26769	 0.017473	 0.013828	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26769	 26770	 0.025254	 0.019985	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84213	 26769	 0.014397	 0.018736	 0.00026	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26770	 26771	 0.017991	 0.019596	 0.00027	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26770	 26775	 0.023607	 0.025965	 0.00035	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26771	 26772	 0.009538	 0.02929	 0.00055	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26771	 26775	 0.008859	 0.022772	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26772	 26773	 0.006749	 0.013363	 0.0002	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26773	 26774	 0.004696	 0.015665	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26774	 26787	 0.029398	 0.035838	 0.00057	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26774	 26788	 0.006326	 0.024611	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26775	 26776	 0.006557	 0.018808	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26775	 26777	 0.01184	 0.022015	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26776	 84221	 0.008959	 0.026345	 0.00054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26777	 84221	 0.004454	 0.019846	 0.00034	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26778	 26779	 0.000498	 0.00419	 0.00124	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26778	 84221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26778	 84221	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26779	 84222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26779	 84222	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26780	 26785	 0.039661	 0.031387	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84222	 26780	 0.009349	 0.0217	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26780	 84223	 0.006955	 0.029031	 0.00084	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26781	 84223	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26781	 84223	 0.001943	 0.085478	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26782	 26783	 0.001331	 0.010025	 0.00278	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26782	 26792	 0.001342	 0.015343	 0.00468	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26783	 84224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26783	 84224	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84215	 26784	 0.047943	 0.073444	 0.00103	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84224	 26784	 0.013996	 0.053624	 0.00152	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26786	 26790	 0.013459	 0.060225	 0.00124	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84223	 26786	 0.010067	 0.039165	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26787	 26789	 0.089479	 0.070814	 0.00089	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84223	 26787	 0.018776	 0.094982	 0.00165	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84223	 26788	 0.01135	 0.069778	 0.00126	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84086	 26792	 0.001832	 0.026688	 0.00854	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26792	 84225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26792	 84225	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26793	 84226	 0.17271	 0.13249	 0.00178	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26793	 84371	 0.1153	 0.090383	 0.00116	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26794	 26795	 0.003924	 0.01037	 0.00243	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26794	 27175	 0.008103	 0.021416	 0.00501	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26795	 84226	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26795	 84226	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84226	 26796	 0.009275	 0.026603	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26796	 84227	 0.012664	 0.011876	 0.00018	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26796	 84229	 0.011853	 0.027518	 0.00041	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26797	 27776	 0.003497	 0.009241	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26797	 84227	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26797	 84227	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26797	 84228	 0.001484	 0.003923	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26798	 27786	 0.000325	 0.003747	 0.03285	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26798	 84228	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26800	 27778	 0.004695	 0.016104	 0.00386	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84228	 26800	 0.003672	 0.012597	 0.00302	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26800	 84230	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26800	 84230	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26802	 26805	 0.000358	 0.004051	 0.03688	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26802	 27673	 0.000397	 0.004356	 0.04231	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26804	 84232	 0.04877	 0.074712	 0.00105	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26805	 84231	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26805	 84231	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26807	 26811	 0.040548	 0.1163	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26808	 26809	 0.001568	 0.008169	 0.00214	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26808	 26812	 0.02255	 0.059604	 0.01395	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84231	 26808	 0.002464	 0.019797	 0.00556	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26808	 84232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26808	 84232	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26809	 26813	 0.003853	 0.03305	 0.00941	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83952	 26809	 0.008599	 0.057696	 0.01393	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84232	 26810	 0.055035	 0.043554	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26811	 84233	 0.053945	 0.13205	 0.00226	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82038	 26812	 0.006559	 0.026262	 0.00662	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26812	 84233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26812	 84233	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26814	 26815	 0.000686	 0.004345	 0.00118	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26814	 26880	 0.000869	 0.005344	 0.00154	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26815	 26836	 0.00147	 0.00912	 0.00221	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26815	 27619	 0.000812	 0.00898	 0.00269	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26815	 27621	 0.002911	 0.011657	 0.00294	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26816	 84240	 0.023489	 0.018589	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26817	 84240	 0.006824	 0.019572	 0.0003	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26817	 84241	 0.018909	 0.037438	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26817	 84254	 0.007663	 0.014483	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26818	 26826	 0.001437	 0.005204	 0.00112	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26818	 26879	 0.000358	 0.00312	 0.00086	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26818	 26881	 0.002515	 0.006848	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26818	 84234	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26818	 84234	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26818	 84244	 0.004103	 0.025227	 0.00728	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26819	 26820	 0.014004	 0.011082	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26819	 26822	 0.028532	 0.022365	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26819	 26823	 0.024018	 0.018826	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26819	 84235	 0.009435	 0.011059	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26820	 26821	 0.017421	 0.013787	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26821	 84242	 0.017446	 0.015632	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26822	 84242	 0.027095	 0.019586	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26824	 26826	 0.001649	 0.004145	 0.00107	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26824	 84235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26824	 84235	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84234	 26825	 0.006077	 0.012032	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26825	 84236	 0.004431	 0.008683	 0.00013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26826	 84236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26826	 84236	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26827	 26829	 0.000881	 0.002329	 0.00055	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26827	 84237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26827	 84237	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26828	 26852	 0.002629	 0.014944	 0.00027	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84237	 26828	 0.002432	 0.010717	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26829	 26832	 0.001307	 0.003646	 0.00077	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26830	 26834	 0.001703	 0.004636	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26830	 26881	 0.001574	 0.004087	 0.00099	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26831	 26861	 0.009885	 0.056189	 0.00102	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26831	 26864	 0.005385	 0.013841	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26831	 84238	 0.002111	 0.011998	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26831	 84250	 0.015325	 0.027652	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26832	 84238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26832	 84238	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26833	 26835	 0.003113	 0.015746	 0.00027	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84238	 26833	 0.017427	 0.029356	 0.00042	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26833	 84250	 0.004115	 0.018129	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26834	 84239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26834	 84239	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84239	 26835	 0.001314	 0.005854	 0.0001	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26836	 26879	 0.000876	 0.006813	 0.00177	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26836	 84240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26836	 84240	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26837	 26882	 0.00462	 0.009899	 0.00017	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84240	 26837	 0.005991	 0.013908	 0.00021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26838	 26839	 0.017073	 0.013511	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84240	 26839	 0.007613	 0.015074	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26840	 26842	 0.007215	 0.014285	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26840	 26846	 0.046025	 0.036423	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26840	 84241	 0.02819	 0.022309	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26841	 26843	 0.000642	 0.005403	 0.0016	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26841	 26880	 0.001281	 0.009648	 0.00268	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26841	 84241	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26841	 84241	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26842	 26845	 0.004672	 0.023368	 0.00042	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84241	 26842	 0.004963	 0.012758	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26843	 84242	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26843	 84242	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26843	 84244	 0.001845	 0.015823	 0.0045	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84242	 26844	 0.005172	 0.010585	 0.00026	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26844	 84243	 0.010054	 0.028531	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26845	 84243	 0.003694	 0.019211	 0.00042	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26847	 84243	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26847	 84243	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26847	 84244	 0.001523	 0.008094	 0.00188	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26848	 26862	 0.000383	 0.006828	 0.07082	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26848	 84244	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26848	 84244	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84243	 26849	 0.035931	 0.028435	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84243	 26850	 0.048382	 0.031322	 0.0006	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26850	 84246	 0.02073	 0.027245	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84235	 26851	 0.005311	 0.021254	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26851	 84245	 0.009446	 0.024281	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26851	 84246	 0.002998	 0.015588	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26852	 84245	 0.003017	 0.016146	 0.00049	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26853	 84245	 0.022112	 0.036878	 0.00054	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26854	 84245	 0.026738	 0.020959	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26855	 84245	 0.009441	 0.006342	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26856	 26858	 0.001606	 0.009407	 0.00256	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26856	 84245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26856	 84245	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26857	 26858	 0.00187	 0.007108	 0.00199	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26857	 84246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26857	 84246	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26858	 26859	 0.000389	 0.005667	 0.00181	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84244	 26858	 0.003737	 0.014961	 0.00377	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26859	 26877	 0.001153	 0.012125	 0.00681	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26859	 84247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26859	 84247	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26860	 26861	 0.015497	 0.035978	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26860	 26876	 0.038722	 0.11106	 0.00171	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84247	 26860	 0.009743	 0.022099	 0.00044	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26861	 84249	 0.005356	 0.032931	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26861	 84253	 0.028922	 0.096484	 0.00153	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26862	 84248	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26863	 26865	 0.000734	 0.005719	 0.00171	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26863	 26867	 0.000665	 0.004133	 0.00117	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26863	 84250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26863	 84250	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26864	 26868	 0.017736	 0.017787	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26865	 27621	 0.002964	 0.018393	 0.00446	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26865	 84251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26865	 84251	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26866	 27636	 0.010447	 0.032048	 0.00087	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26866	 84252	 0.005835	 0.031222	 0.00095	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26867	 26869	 0.000961	 0.008083	 0.00239	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84248	 26869	 0.000838	 0.013621	 0.00386	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26869	 84252	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26869	 84252	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84249	 26870	 0.048852	 0.11342	 0.00169	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26870	 84390	 0.070697	 0.17981	 0.00284	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26871	 26872	 0.005779	 0.021023	 0.00644	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26871	 27638	 0.004796	 0.019202	 0.00484	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26872	 27239	 0.008016	 0.030468	 0.00853	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83645	 26872	 0.008331	 0.033355	 0.0084	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84248	 26872	 0.004409	 0.027923	 0.00758	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26873	 26874	 0.001918	 0.007677	 0.00193	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26873	 84465	 0.002161	 0.016432	 0.00516	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83646	 26875	 0.084796	 0.054899	 0.00105	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83646	 26876	 0.031337	 0.064129	 0.00158	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83641	 26877	 0.001175	 0.016139	 0.00582	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26877	 84253	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26877	 84253	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84244	 26878	 0.006212	 0.017817	 0.00438	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26879	 84254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26879	 84254	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26882	 26883	 0.008867	 0.022794	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26882	 84556	 0.038947	 0.0349	 0.00071	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84239	 26883	 0.005077	 0.016936	 0.00027	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26883	 84564	 0.013366	 0.035426	 0.0009	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26884	 26888	 0.016037	 0.012692	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26885	 26893	 0.001604	 0.004646	 0.00112	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26885	 84255	 0.002615	 0.008811	 0.00219	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26886	 84256	 0.028586	 0.022622	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26887	 27308	 0.003419	 0.03955	 0.34789	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26887	 84255	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26888	 26889	 0.008459	 0.010126	 0.00017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26888	 26890	 0.005543	 0.021563	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84256	 26888	 0.003228	 0.018139	 0.00034	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26889	 26891	 0.012942	 0.013821	 0.00029	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26890	 26894	 0.007171	 0.023921	 0.00038	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26890	 26900	 0.006249	 0.035519	 0.00064	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26891	 26892	 0.007474	 0.008221	 0.00011	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26892	 84257	 0.01174	 0.018318	 0.00031	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26893	 26895	 0.001632	 0.004195	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26893	 84257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26893	 84257	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26894	 26896	 0.038649	 0.079095	 0.00195	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26895	 26898	 0.002194	 0.005889	 0.00133	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26896	 27138	 0.054262	 0.12467	 0.00189	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26897	 26898	 0.009684	 0.025592	 0.00599	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26897	 27666	 0.011077	 0.11892	 0.03099	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26897	 27809	 0.005846	 0.029373	 0.00764	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26899	 26901	 0.038096	 0.17295	 0.00375	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26900	 26901	 0.014498	 0.070748	 0.00122	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84256	 26900	 0.019651	 0.0351	 0.00052	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84256	 26901	 0.057355	 0.11356	 0.00167	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26902	 26907	 0.003904	 0.018607	 0.00539	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26902	 26925	 0.002248	 0.012776	 0.0037	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26903	 26905	 0.061263	 0.074685	 0.0012	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83798	 26903	 0.015958	 0.07787	 0.00134	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26904	 26918	 0.007621	 0.019784	 0.0048	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26905	 84258	 0.023362	 0.046254	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26906	 26912	 0.002687	 0.007492	 0.00157	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26906	 26932	 0.005253	 0.014103	 0.0032	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26907	 26908	 0.004943	 0.019788	 0.00499	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26908	 26936	 0.005029	 0.01725	 0.00413	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26909	 26917	 0.003598	 0.009509	 0.00223	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26909	 26924	 0.007005	 0.019073	 0.0042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26910	 26912	 0.00186	 0.004676	 0.00121	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26910	 26917	 0.00307	 0.007718	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26911	 26916	 0.027949	 0.022118	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26912	 26913	 0.003512	 0.00943	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26913	 26914	 0.002583	 0.008704	 0.00216	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26913	 84258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26913	 84258	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26914	 26919	 0.00358	 0.011678	 0.0031	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26914	 26922	 0.009155	 0.035616	 0.00951	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83808	 26914	 0.039867	 0.10541	 0.02469	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26914	 84259	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26914	 84259	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84258	 26915	 0.040299	 0.052446	 0.00073	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84259	 26915	 0.039265	 0.031074	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26915	 84261	 0.054698	 0.15523	 0.00244	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26916	 84260	 0.008649	 0.022234	 0.00034	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26917	 84260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26917	 84260	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26918	 26922	 0.007236	 0.020177	 0.00423	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26919	 26923	 0.005806	 0.020236	 0.00469	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84190	 26920	 0.054193	 0.13783	 0.00218	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26920	 84261	 0.033791	 0.096918	 0.00149	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26921	 26922	 0.002189	 0.008319	 0.00233	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26921	 27753	 0.004204	 0.023067	 0.0061	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26922	 84261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26922	 84261	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26923	 27754	 0.005983	 0.027448	 0.00703	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26923	 84262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26923	 84262	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26924	 27763	 0.007989	 0.02074	 0.00503	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83797	 26925	 0.001586	 0.009352	 0.00762	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26925	 84263	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26925	 84263	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26926	 26927	 0.004199	 0.016336	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84263	 26926	 0.005705	 0.019031	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26927	 26934	 0.008587	 0.019935	 0.0003	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26927	 84264	 0.011304	 0.029059	 0.00045	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26928	 84264	 0.022977	 0.016905	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26929	 26932	 0.004553	 0.012032	 0.00282	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83797	 26929	 0.001601	 0.00834	 0.00219	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26929	 84264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26929	 84264	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26930	 26931	 0.023043	 0.023274	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84263	 26930	 0.00632	 0.031968	 0.00056	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26935	 84265	 0.022352	 0.044255	 0.00065	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26935	 84267	 0.005701	 0.039133	 0.00071	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26935	 84533	 0.019017	 0.085092	 0.00175	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26936	 26937	 0.004068	 0.010921	 0.00248	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26936	 84265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26936	 84265	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26937	 27758	 0.002339	 0.014148	 0.00361	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26937	 84266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26937	 84266	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26938	 27764	 0.002527	 0.01233	 0.00341	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26938	 84267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26938	 84267	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26939	 26943	 0.002189	 0.034069	 0.01057	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83539	 26939	 0.003413	 0.024028	 0.01366	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26940	 26942	 0.00021	 0.004121	 0.06604	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26940	 84268	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26940	 84268	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26941	 84269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26941	 84269	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82000	 26942	 0.000186	 0.002952	 0.04846	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26942	 84270	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26942	 84270	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84270	 26943	 0.00114	 0.012285	 0.00657	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26943	 84271	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26943	 84271	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84271	 26944	 0.031396	 0.096319	 0.00261	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84271	 26944	 0.031396	 0.096319	 0.00261	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26945	 26946	 0.092942	 0.12096	 0.00169	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26945	 27677	 0.16755	 0.13261	 0.00167	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26945	 27682	 0.19057	 0.19116	 0.00309	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26946	 84272	 0.0208	 0.069389	 0.0011	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26946	 84273	 0.16493	 0.12929	 0.00166	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26947	 26948	 0.002647	 0.01705	 0.00447	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26947	 26950	 0.0036	 0.017752	 0.0048	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26947	 84272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26947	 84272	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26948	 26949	 0.002379	 0.006176	 0.0015	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26948	 84273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26948	 84273	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26949	 26951	 0.005957	 0.014975	 0.00388	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26949	 84274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26949	 84274	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26950	 26953	 0.003028	 0.027542	 0.00695	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26950	 84275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26950	 84275	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26951	 84276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26951	 84276	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26952	 84277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26952	 84277	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26954	 26958	 0.002047	 0.015687	 0.0042	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26954	 27361	 0.012259	 0.044392	 0.00953	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26954	 84278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26954	 84278	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26955	 26957	 0.013086	 0.037534	 0.00058	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26955	 84279	 0.010797	 0.052685	 0.00091	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26956	 26960	 0.001421	 0.01142	 0.00321	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26956	 84279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26956	 84279	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26956	 84282	 0.004226	 0.01692	 0.00426	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26957	 27366	 0.094981	 0.10447	 0.00139	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26957	 84280	 0.1009	 0.079095	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26958	 84280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26958	 84280	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26958	 84282	 0.001753	 0.014936	 0.00373	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26959	 26960	 0.000965	 0.011027	 0.00336	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82050	 26961	 0.029899	 0.20289	 0.00379	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26961	 84283	 0.014374	 0.077201	 0.00183	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26962	 26963	 0.004884	 0.01879	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26962	 27123	 0.11577	 0.11694	 0.00155	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83812	 26962	 0.042303	 0.16276	 0.00278	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26963	 84343	 0.038571	 0.099154	 0.00153	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26964	 84281	 0.014686	 0.036452	 0.00061	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26964	 84348	 0.039733	 0.090871	 0.00222	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26965	 26966	 0.002491	 0.006403	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26965	 26972	 0.006408	 0.015443	 0.00436	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26965	 27114	 0.003839	 0.019902	 0.00486	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26965	 84281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26965	 84281	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26966	 26973	 0.005843	 0.014687	 0.00381	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26967	 84282	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84283	 26968	 0.03829	 0.06909	 0.001	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26969	 26970	 0.013098	 0.023989	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26970	 84285	 0.013405	 0.034458	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26970	 84345	 0.042477	 0.13045	 0.00245	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26971	 26972	 0.003136	 0.008419	 0.00191	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26971	 84284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26971	 84284	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84282	 26972	 0.00677	 0.017893	 0.00419	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26972	 84285	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26972	 84285	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26973	 27104	 0.004369	 0.015443	 0.00348	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26973	 84286	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26973	 84286	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84286	 26974	 0.24714	 0.19376	 0.00249	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26975	 26976	 0.11075	 0.21931	 0.00322	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82036	 26975	 0.071377	 0.21923	 0.00411	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26976	 26977	 0.014638	 0.065229	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26977	 26978	 0.023092	 0.10117	 0.00218	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26978	 84604	 0.032908	 0.18708	 0.00339	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26979	 26988	 0.000198	 0.002198	 0.02093	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26979	 27086	 5.9e-05	 0.000642	 0.00624	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26979	 84287	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26980	 26981	 0.011846	 0.011849	 0.00016	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84288	 26980	 0.011465	 0.015068	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26980	 84331	 0.008813	 0.01745	 0.00026	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26981	 84289	 0.005268	 0.010429	 0.00015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26981	 84290	 0.008257	 0.016347	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26982	 26983	 0.000384	 0.003297	 0.00094	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26982	 27014	 0.000422	 0.003427	 0.00109	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26982	 84289	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26982	 84289	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26983	 27090	 0.000751	 0.006032	 0.0017	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26983	 84290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26983	 84290	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26984	 26985	 0.012407	 0.009819	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26985	 84293	 0.016972	 0.013431	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84290	 26986	 0.015153	 0.011992	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26987	 26990	 0.003357	 0.01306	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26987	 27130	 0.011423	 0.021589	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26987	 84292	 0.003027	 0.010096	 0.00016	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26988	 26989	 4e-05	 0.000457	 0.00416	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26988	 84291	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26989	 27129	 4.6e-05	 0.000527	 0.00479	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	26989	 84293	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26989	 84293	 0.004748	 0.17093	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26990	 26993	 0.003356	 0.008894	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26991	 26994	 0.000273	 0.003072	 0.00089	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84291	 26991	 0.000114	 0.001842	 0.0006	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26992	 26994	 0.000364	 0.005305	 0.0017	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26992	 84294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26992	 84294	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26992	 84302	 0.000428	 0.006229	 0.00199	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26993	 27092	 0.00346	 0.010614	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26993	 84295	 0.035028	 0.027457	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26993	 84334	 0.003235	 0.014415	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26994	 26995	 0.000302	 0.003321	 0.00197	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26994	 84295	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26994	 84295	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26995	 27093	 0.002996	 0.008677	 0.00209	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26995	 27094	 0.001326	 0.007765	 0.00212	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26995	 27097	 0.002508	 0.008604	 0.00206	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83977	 26995	 0.004035	 0.023636	 0.00644	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26996	 27013	 0.000104	 0.001748	 0.01808	 998.0	 1047.9	 1097.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26996	 84296	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26997	 27097	 0.000368	 0.00432	 0.00115	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84296	 26997	 0.000276	 0.004346	 0.00148	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26998	 27009	 0.003266	 0.010893	 0.00017	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84294	 26998	 0.01834	 0.024104	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84297	 26998	 0.004766	 0.01367	 0.00021	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26999	 27000	 0.002732	 0.007753	 0.00012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84297	 26999	 0.00344	 0.013235	 0.00023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27000	 27001	 0.004666	 0.011995	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27001	 27002	 0.007672	 0.019721	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27001	 84338	 0.003207	 0.012476	 0.00021	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27002	 27003	 0.006664	 0.013194	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27002	 84300	 0.003711	 0.021094	 0.00038	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27003	 27101	 0.015382	 0.016919	 0.00023	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27004	 27101	 0.003731	 0.010586	 0.00017	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27004	 84308	 0.005802	 0.016071	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27005	 84298	 0.002816	 0.011271	 0.00024	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27005	 84307	 0.004215	 0.011142	 0.0002	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27006	 27009	 0.00307	 0.009419	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27006	 84298	 0.00221	 0.009736	 0.00017	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27007	 27008	 0.000918	 0.002426	 0.00057	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27007	 27033	 0.001106	 0.004004	 0.00086	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27007	 84298	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27007	 84298	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27008	 84299	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27008	 84299	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27009	 84300	 0.00609	 0.01151	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27010	 84300	 0.006193	 0.012262	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27010	 84301	 0.0025	 0.006426	 0.0001	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27011	 27012	 0.000875	 0.004396	 0.00114	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27011	 27022	 0.000539	 0.004328	 0.00122	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84296	 27011	 0.000945	 0.007348	 0.00191	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27011	 84300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27011	 84300	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27012	 84301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27012	 84301	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27012	 84302	 0.00034	 0.003757	 0.00113	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27013	 27129	 6.6e-05	 0.000721	 0.00708	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27013	 84302	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27013	 84302	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27014	 27015	 0.000341	 0.002739	 0.00077	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27014	 84351	 0.002651	 0.007005	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27015	 27017	 0.000287	 0.003335	 0.00098	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27015	 84351	 0.001437	 0.005754	 0.00145	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82047	 27016	 0.009447	 0.021933	 0.00033	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27016	 84303	 0.005159	 0.011978	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27017	 27018	 0.000577	 0.004062	 0.00231	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27017	 84303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27017	 84303	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27018	 27047	 0.000613	 0.005426	 0.00298	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82046	 27018	 0.001652	 0.006493	 0.0017	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27018	 84304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27018	 84304	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27019	 27020	 0.002989	 0.0115	 0.0002	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84289	 27019	 0.012035	 0.034518	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27019	 84330	 0.014444	 0.010943	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27020	 27077	 0.006569	 0.01884	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84303	 27020	 0.009285	 0.010883	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27021	 27022	 0.000297	 0.00199	 0.00061	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27021	 27023	 0.000371	 0.002372	 0.0008	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27022	 84305	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27022	 84305	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82046	 27023	 0.000692	 0.005115	 0.00148	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27024	 27025	 0.001674	 0.004669	 0.00098	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27024	 27046	 0.001694	 0.004612	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27025	 27026	 0.000383	 0.004452	 0.00131	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27025	 27032	 0.000479	 0.005365	 0.00171	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27026	 27065	 0.000725	 0.005371	 0.00275	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27027	 27028	 0.000219	 0.002283	 0.00063	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27027	 27029	 0.000264	 0.002713	 0.00086	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27028	 27040	 0.000419	 0.003809	 0.00096	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27029	 27051	 0.000286	 0.002966	 0.00092	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27030	 27031	 0.013058	 0.010334	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27030	 84310	 0.012826	 0.013097	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27031	 84306	 0.008569	 0.011261	 0.00015	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27032	 27033	 0.000204	 0.001947	 0.00064	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27032	 84306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27032	 84306	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27033	 27035	 0.000605	 0.003255	 0.00089	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27034	 27035	 0.000279	 0.003012	 0.00086	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27034	 27036	 0.000286	 0.003489	 0.00115	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27034	 84307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27034	 84307	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27035	 27039	 0.000844	 0.003378	 0.00085	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27036	 27100	 0.000832	 0.008924	 0.00232	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27036	 84308	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27036	 84308	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27037	 27038	 0.002343	 0.008203	 0.00023	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84308	 27037	 0.004624	 0.014186	 0.00038	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27037	 84309	 0.004456	 0.015918	 0.00032	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27038	 84311	 0.002785	 0.013591	 0.00023	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27039	 27040	 0.000274	 0.002063	 0.00057	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27039	 84309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27039	 84309	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27040	 84310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27040	 84310	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27041	 84311	 0.001116	 0.00628	 0.00014	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27041	 84312	 0.001615	 0.009086	 0.0002	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27042	 27043	 0.000321	 0.003953	 0.00128	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27042	 84311	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27042	 84311	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27043	 27044	 0.000212	 0.003238	 0.00104	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27043	 84312	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27043	 84312	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27044	 84313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27044	 84313	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27044	 84316	 0.000239	 0.003726	 0.00116	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84313	 27045	 0.013047	 0.010008	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82046	 27046	 0.001549	 0.006086	 0.00159	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27046	 84322	 0.002206	 0.014211	 0.00373	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27047	 27066	 0.000372	 0.003687	 0.00113	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27047	 84322	 0.001329	 0.008692	 0.00221	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27048	 27049	 0.006826	 0.017691	 0.00033	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27048	 84314	 0.011435	 0.014882	 0.00021	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27048	 84315	 0.00495	 0.015184	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27049	 84321	 0.005567	 0.017097	 0.00032	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27050	 27051	 0.000599	 0.003529	 0.00287	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27050	 27058	 0.000354	 0.003206	 0.00168	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27050	 84314	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27050	 84314	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27051	 84315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27051	 84315	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84313	 27052	 0.009191	 0.015267	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27053	 27054	 9.7e-05	 0.001099	 0.00993	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27053	 27055	 7.6e-05	 0.001272	 0.01183	 970.0	 1018.5	 1067.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27053	 84316	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27053	 84316	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27054	 84317	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27054	 84317	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27055	 27057	 9.9e-05	 0.001082	 0.01051	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27055	 84318	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27055	 84318	 0.001681	 0.073981	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27056	 27695	 0.002115	 0.011269	 0.00316	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27056	 84319	 0.001002	 0.004743	 0.00114	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27057	 27694	 0.000271	 0.00491	 0.04908	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27057	 84319	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27057	 84319	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27058	 27059	 0.001495	 0.006329	 0.00142	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27058	 27063	 0.001126	 0.008145	 0.00438	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27058	 84320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27058	 84320	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84317	 27059	 0.000567	 0.00477	 0.00141	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84319	 27059	 0.001664	 0.008666	 0.00227	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27060	 27061	 0.002093	 0.006826	 0.00181	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27060	 27063	 0.002023	 0.006818	 0.00169	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27062	 27065	 0.000284	 0.003185	 0.00101	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27062	 84323	 0.000326	 0.002294	 0.0013	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27063	 27073	 0.000317	 0.004612	 0.00148	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27064	 84321	 0.006173	 0.016361	 0.00041	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27064	 84324	 0.005602	 0.02155	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27065	 84321	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27065	 84321	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27066	 27076	 0.001573	 0.011382	 0.00612	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82048	 27066	 0.001361	 0.014672	 0.00784	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27066	 84322	 0.000468	 0.004955	 0.00147	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27067	 27068	 7.3e-05	 0.000843	 0.00739	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27067	 27069	 7e-05	 0.000768	 0.00754	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27067	 27072	 8e-05	 0.001483	 0.01424	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27067	 84322	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27067	 84322	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27068	 27069	 6.8e-05	 0.000757	 0.00714	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27068	 27072	 6e-05	 0.001058	 0.01132	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27068	 84323	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27069	 84325	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27069	 84325	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27070	 27074	 0.000617	 0.006441	 0.00177	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84325	 27070	 0.000272	 0.0041	 0.00122	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27070	 84327	 0.001897	 0.006869	 0.00147	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27070	 84349	 0.002813	 0.018874	 0.00456	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27071	 27072	 8.8e-05	 0.000926	 0.01385	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27071	 27687	 0.000116	 0.002056	 0.02154	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27071	 27689	 0.000181	 0.001987	 0.0193	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27071	 84326	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27071	 84326	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27072	 84327	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27072	 84327	 0.000282	 0.019731	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84326	 27073	 0.000438	 0.004608	 0.00259	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84327	 27073	 0.000848	 0.006352	 0.00155	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82048	 27074	 0.000804	 0.006892	 0.00196	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27074	 84328	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27074	 84328	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27075	 27125	 0.002698	 0.030858	 0.00864	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27075	 84349	 0.001993	 0.014418	 0.00776	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27076	 27080	 0.000754	 0.005335	 0.00146	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27076	 84329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27076	 84329	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84304	 27077	 0.010563	 0.027153	 0.00042	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84329	 27077	 0.014144	 0.025521	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27078	 27084	 0.044807	 0.03546	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27079	 27118	 0.008508	 0.024403	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27079	 84333	 0.00463	 0.022224	 0.00066	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27080	 27081	 0.000661	 0.004979	 0.00138	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27081	 27082	 0.000744	 0.005941	 0.00146	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27081	 84330	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27081	 84330	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84287	 27082	 0.001637	 0.006553	 0.00165	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27082	 84331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27082	 84331	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84331	 27083	 0.047031	 0.030448	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84331	 27084	 0.018367	 0.047214	 0.00073	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84288	 27085	 0.030229	 0.01957	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27086	 84332	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27086	 84332	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27087	 27089	 0.001582	 0.004108	 0.001	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27087	 27091	 0.001051	 0.009173	 0.00252	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84332	 27087	 0.000298	 0.003884	 0.00112	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27087	 84333	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27087	 84333	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27088	 27119	 0.03958	 0.031323	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84333	 27088	 0.006993	 0.020056	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27088	 84335	 0.009805	 0.024936	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27089	 27090	 0.001044	 0.003078	 0.00072	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27090	 84334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27090	 84334	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27091	 27093	 0.001854	 0.007422	 0.00187	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27091	 84335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27091	 84335	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27092	 84336	 0.008123	 0.018577	 0.00045	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27093	 27113	 0.00313	 0.010736	 0.00257	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27093	 84336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27093	 84336	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27094	 27096	 0.001066	 0.005445	 0.00137	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83978	 27095	 0.050725	 0.049632	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27095	 84337	 0.008028	 0.019011	 0.00035	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27095	 84342	 0.018898	 0.026787	 0.00055	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27096	 27109	 0.001545	 0.005299	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27096	 84337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27096	 84337	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27098	 27100	 0.000359	 0.003806	 0.00113	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27098	 27102	 0.000256	 0.002016	 0.00059	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27098	 84338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27098	 84338	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84338	 27099	 0.004103	 0.011643	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27099	 84340	 0.003253	 0.006657	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27100	 84339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27100	 84339	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84339	 27101	 0.004906	 0.012612	 0.0002	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83977	 27102	 0.00264	 0.017713	 0.00428	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27102	 84340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27102	 84340	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27103	 27106	 0.018946	 0.018612	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84336	 27103	 0.009972	 0.044437	 0.00075	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27104	 27110	 0.003751	 0.009739	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27104	 84341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27104	 84341	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84341	 27105	 0.0135	 0.013635	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27106	 84342	 0.01081	 0.014207	 0.00019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27107	 27108	 0.001355	 0.004907	 0.00105	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27107	 84342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27107	 84342	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27108	 27109	 0.001105	 0.003605	 0.00096	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83977	 27110	 0.004055	 0.013664	 0.0034	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27111	 27115	 0.002581	 0.010334	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27111	 27122	 0.002747	 0.0126	 0.00323	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27111	 84343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27111	 84343	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27112	 27116	 0.040558	 0.031792	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27112	 84344	 0.023824	 0.039732	 0.00058	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27113	 27115	 0.003393	 0.011318	 0.00287	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27113	 84344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27113	 84344	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27114	 27115	 0.001401	 0.0061	 0.00174	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83977	 27114	 0.013524	 0.036823	 0.00811	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27114	 84345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27114	 84345	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27115	 84346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27115	 84346	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84343	 27116	 0.015218	 0.031143	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84346	 27116	 0.014286	 0.021667	 0.00031	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27117	 27121	 0.000443	 0.004962	 0.00158	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27117	 27125	 0.003125	 0.027267	 0.00749	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27117	 84347	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27117	 84347	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27118	 84348	 0.020096	 0.033852	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84347	 27120	 0.04098	 0.053859	 0.00074	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27121	 27122	 0.000464	 0.004599	 0.00141	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27122	 84348	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27122	 84348	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27123	 27124	 0.026735	 0.048053	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84329	 27124	 0.24397	 0.18488	 0.00255	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84347	 27124	 0.021311	 0.071093	 0.00113	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27124	 84403	 0.012474	 0.097222	 0.00182	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27126	 84350	 0.041369	 0.096045	 0.00143	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83585	 27127	 0.05239	 0.066676	 0.00098	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27127	 84350	 0.063815	 0.061659	 0.0009	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27128	 27246	 0.000371	 0.006858	 0.06589	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27128	 27687	 0.000275	 0.003014	 0.02928	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27128	 84349	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27129	 84351	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84292	 27130	 0.004052	 0.011621	 0.00018	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84294	 27130	 0.00601	 0.011779	 0.00018	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84340	 27131	 0.01809	 0.013077	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82012	 27132	 0.000361	 0.004166	 0.03652	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27132	 84353	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27132	 84353	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27133	 27134	 0.011438	 0.03023	 0.00708	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27133	 27156	 0.007379	 0.073231	 0.01992	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27133	 27185	 0.02132	 0.055356	 0.01344	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84353	 27133	 0.004552	 0.026438	 0.00623	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27134	 27185	 0.011109	 0.028841	 0.007	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82022	 27135	 0.038315	 0.1099	 0.00169	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27136	 27137	 0.009037	 0.024605	 0.00542	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27136	 84354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27136	 84354	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27137	 27140	 0.005716	 0.03078	 0.00846	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27137	 27288	 0.009553	 0.034591	 0.00742	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27138	 27139	 0.047519	 0.10779	 0.00215	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83819	 27138	 0.15168	 0.39009	 0.00604	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84354	 27138	 0.055919	 0.14375	 0.00222	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27140	 27141	 0.005002	 0.028738	 0.00814	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27141	 84355	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27141	 84355	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27142	 27148	 0.000553	 0.006264	 0.05703	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27142	 27160	 0.000406	 0.004193	 0.06588	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27142	 27160	 0.000406	 0.004193	 0.06588	 1097.0	 1151.9	 1206.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82028	 27143	 0.015282	 0.039287	 0.00973	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27143	 84356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27143	 84356	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84356	 27144	 0.072432	 0.094264	 0.00132	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27145	 27156	 0.005947	 0.026055	 0.00896	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27146	 27155	 0.004386	 0.012932	 0.00301	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27146	 84357	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27146	 84357	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27146	 84358	 0.006371	 0.016837	 0.00394	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27147	 84359	 0.019499	 0.038606	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27148	 27150	 0.000179	 0.00207	 0.01815	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27148	 84358	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84356	 27149	 0.054721	 0.1495	 0.00254	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84359	 27149	 0.015581	 0.036173	 0.00054	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27149	 84361	 0.003014	 0.010553	 0.00029	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27150	 27183	 0.001083	 0.012266	 0.1117	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27150	 84360	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27151	 27159	 0.004287	 0.014302	 0.00363	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84360	 27151	 0.002357	 0.008084	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27152	 27153	 0.00177	 0.006073	 0.00145	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27152	 27157	 0.01062	 0.0273	 0.00676	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27152	 27159	 0.005495	 0.014242	 0.00431	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84360	 27153	 0.002271	 0.00779	 0.00187	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27153	 84362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27153	 84362	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27154	 27155	 0.002237	 0.005808	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27154	 84363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27154	 84363	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27155	 27156	 0.00262	 0.008987	 0.00215	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27156	 27157	 0.007228	 0.019102	 0.00447	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27157	 27184	 0.006532	 0.026151	 0.00659	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27158	 27159	 0.003617	 0.032849	 0.0107	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84353	 27158	 0.004472	 0.048996	 0.01359	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83984	 27160	 0.000181	 0.004251	 0.0806	 1940.0	 2037.0	 2134.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27161	 84365	 0.009048	 0.035564	 0.0093	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27162	 84364	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27162	 84364	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27162	 84364	 0.000136	 0.010888	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84365	 27162	 0.000178	 0.014266	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 0	 -30.0	 30.0;
	84365	 27162	 0.000178	 0.014266	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 0	 -30.0	 30.0;
	27163	 84605	 0.21822	 0.17272	 0.00217	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27164	 27166	 0.018503	 0.081525	 0.00142	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82002	 27164	 0.048858	 0.21774	 0.0037	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27165	 27166	 0.008532	 0.026174	 0.00071	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27165	 84367	 0.010729	 0.038328	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27165	 84368	 0.026303	 0.075442	 0.00116	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27167	 27176	 0.000368	 0.004754	 0.07978	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27167	 84366	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84367	 27168	 0.081485	 0.064487	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27169	 27170	 0.001141	 0.007079	 0.00171	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84366	 27169	 0.001588	 0.016251	 0.00966	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27169	 84368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27169	 84368	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27169	 84372	 0.001163	 0.013661	 0.00362	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27170	 84372	 0.001072	 0.006593	 0.0019	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27171	 27172	 0.035933	 0.028437	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82002	 27172	 0.039552	 0.07109	 0.00128	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27173	 27174	 0.000342	 0.003749	 0.03641	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27174	 84369	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84369	 27175	 0.006952	 0.018928	 0.00417	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27175	 84371	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27175	 84371	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27176	 84372	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27176	 84372	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27177	 84375	 0.027787	 0.1081	 0.0018	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27178	 27180	 0.0117	 0.030076	 0.00745	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27178	 84373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27178	 84373	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27179	 84374	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27179	 84374	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84374	 27180	 0.002864	 0.020716	 0.01115	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27180	 84375	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27180	 84375	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84375	 27181	 0.1464	 0.16104	 0.00215	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27182	 84376	 0.002603	 0.015348	 0.0125	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27183	 27186	 0.000401	 0.004379	 0.04299	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27183	 84376	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27183	 84376	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27184	 84377	 0.005118	 0.027558	 0.00757	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83536	 27185	 0.002593	 0.026529	 0.01577	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27185	 84377	 0.001643	 0.018079	 0.01074	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27186	 84377	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27186	 84377	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84094	 27187	 0.003647	 0.026387	 0.0142	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84377	 27187	 0.002161	 0.016011	 0.0082	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27188	 27191	 0.000153	 0.001734	 0.01579	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27188	 84378	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27189	 27190	 0.010056	 0.018145	 0.00026	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84379	 27189	 0.004103	 0.010547	 0.00016	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27191	 27192	 0.00022	 0.002442	 0.02325	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27191	 27198	 0.000532	 0.006349	 0.05782	 768.0	 806.4	 844.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27191	 84380	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27191	 84380	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27192	 27200	 0.000359	 0.004011	 0.03748	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27192	 84381	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27192	 84381	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84381	 27193	 0.002567	 0.031188	 0.0084	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84380	 27194	 0.002502	 0.02155	 0.01251	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27195	 27196	 0.000146	 0.002282	 0.02405	 960.0	 1008.0	 1056.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27195	 84382	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27195	 84382	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82038	 27197	 0.002617	 0.024628	 0.00746	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84380	 27197	 0.007416	 0.042611	 0.01207	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27198	 27199	 0.000221	 0.003504	 0.05753	 1419.0	 1489.9	 1560.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27199	 27292	 0.000442	 0.005455	 0.08647	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27199	 84383	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27199	 84383	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27200	 27291	 0.00025	 0.003	 0.05036	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27200	 84384	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27200	 84384	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27201	 27303	 0.000719	 0.009267	 0.17987	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27201	 27324	 0.000224	 0.004151	 0.07443	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27201	 84385	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27201	 84385	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27202	 27204	 0.001992	 0.018121	 0.00457	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84385	 27202	 0.001866	 0.021329	 0.00651	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27203	 84386	 0.01472	 0.065592	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27203	 84441	 0.056974	 0.25392	 0.00431	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27204	 27306	 0.00321	 0.026634	 0.00701	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27204	 84386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27204	 84386	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27205	 27206	 0.003081	 0.029581	 0.00861	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27205	 27307	 0.001827	 0.015583	 0.01338	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83499	 27205	 0.007234	 0.052526	 0.01815	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27206	 27325	 0.003587	 0.031333	 0.01241	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27207	 27208	 0.028259	 0.080192	 0.00126	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27207	 27209	 0.029646	 0.0678	 0.00166	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27207	 84388	 0.041431	 0.11883	 0.00183	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27208	 27608	 0.012704	 0.060982	 0.00182	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83969	 27208	 0.06948	 0.17247	 0.00287	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27209	 27215	 0.017716	 0.078057	 0.00136	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27210	 27211	 0.002527	 0.009933	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27211	 27214	 0.001385	 0.010797	 0.00323	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27211	 84537	 0.007761	 0.030502	 0.00798	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27212	 27214	 0.002973	 0.010017	 0.00249	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27212	 27532	 0.004195	 0.016321	 0.00436	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27212	 84387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27212	 84387	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27213	 27214	 0.000911	 0.010607	 0.00312	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27213	 27227	 0.001577	 0.013778	 0.00546	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27215	 27216	 0.030113	 0.068868	 0.00168	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27215	 84393	 0.010941	 0.0751	 0.00137	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27216	 84388	 0.017443	 0.061071	 0.00169	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27216	 84389	 0.022385	 0.074674	 0.00118	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27217	 27219	 0.007565	 0.017561	 0.00535	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27217	 84388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27217	 84388	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27218	 27220	 0.002016	 0.01935	 0.00563	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27218	 27222	 0.001314	 0.016536	 0.00512	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27218	 84389	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27218	 84389	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27219	 27639	 0.005523	 0.018013	 0.00478	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27219	 84390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27219	 84390	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27220	 27221	 0.001985	 0.018685	 0.00566	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27221	 27239	 0.005018	 0.020089	 0.00506	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27221	 84391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27221	 84391	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27222	 27223	 0.000501	 0.004713	 0.00143	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27222	 84392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27222	 84392	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27223	 27224	 0.001559	 0.006242	 0.00157	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27223	 27226	 0.000598	 0.005846	 0.00164	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27223	 84393	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27223	 84393	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27224	 27237	 0.004268	 0.018062	 0.00406	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27225	 27236	 0.007834	 0.024033	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84392	 27225	 0.005675	 0.021834	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27226	 27233	 0.00068	 0.006529	 0.0019	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27227	 27233	 0.000536	 0.004646	 0.00167	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27227	 84394	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27227	 84394	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27227	 84397	 0.000732	 0.010568	 0.00336	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27228	 27541	 0.003392	 0.00872	 0.00216	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27228	 84395	 0.002694	 0.00712	 0.00167	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27229	 27234	 0.000126	 0.001427	 0.01299	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27229	 27235	 0.000255	 0.002844	 0.02682	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27229	 27488	 0.000673	 0.007653	 0.06912	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27229	 27570	 0.000449	 0.007956	 0.08335	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27229	 84395	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27230	 27231	 0.002125	 0.010812	 0.00024	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84396	 27230	 0.00301	 0.012563	 0.00036	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27230	 84398	 0.013433	 0.028232	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27231	 27232	 0.012258	 0.012294	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84394	 27231	 0.002835	 0.012632	 0.00021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27234	 27241	 0.000388	 0.004395	 0.04002	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27234	 84397	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27235	 27241	 0.000254	 0.002893	 0.02612	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27235	 27464	 0.000334	 0.003665	 0.0356	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27235	 84399	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84400	 27236	 0.016393	 0.080034	 0.00168	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27237	 27240	 0.004266	 0.017612	 0.00417	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27238	 27240	 0.00543	 0.02174	 0.00548	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27238	 27391	 0.005414	 0.020579	 0.00576	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27241	 27407	 0.000861	 0.010701	 0.10752	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27241	 84401	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27242	 27243	 0.028307	 0.075029	 0.0019	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82710	 27242	 0.023156	 0.090083	 0.0015	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27243	 84407	 0.13516	 0.11125	 0.00225	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27244	 84403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27244	 84403	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27244	 84404	 0.00735	 0.025981	 0.00585	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27245	 27246	 0.00036	 0.003955	 0.03842	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27245	 27252	 0.000571	 0.007819	 0.07969	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27245	 84404	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27245	 84404	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27246	 84405	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27247	 27248	 0.090784	 0.058775	 0.00112	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27247	 84407	 0.018375	 0.032315	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27248	 27251	 0.022468	 0.064441	 0.00099	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84406	 27248	 0.039358	 0.080883	 0.00154	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27248	 84407	 0.021825	 0.043213	 0.00063	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84404	 27249	 0.009093	 0.024033	 0.00563	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27249	 84407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27249	 84407	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27249	 84408	 0.011376	 0.039025	 0.00935	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27250	 27251	 0.10443	 0.082649	 0.00104	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27251	 84409	 0.027152	 0.063028	 0.0012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27252	 84408	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84405	 27253	 0.009777	 0.025841	 0.00605	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27254	 27256	 0.00828	 0.029266	 0.00659	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27255	 27260	 0.064311	 0.18447	 0.00284	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84088	 27255	 0.2885	 0.21865	 0.00301	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83504	 27256	 0.007973	 0.068392	 0.01947	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27256	 84410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27256	 84410	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27258	 27259	 0.021534	 0.075398	 0.00209	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84410	 27258	 0.052882	 0.10471	 0.00154	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27259	 27260	 0.040921	 0.11737	 0.00181	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83505	 27259	 0.06535	 0.18546	 0.00291	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27260	 84578	 0.016422	 0.11273	 0.00206	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27261	 27262	 0.001258	 0.003324	 0.00078	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27261	 27267	 0.002432	 0.006529	 0.00148	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27261	 84411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27261	 84411	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27262	 27270	 0.001404	 0.003916	 0.00082	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27262	 84412	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27262	 84412	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27263	 27264	 0.00567	 0.011112	 0.00017	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84412	 27263	 0.021003	 0.016463	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27263	 84414	 0.014832	 0.014981	 0.0002	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27263	 84415	 0.031603	 0.024772	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27264	 27273	 0.003332	 0.016663	 0.0003	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27264	 84415	 0.024778	 0.031135	 0.00047	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27264	 84425	 0.007088	 0.020112	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27265	 27275	 0.003096	 0.008039	 0.00195	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27265	 27290	 0.001742	 0.004743	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27266	 84413	 0.039777	 0.031479	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27266	 84425	 0.019665	 0.031546	 0.00058	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27267	 27275	 0.006659	 0.017287	 0.0042	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27267	 84413	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27267	 84413	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27267	 84418	 0.008	 0.022309	 0.00468	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27268	 27278	 0.013673	 0.027072	 0.0004	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84411	 27268	 0.010105	 0.015767	 0.00026	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27269	 27278	 0.013095	 0.025927	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27269	 84414	 0.015072	 0.021005	 0.00036	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27270	 27271	 0.001681	 0.004442	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27270	 84414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27270	 84414	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27271	 27282	 0.004212	 0.011132	 0.00261	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27271	 84415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27271	 84415	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27272	 27273	 0.011998	 0.017563	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27273	 84416	 0.032387	 0.032395	 0.00044	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83522	 27274	 0.021272	 0.056226	 0.01316	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27274	 84416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27274	 84416	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27275	 27276	 0.00421	 0.014184	 0.00353	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27276	 84417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27276	 84417	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27277	 27289	 0.000364	 0.004227	 0.03654	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27277	 84418	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27278	 27279	 0.008129	 0.031624	 0.00053	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27278	 27280	 0.023921	 0.06861	 0.00106	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84419	 27279	 0.048761	 0.096544	 0.00142	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27279	 84423	 0.01969	 0.099605	 0.00173	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84118	 27280	 0.043191	 0.15124	 0.00419	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27281	 27282	 0.003185	 0.009955	 0.00288	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27281	 84420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27281	 84420	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27282	 84421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27282	 84421	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83666	 27283	 0.014131	 0.062969	 0.00107	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27284	 27286	 0.075382	 0.068013	 0.00114	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84416	 27285	 0.011141	 0.056015	 0.00152	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83522	 27287	 0.016516	 0.043653	 0.01022	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27287	 84422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27287	 84422	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27288	 27290	 0.007366	 0.045775	 0.01292	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27288	 84423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27288	 84423	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27289	 84424	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27289	 84424	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27290	 84425	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27290	 84425	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27291	 27304	 0.000227	 0.003051	 0.05451	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27291	 84426	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27291	 84426	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27292	 27296	 0.000419	 0.004573	 0.0449	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27292	 27301	 0.000288	 0.003258	 0.02966	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27293	 27298	 0.000576	 0.005926	 0.00168	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27293	 84427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27293	 84427	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27293	 84433	 0.001402	 0.005329	 0.00149	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84383	 27294	 0.002385	 0.025281	 0.0075	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27294	 84429	 0.002138	 0.025972	 0.007	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27295	 27307	 0.012467	 0.038771	 0.00809	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84089	 27295	 0.015432	 0.043035	 0.00903	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27295	 84428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27295	 84428	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27296	 84429	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27297	 27298	 0.001876	 0.009425	 0.00245	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27297	 27306	 0.00327	 0.022684	 0.00647	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27297	 84431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27297	 84431	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84429	 27298	 0.007001	 0.027516	 0.0072	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27298	 84432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27298	 84432	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27299	 27300	 0.005484	 0.010197	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82059	 27299	 0.009867	 0.025363	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84432	 27299	 0.015784	 0.02848	 0.00041	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84431	 27300	 0.015835	 0.045418	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27301	 27303	 0.000247	 0.002853	 0.02501	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27301	 84433	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27301	 84433	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82059	 27302	 0.02855	 0.020639	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27303	 27304	 0.000189	 0.002734	 0.04199	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27303	 84434	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27303	 84434	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84386	 27305	 0.10566	 0.15468	 0.00239	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84429	 27307	 0.00271	 0.032179	 0.01121	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27308	 84435	 0.000232	 0.01741	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27309	 27310	 0.005124	 0.033508	 0.00852	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27309	 27316	 0.00301	 0.015121	 0.00394	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82023	 27310	 0.003645	 0.026932	 0.00777	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27310	 84437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27310	 84437	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27311	 27312	 0.033935	 0.10422	 0.00196	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27311	 84632	 0.01984	 0.095238	 0.00285	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27312	 84438	 0.05451	 0.12524	 0.0019	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27312	 84452	 0.07669	 0.11632	 0.00167	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27313	 27315	 0.045632	 0.036113	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27314	 27315	 0.019139	 0.015002	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27315	 84438	 0.003804	 0.013932	 0.00035	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27315	 84439	 0.005225	 0.025498	 0.00044	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27316	 84438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27316	 84438	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27317	 27345	 0.010176	 0.051787	 0.01878	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27317	 27349	 0.038047	 0.098817	 0.024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84435	 27317	 0.004375	 0.018517	 0.00417	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27317	 84439	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27317	 84439	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27318	 27319	 0.016605	 0.055392	 0.00088	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84436	 27318	 0.053615	 0.090321	 0.00129	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84439	 27318	 0.004523	 0.020973	 0.00044	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27319	 27344	 0.030082	 0.071752	 0.00161	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84435	 27320	 0.002651	 0.02411	 0.00609	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27320	 84440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27320	 84440	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27321	 27322	 0.029684	 0.085138	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84440	 27321	 0.01814	 0.070571	 0.00118	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84104	 27322	 0.010418	 0.029564	 0.00046	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27323	 27327	 0.016715	 0.10159	 0.00187	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27323	 84441	 0.016588	 0.094297	 0.00171	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27324	 27333	 0.000283	 0.004464	 0.09691	 1786.0	 1875.3	 1964.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27324	 84441	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27324	 84441	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27325	 27326	 0.005579	 0.026593	 0.0077	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27325	 84442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27325	 84442	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27326	 27341	 0.00274	 0.021588	 0.00631	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27326	 84443	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27326	 84443	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27327	 84448	 0.008282	 0.044478	 0.00106	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27328	 84446	 0.034942	 0.13444	 0.0023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27328	 84446	 0.034942	 0.13444	 0.0023	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27329	 84446	 0.010172	 0.048825	 0.00146	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27331	 84444	 0.000126	 0.01005	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27331	 84444	 0.000126	 0.01005	 0.0	 1950.0	 1950.0	 1950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84445	 27332	 0.001385	 0.012598	 0.00318	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27332	 84447	 0.001608	 0.011671	 0.00403	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27333	 27337	 0.00019	 0.002593	 0.02643	 868.0	 911.4	 954.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84444	 27333	 0.000208	 0.002863	 0.04846	 1306.0	 1371.3	 1436.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27333	 84447	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27334	 27335	 0.019129	 0.025141	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27334	 27336	 0.020637	 0.027123	 0.00037	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84446	 27334	 0.036634	 0.10508	 0.00162	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84448	 27334	 0.013401	 0.034449	 0.00053	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27335	 27336	 0.004673	 0.009603	 0.00018	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27335	 84451	 0.002908	 0.008922	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27336	 84450	 0.003733	 0.009597	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27337	 84449	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27338	 27342	 0.11317	 0.14605	 0.00293	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84450	 27338	 0.008207	 0.013099	 0.0003	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27339	 27341	 0.000878	 0.00887	 0.00261	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84449	 27339	 0.000368	 0.004064	 0.00122	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27339	 84451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27339	 84451	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84451	 27340	 0.059016	 0.04626	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82004	 27342	 0.067787	 0.24221	 0.00481	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84442	 27342	 0.080648	 0.20734	 0.00321	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27343	 27344	 0.032115	 0.12494	 0.00209	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27344	 27352	 0.020832	 0.09127	 0.00196	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27344	 27356	 0.085273	 0.21923	 0.00339	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84440	 27344	 0.037685	 0.12437	 0.00201	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27345	 27346	 0.00507	 0.019928	 0.00521	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27345	 84452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27345	 84452	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84078	 27346	 0.004005	 0.021212	 0.00538	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27346	 84453	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27346	 84453	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27347	 27348	 0.006988	 0.024961	 0.0005	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27347	 27800	 0.089026	 0.08905	 0.0012	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84079	 27347	 0.007815	 0.053027	 0.00099	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84452	 27347	 0.037681	 0.10808	 0.00166	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84453	 27348	 0.03674	 0.044788	 0.00072	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27349	 27804	 0.012432	 0.041475	 0.01052	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27349	 27805	 0.006225	 0.031796	 0.008	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27349	 84454	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27349	 84454	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27350	 27355	 0.027975	 0.071913	 0.00111	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84454	 27350	 0.018791	 0.073103	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27351	 27352	 0.028923	 0.068489	 0.00125	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27351	 27353	 0.070393	 0.050888	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84439	 27351	 0.3775	 0.29889	 0.00376	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84452	 27351	 0.024431	 0.093993	 0.0016	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27352	 27355	 0.021676	 0.080148	 0.00148	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27353	 27354	 0.065765	 0.052046	 0.00066	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27354	 27355	 0.057808	 0.045749	 0.00058	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27355	 84639	 0.093848	 0.16506	 0.0031	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83665	 27356	 0.1371	 0.26875	 0.00403	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83545	 27357	 0.060765	 0.14108	 0.0021	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27357	 84456	 0.19129	 0.15141	 0.00191	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27358	 27360	 0.011703	 0.032636	 0.00685	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27359	 84455	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27359	 84455	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27360	 27362	 0.007599	 0.019729	 0.00479	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27360	 84456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27360	 84456	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27361	 27362	 0.003709	 0.009802	 0.00229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27361	 84457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27361	 84457	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83977	 27362	 0.039596	 0.12925	 0.03435	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27362	 84458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27362	 84458	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84457	 27363	 0.022147	 0.019845	 0.00041	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84458	 27363	 0.043993	 0.031802	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84456	 27364	 0.051967	 0.052489	 0.0007	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84457	 27364	 0.034745	 0.027235	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84458	 27365	 0.043275	 0.085682	 0.00126	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84455	 27366	 0.020285	 0.084676	 0.00244	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84456	 27366	 0.054179	 0.1554	 0.00239	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27367	 84462	 0.005999	 0.012277	 0.0003	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27367	 84463	 0.009178	 0.026323	 0.0004	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27368	 27420	 0.029205	 0.032122	 0.00043	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27368	 84463	 0.003784	 0.018161	 0.00054	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27368	 84475	 0.010993	 0.02514	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27369	 27370	 0.020139	 0.014558	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27369	 84463	 0.018209	 0.013397	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27370	 27372	 0.005989	 0.015231	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27370	 84459	 0.027194	 0.021521	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27371	 27372	 0.006949	 0.013307	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27371	 84463	 0.016702	 0.014966	 0.00031	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27372	 27374	 0.004589	 0.010409	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27373	 27379	 0.000881	 0.00905	 0.00286	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27373	 27411	 0.001538	 0.003992	 0.00097	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27373	 27421	 0.002537	 0.013971	 0.00504	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27373	 84459	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27373	 84459	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27374	 27375	 0.005436	 0.013824	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27375	 27380	 0.006727	 0.012092	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27375	 84461	 0.003455	 0.015398	 0.00026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27375	 84471	 0.009772	 0.019152	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27376	 27410	 0.000454	 0.003318	 0.00085	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27376	 84460	 0.000594	 0.003148	 0.00105	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27376	 84480	 0.001182	 0.005004	 0.00113	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27377	 84461	 0.004391	 0.011166	 0.00018	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27377	 84462	 0.008926	 0.024384	 0.00041	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27377	 84481	 0.007185	 0.016681	 0.00025	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27378	 27384	 5.8e-05	 0.000635	 0.00617	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27378	 27433	 9.9e-05	 0.001118	 0.01017	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27378	 84460	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27379	 27382	 0.001966	 0.008002	 0.00195	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27379	 84462	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27379	 84462	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27379	 84464	 0.000326	 0.003538	 0.00217	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84462	 27380	 0.004529	 0.010357	 0.00025	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27380	 84463	 0.01195	 0.034274	 0.00053	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27381	 27382	 0.000293	 0.00346	 0.00098	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27381	 27383	 0.001484	 0.009557	 0.00251	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27381	 27421	 0.001158	 0.012028	 0.00372	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27381	 27423	 0.002673	 0.01533	 0.0051	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27381	 84463	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27381	 84463	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27382	 84478	 0.001234	 0.008928	 0.0048	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27383	 84464	 0.0007	 0.005517	 0.00161	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27384	 27430	 0.000124	 0.001489	 0.02499	 1190.0	 1249.5	 1309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27384	 27488	 0.001159	 0.013138	 0.11966	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27384	 27735	 0.000993	 0.018368	 0.17662	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27384	 84464	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27384	 84464	 0.000282	 0.021141	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27385	 84465	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27386	 27390	 0.016897	 0.013372	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84466	 27386	 0.007404	 0.01466	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84466	 27387	 0.021179	 0.016601	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27388	 27389	 0.001203	 0.005838	 0.00133	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84465	 27388	 0.001223	 0.006249	 0.0017	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27389	 27426	 0.002795	 0.012587	 0.00335	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27391	 27392	 0.001166	 0.018754	 0.00613	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84465	 27391	 0.000663	 0.006363	 0.00296	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27392	 27393	 0.001702	 0.016867	 0.00517	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27393	 27394	 0.004542	 0.013671	 0.00428	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27393	 27396	 0.001845	 0.011688	 0.00317	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84401	 27393	 0.004333	 0.022151	 0.00604	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27394	 27395	 0.001844	 0.005141	 0.00108	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27394	 27550	 0.002446	 0.009792	 0.00247	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27395	 27396	 0.002889	 0.007635	 0.00179	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27396	 27397	 0.000849	 0.006456	 0.00203	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27396	 27578	 0.004435	 0.011514	 0.00279	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27397	 27416	 0.000532	 0.005005	 0.00152	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27398	 27760	 0.02538	 0.067092	 0.00122	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27398	 84470	 0.030743	 0.071364	 0.00136	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27399	 27400	 0.002363	 0.00946	 0.00238	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27399	 27556	 0.002083	 0.010798	 0.00264	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27399	 27558	 0.00554	 0.014383	 0.00349	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27399	 84467	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27399	 84467	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27400	 27406	 0.002774	 0.010542	 0.00295	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27401	 27436	 0.019477	 0.098509	 0.00192	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27401	 27552	 0.012344	 0.039585	 0.00098	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84467	 27401	 0.030463	 0.078309	 0.00121	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27402	 27405	 0.026076	 0.03955	 0.00057	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27403	 27404	 0.009584	 0.024637	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27403	 84473	 0.032753	 0.029349	 0.0006	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27404	 27408	 0.009071	 0.021479	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27405	 27408	 0.016349	 0.037956	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27405	 27435	 0.011525	 0.026479	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27405	 84468	 0.019432	 0.032735	 0.00047	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27405	 84481	 0.03459	 0.055213	 0.00127	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27406	 84468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27406	 84468	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27406	 84469	 0.001744	 0.006982	 0.00176	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27407	 27433	 0.000314	 0.003556	 0.03238	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27407	 27439	 0.000116	 0.001313	 0.01195	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27407	 84469	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27408	 84471	 0.005755	 0.025645	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27409	 84471	 0.007278	 0.017359	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27409	 84472	 0.008561	 0.01958	 0.00048	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27410	 84471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27410	 84471	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27411	 27412	 0.002443	 0.006279	 0.00155	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27411	 84472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27411	 84472	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27412	 84473	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27412	 84473	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84473	 27413	 0.006351	 0.024709	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27413	 84474	 0.011251	 0.022276	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27414	 27416	 0.000565	 0.005755	 0.00148	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84464	 27414	 0.002294	 0.026225	 0.008	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27414	 84474	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27414	 84474	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27415	 84475	 0.023337	 0.059349	 0.00094	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84474	 27417	 0.029749	 0.021073	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27418	 27419	 0.012576	 0.024085	 0.00038	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84472	 27418	 0.008426	 0.017988	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84474	 27418	 0.011833	 0.022002	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27419	 27420	 0.025393	 0.018357	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27421	 27423	 0.000501	 0.006694	 0.00183	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27421	 27424	 0.0019	 0.012426	 0.00316	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27421	 84475	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27421	 84475	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84475	 27422	 0.021476	 0.0158	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27423	 27424	 0.000842	 0.005177	 0.00149	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27423	 27425	 0.002232	 0.00978	 0.00336	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27424	 27428	 0.004163	 0.01812	 0.00516	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84465	 27424	 0.005113	 0.037774	 0.0109	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27425	 27426	 0.004033	 0.01922	 0.00557	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27427	 27430	 0.00047	 0.008246	 0.08823	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27427	 84476	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84476	 27428	 0.003824	 0.020981	 0.00555	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84463	 27429	 0.009484	 0.038762	 0.00078	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27430	 27450	 0.000117	 0.001966	 0.03565	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27430	 84478	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27430	 84478	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27431	 84479	 0.040615	 0.029361	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27432	 27444	 0.00178	 0.012803	 0.00339	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84464	 27432	 0.001403	 0.008418	 0.00255	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27432	 84479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27432	 84479	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27433	 84480	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27434	 27452	 0.003099	 0.010842	 0.00359	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84480	 27434	 0.001249	 0.00486	 0.0013	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27434	 84482	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27434	 84482	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27435	 27443	 0.009301	 0.019113	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84482	 27435	 0.031251	 0.034372	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84479	 27436	 0.013129	 0.043798	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84482	 27436	 0.004666	 0.018151	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27437	 27438	 0.006525	 0.012919	 0.00019	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84468	 27437	 0.023203	 0.045473	 0.00068	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27437	 84484	 0.034865	 0.022572	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27438	 84484	 0.01766	 0.013976	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27438	 84490	 0.004884	 0.012554	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27439	 84483	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27440	 27441	 0.036958	 0.029248	 0.00037	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84470	 27440	 0.014885	 0.042692	 0.00066	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84484	 27440	 0.004523	 0.017594	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27440	 84487	 0.003084	 0.012363	 0.00032	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27440	 84488	 0.011982	 0.053392	 0.00091	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27441	 27442	 0.022726	 0.017985	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27442	 84485	 0.002258	 0.0155	 0.00028	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27442	 84490	 0.003631	 0.011138	 0.0003	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27443	 84490	 0.005124	 0.015736	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27444	 27445	 0.000556	 0.005992	 0.0032	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27444	 27452	 0.000623	 0.006673	 0.00213	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27444	 84485	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27444	 84485	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27445	 27449	 0.000886	 0.01003	 0.00563	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27445	 84486	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27445	 84486	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27446	 27447	 0.001112	 0.010111	 0.00255	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84483	 27446	 0.001642	 0.008014	 0.00221	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27446	 84487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27446	 84487	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27447	 27448	 0.001706	 0.021028	 0.00679	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27447	 84488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27447	 84488	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27448	 27643	 0.001364	 0.019292	 0.00639	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27448	 84489	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27448	 84489	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27449	 84565	 0.00133	 0.016813	 0.00868	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27450	 27645	 0.00013	 0.002296	 0.03812	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84478	 27451	 0.003365	 0.024577	 0.00632	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84483	 27452	 0.001041	 0.004532	 0.00129	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27452	 84490	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27452	 84490	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27453	 27510	 0.02116	 0.016746	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27454	 27474	 0.00309	 0.007943	 0.00012	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27454	 27475	 0.003423	 0.008105	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27454	 84507	 0.002692	 0.006847	 0.00011	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27455	 27481	 0.000977	 0.002537	 0.00062	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27455	 27494	 0.000728	 0.001891	 0.00046	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27456	 27482	 0.006007	 0.009201	 0.00013	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27456	 84507	 0.005216	 0.009554	 0.00016	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27457	 27504	 0.011862	 0.010926	 0.00018	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27457	 84492	 0.017654	 0.017831	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27458	 27459	 0.001503	 0.004674	 0.00098	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27458	 84491	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27458	 84491	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27459	 27460	 0.00089	 0.00455	 0.00124	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27459	 84492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27459	 84492	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27460	 84493	 0.000551	 0.00328	 0.00086	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27461	 27462	 4.6e-05	 0.000514	 0.0049	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27461	 27506	 0.000112	 0.00147	 0.0133	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27461	 84493	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27462	 27464	 7e-05	 0.000782	 0.00731	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84494	 27463	 0.029824	 0.029911	 0.00048	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27463	 84496	 0.020135	 0.014814	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27464	 27547	 0.000135	 0.001504	 0.01419	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27464	 84495	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27465	 27474	 0.012141	 0.0086	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27466	 27468	 0.005535	 0.008478	 0.00015	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27466	 27478	 0.007001	 0.011794	 0.00017	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27467	 27468	 0.038802	 0.030415	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27467	 27469	 0.021594	 0.015888	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27467	 84499	 0.00959	 0.021752	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27467	 84503	 0.00845	 0.031699	 0.00057	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27468	 27469	 0.005521	 0.012626	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84494	 27468	 0.002347	 0.009933	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27469	 84497	 0.010178	 0.017145	 0.00024	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27470	 27471	 0.00127	 0.00428	 0.00106	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27470	 27473	 0.002739	 0.007109	 0.00173	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27470	 84497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27470	 84497	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27471	 84498	 0.001013	 0.003582	 0.00081	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27472	 27547	 7e-05	 0.000781	 0.00736	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27472	 84498	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27472	 84498	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27473	 27549	 0.001793	 0.007178	 0.00181	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27473	 84499	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27473	 84499	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27473	 84502	 0.002113	 0.013381	 0.00363	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27474	 27478	 0.007205	 0.014266	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27475	 27477	 0.004288	 0.008775	 0.00022	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27476	 27477	 0.011179	 0.008847	 0.00011	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27477	 27478	 0.012049	 0.007801	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27477	 27479	 0.012513	 0.009903	 0.00012	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27479	 27480	 0.010449	 0.010669	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27480	 84503	 0.00534	 0.017812	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27481	 27485	 0.001275	 0.003205	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27482	 27484	 0.024403	 0.019312	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27482	 84500	 0.012092	 0.007828	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27483	 27487	 0.001919	 0.005073	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27483	 27507	 0.001125	 0.002829	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27484	 27513	 0.056156	 0.036356	 0.00069	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27484	 84500	 0.015383	 0.011799	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27485	 84500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27485	 84500	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27485	 84502	 0.001574	 0.004226	 0.00096	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27486	 27579	 0.038954	 0.02988	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27486	 84501	 0.015463	 0.012237	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27487	 27559	 0.002593	 0.006961	 0.00158	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27487	 84501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27487	 84501	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27487	 84502	 0.001635	 0.005921	 0.00127	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27488	 27506	 0.000191	 0.002163	 0.01969	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27488	 84502	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27489	 27497	 0.00243	 0.006775	 0.00142	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27489	 27509	 0.003072	 0.007975	 0.00194	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27489	 84504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27489	 84504	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84504	 27490	 0.020978	 0.016602	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27490	 84515	 0.023989	 0.018401	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27491	 27492	 0.000812	 0.002089	 0.00052	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27491	 27499	 0.001783	 0.004972	 0.00104	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27491	 84505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27491	 84505	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27492	 27508	 0.000837	 0.002246	 0.00051	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27493	 27502	 0.010052	 0.013211	 0.00018	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27493	 84512	 0.007484	 0.011946	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27494	 27508	 0.000889	 0.002308	 0.00056	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27495	 27506	 5.8e-05	 0.000665	 0.00583	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27495	 84506	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27496	 27499	 0.002338	 0.006521	 0.00137	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27496	 27505	 0.003147	 0.008088	 0.002	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27497	 27564	 0.001967	 0.005355	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27498	 27500	 0.021495	 0.015226	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27498	 84508	 0.021686	 0.014567	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27499	 84508	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27499	 84508	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27500	 27501	 0.034429	 0.026987	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27500	 84509	 0.021617	 0.013995	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27501	 27502	 0.017811	 0.011531	 0.00022	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84505	 27501	 0.014257	 0.011175	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27503	 27522	 0.001503	 0.003972	 0.00093	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27503	 84509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27503	 84509	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27503	 84511	 0.004287	 0.011129	 0.0027	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27504	 27523	 0.009592	 0.013977	 0.00032	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27505	 27566	 0.003689	 0.012653	 0.00303	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27505	 84510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27505	 84510	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27506	 84511	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27507	 27509	 0.002063	 0.005538	 0.00126	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27507	 84513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27507	 84513	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27508	 84514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27508	 84514	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27509	 84515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27509	 84515	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27510	 27511	 0.015152	 0.011991	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84503	 27510	 0.022985	 0.053363	 0.00079	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84512	 27510	 0.003291	 0.014498	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27512	 27513	 0.022879	 0.02492	 0.00034	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27512	 27517	 0.005525	 0.015847	 0.00024	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27512	 84516	 0.026955	 0.021332	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84501	 27513	 0.038135	 0.029252	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27513	 84534	 0.016078	 0.021917	 0.00049	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84502	 27514	 0.00632	 0.016245	 0.00402	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27514	 84516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27514	 84516	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27515	 27579	 0.023596	 0.018673	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84516	 27515	 0.024818	 0.01964	 0.00025	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27516	 27517	 0.006702	 0.017229	 0.00027	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27516	 84533	 0.005895	 0.019666	 0.00031	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84516	 27517	 0.016212	 0.031772	 0.00048	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27517	 84533	 0.006606	 0.024781	 0.00045	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27518	 27521	 0.023658	 0.018723	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27518	 27523	 0.00474	 0.012948	 0.00022	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84491	 27518	 0.016668	 0.015631	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27518	 84517	 0.018241	 0.014298	 0.00018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27519	 27526	 0.002314	 0.006007	 0.00146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27519	 27544	 0.003722	 0.00864	 0.00263	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27519	 84517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27519	 84517	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84517	 27520	 0.018876	 0.014938	 0.00019	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27522	 27524	 0.001824	 0.004584	 0.00119	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27522	 84518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27522	 84518	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27523	 27525	 0.0095	 0.016003	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84518	 27523	 0.002441	 0.013876	 0.00025	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27524	 27577	 0.002547	 0.00796	 0.00231	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27524	 84519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27524	 84519	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84519	 27525	 0.004341	 0.01333	 0.00025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27525	 84520	 0.003565	 0.010117	 0.00016	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27526	 84520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27526	 84520	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84520	 27527	 0.012862	 0.010082	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27528	 27542	 0.003481	 0.010678	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84520	 27528	 0.009596	 0.018807	 0.00028	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27529	 27533	 0.010862	 0.027923	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27529	 84521	 0.034031	 0.030494	 0.00062	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27530	 27531	 0.017782	 0.017468	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27530	 84538	 0.019084	 0.031828	 0.00046	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27530	 84539	 0.012101	 0.023175	 0.00036	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27532	 27580	 0.001477	 0.00865	 0.00236	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27532	 84521	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27532	 84521	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27532	 84537	 0.001159	 0.010127	 0.00401	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83794	 27533	 0.011756	 0.031076	 0.00056	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27534	 84522	 0.022603	 0.015183	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27534	 84523	 0.022598	 0.020815	 0.00033	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27534	 84524	 0.017188	 0.018721	 0.00025	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27535	 27536	 0.001369	 0.003818	 0.0008	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27535	 84522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27535	 84522	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27536	 27539	 0.003686	 0.00974	 0.00228	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84395	 27536	 0.003854	 0.011163	 0.00269	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27536	 84523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27536	 84523	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27537	 27543	 0.006388	 0.016931	 0.00043	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84396	 27537	 0.034537	 0.037986	 0.00051	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84523	 27537	 0.003936	 0.015313	 0.00026	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27538	 27539	 0.000859	 0.004171	 0.00095	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27538	 27577	 0.003539	 0.009352	 0.00219	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27538	 27586	 0.001316	 0.010944	 0.00331	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27539	 84524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27539	 84524	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27540	 27541	 0.002102	 0.005556	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27540	 27582	 0.002348	 0.007658	 0.00203	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27540	 84525	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27540	 84525	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27541	 84526	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27541	 84526	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84524	 27542	 0.004849	 0.020131	 0.00052	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27543	 27545	 0.027175	 0.035716	 0.00049	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84502	 27544	 0.007748	 0.02658	 0.00637	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27544	 84527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27544	 84527	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27545	 27546	 0.01201	 0.022332	 0.00052	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84527	 27545	 0.029781	 0.027927	 0.00043	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84400	 27546	 0.03956	 0.049107	 0.00107	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27546	 84529	 0.013779	 0.031657	 0.00048	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27547	 84528	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27548	 27549	 0.0014	 0.004898	 0.00162	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27548	 27550	 0.002047	 0.008196	 0.00206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84401	 27548	 0.004413	 0.014394	 0.00382	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27548	 84530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27548	 84530	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27551	 27553	 0.037516	 0.024288	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84499	 27551	 0.012193	 0.031343	 0.00049	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27552	 27554	 0.021993	 0.039529	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84402	 27552	 0.20696	 0.16381	 0.00206	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27552	 84531	 0.024968	 0.06916	 0.00114	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27552	 84541	 0.005976	 0.028559	 0.00063	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84530	 27553	 0.071689	 0.061272	 0.00115	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27554	 84531	 0.014941	 0.034682	 0.00066	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27555	 27556	 0.00404	 0.011266	 0.00236	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27555	 27559	 0.004518	 0.012301	 0.00271	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27556	 84531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27556	 84531	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27557	 27558	 0.003461	 0.009146	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27557	 27561	 0.006315	 0.016232	 0.00402	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27557	 84532	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27557	 84532	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84503	 27560	 0.017937	 0.041208	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84502	 27561	 0.008079	 0.027715	 0.00664	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27561	 84533	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27561	 84533	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27562	 27585	 0.017375	 0.049834	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84265	 27562	 0.008374	 0.035965	 0.00066	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27562	 84534	 0.008031	 0.039192	 0.00068	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27563	 27583	 0.0046	 0.012349	 0.0028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84502	 27563	 0.006595	 0.017957	 0.00396	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27563	 84534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27563	 84534	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27564	 27566	 0.002161	 0.012058	 0.00308	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27564	 27583	 0.004198	 0.011707	 0.00246	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27564	 84535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27564	 84535	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27565	 84536	 0.029397	 0.045034	 0.00063	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27566	 27568	 0.001029	 0.012766	 0.00553	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27566	 84536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27566	 84536	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27567	 27568	 0.000656	 0.009281	 0.00307	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83732	 27567	 0.001025	 0.007214	 0.0041	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27569	 84538	 0.018031	 0.076312	 0.00144	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27569	 84544	 0.04148	 0.069878	 0.001	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83807	 27570	 0.000494	 0.006382	 0.10713	 1251.0	 1313.5	 1376.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27570	 84537	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83805	 27571	 0.006266	 0.031689	 0.00062	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27571	 84539	 0.004772	 0.026278	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27572	 27574	 0.008783	 0.029299	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84538	 27572	 0.006763	 0.030136	 0.00051	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83805	 27573	 0.019848	 0.037512	 0.00061	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83731	 27574	 0.022016	 0.063144	 0.00097	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84537	 27575	 0.003024	 0.008433	 0.00177	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27575	 84539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27575	 84539	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84510	 27576	 0.053706	 0.042097	 0.00054	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84536	 27576	 0.040819	 0.053648	 0.00074	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84537	 27577	 0.004345	 0.037009	 0.00923	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27577	 84540	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27577	 84540	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27578	 84541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27578	 84541	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84501	 27579	 0.024234	 0.019178	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27580	 27581	 0.00098	 0.005106	 0.00134	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27581	 27582	 0.001543	 0.007077	 0.00181	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27582	 84542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27582	 84542	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27583	 84543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27583	 84543	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84535	 27584	 0.014736	 0.034896	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84543	 27585	 0.027059	 0.036885	 0.00082	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27586	 27587	 0.001234	 0.010513	 0.00262	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27586	 84544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27586	 84544	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84537	 27587	 0.001467	 0.011413	 0.00296	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27588	 27589	 0.001159	 0.003008	 0.00073	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27588	 27641	 0.000646	 0.003562	 0.00083	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27588	 84545	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27588	 84545	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27589	 27600	 0.002368	 0.006357	 0.00144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27589	 84546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27589	 84546	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84546	 27590	 0.006476	 0.016404	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27590	 84558	 0.01823	 0.041882	 0.00064	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27591	 27593	 0.000769	 0.006812	 0.00181	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83645	 27591	 0.008151	 0.057399	 0.03265	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27591	 84547	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27591	 84547	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27592	 27634	 0.014823	 0.038104	 0.00059	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84547	 27592	 0.020086	 0.03206	 0.00074	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27593	 27595	 0.000924	 0.00541	 0.00147	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27593	 27596	 0.001021	 0.005933	 0.0014	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27593	 84548	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27593	 84548	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27594	 27634	 0.010415	 0.026992	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27594	 84549	 0.00563	 0.013332	 0.00024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27595	 27597	 0.000608	 0.003221	 0.00107	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27595	 84549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27595	 84549	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27596	 27598	 0.002071	 0.005369	 0.00162	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27596	 27641	 0.000894	 0.003067	 0.00073	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27596	 84550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27596	 84550	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27597	 27609	 0.001313	 0.010213	 0.00265	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27597	 84551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27597	 84551	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27598	 27611	 0.007234	 0.026194	 0.00562	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27598	 84552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27598	 84552	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84545	 27599	 0.007128	 0.020443	 0.00031	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84546	 27599	 0.002547	 0.016434	 0.00052	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27599	 84560	 0.00571	 0.022211	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27599	 84560	 0.00571	 0.022211	 0.00037	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27600	 27601	 0.001645	 0.004348	 0.00102	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27601	 27629	 0.002203	 0.006179	 0.00159	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27602	 27603	 0.05582	 0.1296	 0.00193	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27602	 27604	 0.035276	 0.078077	 0.00128	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27603	 27615	 0.03988	 0.092587	 0.00138	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27604	 84554	 0.022006	 0.11006	 0.00196	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27605	 27606	 0.11514	 0.091122	 0.00115	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27606	 27607	 0.024493	 0.081708	 0.0013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27606	 84553	 0.060095	 0.12299	 0.00303	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83969	 27607	 0.028261	 0.098888	 0.00205	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27608	 84553	 0.010719	 0.051452	 0.00154	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27609	 84553	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27609	 84553	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84553	 27610	 0.033023	 0.040257	 0.00065	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27611	 84554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27611	 84554	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84552	 27612	 0.042987	 0.047696	 0.00093	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84554	 27613	 0.07523	 0.054384	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27614	 84559	 0.044465	 0.063122	 0.00104	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27615	 84555	 0.035241	 0.081817	 0.00122	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27616	 84555	 0.038702	 0.054941	 0.0009	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27617	 27618	 0.000454	 0.003541	 0.00106	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27617	 84555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27617	 84555	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27618	 27619	 0.000387	 0.003323	 0.00095	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27620	 84556	 0.060435	 0.045788	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27621	 27623	 0.003454	 0.009129	 0.00214	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84244	 27621	 0.007842	 0.043031	 0.01137	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27621	 84556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27621	 84556	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84554	 27622	 0.076186	 0.17505	 0.00266	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84556	 27622	 0.01961	 0.043403	 0.00071	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27622	 84564	 0.040422	 0.052605	 0.00074	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27623	 27642	 0.001661	 0.004271	 0.00106	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27624	 84564	 0.017625	 0.019385	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82030	 27625	 0.021517	 0.023666	 0.00032	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27626	 27629	 0.00179	 0.007284	 0.00177	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27626	 27631	 0.001002	 0.009173	 0.00367	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27626	 84557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27626	 84557	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84557	 27627	 0.012383	 0.019864	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82030	 27628	 0.007081	 0.022801	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84557	 27628	 0.008305	 0.014985	 0.00022	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27628	 84558	 0.00658	 0.015116	 0.00023	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27629	 27630	 0.001691	 0.006772	 0.00171	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27629	 84558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27629	 84558	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27631	 27633	 0.00191	 0.011378	 0.00299	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27631	 84559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27631	 84559	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27632	 84560	 0.023417	 0.02495	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27633	 84560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27633	 84560	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27634	 27640	 0.009918	 0.056379	 0.00102	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84547	 27634	 0.029118	 0.062398	 0.00109	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82030	 27635	 0.015212	 0.031131	 0.00077	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82030	 27636	 0.008225	 0.021143	 0.00033	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84547	 27637	 0.009124	 0.051866	 0.00094	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27637	 84561	 0.014883	 0.071482	 0.00138	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27638	 27639	 0.002527	 0.008513	 0.00212	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27638	 84561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27638	 84561	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27639	 84562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27639	 84562	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84388	 27640	 0.020418	 0.062637	 0.0017	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84562	 27640	 0.015725	 0.050636	 0.00086	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27641	 84563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27641	 84563	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27642	 84564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27642	 84564	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27643	 27647	 0.001897	 0.014872	 0.0068	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27644	 27645	 0.000102	 0.001723	 0.03124	 1536.0	 1612.8	 1689.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27644	 27648	 0.000106	 0.002032	 0.03427	 1624.0	 1705.2	 1786.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27644	 84565	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27644	 84565	 0.000285	 0.022767	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82057	 27646	 0.010852	 0.099833	 0.00198	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83598	 27646	 0.012903	 0.10057	 0.00188	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27647	 27656	 0.002857	 0.020672	 0.01112	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27647	 84566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27647	 84566	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27647	 84567	 0.003926	 0.018012	 0.00461	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27648	 84567	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82057	 27649	 0.008802	 0.02703	 0.00051	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84568	 27649	 0.011352	 0.025962	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27650	 27652	 0.003895	 0.013574	 0.00315	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27650	 27653	 0.001885	 0.004847	 0.0012	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27651	 27652	 0.002719	 0.010687	 0.0028	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27651	 27653	 0.002076	 0.006772	 0.0018	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27652	 27654	 0.000992	 0.010965	 0.00329	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27652	 84569	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27652	 84569	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27654	 27662	 0.001237	 0.014143	 0.00431	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27655	 27656	 0.00485	 0.016637	 0.00399	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83656	 27656	 0.002308	 0.025401	 0.01509	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27657	 27659	 0.029074	 0.16337	 0.00303	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84569	 27657	 0.017124	 0.076307	 0.0013	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27657	 84571	 0.038487	 0.088423	 0.00134	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27658	 84571	 0.024705	 0.051923	 0.00095	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27658	 84572	 0.032097	 0.073407	 0.00179	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27659	 27660	 0.040881	 0.078291	 0.00123	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83660	 27659	 0.09049	 0.25959	 0.00399	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83663	 27659	 0.016194	 0.11116	 0.00203	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27660	 84570	 0.041405	 0.096129	 0.00143	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27661	 27663	 0.004376	 0.020408	 0.00505	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27661	 84570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27661	 84570	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27662	 27663	 0.00148	 0.016393	 0.00533	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27662	 84571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27662	 84571	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83983	 27663	 0.00745	 0.11448	 0.03206	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27663	 84572	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27663	 84572	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27664	 27665	 0.1287	 0.09304	 0.00141	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27664	 84573	 0.11538	 0.21136	 0.00365	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27665	 27668	 0.12984	 0.091978	 0.00145	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27666	 27669	 0.004266	 0.023802	 0.00608	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83977	 27666	 0.011508	 0.12122	 0.06823	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27666	 84573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27666	 84573	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27667	 27668	 0.072786	 0.047123	 0.0009	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27667	 84574	 0.016347	 0.042366	 0.0008	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27667	 84576	 0.030997	 0.10341	 0.00164	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27669	 27670	 0.002706	 0.009798	 0.0021	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27669	 84574	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27669	 84574	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27670	 84577	 0.004164	 0.01667	 0.0042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83953	 27671	 0.098881	 0.064018	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27671	 84576	 0.047457	 0.086924	 0.0015	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27672	 27673	 0.000291	 0.005377	 0.05166	 1046.0	 1098.3	 1150.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27672	 84575	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27673	 84577	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27673	 84577	 0.002529	 0.098634	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27674	 27678	 0.005604	 0.030751	 0.00813	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27674	 27680	 0.004848	 0.0269	 0.00818	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82016	 27675	 0.030208	 0.055329	 0.00096	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82016	 27676	 0.18495	 0.14639	 0.00184	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27677	 84578	 0.094128	 0.15026	 0.00346	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27677	 84580	 0.024835	 0.099389	 0.0021	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83502	 27678	 0.011805	 0.030648	 0.00744	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27678	 84578	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27678	 84578	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27679	 84579	 0.014211	 0.032648	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27679	 84580	 0.01825	 0.03293	 0.00048	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27680	 27681	 0.002252	 0.007512	 0.00191	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82015	 27680	 0.002287	 0.029292	 0.00874	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27680	 84579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27680	 84579	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27681	 84580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27681	 84580	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84580	 27682	 0.011524	 0.022816	 0.00033	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27683	 27684	 0.010262	 0.02755	 0.00624	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27684	 84581	 0.002405	 0.030804	 0.0092	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27685	 84581	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27685	 84581	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27686	 27687	 0.000102	 0.001132	 0.01077	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27686	 84582	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27686	 84582	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27687	 84583	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27687	 84583	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27688	 27717	 0.001664	 0.005707	 0.00137	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27688	 27718	 0.001288	 0.003463	 0.00097	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84583	 27688	 0.001195	 0.003255	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27689	 27692	 0.000153	 0.001766	 0.01548	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27689	 84584	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27690	 27691	 0.029273	 0.023166	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27690	 84599	 0.013302	 0.044373	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27691	 84588	 0.059418	 0.065353	 0.00087	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27692	 84586	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27692	 84586	 0.000529	 0.036996	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27693	 27702	 0.005103	 0.018037	 0.00406	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84586	 27693	 0.002696	 0.009395	 0.00218	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27694	 27700	 0.00026	 0.002943	 0.02679	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27694	 84587	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84587	 27695	 0.002038	 0.013987	 0.00408	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27696	 84590	 0.07492	 0.14834	 0.00218	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27697	 27698	 0.009612	 0.022313	 0.0068	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27698	 84589	 0.003883	 0.010262	 0.0024	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27699	 84597	 0.001622	 0.010063	 0.00244	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27700	 27712	 0.000273	 0.002992	 0.02906	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27700	 84589	 0.00037	 0.029598	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84589	 27701	 0.00129	 0.004903	 0.00137	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27701	 84591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27701	 84591	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27702	 27703	 0.000872	 0.005192	 0.00137	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27702	 84592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27702	 84592	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27703	 27705	 0.002593	 0.01943	 0.00474	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27704	 27705	 0.003214	 0.008262	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27704	 27707	 0.00373	 0.009682	 0.00235	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27705	 27706	 0.003673	 0.009442	 0.00234	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27705	 84593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27705	 84593	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27706	 27709	 0.003156	 0.007934	 0.00206	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27706	 84594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27706	 84594	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27707	 27709	 0.004388	 0.011781	 0.00267	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27709	 27710	 0.00165	 0.005833	 0.00131	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27709	 84595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27709	 84595	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27710	 84596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27710	 84596	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84596	 27711	 0.013073	 0.023589	 0.00034	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27712	 84597	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27712	 84597	 0.000783	 0.042278	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84597	 27713	 0.005427	 0.014342	 0.00336	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27713	 84598	 0.004127	 0.014157	 0.00339	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27714	 84598	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27714	 84598	 0.000438	 0.032886	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27715	 27716	 0.10768	 0.069713	 0.00133	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83618	 27716	 0.015296	 0.078518	 0.00149	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83640	 27716	 0.040406	 0.080002	 0.00117	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27717	 27718	 0.0017	 0.00583	 0.0014	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84326	 27717	 0.002755	 0.011658	 0.00262	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27717	 84599	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27717	 84599	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84586	 27718	 0.002443	 0.00614	 0.00159	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27719	 27720	 0.005058	 0.019676	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27719	 27720	 0.005058	 0.019676	 0.00033	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27719	 84601	 0.01393	 0.047583	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27719	 84601	 0.01393	 0.047583	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27721	 84600	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27722	 27727	 0.001787	 0.02216	 0.0096	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82021	 27722	 0.002928	 0.037025	 0.01912	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27722	 84602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27722	 84602	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27723	 27724	 0.046386	 0.03636	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27724	 27725	 0.004096	 0.015758	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84602	 27724	 0.019521	 0.075944	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84602	 27724	 0.019521	 0.075944	 0.00127	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27725	 27726	 0.004585	 0.016053	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27726	 84603	 0.005258	 0.02104	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27727	 27729	 0.013027	 0.043896	 0.01091	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27727	 27731	 0.001155	 0.013213	 0.0037	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27727	 84603	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27727	 84603	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84603	 27728	 0.014436	 0.046293	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84603	 27728	 0.014436	 0.046293	 0.00115	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27728	 84604	 0.060856	 0.17456	 0.00268	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27729	 84604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27729	 84604	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27730	 27731	 0.002386	 0.023904	 0.00796	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82014	 27730	 0.002674	 0.033645	 0.01042	 347.0	 364.4	 381.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27730	 84605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27730	 84605	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84602	 27732	 0.016598	 0.081034	 0.0017	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84605	 27732	 0.018408	 0.093118	 0.00162	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27733	 27734	 0.007976	 0.035911	 0.00956	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82021	 27733	 0.004256	 0.016178	 0.00453	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27735	 27739	 0.000159	 0.002012	 0.01961	 812.0	 852.6	 893.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27735	 84606	 0.000264	 0.018498	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27736	 27737	 0.012905	 0.01696	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27736	 27766	 0.007748	 0.015184	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27737	 27766	 0.004376	 0.009344	 0.00021	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27737	 84611	 0.028205	 0.086619	 0.00163	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27738	 27747	 0.005003	 0.020656	 0.00489	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27738	 27749	 0.004688	 0.016403	 0.00544	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27738	 84608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27738	 84608	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27738	 84610	 0.006407	 0.019286	 0.00603	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27739	 27740	 0.000286	 0.003238	 0.02947	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27739	 84609	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27739	 84609	 0.001368	 0.068386	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27740	 84610	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27740	 84610	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27741	 27742	 0.001959	 0.015436	 0.00451	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27741	 27755	 0.004821	 0.024223	 0.0063	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84606	 27741	 0.000747	 0.011417	 0.00368	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27742	 27756	 0.004185	 0.021375	 0.00538	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27742	 84611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27742	 84611	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27743	 27759	 0.002131	 0.01427	 0.00897	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27743	 84612	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27743	 84612	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27744	 27761	 0.004812	 0.01677	 0.00389	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27744	 84613	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27744	 84613	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27745	 27746	 0.001272	 0.00593	 0.00147	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27746	 27747	 0.002975	 0.013396	 0.00356	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27747	 84614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27747	 84614	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27748	 27762	 0.001641	 0.017151	 0.00577	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27748	 84615	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27748	 84615	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27750	 27751	 0.004649	 0.020934	 0.00557	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27751	 27752	 0.005105	 0.024773	 0.00566	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27752	 27753	 0.005379	 0.023968	 0.00651	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84610	 27753	 0.010928	 0.035644	 0.00946	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27753	 84616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27753	 84616	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84610	 27754	 0.002859	 0.024518	 0.00698	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27754	 84617	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27754	 84617	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27755	 27764	 0.003829	 0.024251	 0.00658	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27755	 84618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27755	 84618	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27756	 27763	 0.002518	 0.01122	 0.00305	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84266	 27757	 0.013832	 0.035849	 0.00068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27757	 84619	 0.013672	 0.02442	 0.00036	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27757	 84620	 0.021718	 0.062291	 0.00096	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27758	 27759	 0.001191	 0.009057	 0.00285	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27758	 84619	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27758	 84619	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27759	 84620	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27759	 84620	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84467	 27760	 0.042859	 0.11018	 0.00171	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84613	 27760	 0.009209	 0.036537	 0.00104	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27761	 27762	 0.002434	 0.012227	 0.00318	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27762	 84621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27762	 84621	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27763	 27764	 0.002172	 0.005915	 0.0013	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27763	 84622	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27763	 84622	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84614	 27765	 0.028643	 0.050002	 0.00077	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84615	 27765	 0.033245	 0.076378	 0.00116	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84621	 27765	 0.049188	 0.097391	 0.00143	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84607	 27766	 0.001486	 0.006619	 0.00011	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27767	 27769	 0.009522	 0.025165	 0.00589	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27767	 84623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27767	 84623	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27768	 27769	 0.004384	 0.024919	 0.00721	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27769	 84625	 0.014166	 0.03857	 0.0085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84623	 27770	 0.040754	 0.093206	 0.00228	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27770	 84624	 0.094209	 0.12382	 0.0017	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83957	 27771	 0.004768	 0.030711	 0.00805	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27771	 84624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27771	 84624	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27771	 84625	 0.003779	 0.017853	 0.00571	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27772	 84625	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27772	 84625	 0.001184	 0.059188	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27773	 27774	 0.000776	 0.008114	 0.00273	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27774	 27775	 0.002137	 0.02443	 0.00745	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84228	 27776	 0.002063	 0.005452	 0.00128	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27776	 84629	 0.002698	 0.009	 0.00228	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84230	 27777	 0.034688	 0.03394	 0.00048	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27777	 84626	 0.005586	 0.023316	 0.00067	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27778	 27780	 0.005949	 0.015445	 0.00375	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27778	 84626	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27778	 84626	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27778	 84629	 0.006479	 0.01764	 0.00389	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27779	 27781	 0.023518	 0.024743	 0.00036	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84626	 27779	 0.05167	 0.040891	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27779	 84627	 0.03828	 0.024782	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27780	 27784	 0.003009	 0.007953	 0.00186	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27780	 84627	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27780	 84627	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84627	 27781	 0.040712	 0.032219	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27782	 27783	 0.044076	 0.034881	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84627	 27782	 0.026568	 0.021026	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27783	 27789	 0.079664	 0.074709	 0.00115	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84215	 27783	 0.02017	 0.041276	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27784	 27787	 0.010457	 0.026882	 0.00666	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27784	 84628	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27784	 84628	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27785	 27786	 0.000156	 0.001734	 0.0165	 736.0	 772.8	 809.6	 0.0	 0.0	 1	 -30.0	 30.0;
	27785	 84629	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27786	 84631	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27786	 84631	 0.000949	 0.049324	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82023	 27787	 0.000438	 0.001138	 0.00028	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27788	 27798	 0.009172	 0.033212	 0.00713	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27788	 27799	 0.012203	 0.032253	 0.00755	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82023	 27788	 0.008677	 0.022931	 0.00537	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27788	 84632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27788	 84632	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27789	 84634	 0.041349	 0.081868	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84225	 27790	 0.03082	 0.07838	 0.00124	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	27790	 84634	 0.033915	 0.087899	 0.00166	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27791	 27792	 0.001996	 0.021156	 0.00628	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	27791	 84633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27791	 84633	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27792	 27797	 0.001364	 0.013037	 0.0043	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	27793	 84634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27793	 84634	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27794	 84635	 0.017145	 0.013568	 0.00017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27795	 27797	 0.001914	 0.00693	 0.00149	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27795	 27798	 0.001136	 0.00396	 0.00092	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27795	 84635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27795	 84635	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27797	 27798	 0.002681	 0.009198	 0.0022	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	27797	 84636	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27797	 84636	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27798	 84637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27798	 84637	 0.003471	 0.12495	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27799	 84638	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27799	 84638	 0.00806	 0.24987	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84079	 27800	 0.01443	 0.082027	 0.00148	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84638	 27800	 0.029641	 0.078565	 0.00199	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27801	 27802	 0.015515	 0.0445	 0.00068	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84410	 27801	 0.12537	 0.35972	 0.00553	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84633	 27801	 0.12611	 0.15097	 0.00251	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84081	 27802	 0.15899	 0.15363	 0.00223	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82024	 27803	 0.2821	 0.22331	 0.00281	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84632	 27803	 0.16022	 0.12681	 0.0016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84637	 27803	 0.01607	 0.042482	 0.00077	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27804	 27807	 0.010039	 0.025806	 0.00639	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	27804	 84639	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27804	 84639	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27805	 27806	 0.016898	 0.046009	 0.01014	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84080	 27805	 0.005982	 0.048559	 0.01546	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	27806	 27807	 0.001779	 0.027315	 0.00764	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	27806	 84640	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27806	 84640	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	27807	 27808	 0.002103	 0.009648	 0.00247	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	27808	 27809	 0.004397	 0.020809	 0.005	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81860	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81859	 81860	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81859	 81862	 0.080337	 0.20899	 0.05085	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81872	 0.028973	 0.16993	 0.04637	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81873	 0.059269	 0.13774	 0.04201	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81894	 0.015508	 0.15228	 0.13299	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81898	 0.065297	 0.23695	 0.05099	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81900	 0.026736	 0.15352	 0.05113	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81906	 0.019467	 0.06679	 0.01601	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81913	 0.026166	 0.18481	 0.10557	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81859	 81921	 0.049845	 0.1295	 0.03146	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81861	 81862	 0.000109	 0.008705	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81861	 81862	 0.000109	 0.008705	 0.0	 1700.0	 1700.0	 1700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81862	 81863	 0.00012	 0.009615	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81862	 81863	 0.00012	 0.009615	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81864	 81865	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81864	 81865	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81866	 81867	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81866	 81867	 0.000208	 0.015578	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81867	 81868	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81867	 81868	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81868	 81899	 0.1917	 0.44532	 0.00849	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81868	 81901	 0.46447	 0.6485	 0.0111	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81868	 81918	 0.62417	 0.45188	 0.00685	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81868	 82153	 0.69939	 0.53082	 0.00731	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81868	 82155	 0.28679	 0.56837	 0.00835	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81869	 81870	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81869	 81870	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81869	 81911	 0.00188	 0.004881	 0.00118	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81869	 82232	 0.006202	 0.034157	 0.01233	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81870	 81912	 0.027381	 0.021462	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81870	 82566	 0.030641	 0.18624	 0.00344	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81870	 82685	 0.038116	 0.090915	 0.00204	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81871	 81872	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81871	 81872	 0.000185	 0.014799	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81873	 81874	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81873	 81874	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81875	 81876	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81875	 81876	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81876	 82633	 0.081479	 0.31707	 0.00529	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81878	 81879	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81878	 81879	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81879	 82125	 0.13075	 0.30364	 0.00452	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81879	 82661	 0.096411	 0.15391	 0.00355	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81881	 81882	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81881	 81882	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81883	 81884	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81883	 81884	 0.000128	 0.010206	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81884	 81885	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81884	 81885	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81884	 82156	 0.00016	 0.002542	 0.00161	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81885	 82157	 0.004081	 0.014578	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81885	 82157	 0.004081	 0.014578	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81885	 82599	 0.55237	 0.43759	 0.00551	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81886	 81887	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81886	 81887	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81887	 82499	 0.033005	 0.065347	 0.00096	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81888	 81906	 0.000191	 0.001563	 0.00042	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81889	 82347	 0.006456	 0.039235	 0.00072	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81889	 82354	 0.006452	 0.044286	 0.00081	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81890	 81891	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81890	 81891	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81891	 81892	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81891	 81892	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81892	 82157	 0.008545	 0.026242	 0.00049	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81895	 82116	 0.002734	 0.027633	 0.00813	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81895	 82552	 0.004722	 0.02903	 0.00837	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81896	 82309	 0.11297	 0.12426	 0.00166	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81896	 82310	 0.061181	 0.15728	 0.00243	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81897	 82347	 0.00931	 0.03622	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81897	 82347	 0.00931	 0.03622	 0.0006	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81898	 81899	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81898	 81899	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81899	 82153	 0.1134	 0.32536	 0.00501	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81900	 81901	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81900	 81901	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81900	 82154	 0.004942	 0.029663	 0.00898	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81902	 81903	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81902	 81903	 0.000116	 0.009249	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81904	 82314	 0.009732	 0.038965	 0.00982	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81905	 82702	 0.00116	 0.003979	 0.00095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81908	 81909	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81908	 81909	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81908	 82116	 0.001451	 0.020952	 0.00665	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81910	 82364	 0.012009	 0.027464	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81910	 82364	 0.012009	 0.027464	 0.00067	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81911	 81912	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81911	 81912	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81911	 82231	 0.016803	 0.081568	 0.01865	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81913	 81914	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81913	 81914	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81914	 82398	 0.05585	 0.12774	 0.00312	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81917	 81918	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81917	 81918	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81917	 82246	 0.002097	 0.02157	 0.00612	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81917	 82247	 0.007263	 0.02175	 0.0049	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81918	 82333	 0.13832	 0.3519	 0.00557	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81919	 81920	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81919	 81920	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81919	 82715	 0.004684	 0.035624	 0.0112	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81920	 82321	 0.28309	 0.3686	 0.00516	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81923	 82550	 0.077478	 0.063773	 0.00129	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81924	 82213	 0.019692	 0.032841	 0.00048	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81924	 82214	 0.007883	 0.030203	 0.00085	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81925	 82708	 0.002162	 0.00915	 0.00206	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81925	 82713	 0.003112	 0.010484	 0.00261	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81926	 82404	 0.014145	 0.080407	 0.00145	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81928	 82159	 0.060036	 0.26757	 0.00455	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81929	 81930	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81929	 81930	 0.000148	 0.011839	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81930	 81931	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81930	 81931	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81932	 81933	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81932	 81933	 0.000168	 0.013453	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81933	 82770	 0.001723	 0.010706	 0.00302	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81935	 81936	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81935	 81936	 0.000359	 0.026907	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81936	 81962	 7.3e-05	 0.000793	 0.00025	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81937	 81938	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81937	 81938	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81937	 83087	 0.003888	 0.015565	 0.00392	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81938	 83086	 0.027826	 0.078963	 0.00124	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81939	 81940	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81939	 81940	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81943	 83248	 0.008502	 0.021856	 0.00541	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81944	 81945	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81944	 81945	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81944	 83449	 0.001075	 0.003114	 0.00075	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81945	 83374	 0.025589	 0.019628	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81945	 83495	 0.011412	 0.010296	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81945	 83495	 0.011412	 0.010296	 0.00017	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81946	 81947	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81946	 81947	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81947	 82804	 0.057375	 0.15168	 0.00275	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81948	 83158	 0.02991	 0.045819	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81949	 81951	 0.000143	 0.001611	 0.00047	 317.0	 332.9	 348.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81951	 83096	 0.00461	 0.066562	 0.02114	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81952	 81953	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81952	 81953	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81953	 83358	 0.000788	 0.004096	 9e-05	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81955	 81956	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81955	 81956	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81955	 83487	 0.000615	 0.002391	 0.00064	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81957	 81958	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81957	 81958	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81958	 83110	 0.075419	 0.055489	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81959	 81960	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81959	 81960	 0.000219	 0.016443	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81960	 81961	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81960	 81961	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81962	 81963	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81962	 81963	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81962	 83018	 0.01175	 0.05703	 0.01304	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	81963	 83295	 0.026056	 0.048448	 0.00113	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81964	 81965	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81964	 81965	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81967	 83087	 0.000396	 0.003181	 0.00089	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81968	 81986	 0.00353	 0.020063	 0.00036	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	81968	 81991	 0.014555	 0.031191	 0.00055	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81968	 83234	 0.042929	 0.17546	 0.00355	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81969	 81970	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81969	 81970	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81970	 83238	 0.001522	 0.014165	 0.00027	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81972	 81973	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81972	 81973	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81972	 82926	 0.003264	 0.013067	 0.00329	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	81976	 83101	 0.011656	 0.045343	 0.00076	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81978	 83329	 0.082601	 0.064747	 0.00083	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81981	 83231	 0.078407	 0.18205	 0.00271	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81983	 81984	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81983	 81984	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81984	 82887	 0.016373	 0.078996	 0.00139	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	81984	 82896	 0.037821	 0.16665	 0.00289	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	81985	 83498	 0.009986	 0.013612	 0.0003	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81989	 81990	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81989	 81990	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81990	 82812	 0.047438	 0.16948	 0.00337	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81990	 82812	 0.047438	 0.16948	 0.00337	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81991	 83233	 0.016088	 0.03735	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	81993	 82735	 0.044917	 0.10273	 0.00251	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81993	 82736	 0.019158	 0.036207	 0.00059	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	81993	 82738	 0.027379	 0.072376	 0.00131	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81993	 82922	 0.070006	 0.16012	 0.00391	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81996	 81997	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81996	 81997	 0.000132	 0.010571	 0.0	 1400.0	 1400.0	 1400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81997	 81998	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81997	 81998	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	81999	 84140	 0.001956	 0.018776	 0.00546	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	81999	 84142	 0.000543	 0.009081	 0.00515	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82000	 82001	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82000	 82001	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82003	 82004	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82003	 82004	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82003	 82007	 0.004674	 0.033813	 0.01819	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82003	 83500	 0.004968	 0.057621	 0.0308	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82003	 84449	 0.033409	 0.10903	 0.02897	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82005	 82035	 0.005491	 0.06634	 0.03764	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82005	 83547	 0.009101	 0.057649	 0.01565	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82006	 82007	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82006	 82007	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82008	 82009	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82008	 82009	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82008	 83813	 0.002972	 0.014166	 0.0041	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82009	 84087	 0.08436	 0.25888	 0.00701	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82013	 84385	 0.042862	 0.1772	 0.042	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82015	 82016	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82015	 82016	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82015	 84374	 0.014659	 0.044517	 0.00975	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82016	 82091	 0.27895	 0.20529	 0.003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82017	 82018	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82017	 82018	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82018	 84269	 0.013402	 0.091999	 0.00168	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82019	 82020	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82019	 82020	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82021	 82022	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82021	 82022	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82021	 84353	 0.005789	 0.036668	 0.00995	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82021	 84377	 0.025253	 0.11959	 0.02878	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82021	 84600	 0.016424	 0.069525	 0.01565	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82022	 84605	 0.03107	 0.17485	 0.00378	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82023	 82024	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82023	 82024	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82023	 84631	 0.008228	 0.022401	 0.00494	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82025	 82026	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82025	 82026	 0.000329	 0.024664	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82026	 82027	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82026	 82027	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82028	 83657	 0.01513	 0.05887	 0.01573	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82028	 84358	 0.008146	 0.056521	 0.01613	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82029	 84208	 0.014215	 0.056885	 0.0012	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82030	 84251	 0.013091	 0.052387	 0.00111	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82030	 84564	 0.003558	 0.032726	 0.00065	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82031	 84133	 0.00023	 0.002481	 0.00133	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82032	 82033	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82032	 82033	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82032	 84063	 0.001519	 0.022734	 0.00764	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82033	 83635	 0.021587	 0.050117	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82035	 82036	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82035	 82036	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82036	 83553	 0.029533	 0.20274	 0.0037	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82037	 83581	 0.002378	 0.006474	 0.00143	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82038	 84382	 0.003609	 0.023597	 0.006	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82039	 82047	 0.000174	 0.001355	 3e-05	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82039	 84308	 0.021099	 0.082081	 0.00137	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82040	 82041	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82040	 82041	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82040	 83573	 0.002524	 0.012447	 0.00337	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82040	 83583	 0.001578	 0.009469	 0.00287	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82041	 83584	 0.015013	 0.038908	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82042	 82043	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82042	 82043	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82043	 84168	 0.010999	 0.075501	 0.00138	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82043	 84170	 0.006663	 0.037907	 0.00117	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82044	 82045	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82044	 82045	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82044	 84176	 0.000737	 0.011006	 0.00326	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82044	 84191	 0.000234	 0.003381	 0.00138	 418.0	 438.9	 459.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82045	 83829	 0.076532	 0.19676	 0.00305	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82045	 84171	 0.017399	 0.045092	 0.00085	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82046	 82047	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82046	 82047	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82046	 84302	 0.000212	 0.002454	 0.00131	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82047	 84309	 0.04083	 0.080841	 0.00119	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82048	 84583	 0.002365	 0.011029	 0.00273	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82048	 84584	 0.005228	 0.013571	 0.00329	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82049	 83682	 0.005766	 0.013248	 0.0002	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82049	 83685	 0.002487	 0.013101	 0.00024	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82049	 83693	 0.002974	 0.012153	 0.00025	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82050	 82596	 0.049638	 0.17382	 0.00481	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82051	 84141	 0.01615	 0.046319	 0.00071	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82053	 84624	 0.10194	 0.28935	 0.00455	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82054	 83676	 0.013387	 0.010594	 0.00013	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82055	 83565	 0.004645	 0.01285	 0.0003	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82057	 84569	 0.028484	 0.06745	 0.00123	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82059	 84427	 0.077374	 0.055934	 0.00085	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82060	 83604	 0.0098	 0.02014	 0.00038	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82062	 82063	 0.07501	 0.059363	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82063	 82318	 0.059543	 0.13619	 0.00332	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82066	 82067	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82066	 82093	 0.001011	 0.007465	 0.00215	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82068	 82069	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82068	 82076	 0.00062	 0.003929	 0.00107	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82074	 82102	 0.011423	 0.020531	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82076	 82077	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82082	 82098	 0.057151	 0.04704	 0.00095	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82082	 82722	 0.065163	 0.25355	 0.00423	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82082	 82723	 0.026727	 0.15194	 0.00275	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82083	 82086	 0.015307	 0.024433	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82084	 82085	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82085	 82102	 0.009537	 0.017733	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82089	 82090	 0.010034	 0.039036	 0.00065	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82091	 84373	 0.099463	 0.25573	 0.00396	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82093	 82094	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82101	 82102	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82103	 82104	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82103	 82105	 0.001306	 0.005228	 0.00132	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82103	 82111	 0.00695	 0.023842	 0.00571	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82104	 82110	 0.010418	 0.024186	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82104	 82113	 0.17489	 0.13842	 0.00174	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82105	 82106	 0.00252	 0.006861	 0.00151	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82107	 82110	 0.07146	 0.054815	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82109	 82110	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82111	 82112	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82114	 82115	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82117	 82242	 0.072754	 0.20648	 0.00324	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82118	 82119	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82119	 82544	 0.11351	 0.25967	 0.00634	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82120	 82413	 0.007794	 0.018092	 0.00551	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82121	 82414	 0.024754	 0.063634	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82122	 82332	 0.013575	 0.076275	 0.00141	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82122	 82398	 0.17602	 0.50522	 0.00778	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82123	 82132	 0.003779	 0.03241	 0.00922	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82126	 82127	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82128	 82716	 0.044115	 0.14717	 0.00233	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82130	 82132	 0.007409	 0.029665	 0.00747	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82131	 82132	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82131	 82132	 0.000154	 0.012332	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82132	 82133	 0.007858	 0.030887	 0.00808	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82134	 82135	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82134	 82136	 0.001589	 0.004325	 0.00095	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82136	 82137	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82138	 82222	 0.01931	 0.064416	 0.00102	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82140	 82141	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82141	 82142	 0.013675	 0.054723	 0.00116	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82143	 82633	 0.071924	 0.16451	 0.00402	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82144	 82145	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82146	 82656	 0.071801	 0.26941	 0.00484	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82147	 82148	 0.035136	 0.027806	 0.00035	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82150	 82275	 0.084753	 0.16782	 0.00246	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82150	 82561	 0.28082	 0.28373	 0.00376	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82151	 82152	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82152	 82277	 0.055151	 0.184	 0.00292	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82156	 82157	 0.00013	 0.010416	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82158	 82598	 0.25819	 0.24954	 0.00362	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82161	 82162	 0.098926	 0.19589	 0.00288	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82163	 82164	 0.02568	 0.12991	 0.00226	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82165	 82166	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82166	 82167	 0.007206	 0.037959	 0.00068	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82166	 82554	 0.065836	 0.18684	 0.00294	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82169	 82170	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82173	 82174	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82174	 82175	 0.007731	 0.015821	 0.00039	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82179	 82180	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82179	 82183	 0.0049	 0.019618	 0.00494	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82180	 82594	 0.064446	 0.2857	 0.00858	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82182	 82183	 0.003716	 0.014123	 0.00395	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82183	 82184	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82185	 82186	 0.015477	 0.07829	 0.00136	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82189	 82192	 0.009542	 0.024529	 0.00607	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82190	 82562	 0.077805	 0.30276	 0.00506	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82191	 82192	 0.00316	 0.011494	 0.00352	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82193	 82336	 0.31091	 0.22883	 0.00335	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82193	 82513	 0.10632	 0.26938	 0.00534	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82196	 82559	 0.012159	 0.032136	 0.00752	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82198	 82199	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82198	 82199	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82199	 82623	 0.003774	 0.012948	 0.0031	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82200	 82210	 0.031229	 0.034348	 0.00046	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82201	 82203	 0.010993	 0.023105	 0.00042	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82201	 82204	 0.016201	 0.037612	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82202	 82203	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82206	 82207	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82211	 82213	 0.004605	 0.026179	 0.00047	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82212	 82213	 0.1008	 0.10979	 0.00149	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82212	 82214	 0.15808	 0.11631	 0.0017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82213	 82215	 0.013753	 0.073596	 0.00223	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82216	 82222	 0.042275	 0.033456	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82218	 82219	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82221	 82222	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82222	 82223	 0.024014	 0.068877	 0.00106	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82222	 82226	 0.006324	 0.042911	 0.0008	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82223	 82226	 0.02009	 0.042224	 0.00077	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82223	 82227	 0.015075	 0.10348	 0.00189	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82224	 82225	 0.004347	 0.019369	 0.00033	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82224	 82226	 0.01483	 0.034429	 0.00051	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82229	 82231	 0.01135	 0.038243	 0.0095	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82234	 82523	 0.47249	 0.36272	 0.00487	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82234	 82586	 0.043778	 0.30058	 0.00548	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82235	 82521	 0.013724	 0.03563	 0.00865	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82240	 82241	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82240	 82243	 0.002117	 0.014977	 0.00411	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82241	 82245	 0.01627	 0.045007	 0.00105	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82243	 82244	 0.003257	 0.008456	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82244	 82245	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82245	 82406	 0.067133	 0.19052	 0.00299	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82247	 82248	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82248	 82564	 0.15427	 0.44272	 0.00681	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82250	 82251	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82252	 82262	 0.021612	 0.061987	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82253	 82254	 0.002167	 0.010256	 0.00247	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82255	 82256	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82256	 82264	 0.049057	 0.064476	 0.00088	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82257	 82258	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82257	 82438	 0.005325	 0.02922	 0.00772	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82261	 82262	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82262	 82264	 0.002907	 0.02266	 0.00042	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82263	 82264	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82265	 82266	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82268	 82269	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82270	 82414	 0.015779	 0.036086	 0.00088	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82270	 82421	 0.007323	 0.024429	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82271	 82272	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82272	 82634	 0.098041	 0.15651	 0.00361	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82274	 82275	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82276	 82277	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82278	 82279	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82280	 82281	 0.000134	 0.010687	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82280	 82281	 0.000134	 0.010687	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82282	 82288	 0.18304	 0.1849	 0.00245	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82284	 82285	 0.023697	 0.046918	 0.00069	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82287	 82548	 0.069526	 0.070225	 0.00093	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82288	 82590	 0.064425	 0.16698	 0.00316	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82289	 82290	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82293	 82296	 0.062002	 0.049068	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82295	 82296	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82298	 82299	 0.014922	 0.075931	 0.00172	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82298	 82301	 0.017032	 0.06626	 0.00111	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82298	 82301	 0.017032	 0.06626	 0.00111	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82299	 82301	 0.015783	 0.10834	 0.00198	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82300	 82301	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82300	 82302	 0.001166	 0.011783	 0.00346	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82302	 82700	 0.002068	 0.031597	 0.01018	 399.0	 418.9	 438.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82306	 82307	 0.025585	 0.12228	 0.00268	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82309	 82588	 0.030918	 0.1901	 0.00343	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82311	 82314	 0.014651	 0.038724	 0.00906	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82312	 82313	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82313	 82717	 0.047812	 0.15951	 0.00253	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82314	 82315	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82315	 82717	 0.029454	 0.19261	 0.00446	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82316	 82317	 0.006713	 0.043246	 0.01134	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82316	 82320	 0.01112	 0.030276	 0.00667	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82317	 82318	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82318	 82319	 0.02993	 0.099848	 0.00158	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82320	 82321	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82329	 82330	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82330	 82331	 0.044722	 0.11497	 0.00178	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82330	 82503	 0.042927	 0.056419	 0.00077	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82331	 82549	 0.07196	 0.19025	 0.00345	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82338	 82339	 0.014511	 0.056451	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82339	 82340	 0.040457	 0.093914	 0.00179	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82341	 82559	 0.017171	 0.095318	 0.02899	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82341	 82699	 0.022632	 0.076271	 0.01896	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82343	 82554	 0.073895	 0.22697	 0.00426	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82344	 82345	 0.10602	 0.083904	 0.00106	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82346	 82347	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82346	 82350	 0.000699	 0.007496	 0.00195	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82348	 82349	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82349	 82357	 0.016885	 0.028445	 0.00041	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82350	 82351	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82353	 82356	 0.004158	 0.015597	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82353	 82356	 0.004158	 0.015597	 0.00028	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82355	 82356	 0.007937	 0.030878	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82355	 82356	 0.007937	 0.030878	 0.00052	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82359	 82367	 0.006532	 0.018736	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82360	 82361	 0.033183	 0.024414	 0.00036	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82361	 82362	 0.012231	 0.022403	 0.00039	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82363	 82364	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82365	 82366	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82366	 82367	 0.00744	 0.036305	 0.00063	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82371	 82372	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82372	 82378	 0.041779	 0.05491	 0.00075	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82372	 82380	 0.002983	 0.022162	 0.00053	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82374	 82375	 0.007795	 0.022356	 0.00034	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82377	 82380	 0.016598	 0.079324	 0.00174	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	82379	 82380	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82386	 82387	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82386	 82574	 0.001811	 0.020998	 0.01122	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82388	 82389	 0.00224	 0.009248	 0.00219	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82389	 82772	 0.002567	 0.023353	 0.00589	 261.0	 274.0	 287.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82391	 82392	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82394	 82395	 0.005853	 0.034135	 0.00069	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82396	 82579	 0.062141	 0.17635	 0.00277	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82397	 82630	 0.23601	 0.16721	 0.00264	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82398	 82541	 0.10533	 0.13844	 0.0019	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82399	 82536	 0.039798	 0.1221	 0.00331	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82400	 82401	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82401	 82541	 0.28962	 0.22927	 0.00289	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82407	 82408	 0.030108	 0.15231	 0.00265	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82412	 82413	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82412	 82413	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82412	 82413	 0.000123	 0.009866	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82414	 82425	 0.01373	 0.039378	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82416	 82417	 0.018727	 0.031231	 0.00045	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82417	 82430	 0.010466	 0.054424	 0.00118	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82423	 82439	 0.016129	 0.045771	 0.00072	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82428	 82435	 0.004476	 0.017411	 0.00029	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82429	 82434	 0.02912	 0.031026	 0.00044	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82430	 82433	 0.016757	 0.016925	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82433	 82434	 0.011223	 0.029667	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82434	 82435	 0.006373	 0.01828	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82434	 82461	 0.007914	 0.020344	 0.00031	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82435	 82490	 0.029107	 0.082599	 0.0013	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82436	 82437	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82436	 82438	 0.001244	 0.006482	 0.0017	 191.0	 200.6	 210.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82437	 82439	 0.009346	 0.022292	 0.0005	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82438	 82439	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82439	 82508	 0.009094	 0.044379	 0.00077	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82441	 82442	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82441	 82454	 0.00256	 0.008539	 0.00217	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82443	 82444	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82451	 82509	 0.000519	 0.001973	 0.00055	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82452	 82456	 0.041625	 0.030091	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82453	 82454	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82453	 82454	 0.000161	 0.012869	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82454	 82455	 0.000969	 0.007076	 0.00182	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82457	 82458	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82457	 82458	 0.000142	 0.011384	 0.0	 1300.0	 1300.0	 1300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82458	 82487	 0.001063	 0.006847	 0.00179	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82459	 82509	 0.0004	 0.002967	 0.00152	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82462	 82466	 0.004354	 0.012488	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82464	 82465	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82464	 82468	 0.001204	 0.003278	 0.00072	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82468	 82510	 0.001749	 0.005893	 0.00146	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82469	 82480	 0.016148	 0.031971	 0.00047	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82470	 82478	 0.011918	 0.013108	 0.00017	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82473	 82474	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82475	 82476	 0.002645	 0.006991	 0.00164	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82476	 82477	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82478	 82485	 0.017219	 0.033746	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82480	 82511	 0.006199	 0.01778	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82482	 82483	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82482	 82486	 0.004665	 0.016257	 0.00377	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82483	 82500	 0.028326	 0.02084	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82484	 82485	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82484	 82486	 0.000846	 0.004913	 0.00116	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82493	 82494	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82495	 82500	 0.029221	 0.052725	 0.00076	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82497	 82504	 0.027244	 0.051491	 0.00083	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82505	 82506	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82510	 82511	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82512	 82513	 0.000175	 0.013157	 0.0	 950.0	 950.0	 950.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82513	 82519	 0.074058	 0.19039	 0.00295	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82513	 82631	 0.027635	 0.10793	 0.00239	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82514	 82626	 0.30673	 0.22181	 0.00336	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82515	 82516	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82516	 82519	 0.019027	 0.073203	 0.00125	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82516	 82519	 0.019027	 0.073203	 0.00125	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82517	 82518	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82521	 82522	 0.013418	 0.03373	 0.00874	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82521	 82524	 0.012636	 0.043349	 0.01039	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82522	 82523	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82522	 82524	 0.00132	 0.008629	 0.00219	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82523	 82525	 0.007118	 0.034732	 0.0006	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82525	 82526	 0.012266	 0.021571	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82528	 82531	 0.047714	 0.037761	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82530	 82535	 0.079155	 0.051246	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82532	 82535	 0.067214	 0.047612	 0.00075	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82534	 82535	 0.043793	 0.044233	 0.00059	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82537	 82538	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82538	 82563	 0.093395	 0.18493	 0.00271	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82540	 82541	 0.065298	 0.14935	 0.00365	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82542	 82544	 0.14273	 0.14022	 0.00237	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82543	 82566	 0.40055	 0.31716	 0.00399	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82545	 82546	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82552	 82553	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82555	 82556	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82557	 82558	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82557	 82559	 0.001885	 0.008592	 0.00273	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82560	 82561	 0.04847	 0.10387	 0.00182	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82563	 82564	 0.05142	 0.13219	 0.00205	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82567	 82685	 0.034378	 0.1532	 0.0026	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82567	 82686	 0.070142	 0.11816	 0.00168	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82568	 82569	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82571	 82572	 0.016142	 0.086376	 0.00262	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82580	 82581	 0.081019	 0.16042	 0.00235	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82585	 82586	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82585	 82587	 0.008682	 0.041094	 0.00988	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82585	 82644	 0.018529	 0.048107	 0.01168	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82586	 82588	 0.057055	 0.14453	 0.00286	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82587	 82588	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82588	 82716	 0.1511	 0.27684	 0.00478	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82590	 82591	 0.21826	 0.17276	 0.00218	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82593	 82594	 0.019373	 0.10668	 0.00241	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82593	 82596	 0.029724	 0.13246	 0.00225	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82595	 82597	 0.039978	 0.10361	 0.00196	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82602	 82604	 0.007584	 0.01389	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82602	 82619	 0.019035	 0.048932	 0.00076	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82604	 82613	 0.03301	 0.050561	 0.00088	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82608	 82609	 0.003275	 0.010046	 0.00027	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82610	 82611	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82613	 82627	 0.025118	 0.041891	 0.00061	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82615	 82623	 0.006131	 0.017098	 0.00359	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82617	 82618	 0.001112	 0.016341	 0.005	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82617	 82629	 0.009027	 0.060569	 0.01462	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82619	 82781	 0.037265	 0.06698	 0.0012	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82623	 82624	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82624	 82625	 0.058651	 0.043152	 0.00063	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82624	 82626	 0.025346	 0.057966	 0.00142	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82629	 82630	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82636	 82640	 0.009153	 0.035609	 0.00059	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82636	 82641	 0.007906	 0.049645	 0.00109	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82638	 82640	 0.006148	 0.020509	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82639	 82640	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82655	 82656	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82660	 82661	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82660	 82663	 0.002237	 0.014984	 0.00942	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82663	 82664	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82666	 82667	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82669	 82670	 0.008384	 0.016601	 0.00024	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82671	 82672	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82672	 82675	 0.035713	 0.025816	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82674	 82681	 0.036861	 0.055263	 0.001	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82677	 82678	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82679	 82681	 0.021119	 0.039268	 0.00092	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82680	 82681	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82682	 82683	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82686	 82688	 0.024376	 0.069913	 0.00108	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82687	 82688	 0.084614	 0.056839	 0.001	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82689	 82695	 0.005661	 0.011584	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82691	 82692	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82692	 82693	 0.013911	 0.030788	 0.0005	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82694	 82696	 0.009074	 0.023327	 0.00578	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82698	 82699	 0.007185	 0.035428	 0.00958	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82698	 82700	 0.007934	 0.043693	 0.01578	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82699	 82701	 0.004401	 0.023697	 0.00651	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82704	 82705	 0.034679	 0.068662	 0.00101	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82707	 82710	 0.012552	 0.028705	 0.0007	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82709	 82710	 0.014232	 0.046965	 0.00076	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82712	 82713	 0.00418	 0.014341	 0.00344	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82713	 82714	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82716	 82717	 0.044713	 0.13718	 0.00372	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82724	 82725	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82727	 82729	 0.01174	 0.040273	 0.00965	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	82732	 83317	 0.057931	 0.092472	 0.00213	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82734	 82735	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82736	 82737	 0.026172	 0.047937	 0.00083	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82737	 82738	 0.019313	 0.063732	 0.00103	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82737	 82739	 0.026391	 0.068399	 0.00129	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82739	 82745	 0.32616	 0.30059	 0.00482	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82740	 82741	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82741	 83254	 0.016777	 0.04812	 0.00074	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82743	 82748	 0.42621	 0.43083	 0.00571	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82745	 82984	 0.12378	 0.23399	 0.00379	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82746	 83276	 0.079801	 0.19535	 0.00334	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82748	 83276	 0.090589	 0.2329	 0.00361	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82750	 82751	 0.022506	 0.064549	 0.00099	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82751	 82753	 0.017284	 0.040127	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82751	 82754	 0.02116	 0.10157	 0.00304	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82752	 82753	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82758	 83080	 0.093118	 0.31072	 0.00493	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82759	 82760	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82760	 82763	 0.045177	 0.035412	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82761	 82762	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82762	 82763	 0.020004	 0.022002	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82763	 82765	 0.10043	 0.093451	 0.00177	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82764	 82765	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82765	 82773	 0.075141	 0.29239	 0.00488	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82768	 82769	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82770	 82771	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82770	 82774	 0.00408	 0.029519	 0.01588	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82772	 82773	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82772	 82774	 0.003274	 0.021407	 0.00544	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82774	 82775	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82780	 82781	 0.10176	 0.08053	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82783	 82786	 0.021187	 0.14544	 0.00265	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82785	 82786	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82787	 82794	 0.00313	 0.011182	 0.00022	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82801	 82802	 0.010621	 0.022761	 0.0004	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82802	 82886	 0.07567	 0.062284	 0.00126	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82803	 82886	 0.020497	 0.073223	 0.00145	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82805	 82806	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82820	 82821	 0.003918	 0.016583	 0.00031	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82822	 82826	 0.012925	 0.024032	 0.00056	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82822	 82842	 0.004668	 0.016332	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82824	 82825	 0.005376	 0.017935	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82825	 82834	 0.011608	 0.026946	 0.00051	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82825	 82863	 0.018257	 0.023995	 0.00033	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82828	 82831	 0.0141	 0.027916	 0.00041	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82828	 82865	 0.013766	 0.022564	 0.0004	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82829	 82852	 0.009688	 0.027491	 0.00043	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82830	 82864	 0.052456	 0.10386	 0.00152	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82831	 82834	 0.005314	 0.014048	 0.00026	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82832	 82849	 0.011293	 0.031282	 0.00052	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82833	 82848	 0.013387	 0.038395	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82834	 82864	 0.090567	 0.064155	 0.00101	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82837	 83290	 0.022674	 0.1134	 0.00202	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82839	 83290	 0.023767	 0.14604	 0.00334	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82843	 82856	 0.027388	 0.062637	 0.00153	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82844	 82856	 0.01618	 0.044202	 0.00075	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82845	 82846	 0.019198	 0.04457	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82846	 82858	 0.008376	 0.042372	 0.00074	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82846	 82862	 0.17389	 0.1334	 0.00179	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82848	 82857	 0.01453	 0.03735	 0.00058	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82853	 82863	 0.063859	 0.0645	 0.00085	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82854	 83289	 0.022056	 0.067734	 0.00127	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82855	 83280	 0.005448	 0.053983	 0.01654	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	82858	 82859	 0.019202	 0.039295	 0.00097	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82858	 82864	 0.031343	 0.089898	 0.00138	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82862	 83003	 0.043421	 0.14486	 0.0023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82868	 82872	 0.061721	 0.063024	 0.00098	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82869	 82870	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82870	 82872	 0.010089	 0.044453	 0.00077	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82871	 82872	 0.014134	 0.032813	 0.00049	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82871	 82873	 0.012215	 0.024184	 0.00035	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82874	 82877	 0.090649	 0.24769	 0.00421	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82874	 82907	 0.021454	 0.13039	 0.00241	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82876	 83285	 0.068906	 0.17715	 0.00274	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82877	 83286	 0.041223	 0.12647	 0.00343	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82878	 82919	 0.030497	 0.15428	 0.00268	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82880	 82881	 0.017303	 0.053137	 0.001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82884	 82885	 0.006905	 0.012144	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82889	 82890	 0.006399	 0.028514	 0.00048	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82891	 82892	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82899	 83111	 0.04265	 0.12838	 0.00251	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82900	 82902	 0.055404	 0.1436	 0.00272	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82908	 82909	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82910	 82916	 0.005848	 0.026058	 0.00044	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82910	 82917	 0.048675	 0.035187	 0.00053	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82911	 82912	 0.020416	 0.015468	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82911	 82921	 0.014874	 0.010943	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82923	 82927	 0.036222	 0.02345	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82925	 82927	 0.087324	 0.085444	 0.00121	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	82926	 82927	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82927	 82930	 0.083877	 0.065748	 0.00084	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82929	 82930	 0.000125	 0.009999	 0.0	 1250.0	 1250.0	 1250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82930	 83300	 0.49126	 0.38909	 0.0049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82930	 83302	 0.29655	 0.49996	 0.00713	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	82931	 82939	 0.039282	 0.028397	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82932	 82939	 0.018976	 0.063302	 0.001	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82936	 83318	 0.007854	 0.063551	 0.00164	 141.0	 148.0	 155.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82937	 82938	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82941	 82947	 0.020208	 0.015992	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82943	 82945	 0.003732	 0.009594	 0.00015	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82944	 82945	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82945	 82947	 0.00605	 0.010048	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	82946	 82947	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82951	 82952	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82951	 82964	 0.003703	 0.021278	 0.00603	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82953	 82954	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82957	 82961	 0.15676	 0.12407	 0.00156	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82958	 82959	 0.10168	 0.11184	 0.00149	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82960	 83127	 0.041743	 0.2866	 0.00523	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82962	 82963	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82964	 82965	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82969	 82970	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82969	 82973	 0.003684	 0.014481	 0.00379	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	82973	 82974	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82974	 82981	 0.10276	 0.081325	 0.00102	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82974	 82984	 0.077627	 0.11892	 0.00167	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	82975	 82980	 0.00792	 0.022474	 0.00035	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82976	 83246	 0.028143	 0.17304	 0.00312	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	82985	 82987	 0.03372	 0.096716	 0.00149	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82987	 82991	 0.02274	 0.052007	 0.00127	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82988	 82989	 0.025089	 0.066324	 0.0012	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	82990	 82991	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82996	 82997	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82997	 82998	 0.030875	 0.032972	 0.0007	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83000	 83955	 0.5031	 0.37049	 0.00542	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83005	 83007	 0.10853	 0.14265	 0.00196	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83009	 83014	 0.029991	 0.17971	 0.00432	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83014	 83015	 0.011819	 0.041379	 0.00115	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83014	 83016	 0.008685	 0.038862	 0.0008	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83018	 83019	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83018	 83023	 0.002493	 0.0146	 0.00398	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83020	 83031	 0.080626	 0.1872	 0.00278	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83022	 83208	 0.025071	 0.044091	 0.00083	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83023	 83024	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83023	 83027	 0.008302	 0.032632	 0.00854	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83025	 83026	 0.005556	 0.014726	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83025	 83298	 0.013643	 0.060795	 0.00103	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83027	 83075	 0.018998	 0.052982	 0.01112	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83033	 83052	 0.093022	 0.073618	 0.00093	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83034	 83039	 0.018222	 0.018405	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83034	 83041	 0.019657	 0.025581	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83035	 83037	 0.001819	 0.004953	 0.00109	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83037	 83075	 0.001729	 0.00525	 0.00115	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83038	 83039	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83038	 83075	 0.001438	 0.005012	 0.00116	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83040	 83041	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83041	 83046	 0.011556	 0.033144	 0.00051	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83043	 83044	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83045	 83046	 0.006419	 0.018409	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83046	 83206	 0.013781	 0.039526	 0.00061	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83048	 83052	 0.051094	 0.040436	 0.00051	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83049	 83051	 0.011131	 0.022037	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83049	 83057	 0.01692	 0.030412	 0.00055	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83056	 83057	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83057	 83059	 0.008835	 0.029155	 0.00047	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83062	 83066	 0.008568	 0.024573	 0.00038	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83062	 83079	 0.002767	 0.01328	 0.0004	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83064	 83065	 0.003507	 0.015627	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83064	 83202	 0.044365	 0.086949	 0.0013	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83067	 83202	 0.063495	 0.069161	 0.00094	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83068	 83073	 0.041817	 0.030766	 0.00045	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83072	 83073	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83074	 83075	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83074	 83075	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83075	 83076	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83075	 83076	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83075	 83078	 0.001944	 0.012313	 0.00334	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83078	 83079	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83086	 83088	 0.081162	 0.11312	 0.00193	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83093	 83097	 0.051833	 0.04102	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83094	 83098	 0.046343	 0.030003	 0.00057	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83094	 83099	 0.028541	 0.054658	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83094	 83284	 0.050496	 0.19429	 0.00332	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83095	 83096	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83095	 83096	 0.000176	 0.014094	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83101	 83104	 0.021443	 0.041546	 0.00089	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83102	 83106	 0.12676	 0.13539	 0.00286	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83104	 83106	 0.07652	 0.077289	 0.00102	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83105	 83106	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83108	 84210	 0.062813	 0.040666	 0.00077	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83109	 83110	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83115	 83232	 0.073892	 0.20189	 0.00343	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83116	 83117	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83117	 83124	 0.012171	 0.059394	 0.00103	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 83130	 0.018893	 0.048567	 0.00075	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83117	 83235	 0.041851	 0.25439	 0.00469	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83121	 83123	 0.086936	 0.058399	 0.00103	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83128	 83129	 0.16152	 0.12784	 0.00161	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83129	 83226	 0.1069	 0.30668	 0.00472	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83134	 83135	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83135	 83136	 0.033957	 0.049706	 0.00077	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83144	 83145	 0.049294	 0.088945	 0.00129	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83146	 83147	 0.039257	 0.043178	 0.00058	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83149	 83178	 0.059053	 0.046734	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83156	 83157	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83166	 83167	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83167	 83173	 0.033614	 0.04024	 0.00067	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83167	 83176	 0.015885	 0.061796	 0.00103	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83167	 83214	 0.019566	 0.038739	 0.00057	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83167	 83215	 0.016435	 0.042247	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83168	 83169	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83172	 83174	 0.050328	 0.039829	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83174	 83175	 0.025587	 0.025844	 0.00034	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83175	 83176	 0.012838	 0.025418	 0.00037	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83185	 83187	 0.034987	 0.024783	 0.00039	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83192	 83193	 0.042195	 0.030503	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83194	 83195	 0.024499	 0.044872	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83199	 83200	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83199	 83201	 0.001632	 0.004313	 0.00101	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83200	 83202	 0.018303	 0.018486	 0.00024	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83201	 83202	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83204	 83221	 0.041841	 0.033112	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83206	 83207	 0.047266	 0.037406	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83209	 83210	 0.049928	 0.039513	 0.0005	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83217	 83218	 0.002985	 0.016966	 0.00031	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83218	 83222	 0.007339	 0.028549	 0.00048	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83220	 83221	 0.00419	 0.023818	 0.00043	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83226	 83227	 0.023453	 0.12596	 0.00299	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83229	 83230	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83232	 83234	 0.14538	 0.20641	 0.0034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83238	 83239	 0.005474	 0.033656	 0.00061	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83240	 83241	 0.002647	 0.01705	 0.00447	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83241	 83242	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83251	 83252	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83252	 83253	 0.020287	 0.030751	 0.00064	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83252	 83254	 0.012252	 0.022781	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83253	 83254	 0.004782	 0.012641	 0.00023	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83256	 83257	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83257	 83258	 0.061314	 0.048061	 0.00062	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83257	 83272	 0.01661	 0.03816	 0.00058	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83258	 83262	 0.004591	 0.014723	 0.00036	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83260	 83274	 0.036658	 0.040319	 0.00054	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83260	 83281	 0.015869	 0.052939	 0.00084	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83262	 83268	 0.009167	 0.040388	 0.0007	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83267	 83268	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83268	 83270	 0.005211	 0.02322	 0.00039	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83271	 83272	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83272	 83284	 0.033208	 0.16214	 0.0034	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83273	 83274	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83274	 83278	 0.032953	 0.12678	 0.00216	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83275	 83276	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83276	 83290	 0.041791	 0.18624	 0.00316	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83277	 83278	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83280	 83281	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83280	 83288	 0.002164	 0.019159	 0.01052	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83282	 83286	 0.3088	 0.2	 0.00381	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83284	 83285	 0.031852	 0.084201	 0.00153	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83286	 83287	 0.051644	 0.14813	 0.00228	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83286	 83309	 0.080561	 0.23109	 0.00355	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83288	 83289	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83293	 83295	 0.046138	 0.074012	 0.00137	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83309	 83311	 0.012886	 0.059829	 0.00163	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83316	 83323	 0.058439	 0.097605	 0.00166	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83319	 83320	 0.022529	 0.075155	 0.00119	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83320	 83323	 0.075553	 0.080686	 0.00171	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83321	 83322	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83329	 83420	 0.16932	 0.13273	 0.0017	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83332	 83333	 0.055966	 0.05613	 0.00091	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83333	 83336	 0.050171	 0.036268	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83343	 83349	 0.099651	 0.078865	 0.00099	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83345	 83346	 0.011548	 0.016393	 0.00027	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83352	 83353	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83352	 83377	 0.012228	 0.031746	 0.00771	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83353	 83361	 0.019738	 0.038683	 0.00058	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83355	 83395	 0.019803	 0.015671	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83357	 83358	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83361	 83389	 0.039847	 0.031234	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83362	 83368	 0.014028	 0.010996	 0.00014	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83369	 83370	 0.00134	 0.003543	 0.00083	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83370	 83371	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83370	 83375	 0.001402	 0.004219	 0.00132	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83372	 83376	 0.006822	 0.010889	 0.00025	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83372	 83379	 0.052909	 0.037478	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83373	 83374	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83373	 83377	 0.004741	 0.012187	 0.00302	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83373	 83461	 0.00221	 0.005933	 0.00134	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83375	 83376	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83375	 83493	 0.001745	 0.004752	 0.00105	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83377	 83378	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83377	 84366	 0.05695	 0.22435	 0.05887	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83378	 83494	 0.049458	 0.039141	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83380	 83450	 0.023242	 0.015047	 0.00029	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83381	 83382	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83382	 83388	 0.009159	 0.021264	 0.00032	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83383	 83390	 0.006372	 0.010583	 0.00022	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83388	 83452	 0.038167	 0.029917	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83399	 83403	 0.034757	 0.023347	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83400	 83401	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83402	 83418	 0.004972	 0.015789	 0.00028	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83410	 83411	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83410	 83413	 0.001093	 0.004378	 0.0011	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83411	 83414	 0.007784	 0.018071	 0.00027	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83412	 83413	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83412	 83413	 9.2e-05	 0.007399	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83413	 83414	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83413	 83414	 0.000104	 0.008333	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83415	 83416	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83423	 83424	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83426	 83427	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83426	 83428	 0.002382	 0.006394	 0.00145	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83428	 83429	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83430	 83480	 0.040126	 0.031755	 0.0004	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83434	 83436	 0.005838	 0.015006	 0.00023	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83435	 83436	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83437	 83439	 0.0073	 0.024353	 0.00039	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83439	 83440	 0.009664	 0.01628	 0.00023	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83440	 83441	 0.0116	 0.022966	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83442	 83448	 0.028217	 0.022331	 0.00028	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83447	 83457	 0.010761	 0.011721	 0.00016	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83449	 83450	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83450	 83495	 0.024407	 0.015801	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83451	 83452	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83456	 83457	 0.020606	 0.016152	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83456	 83458	 0.020792	 0.016455	 0.00021	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83458	 83459	 0.004242	 0.012165	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83459	 83467	 0.12088	 0.094754	 0.00122	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83462	 83467	 0.094824	 0.074329	 0.00095	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83463	 83494	 0.007902	 0.020479	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83465	 83467	 0.010119	 0.025733	 0.00041	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83469	 83490	 0.046791	 0.03703	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83470	 83472	 0.008637	 0.028502	 0.00046	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83471	 83472	 0.01503	 0.010865	 0.00016	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83472	 83478	 0.055985	 0.052095	 0.00099	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83473	 83474	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83482	 83489	 0.044646	 0.032847	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83484	 83485	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83493	 83494	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83497	 83498	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83504	 83505	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83505	 83519	 0.09816	 0.077685	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83506	 83519	 0.026477	 0.075942	 0.00117	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83508	 83509	 0.000103	 0.008222	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83508	 83509	 0.000103	 0.008222	 0.0	 1800.0	 1800.0	 1800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83509	 83510	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83509	 83510	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83510	 83512	 0.018129	 0.04165	 0.00063	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83511	 83512	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83511	 83515	 0.004096	 0.0138	 0.00343	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83512	 83545	 0.11146	 0.20113	 0.00291	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83512	 84165	 0.074492	 0.3578	 0.0107	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83514	 83517	 0.000859	 0.003004	 0.001	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83515	 83516	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83515	 83517	 0.001271	 0.005088	 0.00128	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83517	 83518	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83517	 83520	 0.001968	 0.004568	 0.00139	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83519	 83521	 0.019487	 0.014947	 0.0002	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83520	 83521	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83522	 83523	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83524	 84617	 0.094162	 0.27013	 0.00416	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83525	 84419	 0.18031	 0.14271	 0.0018	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83525	 84425	 0.25842	 0.16735	 0.00319	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83525	 84609	 0.10165	 0.27777	 0.00472	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83527	 83528	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83528	 83529	 0.014235	 0.048627	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83528	 83529	 0.014235	 0.048627	 0.00106	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83529	 83531	 0.007412	 0.022738	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83529	 83531	 0.007412	 0.022738	 0.00062	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83530	 83531	 0.011979	 0.036748	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83530	 83531	 0.011979	 0.036748	 0.001	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83540	 83541	 0.039853	 0.11431	 0.00176	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83542	 84163	 0.086758	 0.19845	 0.00485	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83543	 83544	 0.02069	 0.04234	 0.00104	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83547	 83548	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83559	 83560	 0.008476	 0.02431	 0.00037	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83561	 83562	 0.006358	 0.036928	 0.0087	 193.0	 202.6	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83563	 83566	 0.019971	 0.021966	 0.00029	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83563	 83567	 0.017618	 0.032269	 0.00056	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83564	 83566	 0.017529	 0.037565	 0.00066	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83565	 83567	 0.017514	 0.025521	 0.00058	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83566	 84035	 0.006244	 0.024292	 0.00041	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83568	 84019	 0.014199	 0.032472	 0.00079	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83571	 83572	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83575	 83581	 0.003508	 0.009782	 0.00205	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83576	 83577	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83576	 84597	 0.006645	 0.05339	 0.01501	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83577	 84047	 0.02229	 0.057298	 0.00089	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83581	 83582	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83581	 83583	 0.002822	 0.01165	 0.00276	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83582	 83590	 0.063318	 0.056738	 0.00116	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83582	 84588	 0.031582	 0.15412	 0.00266	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83582	 84592	 0.029381	 0.075527	 0.00117	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83583	 83591	 0.001532	 0.009509	 0.0023	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83585	 83587	 0.068371	 0.054108	 0.00068	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83585	 83594	 0.021295	 0.061077	 0.00094	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83586	 83593	 0.000445	 0.003222	 0.00173	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83587	 83588	 0.012544	 0.015964	 0.00023	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83591	 83592	 0.001521	 0.00598	 0.00156	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83592	 84586	 0.001446	 0.015217	 0.00855	 476.0	 499.8	 523.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83593	 83594	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83598	 84477	 0.15788	 0.2419	 0.0034	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83599	 83644	 0.11659	 0.30915	 0.00785	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83599	 84572	 0.053635	 0.3129	 0.00628	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83600	 84165	 0.34953	 0.27673	 0.00348	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83603	 83606	 0.017482	 0.034261	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83603	 83616	 0.011804	 0.032697	 0.00054	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83604	 83605	 0.005271	 0.023489	 0.0004	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83606	 83609	 0.010272	 0.040117	 0.00089	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83607	 83616	 0.005716	 0.016807	 0.00034	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83608	 83615	 0.024933	 0.070754	 0.00111	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83611	 83612	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83613	 83975	 0.15697	 0.15856	 0.0021	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83614	 83615	 0.007054	 0.043364	 0.00078	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83619	 84598	 0.002706	 0.013595	 0.00354	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83620	 83621	 0.00093	 0.006547	 0.00372	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83620	 83623	 0.000825	 0.006585	 0.00162	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83621	 83622	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83621	 83623	 0.002361	 0.008098	 0.00194	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83623	 83624	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83624	 83627	 0.050206	 0.052823	 0.00077	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83624	 83628	 0.029151	 0.021447	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83625	 84060	 0.023864	 0.068445	 0.00105	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83626	 83627	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83626	 83631	 0.0021	 0.019454	 0.00974	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83631	 83632	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83636	 83637	 0.002731	 0.012528	 0.00321	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83637	 83638	 0.002311	 0.010404	 0.00277	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83638	 83639	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83639	 83851	 0.11811	 0.38993	 0.00632	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83639	 84090	 0.10198	 0.3403	 0.0054	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83641	 83642	 0.002524	 0.009921	 0.0026	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83642	 83643	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83643	 83644	 0.035156	 0.099764	 0.00157	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83644	 83647	 0.018796	 0.064208	 0.0014	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83644	 84253	 0.036952	 0.14376	 0.0024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83645	 83646	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83648	 83649	 0.015517	 0.097439	 0.00213	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83648	 83650	 0.024638	 0.082192	 0.0013	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83649	 84246	 0.25428	 0.27976	 0.00373	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83651	 83652	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83654	 83655	 0.002309	 0.019212	 0.00036	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83657	 84115	 0.019069	 0.051923	 0.01144	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83658	 83662	 0.001318	 0.019683	 0.00582	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83659	 83661	 0.001525	 0.01321	 0.00474	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83661	 83662	 0.000707	 0.0072	 0.00186	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83663	 84356	 0.45662	 0.35051	 0.00471	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83663	 84572	 0.12172	 0.34924	 0.00537	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83667	 84420	 0.020204	 0.09003	 0.00153	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83668	 83759	 0.007075	 0.014009	 0.00021	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83670	 83671	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83672	 83720	 0.00555	 0.016704	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83672	 83736	 0.005218	 0.011932	 0.00029	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83675	 83676	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83675	 83683	 0.000697	 0.001843	 0.00043	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83677	 83678	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83680	 83681	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83681	 83809	 0.004578	 0.011207	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83682	 83809	 0.002083	 0.009651	 0.00019	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83683	 83684	 0.001339	 0.003227	 0.00091	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83684	 83685	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83687	 83699	 0.014387	 0.041265	 0.00063	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83689	 83779	 0.006073	 0.017232	 0.00027	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83693	 83697	 0.002105	 0.011963	 0.00022	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83696	 83697	 0.003699	 0.011346	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83696	 83697	 0.003699	 0.011346	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83700	 83708	 0.003835	 0.02954	 0.00057	 125.0	 131.3	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83703	 83704	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83703	 83705	 0.000635	 0.002471	 0.00066	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83703	 83706	 0.000488	 0.003124	 0.00105	 230.0	 241.5	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83705	 83743	 0.001016	 0.003484	 0.00083	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83706	 83707	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83708	 83747	 0.006373	 0.028078	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83711	 83712	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83719	 83720	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83720	 83756	 0.00501	 0.024445	 0.00042	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83722	 83800	 0.013665	 0.065931	 0.00116	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83724	 83725	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83727	 83728	 0.010893	 0.028001	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83729	 83793	 0.017421	 0.034493	 0.00051	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83729	 83799	 0.010381	 0.02385	 0.00036	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83730	 83775	 0.006716	 0.031182	 0.00085	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83732	 83733	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83732	 83734	 0.000979	 0.008553	 0.00339	 293.0	 307.6	 322.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83734	 83735	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83735	 83754	 0.007652	 0.040769	 0.00072	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83736	 83777	 0.03298	 0.043345	 0.00059	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83737	 83738	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83738	 83739	 0.010172	 0.016965	 0.00025	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83741	 83744	 0.004219	 0.0121	 0.00019	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83743	 83744	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83745	 83746	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83746	 83752	 0.009409	 0.050132	 0.00088	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83749	 83750	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83753	 83790	 0.008917	 0.025574	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83763	 83805	 0.007051	 0.031421	 0.00053	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83768	 83769	 0.013816	 0.029037	 0.00053	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83773	 83785	 0.021885	 0.039336	 0.00071	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83776	 83777	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83778	 83790	 0.017754	 0.019527	 0.00026	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83779	 83780	 0.001409	 0.007507	 0.00013	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	83789	 83804	 0.000643	 0.003764	 0.00103	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83792	 83793	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83793	 83966	 0.022296	 0.068399	 0.00185	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83793	 83966	 0.022296	 0.068399	 0.00185	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83797	 83798	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83800	 83802	 0.009001	 0.039656	 0.00069	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83802	 84168	 0.007114	 0.034146	 0.00102	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83804	 83808	 0.000331	 0.003887	 0.00233	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83807	 83808	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83807	 83808	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83807	 83808	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83816	 83817	 0.021681	 0.050335	 0.00075	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	83816	 83822	 0.065938	 0.091899	 0.00157	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83818	 83819	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83818	 84575	 0.003513	 0.025417	 0.01367	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83819	 83820	 0.006469	 0.028826	 0.00049	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83819	 83826	 0.071666	 0.12882	 0.00231	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83821	 83822	 0.061615	 0.065801	 0.00139	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83822	 83823	 0.029552	 0.098586	 0.00156	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83822	 83884	 0.086349	 0.2045	 0.00374	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83824	 83828	 0.023022	 0.05344	 0.00102	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83825	 83826	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83826	 83885	 0.027594	 0.054635	 0.0008	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83829	 83830	 0.034583	 0.12355	 0.00245	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83829	 83830	 0.034583	 0.12355	 0.00245	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83831	 84366	 0.001465	 0.016943	 0.0105	 523.0	 549.1	 575.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83832	 83835	 0.095446	 0.095473	 0.00129	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83835	 83836	 0.047566	 0.12575	 0.00228	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83835	 84436	 0.028898	 0.17768	 0.0032	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83836	 84103	 0.031886	 0.081968	 0.00127	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83837	 83838	 0.00147	 0.014972	 0.00386	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83837	 84376	 0.021991	 0.05988	 0.01319	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83838	 83839	 0.00685	 0.020196	 0.0047	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83839	 83840	 0.00348	 0.0123	 0.00277	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83842	 83843	 0.002481	 0.015713	 0.00426	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83842	 84093	 0.011343	 0.040095	 0.00904	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83843	 83844	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83843	 84384	 0.013455	 0.08275	 0.02387	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83847	 83848	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83852	 84089	 0.004016	 0.032263	 0.00907	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83860	 83869	 0.00685	 0.02665	 0.00044	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83864	 83869	 0.016197	 0.041192	 0.00065	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83864	 83909	 0.007254	 0.018448	 0.00029	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83865	 83954	 0.007213	 0.032139	 0.00055	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83868	 83869	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83872	 83876	 0.024333	 0.017236	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83876	 83878	 0.022643	 0.017919	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83877	 83878	 0.006278	 0.01002	 0.00023	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83877	 83939	 0.025277	 0.019151	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83878	 83880	 0.004229	 0.010872	 0.00017	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83880	 83881	 0.026805	 0.027074	 0.00036	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83881	 83935	 0.00368	 0.014317	 0.00024	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83882	 83887	 0.006245	 0.01791	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83882	 83888	 0.037942	 0.030027	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83882	 83889	 0.011997	 0.046673	 0.00078	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83883	 83884	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83885	 83889	 0.012499	 0.031787	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83887	 83891	 0.018304	 0.036239	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83894	 83895	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83895	 83919	 0.044156	 0.044599	 0.00059	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83897	 83898	 0.010504	 0.017218	 0.0003	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83898	 83902	 0.01248	 0.031738	 0.0005	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83898	 83910	 0.008046	 0.01825	 0.00036	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83900	 83901	 0.038573	 0.059091	 0.00083	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83903	 83912	 0.033005	 0.067543	 0.00166	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83904	 84157	 0.015025	 0.085412	 0.00155	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83907	 84157	 0.040133	 0.17885	 0.00304	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83908	 83912	 0.027372	 0.021662	 0.00027	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83910	 83912	 0.049561	 0.039222	 0.00049	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83911	 83912	 0.011552	 0.022872	 0.00034	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83911	 83913	 0.004754	 0.016634	 0.00034	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83917	 83918	 0.013275	 0.038073	 0.00059	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83920	 83921	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83921	 83922	 0.03228	 0.025546	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83923	 83924	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83923	 83925	 0.001095	 0.015955	 0.00511	 388.0	 407.4	 426.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83925	 83926	 0.000116	 0.009259	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83928	 83929	 0.016007	 0.037905	 0.00069	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83931	 83932	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83931	 83933	 0.001004	 0.006174	 0.00178	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83933	 83934	 0.000223	 0.015623	 0.0	 800.0	 800.0	 800.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83934	 83947	 0.028571	 0.055995	 0.00084	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83936	 83937	 0.001217	 0.004953	 0.00121	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83936	 83951	 0.003951	 0.016721	 0.00376	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83937	 83938	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83940	 83941	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83948	 83949	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83952	 84382	 0.001821	 0.012821	 0.00729	 381.0	 400.1	 419.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83957	 83958	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83964	 83965	 0.013942	 0.078339	 0.00145	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	83967	 83968	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83971	 84308	 0.011976	 0.030785	 0.00048	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	83974	 83975	 0.026582	 0.075432	 0.00119	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83977	 83978	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83977	 83978	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83979	 83980	 0.006564	 0.019352	 0.0045	 128.0	 134.4	 140.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83980	 83981	 0.002233	 0.012693	 0.00367	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83981	 83982	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83983	 83985	 0.005758	 0.019754	 0.00473	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	83984	 83985	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83986	 83995	 0.012961	 0.043236	 0.00069	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	83989	 84057	 0.023243	 0.019131	 0.00039	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	83992	 84014	 0.006374	 0.018282	 0.00028	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	83994	 83995	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	83994	 84067	 0.000488	 0.00527	 0.00181	 325.0	 341.2	 357.5	 0.0	 0.0	 1	 -30.0	 30.0;
	83995	 84027	 0.014478	 0.056323	 0.00094	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84000	 84042	 0.004673	 0.017978	 0.00031	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84001	 84002	 0.004066	 0.012912	 0.00023	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84007	 84008	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84009	 84028	 0.01226	 0.015218	 0.00033	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84009	 84033	 0.010035	 0.019666	 0.00029	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84011	 84012	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84015	 84016	 0.000535	 0.007728	 0.00245	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84017	 84018	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84019	 84035	 0.013531	 0.030945	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84019	 84043	 0.05479	 0.10848	 0.00159	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84019	 84071	 0.039358	 0.11289	 0.00174	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84021	 84074	 0.013454	 0.080614	 0.00194	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84022	 84027	 0.081059	 0.06415	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84024	 84037	 0.030705	 0.019878	 0.00038	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84026	 84027	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84027	 84028	 0.009716	 0.03738	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84027	 84028	 0.009716	 0.03738	 0.00064	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84029	 84031	 0.00408	 0.019582	 0.00059	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84031	 84032	 0.023819	 0.033195	 0.00057	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84032	 84033	 0.007439	 0.031052	 0.0009	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84034	 84043	 0.035527	 0.063458	 0.00094	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84037	 84042	 0.023307	 0.023541	 0.00031	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84038	 84039	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84039	 84040	 0.002448	 0.01091	 0.00019	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84041	 84042	 0.001927	 0.011843	 0.00027	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84041	 84043	 0.010793	 0.027744	 0.00043	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84045	 84046	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84046	 84050	 0.016564	 0.03788	 0.00092	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84048	 84049	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84049	 84051	 0.0155	 0.030376	 0.00046	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84049	 84053	 0.015894	 0.042015	 0.00076	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84052	 84055	 0.021383	 0.060678	 0.00095	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84052	 84595	 0.027887	 0.079984	 0.00123	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84059	 84060	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84059	 84063	 0.004421	 0.014897	 0.0037	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84060	 84075	 0.1227	 0.079444	 0.00151	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84063	 84064	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84067	 84068	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84069	 84071	 0.024726	 0.06356	 0.00098	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84070	 84071	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84071	 84072	 0.018998	 0.073908	 0.00123	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84078	 84079	 0.002136	 0.083306	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84080	 84081	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84081	 84082	 0.01465	 0.062634	 0.00141	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84081	 84639	 0.093125	 0.35841	 0.00612	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84084	 84640	 0.027358	 0.16821	 0.00303	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84086	 84087	 0.000156	 0.012499	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84089	 84090	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84095	 84096	 0.047695	 0.097608	 0.0024	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84095	 84099	 0.050169	 0.1439	 0.00221	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84096	 84097	 0.061697	 0.17509	 0.00275	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84098	 84099	 0.025502	 0.08929	 0.00247	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84098	 84116	 0.066435	 0.19056	 0.00293	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84100	 84489	 0.087496	 0.2268	 0.00429	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84101	 84102	 0.032419	 0.064188	 0.00094	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84101	 84103	 0.024531	 0.040747	 0.00086	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84108	 84109	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84108	 84110	 0.002699	 0.010804	 0.00272	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84110	 84112	 0.001064	 0.012037	 0.00676	 501.0	 526.0	 551.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84112	 84113	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84115	 84116	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84119	 84120	 0.026091	 0.07404	 0.00116	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84121	 84122	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84122	 84123	 0.14029	 0.13158	 0.00203	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84122	 84157	 0.2033	 0.30845	 0.00442	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84123	 84355	 0.13458	 0.1769	 0.00242	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84126	 84127	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84127	 84128	 0.00691	 0.015804	 0.00039	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84129	 84130	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84129	 84147	 0.001737	 0.025529	 0.00781	 384.0	 403.2	 422.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84131	 84144	 0.050516	 0.14336	 0.00225	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84138	 84140	 0.001697	 0.009938	 0.00271	 205.0	 215.2	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84140	 84141	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84141	 84143	 0.032495	 0.12642	 0.00211	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84141	 84143	 0.032495	 0.12642	 0.00211	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84141	 84144	 0.007872	 0.054032	 0.00098	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84142	 84143	 0.000142	 0.011363	 0.0	 1100.0	 1100.0	 1100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84145	 84146	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84147	 84148	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84151	 84446	 0.042968	 0.16717	 0.00279	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84151	 84446	 0.042968	 0.16717	 0.00279	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84155	 84156	 0.076473	 0.14988	 0.00225	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84155	 84162	 0.024138	 0.074127	 0.00139	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84168	 84188	 0.07117	 0.11361	 0.00262	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84172	 84173	 0.020212	 0.022231	 0.0003	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84176	 84177	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84179	 84183	 0.074495	 0.097911	 0.00134	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84182	 84183	 0.004007	 0.018579	 0.00039	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84185	 84187	 0.023129	 0.028195	 0.00045	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84186	 84187	 0.009879	 0.044022	 0.00075	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84188	 84189	 0.053022	 0.053035	 0.00072	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84190	 84422	 0.41681	 0.30151	 0.00457	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84192	 84213	 0.055103	 0.040541	 0.00059	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84193	 84195	 0.014764	 0.033488	 0.00067	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84193	 84210	 0.031557	 0.024974	 0.00031	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84194	 84197	 0.017566	 0.013769	 0.00018	 27.0	 27.0	 27.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84195	 84196	 0.025156	 0.019296	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84196	 84204	 0.045822	 0.036263	 0.00046	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84197	 84198	 0.013509	 0.014859	 0.0002	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84197	 84201	 0.015213	 0.014013	 0.00022	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84199	 84202	 0.014355	 0.025902	 0.00037	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84205	 84230	 0.015906	 0.016986	 0.00036	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84206	 84207	 0.000791	 0.003165	 0.0008	 159.0	 166.9	 174.9	 0.0	 0.0	 0	 -30.0	 30.0;
	84210	 84212	 0.052108	 0.041238	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84214	 84215	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84214	 84216	 0.001255	 0.00619	 0.00167	 185.0	 194.2	 203.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84215	 84628	 0.055701	 0.10917	 0.00164	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84216	 84217	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84219	 84221	 0.037752	 0.024441	 0.00047	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84228	 84229	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84229	 84630	 0.046642	 0.060699	 0.00085	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84236	 84237	 0.001645	 0.007468	 0.00016	 95.0	 99.8	 104.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84237	 84239	 0.015333	 0.037532	 0.00064	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84245	 84246	 0.010015	 0.018344	 0.00032	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84248	 84249	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84250	 84252	 0.013026	 0.050675	 0.00085	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84252	 84402	 0.12205	 0.42735	 0.00886	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84255	 84256	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84259	 84260	 0.012586	 0.044963	 0.00089	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84262	 84616	 0.046739	 0.15425	 0.0025	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84262	 84622	 0.049778	 0.14126	 0.00222	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84266	 84533	 0.009839	 0.043842	 0.00074	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84267	 84618	 0.053488	 0.15179	 0.00239	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84267	 84622	 0.024919	 0.057249	 0.00087	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84268	 84270	 0.005037	 0.03023	 0.00915	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84272	 84274	 0.010344	 0.051323	 0.00122	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84273	 84276	 0.092223	 0.09315	 0.00123	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84274	 84578	 0.39992	 0.36866	 0.00591	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84275	 84276	 0.019648	 0.095877	 0.00165	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84276	 84277	 0.06588	 0.085015	 0.00171	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84282	 84283	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84283	 84284	 0.02397	 0.043084	 0.00077	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84283	 84285	 0.09859	 0.078025	 0.00098	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84287	 84288	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84287	 84332	 0.000995	 0.00391	 0.00102	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84291	 84292	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84291	 84351	 0.001464	 0.005756	 0.00151	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84292	 84293	 0.004302	 0.009985	 0.00019	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84292	 84352	 0.009193	 0.022817	 0.00038	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84296	 84297	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84298	 84305	 0.027588	 0.019943	 0.0003	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84298	 84306	 0.007275	 0.020644	 0.00032	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84299	 84305	 0.014586	 0.011433	 0.00015	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84312	 84315	 0.002373	 0.013841	 0.00028	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84313	 84315	 0.006427	 0.013774	 0.00024	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84317	 84318	 0.001109	 0.004994	 0.00133	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84320	 84321	 0.051682	 0.040511	 0.00052	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84322	 84325	 0.000607	 0.004574	 0.00127	 238.0	 249.9	 261.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84323	 84324	 0.000238	 0.017856	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84323	 84325	 0.001155	 0.004391	 0.00123	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84324	 84328	 0.017959	 0.0476	 0.00121	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84325	 84327	 0.00034	 0.003013	 0.00165	 437.0	 458.9	 480.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84328	 84350	 0.006968	 0.047828	 0.00087	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84328	 84599	 0.037502	 0.074252	 0.00109	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84331	 84352	 0.08149	 0.064491	 0.00081	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84334	 84335	 0.006171	 0.020586	 0.00033	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84335	 84344	 0.011311	 0.028651	 0.00057	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84341	 84342	 0.004733	 0.023095	 0.0004	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84344	 84345	 0.018596	 0.053336	 0.00082	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84349	 84350	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84351	 84352	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84357	 84361	 0.041171	 0.032272	 0.00041	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84358	 84359	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84360	 84361	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84361	 84363	 0.044391	 0.035131	 0.00044	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84362	 84363	 0.024471	 0.019366	 0.00024	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84364	 84365	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84364	 84365	 0.000106	 0.008457	 0.0	 1750.0	 1750.0	 1750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84366	 84367	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84369	 84370	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84369	 84631	 0.005996	 0.020982	 0.00695	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84370	 84437	 0.025233	 0.098164	 0.00164	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84372	 84435	 0.003381	 0.032459	 0.00944	 284.0	 298.2	 312.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84376	 84377	 0.005875	 0.026953	 0.0069	 175.0	 183.7	 192.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84378	 84379	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84378	 84380	 0.004083	 0.0106	 0.00257	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84378	 84381	 0.001205	 0.004905	 0.0012	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84380	 84381	 0.005878	 0.01511	 0.00374	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84384	 84426	 0.002909	 0.021119	 0.0073	 250.0	 262.5	 275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84387	 84542	 0.082615	 0.065382	 0.00082	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84389	 84390	 0.010651	 0.077849	 0.00144	 119.0	 125.0	 130.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84389	 84393	 0.014288	 0.086838	 0.0016	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84391	 84561	 0.044589	 0.10915	 0.00187	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84393	 84398	 0.024038	 0.093517	 0.00156	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84393	 84398	 0.024038	 0.093517	 0.00156	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84395	 84396	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84397	 84398	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84397	 84399	 0.003628	 0.009418	 0.00229	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84399	 84400	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84401	 84402	 0.000238	 0.016665	 0.0	 750.0	 750.0	 750.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84401	 84528	 0.0038	 0.015215	 0.00383	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84402	 84497	 0.056579	 0.090314	 0.00208	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84402	 84541	 0.079221	 0.098343	 0.00214	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84405	 84406	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84405	 84408	 0.002626	 0.025083	 0.00921	 307.0	 322.4	 337.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84408	 84409	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84412	 84425	 0.011335	 0.018903	 0.00027	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84415	 84420	 0.086108	 0.094711	 0.00126	 30.0	 31.5	 33.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84416	 84421	 0.049364	 0.097739	 0.00143	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84416	 84425	 0.013326	 0.051268	 0.00088	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84417	 84425	 0.11212	 0.087887	 0.00113	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84418	 84419	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84418	 84424	 0.006182	 0.025158	 0.00613	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84428	 84430	 0.036881	 0.12304	 0.00195	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84429	 84430	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84430	 84431	 0.060758	 0.10963	 0.00158	 39.0	 41.0	 42.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84435	 84436	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84437	 84438	 0.065545	 0.16989	 0.00321	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84438	 84439	 0.013277	 0.04429	 0.0007	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84441	 84443	 0.01566	 0.10104	 0.00322	 131.0	 137.5	 144.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84444	 84445	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84444	 84445	 0.000137	 0.010962	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84445	 84446	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84445	 84446	 0.000149	 0.011904	 0.0	 1050.0	 1050.0	 1050.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84447	 84448	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84447	 84449	 0.00494	 0.016947	 0.00406	 142.0	 149.1	 156.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84449	 84450	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84460	 84461	 0.000303	 0.022725	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84460	 84464	 0.000984	 0.003738	 0.00105	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84465	 84466	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84466	 84477	 0.032938	 0.17352	 0.00311	 96.0	 100.8	 105.6	 0.0	 0.0	 1	 -30.0	 30.0;
	84469	 84470	 0.00037	 0.027775	 0.0	 450.0	 450.0	 450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84469	 84483	 0.00197	 0.008338	 0.00188	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84476	 84477	 0.000801	 0.041659	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84479	 84486	 0.009444	 0.05806	 0.00105	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84480	 84481	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84483	 84484	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84485	 84489	 0.031508	 0.11256	 0.00223	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84486	 84489	 0.030415	 0.10147	 0.00161	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84488	 84621	 0.013179	 0.080094	 0.00148	 110.0	 115.5	 121.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84491	 84527	 0.033125	 0.026215	 0.00033	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84492	 84503	 0.041936	 0.083031	 0.00122	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84493	 84494	 0.000312	 0.024998	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84493	 84495	 0.003064	 0.007383	 0.00208	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84495	 84496	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84495	 84498	 0.002242	 0.00582	 0.00141	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84500	 84501	 0.041837	 0.033109	 0.00042	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84500	 84514	 0.048224	 0.038164	 0.00048	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84502	 84503	 0.000185	 0.013888	 0.0	 900.0	 900.0	 900.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84502	 84506	 0.003625	 0.00958	 0.00224	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84503	 84513	 0.040406	 0.040811	 0.00054	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84503	 84532	 0.054899	 0.10208	 0.00239	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84504	 84508	 0.025766	 0.020196	 0.00026	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84504	 84543	 0.055083	 0.043592	 0.00055	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84505	 84512	 0.014401	 0.028513	 0.00042	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84506	 84507	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84506	 84511	 0.001538	 0.004187	 0.00092	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84507	 84512	 0.022393	 0.017177	 0.00023	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84510	 84519	 0.01808	 0.035796	 0.00053	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84510	 84540	 0.068754	 0.050585	 0.00074	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84511	 84512	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84514	 84515	 0.031364	 0.023075	 0.00034	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84522	 84525	 0.018929	 0.024879	 0.00034	 33.0	 34.7	 36.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84522	 84542	 0.034198	 0.057609	 0.00082	 37.0	 38.9	 40.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84523	 84526	 0.03911	 0.028272	 0.00043	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84528	 84529	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84531	 84532	 0.037426	 0.071675	 0.00113	 41.0	 43.1	 45.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84532	 84613	 0.056174	 0.15561	 0.00257	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84532	 84620	 0.021239	 0.075872	 0.00151	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84533	 84622	 0.030588	 0.119	 0.00199	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84534	 84535	 0.12811	 0.10139	 0.00128	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84537	 84538	 0.000196	 0.014705	 0.0	 850.0	 850.0	 850.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84545	 84548	 0.008575	 0.028607	 0.00045	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84545	 84560	 0.006879	 0.038654	 0.00072	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84546	 84563	 0.005535	 0.01467	 0.00037	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84547	 84550	 0.014066	 0.046923	 0.00074	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84548	 84563	 0.003227	 0.012915	 0.00027	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84550	 84551	 0.005914	 0.026354	 0.00045	 88.0	 92.4	 96.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84552	 84563	 0.023661	 0.029371	 0.00064	 35.0	 36.8	 38.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84553	 84563	 0.018802	 0.073148	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84553	 84563	 0.018802	 0.073148	 0.00122	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84555	 84556	 0.012842	 0.072999	 0.00132	 103.0	 108.2	 113.3	 0.0	 0.0	 1	 -30.0	 30.0;
	84565	 84567	 0.000664	 0.011349	 0.00615	 650.0	 682.5	 715.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84567	 84568	 0.00024	 0.019229	 0.0	 650.0	 650.0	 650.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84574	 84576	 0.02858	 0.10996	 0.00188	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84575	 84576	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84582	 84583	 0.001736	 0.00695	 0.00175	 159.0	 166.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84584	 84585	 0.00142	 0.062484	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84585	 84599	 0.031701	 0.025087	 0.00032	 24.0	 25.2	 26.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84587	 84588	 0.000661	 0.035708	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84587	 84589	 0.002695	 0.016745	 0.00473	 219.0	 229.9	 240.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84588	 84590	 0.025001	 0.057178	 0.0014	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84589	 84590	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84590	 84595	 0.063285	 0.16731	 0.00304	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84591	 84592	 0.060603	 0.061211	 0.00081	 28.0	 29.4	 30.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84597	 84598	 0.010431	 0.024213	 0.00738	 118.0	 123.9	 129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	84600	 84601	 0.001	 0.04999	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84606	 84607	 0.000278	 0.020831	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	84607	 84608	 0.006495	 0.031693	 0.00055	 92.0	 96.6	 101.2	 0.0	 0.0	 1	 -30.0	 30.0;
	84607	 84609	 0.012695	 0.045352	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84607	 84609	 0.012695	 0.045352	 0.0009	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84607	 84614	 0.031579	 0.090573	 0.00139	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84608	 84609	 0.006231	 0.038289	 0.00087	 115.0	 120.7	 126.5	 0.0	 0.0	 1	 -30.0	 30.0;
	84608	 84613	 0.050053	 0.13267	 0.00337	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84611	 84612	 0.01009	 0.038817	 0.00066	 80.0	 84.0	 88.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84612	 84613	 0.017111	 0.03931	 0.0006	 57.0	 59.9	 62.7	 0.0	 0.0	 1	 -30.0	 30.0;
	84613	 84620	 0.026997	 0.090062	 0.00143	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84616	 84617	 0.032716	 0.084101	 0.0013	 59.0	 61.9	 64.9	 0.0	 0.0	 1	 -30.0	 30.0;
	84617	 84618	 0.018193	 0.060692	 0.00096	 71.0	 74.6	 78.1	 0.0	 0.0	 1	 -30.0	 30.0;
	84617	 84622	 0.05876	 0.16054	 0.00273	 64.0	 67.2	 70.4	 0.0	 0.0	 1	 -30.0	 30.0;
	84629	 84630	 0.000446	 0.031247	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Setting Flat Start
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : Updated Thermal Rating: on line 20621-82078 : Rate C - 26.4 -> 35.0
% INFO    : Updated Thermal Rating: on line 21509-82467 : Rate C - 26.4 -> 35.0
% INFO    : Updated Thermal Rating: on line 84194-84197 : Rate C - 26.4 -> 27.0
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 20401	: V=1.02, theta=-39.844366 -> V=1.0, theta=0.0
% INFO    : Bus 20402	: V=1.02, theta=-38.148979 -> V=1.0, theta=0.0
% INFO    : Bus 20403	: V=1.0169992, theta=-53.843393 -> V=1.0, theta=0.0
% INFO    : Bus 20404	: V=1.02, theta=-39.434437 -> V=1.0, theta=0.0
% INFO    : Bus 20405	: V=1.02, theta=-41.556886 -> V=1.0, theta=0.0
% INFO    : Bus 20406	: V=1.02, theta=-38.249279 -> V=1.0, theta=0.0
% INFO    : Bus 20407	: V=1.02, theta=-39.430951 -> V=1.0, theta=0.0
% INFO    : Bus 20408	: V=1.02, theta=-40.199767 -> V=1.0, theta=0.0
% INFO    : Bus 20409	: V=1.02, theta=-42.038289 -> V=1.0, theta=0.0
% INFO    : Bus 20410	: V=1.0131502, theta=-51.031368 -> V=1.0, theta=0.0
% INFO    : Bus 20411	: V=1.02, theta=-54.116927 -> V=1.0, theta=0.0
% INFO    : Bus 20412	: V=1.02, theta=-54.765856 -> V=1.0, theta=0.0
% INFO    : Bus 20413	: V=1.02, theta=-41.487711 -> V=1.0, theta=0.0
% INFO    : Bus 20414	: V=1.0031404, theta=-48.650587 -> V=1.0, theta=0.0
% INFO    : Bus 20415	: V=1.02, theta=-39.18883 -> V=1.0, theta=0.0
% INFO    : Bus 20416	: V=1.0073892, theta=-56.620862 -> V=1.0, theta=0.0
% INFO    : Bus 20417	: V=1.0200469, theta=-41.468749 -> V=1.0, theta=0.0
% INFO    : Bus 20418	: V=1.0199587, theta=-54.780928 -> V=1.0, theta=0.0
% INFO    : Bus 20419	: V=1.02, theta=-43.281226 -> V=1.0, theta=0.0
% INFO    : Bus 20420	: V=1.0182304, theta=-48.73257 -> V=1.0, theta=0.0
% INFO    : Bus 20421	: V=1.02, theta=-51.911243 -> V=1.0, theta=0.0
% INFO    : Bus 20422	: V=1.0195544, theta=-54.766762 -> V=1.0, theta=0.0
% INFO    : Bus 20423	: V=1.02, theta=-39.849376 -> V=1.0, theta=0.0
% INFO    : Bus 20424	: V=1.0190885, theta=-39.87821 -> V=1.0, theta=0.0
% INFO    : Bus 20425	: V=1.02, theta=-43.124753 -> V=1.0, theta=0.0
% INFO    : Bus 20426	: V=1.0156867, theta=-49.776178 -> V=1.0, theta=0.0
% INFO    : Bus 20427	: V=0.9801531, theta=-55.083823 -> V=1.0, theta=0.0
% INFO    : Bus 20428	: V=1.02, theta=-39.160367 -> V=1.0, theta=0.0
% INFO    : Bus 20429	: V=1.0158173, theta=-49.649492 -> V=1.0, theta=0.0
% INFO    : Bus 20430	: V=1.02, theta=-47.474277 -> V=1.0, theta=0.0
% INFO    : Bus 20431	: V=1.02, theta=-49.189908 -> V=1.0, theta=0.0
% INFO    : Bus 20432	: V=1.02, theta=-49.061114 -> V=1.0, theta=0.0
% INFO    : Bus 20433	: V=0.9987897, theta=-56.904682 -> V=1.0, theta=0.0
% INFO    : Bus 20434	: V=0.9990663, theta=-56.824766 -> V=1.0, theta=0.0
% INFO    : Bus 20435	: V=1.0041719, theta=-57.335444 -> V=1.0, theta=0.0
% INFO    : Bus 20436	: V=1.02, theta=-41.671489 -> V=1.0, theta=0.0
% INFO    : Bus 20437	: V=0.9987918, theta=-48.967947 -> V=1.0, theta=0.0
% INFO    : Bus 20438	: V=1.0183774, theta=-43.732621 -> V=1.0, theta=0.0
% INFO    : Bus 20439	: V=1.0070854, theta=-56.08822 -> V=1.0, theta=0.0
% INFO    : Bus 20440	: V=0.9955095, theta=-51.439913 -> V=1.0, theta=0.0
% INFO    : Bus 20441	: V=1.0171363, theta=-43.150527 -> V=1.0, theta=0.0
% INFO    : Bus 20442	: V=0.9886886, theta=-56.754345 -> V=1.0, theta=0.0
% INFO    : Bus 20443	: V=1.016104, theta=-40.031029 -> V=1.0, theta=0.0
% INFO    : Bus 20444	: V=1.0109842, theta=-55.598697 -> V=1.0, theta=0.0
% INFO    : Bus 20445	: V=1.0113246, theta=-48.396502 -> V=1.0, theta=0.0
% INFO    : Bus 20446	: V=0.9776827, theta=-51.922824 -> V=1.0, theta=0.0
% INFO    : Bus 20447	: V=0.9890337, theta=-52.164081 -> V=1.0, theta=0.0
% INFO    : Bus 20448	: V=0.9822619, theta=-54.228682 -> V=1.0, theta=0.0
% INFO    : Bus 20449	: V=1.02, theta=-40.940566 -> V=1.0, theta=0.0
% INFO    : Bus 20450	: V=0.9873738, theta=-52.682686 -> V=1.0, theta=0.0
% INFO    : Bus 20451	: V=0.9906466, theta=-51.070544 -> V=1.0, theta=0.0
% INFO    : Bus 20452	: V=0.9844407, theta=-54.864303 -> V=1.0, theta=0.0
% INFO    : Bus 20453	: V=0.9819109, theta=-49.754614 -> V=1.0, theta=0.0
% INFO    : Bus 20454	: V=0.9836477, theta=-51.172769 -> V=1.0, theta=0.0
% INFO    : Bus 20455	: V=0.9983085, theta=-42.562158 -> V=1.0, theta=0.0
% INFO    : Bus 20456	: V=0.988516, theta=-54.446773 -> V=1.0, theta=0.0
% INFO    : Bus 20457	: V=1.02, theta=-41.660445 -> V=1.0, theta=0.0
% INFO    : Bus 20458	: V=1.02, theta=-31.773028 -> V=1.0, theta=0.0
% INFO    : Bus 20459	: V=1.02, theta=-42.017845 -> V=1.0, theta=0.0
% INFO    : Bus 20460	: V=1.02, theta=-48.241577 -> V=1.0, theta=0.0
% INFO    : Bus 20461	: V=1.02, theta=-38.611754 -> V=1.0, theta=0.0
% INFO    : Bus 20462	: V=1.02, theta=-25.135093 -> V=1.0, theta=0.0
% INFO    : Bus 20463	: V=1.02, theta=-42.982101 -> V=1.0, theta=0.0
% INFO    : Bus 20464	: V=1.02, theta=-39.987134 -> V=1.0, theta=0.0
% INFO    : Bus 20465	: V=1.02, theta=-48.03459 -> V=1.0, theta=0.0
% INFO    : Bus 20466	: V=1.02, theta=-35.331832 -> V=1.0, theta=0.0
% INFO    : Bus 20467	: V=1.02, theta=-41.2747 -> V=1.0, theta=0.0
% INFO    : Bus 20468	: V=1.0191707, theta=-42.967446 -> V=1.0, theta=0.0
% INFO    : Bus 20469	: V=1.02, theta=-34.08608 -> V=1.0, theta=0.0
% INFO    : Bus 20470	: V=0.9911626, theta=-42.694299 -> V=1.0, theta=0.0
% INFO    : Bus 20471	: V=1.02, theta=-29.630541 -> V=1.0, theta=0.0
% INFO    : Bus 20472	: V=0.9941103, theta=-42.066961 -> V=1.0, theta=0.0
% INFO    : Bus 20473	: V=1.02, theta=-29.5538 -> V=1.0, theta=0.0
% INFO    : Bus 20474	: V=1.0053683, theta=-42.607713 -> V=1.0, theta=0.0
% INFO    : Bus 20475	: V=1.02, theta=-32.252596 -> V=1.0, theta=0.0
% INFO    : Bus 20476	: V=1.0155641, theta=-44.319659 -> V=1.0, theta=0.0
% INFO    : Bus 20477	: V=1.01297, theta=-49.116656 -> V=1.0, theta=0.0
% INFO    : Bus 20478	: V=1.0426666, theta=-30.372941 -> V=1.0, theta=0.0
% INFO    : Bus 20479	: V=1.02, theta=-39.097619 -> V=1.0, theta=0.0
% INFO    : Bus 20480	: V=1.02, theta=-32.665188 -> V=1.0, theta=0.0
% INFO    : Bus 20481	: V=1.0080933, theta=-47.498455 -> V=1.0, theta=0.0
% INFO    : Bus 20482	: V=1.0183871, theta=-25.570627 -> V=1.0, theta=0.0
% INFO    : Bus 20483	: V=1.02, theta=-28.172877 -> V=1.0, theta=0.0
% INFO    : Bus 20484	: V=1.0048188, theta=-38.057407 -> V=1.0, theta=0.0
% INFO    : Bus 20485	: V=1.02, theta=-38.091397 -> V=1.0, theta=0.0
% INFO    : Bus 20486	: V=0.9855535, theta=-51.285101 -> V=1.0, theta=0.0
% INFO    : Bus 20487	: V=1.02, theta=-32.729428 -> V=1.0, theta=0.0
% INFO    : Bus 20488	: V=0.9963513, theta=-44.103169 -> V=1.0, theta=0.0
% INFO    : Bus 20489	: V=1.0118751, theta=-47.836034 -> V=1.0, theta=0.0
% INFO    : Bus 20490	: V=0.9964438, theta=-43.560746 -> V=1.0, theta=0.0
% INFO    : Bus 20491	: V=0.974511, theta=-50.06678 -> V=1.0, theta=0.0
% INFO    : Bus 20492	: V=0.9834093, theta=-41.871349 -> V=1.0, theta=0.0
% INFO    : Bus 20493	: V=0.9949354, theta=-32.894285 -> V=1.0, theta=0.0
% INFO    : Bus 20494	: V=1.02, theta=-47.789057 -> V=1.0, theta=0.0
% INFO    : Bus 20495	: V=0.9968175, theta=-31.661437 -> V=1.0, theta=0.0
% INFO    : Bus 20496	: V=0.981258, theta=-53.800317 -> V=1.0, theta=0.0
% INFO    : Bus 20497	: V=0.9817383, theta=-36.454741 -> V=1.0, theta=0.0
% INFO    : Bus 20498	: V=1.0123431, theta=-32.253112 -> V=1.0, theta=0.0
% INFO    : Bus 20499	: V=0.9733102, theta=-50.379273 -> V=1.0, theta=0.0
% INFO    : Bus 20500	: V=1.02, theta=-36.577135 -> V=1.0, theta=0.0
% INFO    : Bus 20501	: V=0.9975878, theta=-31.154723 -> V=1.0, theta=0.0
% INFO    : Bus 20502	: V=1.02, theta=-28.154587 -> V=1.0, theta=0.0
% INFO    : Bus 20503	: V=1.0161079, theta=-29.694105 -> V=1.0, theta=0.0
% INFO    : Bus 20504	: V=0.9986736, theta=-37.408508 -> V=1.0, theta=0.0
% INFO    : Bus 20505	: V=1.0162837, theta=-42.101684 -> V=1.0, theta=0.0
% INFO    : Bus 20506	: V=0.9950092, theta=-33.079424 -> V=1.0, theta=0.0
% INFO    : Bus 20507	: V=0.9824659, theta=-51.559174 -> V=1.0, theta=0.0
% INFO    : Bus 20508	: V=0.9794976, theta=-43.759648 -> V=1.0, theta=0.0
% INFO    : Bus 20509	: V=0.9958767, theta=-36.15582 -> V=1.0, theta=0.0
% INFO    : Bus 20510	: V=0.9841715, theta=-45.71512 -> V=1.0, theta=0.0
% INFO    : Bus 20511	: V=1.0384525, theta=-30.727048 -> V=1.0, theta=0.0
% INFO    : Bus 20512	: V=1.004177, theta=-34.344294 -> V=1.0, theta=0.0
% INFO    : Bus 20513	: V=1.02, theta=-28.711341 -> V=1.0, theta=0.0
% INFO    : Bus 20514	: V=1.0072748, theta=-31.923186 -> V=1.0, theta=0.0
% INFO    : Bus 20515	: V=1.0322465, theta=-30.379074 -> V=1.0, theta=0.0
% INFO    : Bus 20516	: V=1.0097357, theta=-42.503611 -> V=1.0, theta=0.0
% INFO    : Bus 20517	: V=1.02, theta=-39.20603 -> V=1.0, theta=0.0
% INFO    : Bus 20518	: V=1.02, theta=-28.452949 -> V=1.0, theta=0.0
% INFO    : Bus 20519	: V=1.0145032, theta=-28.732092 -> V=1.0, theta=0.0
% INFO    : Bus 20520	: V=1.0195151, theta=-29.90487 -> V=1.0, theta=0.0
% INFO    : Bus 20521	: V=1.0013909, theta=-44.97281 -> V=1.0, theta=0.0
% INFO    : Bus 20522	: V=1.02, theta=-30.173639 -> V=1.0, theta=0.0
% INFO    : Bus 20523	: V=1.0063658, theta=-43.448978 -> V=1.0, theta=0.0
% INFO    : Bus 20524	: V=1.0104298, theta=-42.359769 -> V=1.0, theta=0.0
% INFO    : Bus 20525	: V=0.9780575, theta=-49.498256 -> V=1.0, theta=0.0
% INFO    : Bus 20526	: V=1.0372911, theta=-30.64108 -> V=1.0, theta=0.0
% INFO    : Bus 20527	: V=1.0033508, theta=-29.826212 -> V=1.0, theta=0.0
% INFO    : Bus 20528	: V=0.9886863, theta=-32.505178 -> V=1.0, theta=0.0
% INFO    : Bus 20529	: V=1.02, theta=-30.603675 -> V=1.0, theta=0.0
% INFO    : Bus 20530	: V=1.0146753, theta=-31.566455 -> V=1.0, theta=0.0
% INFO    : Bus 20531	: V=1.016636, theta=-38.684312 -> V=1.0, theta=0.0
% INFO    : Bus 20532	: V=1.02, theta=-49.603228 -> V=1.0, theta=0.0
% INFO    : Bus 20533	: V=1.02, theta=-36.708177 -> V=1.0, theta=0.0
% INFO    : Bus 20534	: V=1.02, theta=-49.265733 -> V=1.0, theta=0.0
% INFO    : Bus 20535	: V=1.02, theta=-39.358407 -> V=1.0, theta=0.0
% INFO    : Bus 20536	: V=1.02, theta=-40.178372 -> V=1.0, theta=0.0
% INFO    : Bus 20537	: V=1.02, theta=-36.07067 -> V=1.0, theta=0.0
% INFO    : Bus 20538	: V=1.02, theta=-52.828148 -> V=1.0, theta=0.0
% INFO    : Bus 20539	: V=1.0178081, theta=-50.056773 -> V=1.0, theta=0.0
% INFO    : Bus 20540	: V=1.0026319, theta=-55.945649 -> V=1.0, theta=0.0
% INFO    : Bus 20541	: V=1.02, theta=-39.085997 -> V=1.0, theta=0.0
% INFO    : Bus 20542	: V=1.02, theta=-36.577931 -> V=1.0, theta=0.0
% INFO    : Bus 20543	: V=1.02, theta=-39.129102 -> V=1.0, theta=0.0
% INFO    : Bus 20544	: V=1.0033403, theta=-54.198422 -> V=1.0, theta=0.0
% INFO    : Bus 20545	: V=1.02, theta=-38.470985 -> V=1.0, theta=0.0
% INFO    : Bus 20546	: V=1.02, theta=-43.123979 -> V=1.0, theta=0.0
% INFO    : Bus 20547	: V=1.02, theta=-38.86885 -> V=1.0, theta=0.0
% INFO    : Bus 20548	: V=1.0137783, theta=-50.872507 -> V=1.0, theta=0.0
% INFO    : Bus 20549	: V=1.02, theta=-36.23426 -> V=1.0, theta=0.0
% INFO    : Bus 20550	: V=1.02, theta=-46.601324 -> V=1.0, theta=0.0
% INFO    : Bus 20551	: V=0.9967522, theta=-51.736775 -> V=1.0, theta=0.0
% INFO    : Bus 20552	: V=1.0028583, theta=-53.246319 -> V=1.0, theta=0.0
% INFO    : Bus 20553	: V=0.9954198, theta=-49.743447 -> V=1.0, theta=0.0
% INFO    : Bus 20554	: V=1.02, theta=-51.320003 -> V=1.0, theta=0.0
% INFO    : Bus 20555	: V=1.0185091, theta=-43.031995 -> V=1.0, theta=0.0
% INFO    : Bus 20556	: V=0.9829904, theta=-50.836544 -> V=1.0, theta=0.0
% INFO    : Bus 20557	: V=1.02, theta=-39.597065 -> V=1.0, theta=0.0
% INFO    : Bus 20558	: V=1.0026698, theta=-48.494832 -> V=1.0, theta=0.0
% INFO    : Bus 20559	: V=0.9918672, theta=-49.343476 -> V=1.0, theta=0.0
% INFO    : Bus 20560	: V=0.9920903, theta=-49.979898 -> V=1.0, theta=0.0
% INFO    : Bus 20561	: V=1.007823, theta=-48.134259 -> V=1.0, theta=0.0
% INFO    : Bus 20562	: V=1.02, theta=-54.154773 -> V=1.0, theta=0.0
% INFO    : Bus 20563	: V=1.02, theta=-53.821164 -> V=1.0, theta=0.0
% INFO    : Bus 20564	: V=0.9922118, theta=-49.971596 -> V=1.0, theta=0.0
% INFO    : Bus 20565	: V=0.9993866, theta=-49.260154 -> V=1.0, theta=0.0
% INFO    : Bus 20566	: V=0.9939387, theta=-56.439934 -> V=1.0, theta=0.0
% INFO    : Bus 20567	: V=1.0166254, theta=-38.317826 -> V=1.0, theta=0.0
% INFO    : Bus 20568	: V=1.0189666, theta=-43.395239 -> V=1.0, theta=0.0
% INFO    : Bus 20569	: V=0.9915038, theta=-53.723101 -> V=1.0, theta=0.0
% INFO    : Bus 20570	: V=1.010858, theta=-51.563336 -> V=1.0, theta=0.0
% INFO    : Bus 20571	: V=0.9806651, theta=-48.519343 -> V=1.0, theta=0.0
% INFO    : Bus 20572	: V=0.9926413, theta=-58.90927 -> V=1.0, theta=0.0
% INFO    : Bus 20573	: V=0.9890673, theta=-56.177321 -> V=1.0, theta=0.0
% INFO    : Bus 20574	: V=0.9835535, theta=-54.575913 -> V=1.0, theta=0.0
% INFO    : Bus 20575	: V=0.9870578, theta=-58.636398 -> V=1.0, theta=0.0
% INFO    : Bus 20576	: V=0.9946582, theta=-54.73252 -> V=1.0, theta=0.0
% INFO    : Bus 20577	: V=0.9931128, theta=-56.350769 -> V=1.0, theta=0.0
% INFO    : Bus 20578	: V=0.9847243, theta=-48.911224 -> V=1.0, theta=0.0
% INFO    : Bus 20579	: V=0.9914029, theta=-54.590093 -> V=1.0, theta=0.0
% INFO    : Bus 20580	: V=1.02, theta=-41.497794 -> V=1.0, theta=0.0
% INFO    : Bus 20581	: V=0.9904726, theta=-48.802136 -> V=1.0, theta=0.0
% INFO    : Bus 20582	: V=1.0087483, theta=-55.619285 -> V=1.0, theta=0.0
% INFO    : Bus 20583	: V=0.9881636, theta=-51.137318 -> V=1.0, theta=0.0
% INFO    : Bus 20584	: V=1.0, theta=-48.119662 -> V=1.0, theta=0.0
% INFO    : Bus 20585	: V=0.999192, theta=-45.516168 -> V=1.0, theta=0.0
% INFO    : Bus 20586	: V=0.967207, theta=-54.203471 -> V=1.0, theta=0.0
% INFO    : Bus 20587	: V=1.0128564, theta=-50.833479 -> V=1.0, theta=0.0
% INFO    : Bus 20588	: V=1.02, theta=-37.815951 -> V=1.0, theta=0.0
% INFO    : Bus 20589	: V=1.015984, theta=-38.630102 -> V=1.0, theta=0.0
% INFO    : Bus 20590	: V=0.990943, theta=-56.492202 -> V=1.0, theta=0.0
% INFO    : Bus 20591	: V=0.9828912, theta=-54.876607 -> V=1.0, theta=0.0
% INFO    : Bus 20592	: V=0.9612421, theta=-56.421608 -> V=1.0, theta=0.0
% INFO    : Bus 20593	: V=0.9692678, theta=-58.496749 -> V=1.0, theta=0.0
% INFO    : Bus 20594	: V=0.9686041, theta=-58.494508 -> V=1.0, theta=0.0
% INFO    : Bus 20595	: V=0.9677294, theta=-58.624373 -> V=1.0, theta=0.0
% INFO    : Bus 20596	: V=0.9678926, theta=-58.631809 -> V=1.0, theta=0.0
% INFO    : Bus 20597	: V=0.9686587, theta=-58.574749 -> V=1.0, theta=0.0
% INFO    : Bus 20598	: V=0.9691526, theta=-58.485124 -> V=1.0, theta=0.0
% INFO    : Bus 20599	: V=0.9709855, theta=-58.28837 -> V=1.0, theta=0.0
% INFO    : Bus 20600	: V=0.9534817, theta=-60.609181 -> V=1.0, theta=0.0
% INFO    : Bus 20601	: V=0.9542642, theta=-60.527852 -> V=1.0, theta=0.0
% INFO    : Bus 20602	: V=0.9491096, theta=-61.834757 -> V=1.0, theta=0.0
% INFO    : Bus 20603	: V=0.9434075, theta=-62.246483 -> V=1.0, theta=0.0
% INFO    : Bus 20604	: V=0.9455975, theta=-61.840009 -> V=1.0, theta=0.0
% INFO    : Bus 20605	: V=0.9417206, theta=-62.292134 -> V=1.0, theta=0.0
% INFO    : Bus 20606	: V=0.9436753, theta=-62.169815 -> V=1.0, theta=0.0
% INFO    : Bus 20607	: V=0.9411375, theta=-62.316942 -> V=1.0, theta=0.0
% INFO    : Bus 20608	: V=0.9417168, theta=-62.274574 -> V=1.0, theta=0.0
% INFO    : Bus 20609	: V=0.9426486, theta=-62.203654 -> V=1.0, theta=0.0
% INFO    : Bus 20610	: V=0.9445073, theta=-62.010688 -> V=1.0, theta=0.0
% INFO    : Bus 20611	: V=0.9450966, theta=-61.914866 -> V=1.0, theta=0.0
% INFO    : Bus 20612	: V=0.9466204, theta=-61.809884 -> V=1.0, theta=0.0
% INFO    : Bus 20613	: V=0.9696246, theta=-57.724857 -> V=1.0, theta=0.0
% INFO    : Bus 20614	: V=0.9692893, theta=-57.773441 -> V=1.0, theta=0.0
% INFO    : Bus 20615	: V=0.9540792, theta=-60.434648 -> V=1.0, theta=0.0
% INFO    : Bus 20616	: V=0.953391, theta=-60.484183 -> V=1.0, theta=0.0
% INFO    : Bus 20617	: V=0.9521525, theta=-60.640558 -> V=1.0, theta=0.0
% INFO    : Bus 20618	: V=0.9592317, theta=-59.943465 -> V=1.0, theta=0.0
% INFO    : Bus 20619	: V=0.9434597, theta=-61.943911 -> V=1.0, theta=0.0
% INFO    : Bus 20620	: V=0.9442886, theta=-61.803629 -> V=1.0, theta=0.0
% INFO    : Bus 20621	: V=0.952042, theta=-61.213885 -> V=1.0, theta=0.0
% INFO    : Bus 20622	: V=0.9591966, theta=-60.413318 -> V=1.0, theta=0.0
% INFO    : Bus 20623	: V=0.9601939, theta=-59.860905 -> V=1.0, theta=0.0
% INFO    : Bus 20624	: V=0.949942, theta=-61.497712 -> V=1.0, theta=0.0
% INFO    : Bus 20625	: V=0.9484828, theta=-61.629036 -> V=1.0, theta=0.0
% INFO    : Bus 20626	: V=0.9424554, theta=-62.490404 -> V=1.0, theta=0.0
% INFO    : Bus 20627	: V=0.9526342, theta=-60.67517 -> V=1.0, theta=0.0
% INFO    : Bus 20628	: V=0.9465861, theta=-62.078457 -> V=1.0, theta=0.0
% INFO    : Bus 20629	: V=0.9552607, theta=-60.444889 -> V=1.0, theta=0.0
% INFO    : Bus 20630	: V=0.9474122, theta=-61.717473 -> V=1.0, theta=0.0
% INFO    : Bus 20631	: V=0.9432524, theta=-62.317105 -> V=1.0, theta=0.0
% INFO    : Bus 20632	: V=0.9428053, theta=-62.66304 -> V=1.0, theta=0.0
% INFO    : Bus 20633	: V=0.946392, theta=-61.710457 -> V=1.0, theta=0.0
% INFO    : Bus 20634	: V=0.9463787, theta=-61.747941 -> V=1.0, theta=0.0
% INFO    : Bus 20635	: V=0.9596915, theta=-59.906645 -> V=1.0, theta=0.0
% INFO    : Bus 20636	: V=0.9438633, theta=-62.273072 -> V=1.0, theta=0.0
% INFO    : Bus 20637	: V=0.9436098, theta=-62.378426 -> V=1.0, theta=0.0
% INFO    : Bus 20638	: V=0.9706378, theta=-57.644707 -> V=1.0, theta=0.0
% INFO    : Bus 20639	: V=0.9550145, theta=-60.372378 -> V=1.0, theta=0.0
% INFO    : Bus 20640	: V=0.9483681, theta=-61.239683 -> V=1.0, theta=0.0
% INFO    : Bus 20641	: V=0.9424, theta=-62.434773 -> V=1.0, theta=0.0
% INFO    : Bus 20642	: V=0.9525031, theta=-60.692215 -> V=1.0, theta=0.0
% INFO    : Bus 20643	: V=0.9440967, theta=-62.038961 -> V=1.0, theta=0.0
% INFO    : Bus 20644	: V=0.942504, theta=-62.170483 -> V=1.0, theta=0.0
% INFO    : Bus 20645	: V=0.9409796, theta=-62.676488 -> V=1.0, theta=0.0
% INFO    : Bus 20646	: V=0.9363138, theta=-63.208726 -> V=1.0, theta=0.0
% INFO    : Bus 20647	: V=0.9380209, theta=-63.103714 -> V=1.0, theta=0.0
% INFO    : Bus 20648	: V=0.9373875, theta=-62.695483 -> V=1.0, theta=0.0
% INFO    : Bus 20649	: V=0.9364205, theta=-62.90893 -> V=1.0, theta=0.0
% INFO    : Bus 20650	: V=0.9454947, theta=-61.599543 -> V=1.0, theta=0.0
% INFO    : Bus 20651	: V=0.9519744, theta=-60.716487 -> V=1.0, theta=0.0
% INFO    : Bus 20652	: V=0.951728, theta=-60.767996 -> V=1.0, theta=0.0
% INFO    : Bus 20653	: V=0.9646201, theta=-58.414074 -> V=1.0, theta=0.0
% INFO    : Bus 20654	: V=0.9411663, theta=-62.617239 -> V=1.0, theta=0.0
% INFO    : Bus 20655	: V=0.9463483, theta=-61.7263 -> V=1.0, theta=0.0
% INFO    : Bus 20656	: V=0.9451736, theta=-61.895481 -> V=1.0, theta=0.0
% INFO    : Bus 20657	: V=0.9441497, theta=-62.325103 -> V=1.0, theta=0.0
% INFO    : Bus 20658	: V=0.9431955, theta=-62.389879 -> V=1.0, theta=0.0
% INFO    : Bus 20659	: V=0.9427109, theta=-62.419059 -> V=1.0, theta=0.0
% INFO    : Bus 20660	: V=0.9448396, theta=-62.026648 -> V=1.0, theta=0.0
% INFO    : Bus 20661	: V=0.9452553, theta=-62.001656 -> V=1.0, theta=0.0
% INFO    : Bus 20662	: V=0.9600199, theta=-59.879928 -> V=1.0, theta=0.0
% INFO    : Bus 20663	: V=0.9492621, theta=-61.437759 -> V=1.0, theta=0.0
% INFO    : Bus 20664	: V=0.9429514, theta=-62.40302 -> V=1.0, theta=0.0
% INFO    : Bus 20665	: V=0.9421977, theta=-62.421009 -> V=1.0, theta=0.0
% INFO    : Bus 20666	: V=0.9423292, theta=-62.440201 -> V=1.0, theta=0.0
% INFO    : Bus 20667	: V=0.948394, theta=-61.705041 -> V=1.0, theta=0.0
% INFO    : Bus 20668	: V=0.9449834, theta=-62.247632 -> V=1.0, theta=0.0
% INFO    : Bus 20669	: V=0.947466, theta=-61.861688 -> V=1.0, theta=0.0
% INFO    : Bus 20670	: V=0.9664073, theta=-58.314091 -> V=1.0, theta=0.0
% INFO    : Bus 20671	: V=0.9889863, theta=-55.721015 -> V=1.0, theta=0.0
% INFO    : Bus 20672	: V=0.960215, theta=-59.839574 -> V=1.0, theta=0.0
% INFO    : Bus 20673	: V=0.9741913, theta=-57.264301 -> V=1.0, theta=0.0
% INFO    : Bus 20674	: V=0.9591765, theta=-60.476211 -> V=1.0, theta=0.0
% INFO    : Bus 20675	: V=0.9556529, theta=-60.800889 -> V=1.0, theta=0.0
% INFO    : Bus 20676	: V=0.9520128, theta=-61.055656 -> V=1.0, theta=0.0
% INFO    : Bus 20677	: V=0.9548964, theta=-60.838321 -> V=1.0, theta=0.0
% INFO    : Bus 20678	: V=0.9617361, theta=-59.667426 -> V=1.0, theta=0.0
% INFO    : Bus 20679	: V=0.9629122, theta=-59.477369 -> V=1.0, theta=0.0
% INFO    : Bus 20680	: V=0.9507584, theta=-60.796189 -> V=1.0, theta=0.0
% INFO    : Bus 20681	: V=0.9520846, theta=-60.625981 -> V=1.0, theta=0.0
% INFO    : Bus 20682	: V=0.9390023, theta=-63.214982 -> V=1.0, theta=0.0
% INFO    : Bus 20683	: V=0.9386857, theta=-63.240895 -> V=1.0, theta=0.0
% INFO    : Bus 20684	: V=0.9388035, theta=-63.198013 -> V=1.0, theta=0.0
% INFO    : Bus 20685	: V=0.9388454, theta=-63.152301 -> V=1.0, theta=0.0
% INFO    : Bus 20686	: V=0.9462998, theta=-61.380975 -> V=1.0, theta=0.0
% INFO    : Bus 20687	: V=0.9387594, theta=-63.232879 -> V=1.0, theta=0.0
% INFO    : Bus 20688	: V=0.9396907, theta=-63.126018 -> V=1.0, theta=0.0
% INFO    : Bus 20689	: V=0.9412093, theta=-62.733481 -> V=1.0, theta=0.0
% INFO    : Bus 20690	: V=0.9722095, theta=-57.836069 -> V=1.0, theta=0.0
% INFO    : Bus 20691	: V=0.9662348, theta=-59.060288 -> V=1.0, theta=0.0
% INFO    : Bus 20692	: V=0.9731101, theta=-58.272003 -> V=1.0, theta=0.0
% INFO    : Bus 20693	: V=0.9958851, theta=-55.003926 -> V=1.0, theta=0.0
% INFO    : Bus 20694	: V=0.947476, theta=-61.971089 -> V=1.0, theta=0.0
% INFO    : Bus 20695	: V=0.9651088, theta=-58.343994 -> V=1.0, theta=0.0
% INFO    : Bus 20696	: V=0.9863578, theta=-48.409946 -> V=1.0, theta=0.0
% INFO    : Bus 20697	: V=0.9854942, theta=-48.649353 -> V=1.0, theta=0.0
% INFO    : Bus 20698	: V=0.9854015, theta=-48.665458 -> V=1.0, theta=0.0
% INFO    : Bus 20699	: V=0.9809964, theta=-49.509078 -> V=1.0, theta=0.0
% INFO    : Bus 20700	: V=0.9759325, theta=-49.99457 -> V=1.0, theta=0.0
% INFO    : Bus 20701	: V=0.9669111, theta=-50.841301 -> V=1.0, theta=0.0
% INFO    : Bus 20702	: V=0.9857464, theta=-48.606944 -> V=1.0, theta=0.0
% INFO    : Bus 20703	: V=0.9690528, theta=-50.867371 -> V=1.0, theta=0.0
% INFO    : Bus 20704	: V=0.972897, theta=-50.666555 -> V=1.0, theta=0.0
% INFO    : Bus 20705	: V=0.9901643, theta=-47.334546 -> V=1.0, theta=0.0
% INFO    : Bus 20706	: V=0.9697248, theta=-50.868368 -> V=1.0, theta=0.0
% INFO    : Bus 20707	: V=0.9771382, theta=-50.027646 -> V=1.0, theta=0.0
% INFO    : Bus 20708	: V=0.9557574, theta=-51.672113 -> V=1.0, theta=0.0
% INFO    : Bus 20709	: V=0.9718278, theta=-50.16784 -> V=1.0, theta=0.0
% INFO    : Bus 20710	: V=0.9913551, theta=-47.119385 -> V=1.0, theta=0.0
% INFO    : Bus 20711	: V=1.0127826, theta=-49.42201 -> V=1.0, theta=0.0
% INFO    : Bus 20712	: V=1.018342, theta=-48.445183 -> V=1.0, theta=0.0
% INFO    : Bus 20713	: V=1.0172002, theta=-49.033485 -> V=1.0, theta=0.0
% INFO    : Bus 20714	: V=0.9717514, theta=-57.877723 -> V=1.0, theta=0.0
% INFO    : Bus 20715	: V=0.9690929, theta=-57.786331 -> V=1.0, theta=0.0
% INFO    : Bus 20716	: V=0.9683683, theta=-57.712399 -> V=1.0, theta=0.0
% INFO    : Bus 20717	: V=0.9498123, theta=-58.892194 -> V=1.0, theta=0.0
% INFO    : Bus 20718	: V=0.9780161, theta=-51.60132 -> V=1.0, theta=0.0
% INFO    : Bus 20719	: V=0.9727128, theta=-51.416513 -> V=1.0, theta=0.0
% INFO    : Bus 20720	: V=0.9991191, theta=-48.352006 -> V=1.0, theta=0.0
% INFO    : Bus 20721	: V=0.9605054, theta=-53.60511 -> V=1.0, theta=0.0
% INFO    : Bus 20722	: V=0.9607151, theta=-53.635059 -> V=1.0, theta=0.0
% INFO    : Bus 20723	: V=0.9863994, theta=-50.605967 -> V=1.0, theta=0.0
% INFO    : Bus 20724	: V=0.9992809, theta=-48.487436 -> V=1.0, theta=0.0
% INFO    : Bus 20725	: V=0.9854473, theta=-50.601301 -> V=1.0, theta=0.0
% INFO    : Bus 20726	: V=0.9983933, theta=-48.830435 -> V=1.0, theta=0.0
% INFO    : Bus 20727	: V=0.9597012, theta=-51.756962 -> V=1.0, theta=0.0
% INFO    : Bus 20728	: V=0.9820846, theta=-49.929839 -> V=1.0, theta=0.0
% INFO    : Bus 20729	: V=0.9788134, theta=-49.737998 -> V=1.0, theta=0.0
% INFO    : Bus 20730	: V=0.980185, theta=-49.787614 -> V=1.0, theta=0.0
% INFO    : Bus 20731	: V=0.9788248, theta=-49.42317 -> V=1.0, theta=0.0
% INFO    : Bus 20732	: V=0.9935993, theta=-51.478179 -> V=1.0, theta=0.0
% INFO    : Bus 20733	: V=0.9832919, theta=-52.097971 -> V=1.0, theta=0.0
% INFO    : Bus 20734	: V=0.9884046, theta=-52.009781 -> V=1.0, theta=0.0
% INFO    : Bus 20735	: V=0.9954758, theta=-50.499962 -> V=1.0, theta=0.0
% INFO    : Bus 20736	: V=0.9866153, theta=-51.930103 -> V=1.0, theta=0.0
% INFO    : Bus 20737	: V=0.9942811, theta=-51.082102 -> V=1.0, theta=0.0
% INFO    : Bus 20738	: V=0.9789053, theta=-53.166924 -> V=1.0, theta=0.0
% INFO    : Bus 20739	: V=0.9750711, theta=-55.894365 -> V=1.0, theta=0.0
% INFO    : Bus 20740	: V=0.9832815, theta=-54.602245 -> V=1.0, theta=0.0
% INFO    : Bus 20741	: V=0.9918737, theta=-53.328395 -> V=1.0, theta=0.0
% INFO    : Bus 20742	: V=0.9799614, theta=-55.028742 -> V=1.0, theta=0.0
% INFO    : Bus 20743	: V=0.9809797, theta=-54.950108 -> V=1.0, theta=0.0
% INFO    : Bus 20744	: V=0.9901424, theta=-52.715049 -> V=1.0, theta=0.0
% INFO    : Bus 20745	: V=0.9834569, theta=-54.882179 -> V=1.0, theta=0.0
% INFO    : Bus 20746	: V=0.9784104, theta=-55.074011 -> V=1.0, theta=0.0
% INFO    : Bus 20747	: V=0.9919197, theta=-52.202568 -> V=1.0, theta=0.0
% INFO    : Bus 20748	: V=1.0116572, theta=-47.461263 -> V=1.0, theta=0.0
% INFO    : Bus 20749	: V=0.9906512, theta=-52.962673 -> V=1.0, theta=0.0
% INFO    : Bus 20750	: V=0.9910578, theta=-47.005266 -> V=1.0, theta=0.0
% INFO    : Bus 20751	: V=1.0185419, theta=-43.479129 -> V=1.0, theta=0.0
% INFO    : Bus 20752	: V=1.0184129, theta=-43.502016 -> V=1.0, theta=0.0
% INFO    : Bus 20753	: V=0.9993776, theta=-46.357452 -> V=1.0, theta=0.0
% INFO    : Bus 20754	: V=0.99617, theta=-46.550705 -> V=1.0, theta=0.0
% INFO    : Bus 20755	: V=0.9934785, theta=-46.770016 -> V=1.0, theta=0.0
% INFO    : Bus 20756	: V=0.9906282, theta=-46.862933 -> V=1.0, theta=0.0
% INFO    : Bus 20757	: V=0.9936553, theta=-46.707151 -> V=1.0, theta=0.0
% INFO    : Bus 20758	: V=0.9941344, theta=-46.66862 -> V=1.0, theta=0.0
% INFO    : Bus 20759	: V=1.0024796, theta=-45.70935 -> V=1.0, theta=0.0
% INFO    : Bus 20760	: V=1.0014758, theta=-45.836969 -> V=1.0, theta=0.0
% INFO    : Bus 20761	: V=1.0006603, theta=-45.925217 -> V=1.0, theta=0.0
% INFO    : Bus 20762	: V=1.0181133, theta=-43.546261 -> V=1.0, theta=0.0
% INFO    : Bus 20763	: V=0.9998525, theta=-46.125757 -> V=1.0, theta=0.0
% INFO    : Bus 20764	: V=0.9998101, theta=-46.04975 -> V=1.0, theta=0.0
% INFO    : Bus 20765	: V=0.9955747, theta=-46.481693 -> V=1.0, theta=0.0
% INFO    : Bus 20766	: V=1.017764, theta=-43.610484 -> V=1.0, theta=0.0
% INFO    : Bus 20767	: V=1.0047599, theta=-45.385744 -> V=1.0, theta=0.0
% INFO    : Bus 20768	: V=0.9961058, theta=-46.369071 -> V=1.0, theta=0.0
% INFO    : Bus 20769	: V=0.9981754, theta=-45.584744 -> V=1.0, theta=0.0
% INFO    : Bus 20770	: V=0.9963301, theta=-45.678178 -> V=1.0, theta=0.0
% INFO    : Bus 20771	: V=0.9958552, theta=-45.593642 -> V=1.0, theta=0.0
% INFO    : Bus 20772	: V=1.0060472, theta=-44.818338 -> V=1.0, theta=0.0
% INFO    : Bus 20773	: V=1.017554, theta=-43.666173 -> V=1.0, theta=0.0
% INFO    : Bus 20774	: V=0.9989558, theta=-45.85198 -> V=1.0, theta=0.0
% INFO    : Bus 20775	: V=1.004621, theta=-44.488562 -> V=1.0, theta=0.0
% INFO    : Bus 20776	: V=0.9897141, theta=-46.186754 -> V=1.0, theta=0.0
% INFO    : Bus 20777	: V=0.9858832, theta=-46.557467 -> V=1.0, theta=0.0
% INFO    : Bus 20778	: V=0.983796, theta=-46.908162 -> V=1.0, theta=0.0
% INFO    : Bus 20779	: V=0.9916607, theta=-46.007161 -> V=1.0, theta=0.0
% INFO    : Bus 20780	: V=0.993563, theta=-45.659714 -> V=1.0, theta=0.0
% INFO    : Bus 20781	: V=1.0025812, theta=-44.457032 -> V=1.0, theta=0.0
% INFO    : Bus 20782	: V=0.9711974, theta=-54.057146 -> V=1.0, theta=0.0
% INFO    : Bus 20783	: V=0.9701952, theta=-52.671336 -> V=1.0, theta=0.0
% INFO    : Bus 20784	: V=0.9622679, theta=-53.142741 -> V=1.0, theta=0.0
% INFO    : Bus 20785	: V=0.964283, theta=-52.994783 -> V=1.0, theta=0.0
% INFO    : Bus 20786	: V=0.9659321, theta=-52.834573 -> V=1.0, theta=0.0
% INFO    : Bus 20787	: V=0.967651, theta=-52.724352 -> V=1.0, theta=0.0
% INFO    : Bus 20788	: V=0.96745, theta=-52.704681 -> V=1.0, theta=0.0
% INFO    : Bus 20789	: V=0.960063, theta=-53.576853 -> V=1.0, theta=0.0
% INFO    : Bus 20790	: V=1.0024386, theta=-44.721714 -> V=1.0, theta=0.0
% INFO    : Bus 20791	: V=0.9924827, theta=-44.768918 -> V=1.0, theta=0.0
% INFO    : Bus 20792	: V=1.0155596, theta=-42.707267 -> V=1.0, theta=0.0
% INFO    : Bus 20793	: V=1.0055158, theta=-43.020799 -> V=1.0, theta=0.0
% INFO    : Bus 20794	: V=1.0042999, theta=-42.589805 -> V=1.0, theta=0.0
% INFO    : Bus 20795	: V=1.0017969, theta=-43.0374 -> V=1.0, theta=0.0
% INFO    : Bus 20796	: V=1.017941, theta=-40.110492 -> V=1.0, theta=0.0
% INFO    : Bus 20797	: V=1.0131899, theta=-41.090704 -> V=1.0, theta=0.0
% INFO    : Bus 20798	: V=1.0125808, theta=-41.163242 -> V=1.0, theta=0.0
% INFO    : Bus 20799	: V=1.012353, theta=-41.203609 -> V=1.0, theta=0.0
% INFO    : Bus 20800	: V=0.972368, theta=-48.085683 -> V=1.0, theta=0.0
% INFO    : Bus 20801	: V=1.0031601, theta=-45.293214 -> V=1.0, theta=0.0
% INFO    : Bus 20802	: V=0.9987864, theta=-45.371746 -> V=1.0, theta=0.0
% INFO    : Bus 20803	: V=0.9761998, theta=-47.957324 -> V=1.0, theta=0.0
% INFO    : Bus 20804	: V=0.9816465, theta=-47.738495 -> V=1.0, theta=0.0
% INFO    : Bus 20805	: V=1.019051, theta=-43.122384 -> V=1.0, theta=0.0
% INFO    : Bus 20806	: V=1.0110486, theta=-44.213773 -> V=1.0, theta=0.0
% INFO    : Bus 20807	: V=1.0102403, theta=-44.110612 -> V=1.0, theta=0.0
% INFO    : Bus 20808	: V=1.0041677, theta=-44.582843 -> V=1.0, theta=0.0
% INFO    : Bus 20809	: V=0.9864587, theta=-46.714177 -> V=1.0, theta=0.0
% INFO    : Bus 20810	: V=0.9542763, theta=-52.283854 -> V=1.0, theta=0.0
% INFO    : Bus 20811	: V=0.9563989, theta=-51.140368 -> V=1.0, theta=0.0
% INFO    : Bus 20812	: V=0.9535681, theta=-51.832089 -> V=1.0, theta=0.0
% INFO    : Bus 20813	: V=0.9492273, theta=-52.191658 -> V=1.0, theta=0.0
% INFO    : Bus 20814	: V=0.9492521, theta=-51.371499 -> V=1.0, theta=0.0
% INFO    : Bus 20815	: V=0.9630115, theta=-49.600364 -> V=1.0, theta=0.0
% INFO    : Bus 20816	: V=0.9425317, theta=-61.613502 -> V=1.0, theta=0.0
% INFO    : Bus 20817	: V=0.9434256, theta=-61.760255 -> V=1.0, theta=0.0
% INFO    : Bus 20818	: V=0.9543108, theta=-60.409653 -> V=1.0, theta=0.0
% INFO    : Bus 20819	: V=0.9452854, theta=-61.626945 -> V=1.0, theta=0.0
% INFO    : Bus 20820	: V=0.9566735, theta=-59.509177 -> V=1.0, theta=0.0
% INFO    : Bus 20821	: V=0.937905, theta=-62.210249 -> V=1.0, theta=0.0
% INFO    : Bus 20822	: V=0.9396076, theta=-62.282969 -> V=1.0, theta=0.0
% INFO    : Bus 20823	: V=0.9402725, theta=-62.29391 -> V=1.0, theta=0.0
% INFO    : Bus 20824	: V=0.9530595, theta=-60.395539 -> V=1.0, theta=0.0
% INFO    : Bus 20825	: V=0.9745632, theta=-55.702004 -> V=1.0, theta=0.0
% INFO    : Bus 20826	: V=0.9706958, theta=-56.236954 -> V=1.0, theta=0.0
% INFO    : Bus 20827	: V=0.975868, theta=-55.162249 -> V=1.0, theta=0.0
% INFO    : Bus 20828	: V=0.9707507, theta=-56.212719 -> V=1.0, theta=0.0
% INFO    : Bus 20829	: V=0.967309, theta=-56.812613 -> V=1.0, theta=0.0
% INFO    : Bus 20830	: V=0.9706028, theta=-56.180509 -> V=1.0, theta=0.0
% INFO    : Bus 20831	: V=0.9747269, theta=-55.563102 -> V=1.0, theta=0.0
% INFO    : Bus 20832	: V=0.9670797, theta=-56.810827 -> V=1.0, theta=0.0
% INFO    : Bus 20833	: V=0.9702782, theta=-56.213303 -> V=1.0, theta=0.0
% INFO    : Bus 20834	: V=0.9687663, theta=-56.673043 -> V=1.0, theta=0.0
% INFO    : Bus 20835	: V=0.9715681, theta=-56.217836 -> V=1.0, theta=0.0
% INFO    : Bus 20836	: V=0.9716161, theta=-56.218439 -> V=1.0, theta=0.0
% INFO    : Bus 20837	: V=0.9745715, theta=-55.755506 -> V=1.0, theta=0.0
% INFO    : Bus 20838	: V=0.9637224, theta=-57.196582 -> V=1.0, theta=0.0
% INFO    : Bus 20839	: V=0.964911, theta=-57.167998 -> V=1.0, theta=0.0
% INFO    : Bus 20840	: V=0.9705864, theta=-56.242817 -> V=1.0, theta=0.0
% INFO    : Bus 20841	: V=0.9755615, theta=-55.202678 -> V=1.0, theta=0.0
% INFO    : Bus 20842	: V=0.9748839, theta=-55.84196 -> V=1.0, theta=0.0
% INFO    : Bus 20843	: V=0.9627418, theta=-57.248778 -> V=1.0, theta=0.0
% INFO    : Bus 20844	: V=0.9659865, theta=-56.804713 -> V=1.0, theta=0.0
% INFO    : Bus 20845	: V=0.9618087, theta=-57.361803 -> V=1.0, theta=0.0
% INFO    : Bus 20846	: V=0.9788875, theta=-54.660576 -> V=1.0, theta=0.0
% INFO    : Bus 20847	: V=0.9776774, theta=-54.899195 -> V=1.0, theta=0.0
% INFO    : Bus 20848	: V=0.9680752, theta=-56.486902 -> V=1.0, theta=0.0
% INFO    : Bus 20849	: V=0.9699095, theta=-56.323141 -> V=1.0, theta=0.0
% INFO    : Bus 20850	: V=0.9702464, theta=-56.467367 -> V=1.0, theta=0.0
% INFO    : Bus 20851	: V=0.9684175, theta=-57.120442 -> V=1.0, theta=0.0
% INFO    : Bus 20852	: V=0.9762665, theta=-56.080125 -> V=1.0, theta=0.0
% INFO    : Bus 20853	: V=0.967398, theta=-56.828441 -> V=1.0, theta=0.0
% INFO    : Bus 20854	: V=0.9711022, theta=-56.293344 -> V=1.0, theta=0.0
% INFO    : Bus 20855	: V=1.003884, theta=-42.914241 -> V=1.0, theta=0.0
% INFO    : Bus 20856	: V=1.0036127, theta=-43.329817 -> V=1.0, theta=0.0
% INFO    : Bus 20857	: V=1.0136746, theta=-41.942081 -> V=1.0, theta=0.0
% INFO    : Bus 20858	: V=1.0030359, theta=-43.444513 -> V=1.0, theta=0.0
% INFO    : Bus 20859	: V=0.9975603, theta=-44.219837 -> V=1.0, theta=0.0
% INFO    : Bus 20860	: V=1.0122354, theta=-42.139104 -> V=1.0, theta=0.0
% INFO    : Bus 20861	: V=1.0119911, theta=-42.168956 -> V=1.0, theta=0.0
% INFO    : Bus 20862	: V=0.9492234, theta=-57.889322 -> V=1.0, theta=0.0
% INFO    : Bus 20863	: V=0.9373426, theta=-60.259054 -> V=1.0, theta=0.0
% INFO    : Bus 20864	: V=0.9649134, theta=-55.778763 -> V=1.0, theta=0.0
% INFO    : Bus 20865	: V=0.9655909, theta=-55.582447 -> V=1.0, theta=0.0
% INFO    : Bus 20866	: V=0.9487015, theta=-58.023112 -> V=1.0, theta=0.0
% INFO    : Bus 20867	: V=0.9520324, theta=-57.483083 -> V=1.0, theta=0.0
% INFO    : Bus 20868	: V=0.9504313, theta=-57.719727 -> V=1.0, theta=0.0
% INFO    : Bus 20869	: V=0.9426155, theta=-59.422755 -> V=1.0, theta=0.0
% INFO    : Bus 20870	: V=0.9507729, theta=-57.310719 -> V=1.0, theta=0.0
% INFO    : Bus 20871	: V=0.9462545, theta=-58.286437 -> V=1.0, theta=0.0
% INFO    : Bus 20872	: V=0.9471487, theta=-58.181386 -> V=1.0, theta=0.0
% INFO    : Bus 20873	: V=0.9638407, theta=-56.122673 -> V=1.0, theta=0.0
% INFO    : Bus 20874	: V=0.9494902, theta=-58.115916 -> V=1.0, theta=0.0
% INFO    : Bus 20875	: V=0.9693147, theta=-55.300023 -> V=1.0, theta=0.0
% INFO    : Bus 20876	: V=0.9568448, theta=-57.472174 -> V=1.0, theta=0.0
% INFO    : Bus 20877	: V=0.9600093, theta=-56.567274 -> V=1.0, theta=0.0
% INFO    : Bus 20878	: V=1.0004971, theta=-47.190019 -> V=1.0, theta=0.0
% INFO    : Bus 20879	: V=0.9619995, theta=-55.668943 -> V=1.0, theta=0.0
% INFO    : Bus 20880	: V=0.9591516, theta=-55.835917 -> V=1.0, theta=0.0
% INFO    : Bus 20881	: V=0.9575123, theta=-56.133708 -> V=1.0, theta=0.0
% INFO    : Bus 20882	: V=0.9726712, theta=-53.472214 -> V=1.0, theta=0.0
% INFO    : Bus 20883	: V=0.9586179, theta=-55.965825 -> V=1.0, theta=0.0
% INFO    : Bus 20884	: V=0.9577762, theta=-56.111897 -> V=1.0, theta=0.0
% INFO    : Bus 20885	: V=0.9575795, theta=-55.742324 -> V=1.0, theta=0.0
% INFO    : Bus 20886	: V=0.9485575, theta=-57.669657 -> V=1.0, theta=0.0
% INFO    : Bus 20887	: V=0.9571044, theta=-56.296836 -> V=1.0, theta=0.0
% INFO    : Bus 20888	: V=0.9724591, theta=-53.487021 -> V=1.0, theta=0.0
% INFO    : Bus 20889	: V=0.9554869, theta=-56.890305 -> V=1.0, theta=0.0
% INFO    : Bus 20890	: V=0.9467139, theta=-57.775662 -> V=1.0, theta=0.0
% INFO    : Bus 20891	: V=0.9582962, theta=-56.191646 -> V=1.0, theta=0.0
% INFO    : Bus 20892	: V=0.9607757, theta=-55.973968 -> V=1.0, theta=0.0
% INFO    : Bus 20893	: V=0.9749463, theta=-53.168134 -> V=1.0, theta=0.0
% INFO    : Bus 20894	: V=0.9596354, theta=-55.943057 -> V=1.0, theta=0.0
% INFO    : Bus 20895	: V=0.9496045, theta=-57.580725 -> V=1.0, theta=0.0
% INFO    : Bus 20896	: V=0.9493553, theta=-57.634264 -> V=1.0, theta=0.0
% INFO    : Bus 20897	: V=0.9580288, theta=-56.164662 -> V=1.0, theta=0.0
% INFO    : Bus 20898	: V=0.9632265, theta=-52.794786 -> V=1.0, theta=0.0
% INFO    : Bus 20899	: V=0.9756794, theta=-52.062802 -> V=1.0, theta=0.0
% INFO    : Bus 20900	: V=0.9732879, theta=-52.293982 -> V=1.0, theta=0.0
% INFO    : Bus 20901	: V=0.975308, theta=-52.033649 -> V=1.0, theta=0.0
% INFO    : Bus 20902	: V=0.9734078, theta=-52.022331 -> V=1.0, theta=0.0
% INFO    : Bus 20903	: V=0.9719281, theta=-52.197665 -> V=1.0, theta=0.0
% INFO    : Bus 20904	: V=0.9689534, theta=-52.38985 -> V=1.0, theta=0.0
% INFO    : Bus 20905	: V=0.995717, theta=-46.366997 -> V=1.0, theta=0.0
% INFO    : Bus 20906	: V=1.0030015, theta=-45.643517 -> V=1.0, theta=0.0
% INFO    : Bus 20907	: V=1.004493, theta=-45.45277 -> V=1.0, theta=0.0
% INFO    : Bus 20908	: V=1.00509, theta=-45.392364 -> V=1.0, theta=0.0
% INFO    : Bus 20909	: V=1.0056422, theta=-45.330526 -> V=1.0, theta=0.0
% INFO    : Bus 20910	: V=1.019227, theta=-43.344138 -> V=1.0, theta=0.0
% INFO    : Bus 20911	: V=0.998606, theta=-46.070425 -> V=1.0, theta=0.0
% INFO    : Bus 20912	: V=1.0061054, theta=-45.288943 -> V=1.0, theta=0.0
% INFO    : Bus 20913	: V=1.0179378, theta=-43.524028 -> V=1.0, theta=0.0
% INFO    : Bus 20914	: V=1.0044179, theta=-45.519347 -> V=1.0, theta=0.0
% INFO    : Bus 20915	: V=1.0042013, theta=-45.496319 -> V=1.0, theta=0.0
% INFO    : Bus 20916	: V=0.9988412, theta=-45.653039 -> V=1.0, theta=0.0
% INFO    : Bus 20917	: V=0.9979597, theta=-45.15789 -> V=1.0, theta=0.0
% INFO    : Bus 20918	: V=1.0043011, theta=-45.483753 -> V=1.0, theta=0.0
% INFO    : Bus 20919	: V=1.0027752, theta=-45.744893 -> V=1.0, theta=0.0
% INFO    : Bus 20920	: V=1.0011451, theta=-45.923079 -> V=1.0, theta=0.0
% INFO    : Bus 20921	: V=1.0104748, theta=-44.132956 -> V=1.0, theta=0.0
% INFO    : Bus 20922	: V=1.0033932, theta=-45.398967 -> V=1.0, theta=0.0
% INFO    : Bus 20923	: V=1.0070266, theta=-45.209087 -> V=1.0, theta=0.0
% INFO    : Bus 20924	: V=1.0190742, theta=-43.296954 -> V=1.0, theta=0.0
% INFO    : Bus 20925	: V=1.0050904, theta=-45.790206 -> V=1.0, theta=0.0
% INFO    : Bus 20926	: V=1.0047849, theta=-46.79552 -> V=1.0, theta=0.0
% INFO    : Bus 20927	: V=1.0080215, theta=-45.379068 -> V=1.0, theta=0.0
% INFO    : Bus 20928	: V=1.0088564, theta=-44.616126 -> V=1.0, theta=0.0
% INFO    : Bus 20929	: V=1.0141335, theta=-43.283246 -> V=1.0, theta=0.0
% INFO    : Bus 20930	: V=0.9450873, theta=-52.38326 -> V=1.0, theta=0.0
% INFO    : Bus 20931	: V=0.987136, theta=-47.10393 -> V=1.0, theta=0.0
% INFO    : Bus 20932	: V=0.9665882, theta=-49.863738 -> V=1.0, theta=0.0
% INFO    : Bus 20933	: V=0.9581991, theta=-50.553273 -> V=1.0, theta=0.0
% INFO    : Bus 20934	: V=0.9554011, theta=-51.986515 -> V=1.0, theta=0.0
% INFO    : Bus 20935	: V=0.9581846, theta=-57.534323 -> V=1.0, theta=0.0
% INFO    : Bus 20936	: V=0.9717585, theta=-56.068342 -> V=1.0, theta=0.0
% INFO    : Bus 20937	: V=0.9514193, theta=-58.276766 -> V=1.0, theta=0.0
% INFO    : Bus 20938	: V=0.9804953, theta=-54.899034 -> V=1.0, theta=0.0
% INFO    : Bus 20939	: V=0.9750906, theta=-55.655042 -> V=1.0, theta=0.0
% INFO    : Bus 20940	: V=0.984876, theta=-54.68571 -> V=1.0, theta=0.0
% INFO    : Bus 20941	: V=1.0010045, theta=-41.096671 -> V=1.0, theta=0.0
% INFO    : Bus 20942	: V=0.9788305, theta=-44.220477 -> V=1.0, theta=0.0
% INFO    : Bus 20943	: V=1.0011533, theta=-41.805713 -> V=1.0, theta=0.0
% INFO    : Bus 20944	: V=1.0016066, theta=-41.680555 -> V=1.0, theta=0.0
% INFO    : Bus 20945	: V=1.0020453, theta=-41.67763 -> V=1.0, theta=0.0
% INFO    : Bus 20946	: V=1.0040212, theta=-41.47888 -> V=1.0, theta=0.0
% INFO    : Bus 20947	: V=0.9907505, theta=-43.582757 -> V=1.0, theta=0.0
% INFO    : Bus 20948	: V=0.9609149, theta=-58.17055 -> V=1.0, theta=0.0
% INFO    : Bus 20949	: V=0.9692724, theta=-56.666248 -> V=1.0, theta=0.0
% INFO    : Bus 20950	: V=0.9608232, theta=-58.31314 -> V=1.0, theta=0.0
% INFO    : Bus 20951	: V=0.9548799, theta=-58.557134 -> V=1.0, theta=0.0
% INFO    : Bus 20952	: V=0.9682473, theta=-56.609584 -> V=1.0, theta=0.0
% INFO    : Bus 20953	: V=0.9579627, theta=-58.330358 -> V=1.0, theta=0.0
% INFO    : Bus 20954	: V=0.97967, theta=-54.758725 -> V=1.0, theta=0.0
% INFO    : Bus 20955	: V=0.9637808, theta=-57.628162 -> V=1.0, theta=0.0
% INFO    : Bus 20956	: V=0.9510865, theta=-59.575283 -> V=1.0, theta=0.0
% INFO    : Bus 20957	: V=0.9627608, theta=-56.929014 -> V=1.0, theta=0.0
% INFO    : Bus 20958	: V=0.970934, theta=-56.250798 -> V=1.0, theta=0.0
% INFO    : Bus 20959	: V=0.975606, theta=-55.676485 -> V=1.0, theta=0.0
% INFO    : Bus 20960	: V=0.9758558, theta=-55.648924 -> V=1.0, theta=0.0
% INFO    : Bus 20961	: V=0.9704217, theta=-56.524342 -> V=1.0, theta=0.0
% INFO    : Bus 20962	: V=0.9595459, theta=-58.232602 -> V=1.0, theta=0.0
% INFO    : Bus 20963	: V=0.9679653, theta=-56.901435 -> V=1.0, theta=0.0
% INFO    : Bus 20964	: V=0.9960336, theta=-45.063659 -> V=1.0, theta=0.0
% INFO    : Bus 20965	: V=0.9916094, theta=-46.128217 -> V=1.0, theta=0.0
% INFO    : Bus 20966	: V=1.0146783, theta=-43.348385 -> V=1.0, theta=0.0
% INFO    : Bus 20967	: V=1.0161836, theta=-42.399911 -> V=1.0, theta=0.0
% INFO    : Bus 20968	: V=1.0016501, theta=-43.965569 -> V=1.0, theta=0.0
% INFO    : Bus 20969	: V=1.0132232, theta=-42.756892 -> V=1.0, theta=0.0
% INFO    : Bus 20970	: V=1.0132278, theta=-42.805438 -> V=1.0, theta=0.0
% INFO    : Bus 20971	: V=0.9965668, theta=-44.209834 -> V=1.0, theta=0.0
% INFO    : Bus 20972	: V=1.0035079, theta=-44.390181 -> V=1.0, theta=0.0
% INFO    : Bus 20973	: V=0.9939866, theta=-51.654572 -> V=1.0, theta=0.0
% INFO    : Bus 20974	: V=0.9819434, theta=-52.587391 -> V=1.0, theta=0.0
% INFO    : Bus 20975	: V=0.9836042, theta=-52.360216 -> V=1.0, theta=0.0
% INFO    : Bus 20976	: V=0.9920688, theta=-51.183695 -> V=1.0, theta=0.0
% INFO    : Bus 20977	: V=0.9749402, theta=-52.267124 -> V=1.0, theta=0.0
% INFO    : Bus 20978	: V=0.9882359, theta=-51.261959 -> V=1.0, theta=0.0
% INFO    : Bus 20979	: V=0.9883818, theta=-51.14771 -> V=1.0, theta=0.0
% INFO    : Bus 20980	: V=0.9857914, theta=-52.310699 -> V=1.0, theta=0.0
% INFO    : Bus 20981	: V=0.9816765, theta=-52.334026 -> V=1.0, theta=0.0
% INFO    : Bus 20982	: V=0.9916549, theta=-51.246338 -> V=1.0, theta=0.0
% INFO    : Bus 20983	: V=0.9841962, theta=-52.032646 -> V=1.0, theta=0.0
% INFO    : Bus 20984	: V=0.9864404, theta=-52.140264 -> V=1.0, theta=0.0
% INFO    : Bus 20985	: V=0.9926526, theta=-51.330916 -> V=1.0, theta=0.0
% INFO    : Bus 20986	: V=0.98619, theta=-52.065051 -> V=1.0, theta=0.0
% INFO    : Bus 20987	: V=0.9841719, theta=-52.310626 -> V=1.0, theta=0.0
% INFO    : Bus 20988	: V=0.9836699, theta=-52.285739 -> V=1.0, theta=0.0
% INFO    : Bus 20989	: V=0.9779241, theta=-53.137833 -> V=1.0, theta=0.0
% INFO    : Bus 20990	: V=0.9747721, theta=-52.807148 -> V=1.0, theta=0.0
% INFO    : Bus 20991	: V=0.9795104, theta=-52.405483 -> V=1.0, theta=0.0
% INFO    : Bus 20992	: V=0.9874993, theta=-50.870879 -> V=1.0, theta=0.0
% INFO    : Bus 20993	: V=0.9865422, theta=-51.017282 -> V=1.0, theta=0.0
% INFO    : Bus 20994	: V=0.980848, theta=-52.220457 -> V=1.0, theta=0.0
% INFO    : Bus 20995	: V=0.9815348, theta=-51.735472 -> V=1.0, theta=0.0
% INFO    : Bus 20996	: V=0.9828929, theta=-51.406937 -> V=1.0, theta=0.0
% INFO    : Bus 20997	: V=0.9817295, theta=-52.134528 -> V=1.0, theta=0.0
% INFO    : Bus 20998	: V=0.9932132, theta=-49.89559 -> V=1.0, theta=0.0
% INFO    : Bus 20999	: V=0.9871528, theta=-51.166914 -> V=1.0, theta=0.0
% INFO    : Bus 21000	: V=0.9881193, theta=-51.000631 -> V=1.0, theta=0.0
% INFO    : Bus 21001	: V=0.9932964, theta=-49.883814 -> V=1.0, theta=0.0
% INFO    : Bus 21002	: V=0.9932391, theta=-49.882624 -> V=1.0, theta=0.0
% INFO    : Bus 21003	: V=0.9897885, theta=-51.006733 -> V=1.0, theta=0.0
% INFO    : Bus 21004	: V=0.9917062, theta=-50.119916 -> V=1.0, theta=0.0
% INFO    : Bus 21005	: V=0.9837735, theta=-51.563654 -> V=1.0, theta=0.0
% INFO    : Bus 21006	: V=0.98451, theta=-51.444006 -> V=1.0, theta=0.0
% INFO    : Bus 21007	: V=0.9827476, theta=-51.456187 -> V=1.0, theta=0.0
% INFO    : Bus 21008	: V=0.9937177, theta=-49.807199 -> V=1.0, theta=0.0
% INFO    : Bus 21009	: V=0.9886403, theta=-50.824538 -> V=1.0, theta=0.0
% INFO    : Bus 21010	: V=0.9891223, theta=-50.825433 -> V=1.0, theta=0.0
% INFO    : Bus 21011	: V=0.9900291, theta=-50.466837 -> V=1.0, theta=0.0
% INFO    : Bus 21012	: V=0.9521821, theta=-56.335348 -> V=1.0, theta=0.0
% INFO    : Bus 21013	: V=0.9598796, theta=-54.51461 -> V=1.0, theta=0.0
% INFO    : Bus 21014	: V=0.9810898, theta=-51.879614 -> V=1.0, theta=0.0
% INFO    : Bus 21015	: V=0.9542215, theta=-55.909882 -> V=1.0, theta=0.0
% INFO    : Bus 21016	: V=0.939845, theta=-57.141411 -> V=1.0, theta=0.0
% INFO    : Bus 21017	: V=0.9438848, theta=-56.901074 -> V=1.0, theta=0.0
% INFO    : Bus 21018	: V=0.9422421, theta=-57.43221 -> V=1.0, theta=0.0
% INFO    : Bus 21019	: V=0.9505765, theta=-54.437569 -> V=1.0, theta=0.0
% INFO    : Bus 21020	: V=0.9464214, theta=-54.850961 -> V=1.0, theta=0.0
% INFO    : Bus 21021	: V=0.9468843, theta=-54.689141 -> V=1.0, theta=0.0
% INFO    : Bus 21022	: V=1.0013228, theta=-45.007971 -> V=1.0, theta=0.0
% INFO    : Bus 21023	: V=1.0164888, theta=-43.318078 -> V=1.0, theta=0.0
% INFO    : Bus 21024	: V=1.0163251, theta=-43.091933 -> V=1.0, theta=0.0
% INFO    : Bus 21025	: V=1.0170029, theta=-43.211335 -> V=1.0, theta=0.0
% INFO    : Bus 21026	: V=1.0177067, theta=-43.24996 -> V=1.0, theta=0.0
% INFO    : Bus 21027	: V=0.9996153, theta=-44.972234 -> V=1.0, theta=0.0
% INFO    : Bus 21028	: V=0.9986545, theta=-48.289117 -> V=1.0, theta=0.0
% INFO    : Bus 21029	: V=0.9932048, theta=-48.686805 -> V=1.0, theta=0.0
% INFO    : Bus 21030	: V=1.0118639, theta=-45.174381 -> V=1.0, theta=0.0
% INFO    : Bus 21031	: V=0.9773907, theta=-50.72246 -> V=1.0, theta=0.0
% INFO    : Bus 21032	: V=0.9802763, theta=-50.578106 -> V=1.0, theta=0.0
% INFO    : Bus 21033	: V=0.9731364, theta=-50.777222 -> V=1.0, theta=0.0
% INFO    : Bus 21034	: V=0.963943, theta=-51.097835 -> V=1.0, theta=0.0
% INFO    : Bus 21035	: V=0.9685219, theta=-50.754262 -> V=1.0, theta=0.0
% INFO    : Bus 21036	: V=0.9692622, theta=-50.710993 -> V=1.0, theta=0.0
% INFO    : Bus 21037	: V=0.9636464, theta=-51.529471 -> V=1.0, theta=0.0
% INFO    : Bus 21038	: V=0.9869754, theta=-49.960041 -> V=1.0, theta=0.0
% INFO    : Bus 21039	: V=0.9559449, theta=-52.455865 -> V=1.0, theta=0.0
% INFO    : Bus 21040	: V=0.9849676, theta=-50.07426 -> V=1.0, theta=0.0
% INFO    : Bus 21041	: V=0.978547, theta=-50.797518 -> V=1.0, theta=0.0
% INFO    : Bus 21042	: V=0.9930594, theta=-50.085598 -> V=1.0, theta=0.0
% INFO    : Bus 21043	: V=0.9738875, theta=-50.956804 -> V=1.0, theta=0.0
% INFO    : Bus 21044	: V=0.9749524, theta=-50.899586 -> V=1.0, theta=0.0
% INFO    : Bus 21045	: V=0.975656, theta=-50.861213 -> V=1.0, theta=0.0
% INFO    : Bus 21046	: V=0.9605165, theta=-52.177407 -> V=1.0, theta=0.0
% INFO    : Bus 21047	: V=0.9626925, theta=-51.488969 -> V=1.0, theta=0.0
% INFO    : Bus 21048	: V=0.9684766, theta=-50.28375 -> V=1.0, theta=0.0
% INFO    : Bus 21049	: V=0.946299, theta=-57.387794 -> V=1.0, theta=0.0
% INFO    : Bus 21050	: V=0.9417229, theta=-57.588455 -> V=1.0, theta=0.0
% INFO    : Bus 21051	: V=0.9638511, theta=-55.300372 -> V=1.0, theta=0.0
% INFO    : Bus 21052	: V=0.9665684, theta=-55.04785 -> V=1.0, theta=0.0
% INFO    : Bus 21053	: V=0.9740255, theta=-53.037989 -> V=1.0, theta=0.0
% INFO    : Bus 21054	: V=0.9496524, theta=-57.190616 -> V=1.0, theta=0.0
% INFO    : Bus 21055	: V=0.9512179, theta=-57.097218 -> V=1.0, theta=0.0
% INFO    : Bus 21056	: V=0.9526011, theta=-56.94927 -> V=1.0, theta=0.0
% INFO    : Bus 21057	: V=0.9558348, theta=-56.577528 -> V=1.0, theta=0.0
% INFO    : Bus 21058	: V=0.9542886, theta=-56.776605 -> V=1.0, theta=0.0
% INFO    : Bus 21059	: V=0.9608909, theta=-55.794284 -> V=1.0, theta=0.0
% INFO    : Bus 21060	: V=0.9453726, theta=-57.276215 -> V=1.0, theta=0.0
% INFO    : Bus 21061	: V=0.9549206, theta=-55.943167 -> V=1.0, theta=0.0
% INFO    : Bus 21062	: V=0.9882998, theta=-52.838994 -> V=1.0, theta=0.0
% INFO    : Bus 21063	: V=0.9681008, theta=-55.333629 -> V=1.0, theta=0.0
% INFO    : Bus 21064	: V=0.9810345, theta=-53.827354 -> V=1.0, theta=0.0
% INFO    : Bus 21065	: V=0.9788261, theta=-54.121222 -> V=1.0, theta=0.0
% INFO    : Bus 21066	: V=0.9794064, theta=-54.044108 -> V=1.0, theta=0.0
% INFO    : Bus 21067	: V=0.9633173, theta=-55.644283 -> V=1.0, theta=0.0
% INFO    : Bus 21068	: V=0.9652861, theta=-55.416961 -> V=1.0, theta=0.0
% INFO    : Bus 21069	: V=0.9784411, theta=-54.19005 -> V=1.0, theta=0.0
% INFO    : Bus 21070	: V=0.9667164, theta=-55.440195 -> V=1.0, theta=0.0
% INFO    : Bus 21071	: V=0.9681852, theta=-55.350577 -> V=1.0, theta=0.0
% INFO    : Bus 21072	: V=0.9877718, theta=-52.856792 -> V=1.0, theta=0.0
% INFO    : Bus 21073	: V=0.9714863, theta=-55.346606 -> V=1.0, theta=0.0
% INFO    : Bus 21074	: V=0.9778172, theta=-54.216474 -> V=1.0, theta=0.0
% INFO    : Bus 21075	: V=0.9777698, theta=-54.129091 -> V=1.0, theta=0.0
% INFO    : Bus 21076	: V=0.9660778, theta=-56.27402 -> V=1.0, theta=0.0
% INFO    : Bus 21077	: V=0.9764479, theta=-54.438102 -> V=1.0, theta=0.0
% INFO    : Bus 21078	: V=0.9811256, theta=-53.827616 -> V=1.0, theta=0.0
% INFO    : Bus 21079	: V=0.970052, theta=-54.336595 -> V=1.0, theta=0.0
% INFO    : Bus 21080	: V=0.9658544, theta=-55.02339 -> V=1.0, theta=0.0
% INFO    : Bus 21081	: V=0.9647535, theta=-55.333041 -> V=1.0, theta=0.0
% INFO    : Bus 21082	: V=0.9482775, theta=-61.343797 -> V=1.0, theta=0.0
% INFO    : Bus 21083	: V=0.9613499, theta=-58.785468 -> V=1.0, theta=0.0
% INFO    : Bus 21084	: V=0.959957, theta=-59.045652 -> V=1.0, theta=0.0
% INFO    : Bus 21085	: V=0.9590611, theta=-59.207056 -> V=1.0, theta=0.0
% INFO    : Bus 21086	: V=0.9599591, theta=-59.648825 -> V=1.0, theta=0.0
% INFO    : Bus 21087	: V=0.9619673, theta=-58.956829 -> V=1.0, theta=0.0
% INFO    : Bus 21088	: V=0.9703997, theta=-56.72646 -> V=1.0, theta=0.0
% INFO    : Bus 21089	: V=0.970019, theta=-56.805492 -> V=1.0, theta=0.0
% INFO    : Bus 21090	: V=0.9667701, theta=-57.356092 -> V=1.0, theta=0.0
% INFO    : Bus 21091	: V=0.9614799, theta=-50.148846 -> V=1.0, theta=0.0
% INFO    : Bus 21092	: V=0.9619065, theta=-50.181459 -> V=1.0, theta=0.0
% INFO    : Bus 21093	: V=0.9640117, theta=-50.006943 -> V=1.0, theta=0.0
% INFO    : Bus 21094	: V=0.963183, theta=-50.037036 -> V=1.0, theta=0.0
% INFO    : Bus 21095	: V=0.9607687, theta=-50.401923 -> V=1.0, theta=0.0
% INFO    : Bus 21096	: V=0.9639507, theta=-49.943843 -> V=1.0, theta=0.0
% INFO    : Bus 21097	: V=0.9804865, theta=-48.59592 -> V=1.0, theta=0.0
% INFO    : Bus 21098	: V=0.9732779, theta=-48.729654 -> V=1.0, theta=0.0
% INFO    : Bus 21099	: V=0.9760065, theta=-48.46 -> V=1.0, theta=0.0
% INFO    : Bus 21100	: V=0.9550928, theta=-49.102529 -> V=1.0, theta=0.0
% INFO    : Bus 21101	: V=0.9914915, theta=-54.444056 -> V=1.0, theta=0.0
% INFO    : Bus 21102	: V=0.9962205, theta=-53.665065 -> V=1.0, theta=0.0
% INFO    : Bus 21103	: V=1.0072597, theta=-54.071085 -> V=1.0, theta=0.0
% INFO    : Bus 21104	: V=0.9905418, theta=-54.842992 -> V=1.0, theta=0.0
% INFO    : Bus 21105	: V=0.9987009, theta=-52.846665 -> V=1.0, theta=0.0
% INFO    : Bus 21106	: V=1.0154129, theta=-48.984536 -> V=1.0, theta=0.0
% INFO    : Bus 21107	: V=1.0081997, theta=-51.653497 -> V=1.0, theta=0.0
% INFO    : Bus 21108	: V=1.0168527, theta=-48.619876 -> V=1.0, theta=0.0
% INFO    : Bus 21109	: V=0.9791884, theta=-56.350514 -> V=1.0, theta=0.0
% INFO    : Bus 21110	: V=0.9844006, theta=-56.039126 -> V=1.0, theta=0.0
% INFO    : Bus 21111	: V=0.9641303, theta=-58.352842 -> V=1.0, theta=0.0
% INFO    : Bus 21112	: V=0.9704892, theta=-57.442983 -> V=1.0, theta=0.0
% INFO    : Bus 21113	: V=0.9778295, theta=-56.515588 -> V=1.0, theta=0.0
% INFO    : Bus 21114	: V=0.9774406, theta=-56.554141 -> V=1.0, theta=0.0
% INFO    : Bus 21115	: V=0.9743274, theta=-56.743666 -> V=1.0, theta=0.0
% INFO    : Bus 21116	: V=1.0041443, theta=-43.773224 -> V=1.0, theta=0.0
% INFO    : Bus 21117	: V=1.0116127, theta=-41.884683 -> V=1.0, theta=0.0
% INFO    : Bus 21118	: V=1.0039824, theta=-43.858803 -> V=1.0, theta=0.0
% INFO    : Bus 21119	: V=1.0066305, theta=-43.251563 -> V=1.0, theta=0.0
% INFO    : Bus 21120	: V=1.0186249, theta=-40.464702 -> V=1.0, theta=0.0
% INFO    : Bus 21121	: V=1.0071905, theta=-43.211054 -> V=1.0, theta=0.0
% INFO    : Bus 21122	: V=1.0066195, theta=-42.943311 -> V=1.0, theta=0.0
% INFO    : Bus 21123	: V=0.9835128, theta=-47.008698 -> V=1.0, theta=0.0
% INFO    : Bus 21124	: V=0.952553, theta=-51.597065 -> V=1.0, theta=0.0
% INFO    : Bus 21125	: V=0.9507432, theta=-51.730418 -> V=1.0, theta=0.0
% INFO    : Bus 21126	: V=0.9612874, theta=-49.659212 -> V=1.0, theta=0.0
% INFO    : Bus 21127	: V=0.9530724, theta=-51.440302 -> V=1.0, theta=0.0
% INFO    : Bus 21128	: V=0.9731265, theta=-48.192326 -> V=1.0, theta=0.0
% INFO    : Bus 21129	: V=0.9758223, theta=-51.52962 -> V=1.0, theta=0.0
% INFO    : Bus 21130	: V=0.9697917, theta=-52.379163 -> V=1.0, theta=0.0
% INFO    : Bus 21131	: V=0.9682752, theta=-52.463417 -> V=1.0, theta=0.0
% INFO    : Bus 21132	: V=0.9948402, theta=-49.061847 -> V=1.0, theta=0.0
% INFO    : Bus 21133	: V=0.9795402, theta=-51.185504 -> V=1.0, theta=0.0
% INFO    : Bus 21134	: V=0.9710148, theta=-52.114726 -> V=1.0, theta=0.0
% INFO    : Bus 21135	: V=0.9793951, theta=-51.190696 -> V=1.0, theta=0.0
% INFO    : Bus 21136	: V=0.9610567, theta=-53.017006 -> V=1.0, theta=0.0
% INFO    : Bus 21137	: V=0.9823995, theta=-50.971208 -> V=1.0, theta=0.0
% INFO    : Bus 21138	: V=0.9842435, theta=-50.844062 -> V=1.0, theta=0.0
% INFO    : Bus 21139	: V=0.9802377, theta=-51.10997 -> V=1.0, theta=0.0
% INFO    : Bus 21140	: V=0.9814821, theta=-51.030052 -> V=1.0, theta=0.0
% INFO    : Bus 21141	: V=0.9823322, theta=-50.929776 -> V=1.0, theta=0.0
% INFO    : Bus 21142	: V=0.9842878, theta=-50.699738 -> V=1.0, theta=0.0
% INFO    : Bus 21143	: V=0.9632389, theta=-52.479509 -> V=1.0, theta=0.0
% INFO    : Bus 21144	: V=0.9600825, theta=-52.940981 -> V=1.0, theta=0.0
% INFO    : Bus 21145	: V=0.9629805, theta=-52.640168 -> V=1.0, theta=0.0
% INFO    : Bus 21146	: V=0.9651765, theta=-52.421495 -> V=1.0, theta=0.0
% INFO    : Bus 21147	: V=0.9646619, theta=-52.34757 -> V=1.0, theta=0.0
% INFO    : Bus 21148	: V=0.9641363, theta=-52.135409 -> V=1.0, theta=0.0
% INFO    : Bus 21149	: V=0.9506689, theta=-52.795247 -> V=1.0, theta=0.0
% INFO    : Bus 21150	: V=0.977779, theta=-51.294287 -> V=1.0, theta=0.0
% INFO    : Bus 21151	: V=1.0192472, theta=-40.836511 -> V=1.0, theta=0.0
% INFO    : Bus 21152	: V=1.0181352, theta=-41.341041 -> V=1.0, theta=0.0
% INFO    : Bus 21153	: V=0.9824612, theta=-43.080896 -> V=1.0, theta=0.0
% INFO    : Bus 21154	: V=0.9807183, theta=-43.497676 -> V=1.0, theta=0.0
% INFO    : Bus 21155	: V=0.981246, theta=-43.458712 -> V=1.0, theta=0.0
% INFO    : Bus 21156	: V=0.9912409, theta=-42.410406 -> V=1.0, theta=0.0
% INFO    : Bus 21157	: V=0.982443, theta=-43.40777 -> V=1.0, theta=0.0
% INFO    : Bus 21158	: V=0.9851349, theta=-43.220677 -> V=1.0, theta=0.0
% INFO    : Bus 21159	: V=1.0082668, theta=-41.580309 -> V=1.0, theta=0.0
% INFO    : Bus 21160	: V=0.9983151, theta=-41.953968 -> V=1.0, theta=0.0
% INFO    : Bus 21161	: V=0.9442381, theta=-60.861016 -> V=1.0, theta=0.0
% INFO    : Bus 21162	: V=0.9495708, theta=-60.192444 -> V=1.0, theta=0.0
% INFO    : Bus 21163	: V=0.9522093, theta=-57.963322 -> V=1.0, theta=0.0
% INFO    : Bus 21164	: V=0.9374127, theta=-61.952028 -> V=1.0, theta=0.0
% INFO    : Bus 21165	: V=0.946564, theta=-62.573651 -> V=1.0, theta=0.0
% INFO    : Bus 21166	: V=0.9462385, theta=-61.08692 -> V=1.0, theta=0.0
% INFO    : Bus 21167	: V=0.9454811, theta=-61.355361 -> V=1.0, theta=0.0
% INFO    : Bus 21168	: V=0.9464707, theta=-61.56247 -> V=1.0, theta=0.0
% INFO    : Bus 21169	: V=0.9536038, theta=-60.439644 -> V=1.0, theta=0.0
% INFO    : Bus 21170	: V=0.9563231, theta=-59.889067 -> V=1.0, theta=0.0
% INFO    : Bus 21171	: V=0.9567258, theta=-59.976999 -> V=1.0, theta=0.0
% INFO    : Bus 21172	: V=0.9568278, theta=-60.254652 -> V=1.0, theta=0.0
% INFO    : Bus 21173	: V=0.9544715, theta=-60.421977 -> V=1.0, theta=0.0
% INFO    : Bus 21174	: V=0.9527021, theta=-60.633481 -> V=1.0, theta=0.0
% INFO    : Bus 21175	: V=0.9594334, theta=-59.250422 -> V=1.0, theta=0.0
% INFO    : Bus 21176	: V=0.9517259, theta=-60.661818 -> V=1.0, theta=0.0
% INFO    : Bus 21177	: V=0.9657661, theta=-57.697929 -> V=1.0, theta=0.0
% INFO    : Bus 21178	: V=0.9746491, theta=-55.334047 -> V=1.0, theta=0.0
% INFO    : Bus 21179	: V=0.9643727, theta=-57.368627 -> V=1.0, theta=0.0
% INFO    : Bus 21180	: V=0.9397741, theta=-60.471896 -> V=1.0, theta=0.0
% INFO    : Bus 21181	: V=0.9420436, theta=-59.342133 -> V=1.0, theta=0.0
% INFO    : Bus 21182	: V=0.9375605, theta=-59.992661 -> V=1.0, theta=0.0
% INFO    : Bus 21183	: V=0.9456592, theta=-58.448845 -> V=1.0, theta=0.0
% INFO    : Bus 21184	: V=0.9491004, theta=-58.552264 -> V=1.0, theta=0.0
% INFO    : Bus 21185	: V=0.9382363, theta=-61.224493 -> V=1.0, theta=0.0
% INFO    : Bus 21186	: V=0.9383751, theta=-61.428279 -> V=1.0, theta=0.0
% INFO    : Bus 21187	: V=0.9386847, theta=-61.393488 -> V=1.0, theta=0.0
% INFO    : Bus 21188	: V=0.9905985, theta=-58.023172 -> V=1.0, theta=0.0
% INFO    : Bus 21189	: V=0.9903842, theta=-58.068249 -> V=1.0, theta=0.0
% INFO    : Bus 21190	: V=1.0169202, theta=-54.86466 -> V=1.0, theta=0.0
% INFO    : Bus 21191	: V=1.0144478, theta=-54.876124 -> V=1.0, theta=0.0
% INFO    : Bus 21192	: V=0.9863808, theta=-58.557628 -> V=1.0, theta=0.0
% INFO    : Bus 21193	: V=1.0187567, theta=-54.845974 -> V=1.0, theta=0.0
% INFO    : Bus 21194	: V=1.0019584, theta=-57.012099 -> V=1.0, theta=0.0
% INFO    : Bus 21195	: V=1.0028655, theta=-56.955283 -> V=1.0, theta=0.0
% INFO    : Bus 21196	: V=1.0032886, theta=-56.928794 -> V=1.0, theta=0.0
% INFO    : Bus 21197	: V=0.993875, theta=-57.881069 -> V=1.0, theta=0.0
% INFO    : Bus 21198	: V=0.9904406, theta=-58.147038 -> V=1.0, theta=0.0
% INFO    : Bus 21199	: V=0.9897349, theta=-58.118428 -> V=1.0, theta=0.0
% INFO    : Bus 21200	: V=0.9928814, theta=-57.893741 -> V=1.0, theta=0.0
% INFO    : Bus 21201	: V=0.9948532, theta=-57.761067 -> V=1.0, theta=0.0
% INFO    : Bus 21202	: V=0.9960643, theta=-57.33391 -> V=1.0, theta=0.0
% INFO    : Bus 21203	: V=0.9964865, theta=-57.265308 -> V=1.0, theta=0.0
% INFO    : Bus 21204	: V=0.9959495, theta=-57.35145 -> V=1.0, theta=0.0
% INFO    : Bus 21205	: V=0.994691, theta=-57.754254 -> V=1.0, theta=0.0
% INFO    : Bus 21206	: V=0.9940271, theta=-57.813096 -> V=1.0, theta=0.0
% INFO    : Bus 21207	: V=0.9919341, theta=-57.948959 -> V=1.0, theta=0.0
% INFO    : Bus 21208	: V=0.9901659, theta=-57.991247 -> V=1.0, theta=0.0
% INFO    : Bus 21209	: V=0.9930038, theta=-57.866729 -> V=1.0, theta=0.0
% INFO    : Bus 21210	: V=0.9937134, theta=-57.811142 -> V=1.0, theta=0.0
% INFO    : Bus 21211	: V=0.9885631, theta=-58.082867 -> V=1.0, theta=0.0
% INFO    : Bus 21212	: V=0.9870228, theta=-58.097257 -> V=1.0, theta=0.0
% INFO    : Bus 21213	: V=0.9846852, theta=-58.181886 -> V=1.0, theta=0.0
% INFO    : Bus 21214	: V=0.9861641, theta=-58.148688 -> V=1.0, theta=0.0
% INFO    : Bus 21215	: V=0.9832997, theta=-58.205826 -> V=1.0, theta=0.0
% INFO    : Bus 21216	: V=1.0021375, theta=-57.001015 -> V=1.0, theta=0.0
% INFO    : Bus 21217	: V=0.9992635, theta=-57.895599 -> V=1.0, theta=0.0
% INFO    : Bus 21218	: V=1.0027384, theta=-57.5354 -> V=1.0, theta=0.0
% INFO    : Bus 21219	: V=1.0001684, theta=-58.008799 -> V=1.0, theta=0.0
% INFO    : Bus 21220	: V=0.9965602, theta=-57.991477 -> V=1.0, theta=0.0
% INFO    : Bus 21221	: V=0.9923225, theta=-58.09245 -> V=1.0, theta=0.0
% INFO    : Bus 21222	: V=0.9847934, theta=-59.019703 -> V=1.0, theta=0.0
% INFO    : Bus 21223	: V=0.982305, theta=-59.108219 -> V=1.0, theta=0.0
% INFO    : Bus 21224	: V=0.9909424, theta=-58.102909 -> V=1.0, theta=0.0
% INFO    : Bus 21225	: V=0.9883428, theta=-58.093319 -> V=1.0, theta=0.0
% INFO    : Bus 21226	: V=0.9933538, theta=-57.823497 -> V=1.0, theta=0.0
% INFO    : Bus 21227	: V=0.9834412, theta=-58.72737 -> V=1.0, theta=0.0
% INFO    : Bus 21228	: V=0.9826572, theta=-58.773639 -> V=1.0, theta=0.0
% INFO    : Bus 21229	: V=0.9811925, theta=-59.027528 -> V=1.0, theta=0.0
% INFO    : Bus 21230	: V=0.979583, theta=-59.09584 -> V=1.0, theta=0.0
% INFO    : Bus 21231	: V=0.9780083, theta=-59.129902 -> V=1.0, theta=0.0
% INFO    : Bus 21232	: V=0.9771303, theta=-59.130872 -> V=1.0, theta=0.0
% INFO    : Bus 21233	: V=0.9812837, theta=-58.787878 -> V=1.0, theta=0.0
% INFO    : Bus 21234	: V=0.9864734, theta=-58.632643 -> V=1.0, theta=0.0
% INFO    : Bus 21235	: V=0.9841822, theta=-58.708857 -> V=1.0, theta=0.0
% INFO    : Bus 21236	: V=0.999117, theta=-57.555647 -> V=1.0, theta=0.0
% INFO    : Bus 21237	: V=0.9947577, theta=-57.813675 -> V=1.0, theta=0.0
% INFO    : Bus 21238	: V=1.019455, theta=-54.816552 -> V=1.0, theta=0.0
% INFO    : Bus 21239	: V=1.0194347, theta=-54.835215 -> V=1.0, theta=0.0
% INFO    : Bus 21240	: V=0.9958267, theta=-57.985384 -> V=1.0, theta=0.0
% INFO    : Bus 21241	: V=0.9936416, theta=-58.074493 -> V=1.0, theta=0.0
% INFO    : Bus 21242	: V=0.9939653, theta=-57.848645 -> V=1.0, theta=0.0
% INFO    : Bus 21243	: V=0.9950889, theta=-57.894732 -> V=1.0, theta=0.0
% INFO    : Bus 21244	: V=0.9962541, theta=-57.820469 -> V=1.0, theta=0.0
% INFO    : Bus 21245	: V=0.9981312, theta=-57.667714 -> V=1.0, theta=0.0
% INFO    : Bus 21246	: V=1.0007259, theta=-57.761942 -> V=1.0, theta=0.0
% INFO    : Bus 21247	: V=0.9993116, theta=-57.891855 -> V=1.0, theta=0.0
% INFO    : Bus 21248	: V=0.9758855, theta=-59.035951 -> V=1.0, theta=0.0
% INFO    : Bus 21249	: V=0.9761878, theta=-59.064224 -> V=1.0, theta=0.0
% INFO    : Bus 21250	: V=0.984842, theta=-57.648865 -> V=1.0, theta=0.0
% INFO    : Bus 21251	: V=0.9752358, theta=-59.08585 -> V=1.0, theta=0.0
% INFO    : Bus 21252	: V=0.987665, theta=-57.843749 -> V=1.0, theta=0.0
% INFO    : Bus 21253	: V=0.9874931, theta=-57.747061 -> V=1.0, theta=0.0
% INFO    : Bus 21254	: V=0.987945, theta=-57.945089 -> V=1.0, theta=0.0
% INFO    : Bus 21255	: V=0.9827644, theta=-58.672883 -> V=1.0, theta=0.0
% INFO    : Bus 21256	: V=0.983182, theta=-58.598428 -> V=1.0, theta=0.0
% INFO    : Bus 21257	: V=0.9821368, theta=-58.668052 -> V=1.0, theta=0.0
% INFO    : Bus 21258	: V=1.0042663, theta=-55.396619 -> V=1.0, theta=0.0
% INFO    : Bus 21259	: V=0.9840722, theta=-58.537177 -> V=1.0, theta=0.0
% INFO    : Bus 21260	: V=0.984722, theta=-58.295271 -> V=1.0, theta=0.0
% INFO    : Bus 21261	: V=0.9847374, theta=-58.579903 -> V=1.0, theta=0.0
% INFO    : Bus 21262	: V=0.9871093, theta=-58.302615 -> V=1.0, theta=0.0
% INFO    : Bus 21263	: V=0.9863381, theta=-58.268317 -> V=1.0, theta=0.0
% INFO    : Bus 21264	: V=0.9884852, theta=-57.455565 -> V=1.0, theta=0.0
% INFO    : Bus 21265	: V=0.9842895, theta=-58.188416 -> V=1.0, theta=0.0
% INFO    : Bus 21266	: V=0.9819673, theta=-58.619498 -> V=1.0, theta=0.0
% INFO    : Bus 21267	: V=0.9892006, theta=-58.077283 -> V=1.0, theta=0.0
% INFO    : Bus 21268	: V=0.9860577, theta=-58.281438 -> V=1.0, theta=0.0
% INFO    : Bus 21269	: V=0.9789263, theta=-58.604509 -> V=1.0, theta=0.0
% INFO    : Bus 21270	: V=0.9775903, theta=-58.880625 -> V=1.0, theta=0.0
% INFO    : Bus 21271	: V=0.9796748, theta=-58.738246 -> V=1.0, theta=0.0
% INFO    : Bus 21272	: V=0.9782536, theta=-58.797955 -> V=1.0, theta=0.0
% INFO    : Bus 21273	: V=0.9684197, theta=-59.096774 -> V=1.0, theta=0.0
% INFO    : Bus 21274	: V=0.9866437, theta=-57.509649 -> V=1.0, theta=0.0
% INFO    : Bus 21275	: V=0.9834005, theta=-57.663003 -> V=1.0, theta=0.0
% INFO    : Bus 21276	: V=0.9829536, theta=-57.720611 -> V=1.0, theta=0.0
% INFO    : Bus 21277	: V=0.9764035, theta=-58.401402 -> V=1.0, theta=0.0
% INFO    : Bus 21278	: V=0.9779589, theta=-58.319457 -> V=1.0, theta=0.0
% INFO    : Bus 21279	: V=0.9821875, theta=-57.46406 -> V=1.0, theta=0.0
% INFO    : Bus 21280	: V=0.9819315, theta=-57.579617 -> V=1.0, theta=0.0
% INFO    : Bus 21281	: V=0.986089, theta=-57.519288 -> V=1.0, theta=0.0
% INFO    : Bus 21282	: V=0.9745075, theta=-58.597609 -> V=1.0, theta=0.0
% INFO    : Bus 21283	: V=0.9736249, theta=-58.544304 -> V=1.0, theta=0.0
% INFO    : Bus 21284	: V=0.9731611, theta=-58.613646 -> V=1.0, theta=0.0
% INFO    : Bus 21285	: V=0.9726209, theta=-58.6418 -> V=1.0, theta=0.0
% INFO    : Bus 21286	: V=0.9752238, theta=-58.571903 -> V=1.0, theta=0.0
% INFO    : Bus 21287	: V=0.987273, theta=-57.400003 -> V=1.0, theta=0.0
% INFO    : Bus 21288	: V=0.9875046, theta=-57.521255 -> V=1.0, theta=0.0
% INFO    : Bus 21289	: V=1.003088, theta=-55.415863 -> V=1.0, theta=0.0
% INFO    : Bus 21290	: V=0.9857447, theta=-57.577166 -> V=1.0, theta=0.0
% INFO    : Bus 21291	: V=0.9715539, theta=-58.82123 -> V=1.0, theta=0.0
% INFO    : Bus 21292	: V=0.9801445, theta=-56.950292 -> V=1.0, theta=0.0
% INFO    : Bus 21293	: V=0.9715177, theta=-58.748904 -> V=1.0, theta=0.0
% INFO    : Bus 21294	: V=0.9814244, theta=-57.372478 -> V=1.0, theta=0.0
% INFO    : Bus 21295	: V=0.9717919, theta=-58.437186 -> V=1.0, theta=0.0
% INFO    : Bus 21296	: V=0.9814764, theta=-57.214701 -> V=1.0, theta=0.0
% INFO    : Bus 21297	: V=0.9801326, theta=-57.314937 -> V=1.0, theta=0.0
% INFO    : Bus 21298	: V=0.9813686, theta=-56.828257 -> V=1.0, theta=0.0
% INFO    : Bus 21299	: V=0.9679906, theta=-58.461085 -> V=1.0, theta=0.0
% INFO    : Bus 21300	: V=0.9707521, theta=-57.395799 -> V=1.0, theta=0.0
% INFO    : Bus 21301	: V=0.985807, theta=-55.616803 -> V=1.0, theta=0.0
% INFO    : Bus 21302	: V=0.9849895, theta=-55.738966 -> V=1.0, theta=0.0
% INFO    : Bus 21303	: V=0.9742422, theta=-57.140933 -> V=1.0, theta=0.0
% INFO    : Bus 21304	: V=0.9728186, theta=-57.181888 -> V=1.0, theta=0.0
% INFO    : Bus 21305	: V=1.0162818, theta=-54.003246 -> V=1.0, theta=0.0
% INFO    : Bus 21306	: V=1.0063491, theta=-55.137834 -> V=1.0, theta=0.0
% INFO    : Bus 21307	: V=1.0090872, theta=-54.834486 -> V=1.0, theta=0.0
% INFO    : Bus 21308	: V=1.0084647, theta=-54.864101 -> V=1.0, theta=0.0
% INFO    : Bus 21309	: V=1.0075407, theta=-54.896644 -> V=1.0, theta=0.0
% INFO    : Bus 21310	: V=1.0047153, theta=-55.257067 -> V=1.0, theta=0.0
% INFO    : Bus 21311	: V=1.0053565, theta=-55.21175 -> V=1.0, theta=0.0
% INFO    : Bus 21312	: V=1.0081872, theta=-54.822162 -> V=1.0, theta=0.0
% INFO    : Bus 21313	: V=1.013886, theta=-53.958371 -> V=1.0, theta=0.0
% INFO    : Bus 21314	: V=1.0124077, theta=-54.005611 -> V=1.0, theta=0.0
% INFO    : Bus 21315	: V=1.0075048, theta=-54.84068 -> V=1.0, theta=0.0
% INFO    : Bus 21316	: V=1.0078026, theta=-54.889169 -> V=1.0, theta=0.0
% INFO    : Bus 21317	: V=1.0071881, theta=-54.840972 -> V=1.0, theta=0.0
% INFO    : Bus 21318	: V=0.9970726, theta=-55.571783 -> V=1.0, theta=0.0
% INFO    : Bus 21319	: V=0.990388, theta=-54.813486 -> V=1.0, theta=0.0
% INFO    : Bus 21320	: V=0.9793013, theta=-55.76772 -> V=1.0, theta=0.0
% INFO    : Bus 21321	: V=0.984824, theta=-55.966145 -> V=1.0, theta=0.0
% INFO    : Bus 21322	: V=0.9919896, theta=-55.859109 -> V=1.0, theta=0.0
% INFO    : Bus 21323	: V=1.0048225, theta=-54.180935 -> V=1.0, theta=0.0
% INFO    : Bus 21324	: V=0.9893228, theta=-55.941945 -> V=1.0, theta=0.0
% INFO    : Bus 21325	: V=1.0055413, theta=-54.183135 -> V=1.0, theta=0.0
% INFO    : Bus 21326	: V=0.9982119, theta=-55.979386 -> V=1.0, theta=0.0
% INFO    : Bus 21327	: V=1.0041645, theta=-54.869997 -> V=1.0, theta=0.0
% INFO    : Bus 21328	: V=0.9984203, theta=-56.013061 -> V=1.0, theta=0.0
% INFO    : Bus 21329	: V=0.981075, theta=-56.581219 -> V=1.0, theta=0.0
% INFO    : Bus 21330	: V=0.9818181, theta=-57.052309 -> V=1.0, theta=0.0
% INFO    : Bus 21331	: V=1.0017164, theta=-54.289094 -> V=1.0, theta=0.0
% INFO    : Bus 21332	: V=1.0094563, theta=-54.713817 -> V=1.0, theta=0.0
% INFO    : Bus 21333	: V=0.9759002, theta=-47.625387 -> V=1.0, theta=0.0
% INFO    : Bus 21334	: V=0.9914192, theta=-47.157739 -> V=1.0, theta=0.0
% INFO    : Bus 21335	: V=0.9834332, theta=-46.806554 -> V=1.0, theta=0.0
% INFO    : Bus 21336	: V=0.9913116, theta=-46.867916 -> V=1.0, theta=0.0
% INFO    : Bus 21337	: V=0.9826306, theta=-47.650796 -> V=1.0, theta=0.0
% INFO    : Bus 21338	: V=0.985444, theta=-47.304221 -> V=1.0, theta=0.0
% INFO    : Bus 21339	: V=1.0163294, theta=-43.872882 -> V=1.0, theta=0.0
% INFO    : Bus 21340	: V=0.9848278, theta=-47.594522 -> V=1.0, theta=0.0
% INFO    : Bus 21341	: V=0.9932726, theta=-47.194641 -> V=1.0, theta=0.0
% INFO    : Bus 21342	: V=0.990605, theta=-47.0318 -> V=1.0, theta=0.0
% INFO    : Bus 21343	: V=0.9778082, theta=-54.712282 -> V=1.0, theta=0.0
% INFO    : Bus 21344	: V=0.9749411, theta=-55.081412 -> V=1.0, theta=0.0
% INFO    : Bus 21345	: V=0.9786378, theta=-54.700914 -> V=1.0, theta=0.0
% INFO    : Bus 21346	: V=0.977787, theta=-54.803605 -> V=1.0, theta=0.0
% INFO    : Bus 21347	: V=0.9776547, theta=-54.838681 -> V=1.0, theta=0.0
% INFO    : Bus 21348	: V=0.9773717, theta=-54.913419 -> V=1.0, theta=0.0
% INFO    : Bus 21349	: V=0.9766585, theta=-54.983871 -> V=1.0, theta=0.0
% INFO    : Bus 21350	: V=0.9752366, theta=-55.34461 -> V=1.0, theta=0.0
% INFO    : Bus 21351	: V=0.9761115, theta=-55.057929 -> V=1.0, theta=0.0
% INFO    : Bus 21352	: V=0.9766495, theta=-54.983092 -> V=1.0, theta=0.0
% INFO    : Bus 21353	: V=0.9781425, theta=-54.585394 -> V=1.0, theta=0.0
% INFO    : Bus 21354	: V=0.9761589, theta=-54.819493 -> V=1.0, theta=0.0
% INFO    : Bus 21355	: V=0.9753512, theta=-54.958273 -> V=1.0, theta=0.0
% INFO    : Bus 21356	: V=0.9799226, theta=-54.532894 -> V=1.0, theta=0.0
% INFO    : Bus 21357	: V=0.9788415, theta=-54.690848 -> V=1.0, theta=0.0
% INFO    : Bus 21358	: V=0.9779232, theta=-54.833904 -> V=1.0, theta=0.0
% INFO    : Bus 21359	: V=0.9746735, theta=-55.503948 -> V=1.0, theta=0.0
% INFO    : Bus 21360	: V=0.9776576, theta=-54.462102 -> V=1.0, theta=0.0
% INFO    : Bus 21361	: V=0.977418, theta=-54.5107 -> V=1.0, theta=0.0
% INFO    : Bus 21362	: V=0.9771532, theta=-54.585947 -> V=1.0, theta=0.0
% INFO    : Bus 21363	: V=0.9719183, theta=-55.766013 -> V=1.0, theta=0.0
% INFO    : Bus 21364	: V=0.9733323, theta=-55.418478 -> V=1.0, theta=0.0
% INFO    : Bus 21365	: V=0.9741856, theta=-55.371923 -> V=1.0, theta=0.0
% INFO    : Bus 21366	: V=0.9727302, theta=-55.280931 -> V=1.0, theta=0.0
% INFO    : Bus 21367	: V=0.9766453, theta=-54.698166 -> V=1.0, theta=0.0
% INFO    : Bus 21368	: V=0.9801089, theta=-54.051121 -> V=1.0, theta=0.0
% INFO    : Bus 21369	: V=0.9802906, theta=-53.928405 -> V=1.0, theta=0.0
% INFO    : Bus 21370	: V=0.976737, theta=-55.062149 -> V=1.0, theta=0.0
% INFO    : Bus 21371	: V=0.976644, theta=-55.115941 -> V=1.0, theta=0.0
% INFO    : Bus 21372	: V=0.9702354, theta=-54.667646 -> V=1.0, theta=0.0
% INFO    : Bus 21373	: V=0.9802656, theta=-54.178621 -> V=1.0, theta=0.0
% INFO    : Bus 21374	: V=0.974156, theta=-54.245149 -> V=1.0, theta=0.0
% INFO    : Bus 21375	: V=0.9769882, theta=-53.927653 -> V=1.0, theta=0.0
% INFO    : Bus 21376	: V=0.9787304, theta=-54.067396 -> V=1.0, theta=0.0
% INFO    : Bus 21377	: V=0.9770981, theta=-53.63347 -> V=1.0, theta=0.0
% INFO    : Bus 21378	: V=0.9777606, theta=-54.75546 -> V=1.0, theta=0.0
% INFO    : Bus 21379	: V=0.9780449, theta=-54.773352 -> V=1.0, theta=0.0
% INFO    : Bus 21380	: V=0.9863296, theta=-50.475468 -> V=1.0, theta=0.0
% INFO    : Bus 21381	: V=1.0106497, theta=-45.509466 -> V=1.0, theta=0.0
% INFO    : Bus 21382	: V=0.9987292, theta=-48.975183 -> V=1.0, theta=0.0
% INFO    : Bus 21383	: V=0.9904154, theta=-50.342166 -> V=1.0, theta=0.0
% INFO    : Bus 21384	: V=0.9885797, theta=-50.098623 -> V=1.0, theta=0.0
% INFO    : Bus 21385	: V=0.9878934, theta=-50.1646 -> V=1.0, theta=0.0
% INFO    : Bus 21386	: V=0.988792, theta=-50.04786 -> V=1.0, theta=0.0
% INFO    : Bus 21387	: V=0.997991, theta=-49.001416 -> V=1.0, theta=0.0
% INFO    : Bus 21388	: V=0.9859794, theta=-50.422758 -> V=1.0, theta=0.0
% INFO    : Bus 21389	: V=0.9846949, theta=-50.658168 -> V=1.0, theta=0.0
% INFO    : Bus 21390	: V=0.9873342, theta=-50.238498 -> V=1.0, theta=0.0
% INFO    : Bus 21391	: V=0.9964873, theta=-48.933091 -> V=1.0, theta=0.0
% INFO    : Bus 21392	: V=0.9854865, theta=-50.502127 -> V=1.0, theta=0.0
% INFO    : Bus 21393	: V=0.9859145, theta=-50.414514 -> V=1.0, theta=0.0
% INFO    : Bus 21394	: V=0.9809096, theta=-51.039788 -> V=1.0, theta=0.0
% INFO    : Bus 21395	: V=0.9781402, theta=-51.318855 -> V=1.0, theta=0.0
% INFO    : Bus 21396	: V=0.9861002, theta=-50.392926 -> V=1.0, theta=0.0
% INFO    : Bus 21397	: V=0.9900779, theta=-50.4066 -> V=1.0, theta=0.0
% INFO    : Bus 21398	: V=0.9899989, theta=-50.442364 -> V=1.0, theta=0.0
% INFO    : Bus 21399	: V=0.9874247, theta=-50.795581 -> V=1.0, theta=0.0
% INFO    : Bus 21400	: V=0.9959731, theta=-49.372956 -> V=1.0, theta=0.0
% INFO    : Bus 21401	: V=0.9876746, theta=-50.716339 -> V=1.0, theta=0.0
% INFO    : Bus 21402	: V=0.9836615, theta=-51.113923 -> V=1.0, theta=0.0
% INFO    : Bus 21403	: V=0.9873658, theta=-50.834551 -> V=1.0, theta=0.0
% INFO    : Bus 21404	: V=0.9873851, theta=-50.858965 -> V=1.0, theta=0.0
% INFO    : Bus 21405	: V=0.9826648, theta=-51.284946 -> V=1.0, theta=0.0
% INFO    : Bus 21406	: V=0.9775524, theta=-52.29931 -> V=1.0, theta=0.0
% INFO    : Bus 21407	: V=0.9819398, theta=-51.472039 -> V=1.0, theta=0.0
% INFO    : Bus 21408	: V=0.9794658, theta=-51.637935 -> V=1.0, theta=0.0
% INFO    : Bus 21409	: V=0.9772355, theta=-51.911799 -> V=1.0, theta=0.0
% INFO    : Bus 21410	: V=0.9788197, theta=-51.599517 -> V=1.0, theta=0.0
% INFO    : Bus 21411	: V=0.9798796, theta=-51.586341 -> V=1.0, theta=0.0
% INFO    : Bus 21412	: V=0.9857301, theta=-50.904451 -> V=1.0, theta=0.0
% INFO    : Bus 21413	: V=0.9837301, theta=-50.920971 -> V=1.0, theta=0.0
% INFO    : Bus 21414	: V=0.9837065, theta=-51.136715 -> V=1.0, theta=0.0
% INFO    : Bus 21415	: V=0.9841436, theta=-50.816224 -> V=1.0, theta=0.0
% INFO    : Bus 21416	: V=0.9763567, theta=-51.606837 -> V=1.0, theta=0.0
% INFO    : Bus 21417	: V=0.9776968, theta=-51.464609 -> V=1.0, theta=0.0
% INFO    : Bus 21418	: V=0.9766292, theta=-51.681045 -> V=1.0, theta=0.0
% INFO    : Bus 21419	: V=0.9827774, theta=-51.062437 -> V=1.0, theta=0.0
% INFO    : Bus 21420	: V=0.9786638, theta=-51.717746 -> V=1.0, theta=0.0
% INFO    : Bus 21421	: V=0.978992, theta=-51.5867 -> V=1.0, theta=0.0
% INFO    : Bus 21422	: V=0.9788187, theta=-51.536722 -> V=1.0, theta=0.0
% INFO    : Bus 21423	: V=0.9791718, theta=-51.445345 -> V=1.0, theta=0.0
% INFO    : Bus 21424	: V=0.9817896, theta=-51.154213 -> V=1.0, theta=0.0
% INFO    : Bus 21425	: V=0.9801464, theta=-51.286587 -> V=1.0, theta=0.0
% INFO    : Bus 21426	: V=0.9804786, theta=-51.233699 -> V=1.0, theta=0.0
% INFO    : Bus 21427	: V=0.9765272, theta=-51.881549 -> V=1.0, theta=0.0
% INFO    : Bus 21428	: V=0.9807668, theta=-51.244261 -> V=1.0, theta=0.0
% INFO    : Bus 21429	: V=0.9811588, theta=-51.212051 -> V=1.0, theta=0.0
% INFO    : Bus 21430	: V=0.9759629, theta=-51.890335 -> V=1.0, theta=0.0
% INFO    : Bus 21431	: V=0.976017, theta=-51.881679 -> V=1.0, theta=0.0
% INFO    : Bus 21432	: V=0.9787539, theta=-51.51189 -> V=1.0, theta=0.0
% INFO    : Bus 21433	: V=0.9767398, theta=-51.725901 -> V=1.0, theta=0.0
% INFO    : Bus 21434	: V=0.9886729, theta=-50.679588 -> V=1.0, theta=0.0
% INFO    : Bus 21435	: V=0.9896123, theta=-50.419156 -> V=1.0, theta=0.0
% INFO    : Bus 21436	: V=0.9734082, theta=-52.719745 -> V=1.0, theta=0.0
% INFO    : Bus 21437	: V=0.970176, theta=-53.02387 -> V=1.0, theta=0.0
% INFO    : Bus 21438	: V=0.9694098, theta=-53.048498 -> V=1.0, theta=0.0
% INFO    : Bus 21439	: V=0.9728125, theta=-52.806594 -> V=1.0, theta=0.0
% INFO    : Bus 21440	: V=0.9521294, theta=-54.25636 -> V=1.0, theta=0.0
% INFO    : Bus 21441	: V=0.9655982, theta=-53.39919 -> V=1.0, theta=0.0
% INFO    : Bus 21442	: V=0.9695275, theta=-52.386858 -> V=1.0, theta=0.0
% INFO    : Bus 21443	: V=0.9639342, theta=-53.438496 -> V=1.0, theta=0.0
% INFO    : Bus 21444	: V=0.9625998, theta=-53.59112 -> V=1.0, theta=0.0
% INFO    : Bus 21445	: V=0.9560345, theta=-53.998769 -> V=1.0, theta=0.0
% INFO    : Bus 21446	: V=0.9788991, theta=-51.733813 -> V=1.0, theta=0.0
% INFO    : Bus 21447	: V=0.9770917, theta=-51.79628 -> V=1.0, theta=0.0
% INFO    : Bus 21448	: V=0.9721392, theta=-52.17439 -> V=1.0, theta=0.0
% INFO    : Bus 21449	: V=0.9607041, theta=-53.64602 -> V=1.0, theta=0.0
% INFO    : Bus 21450	: V=0.9573662, theta=-53.871607 -> V=1.0, theta=0.0
% INFO    : Bus 21451	: V=0.9584483, theta=-53.787719 -> V=1.0, theta=0.0
% INFO    : Bus 21452	: V=0.9735038, theta=-52.052951 -> V=1.0, theta=0.0
% INFO    : Bus 21453	: V=0.9573071, theta=-53.904657 -> V=1.0, theta=0.0
% INFO    : Bus 21454	: V=0.976217, theta=-51.817499 -> V=1.0, theta=0.0
% INFO    : Bus 21455	: V=0.9765076, theta=-51.765501 -> V=1.0, theta=0.0
% INFO    : Bus 21456	: V=0.990058, theta=-49.74232 -> V=1.0, theta=0.0
% INFO    : Bus 21457	: V=0.9975216, theta=-48.410848 -> V=1.0, theta=0.0
% INFO    : Bus 21458	: V=0.9965431, theta=-48.83312 -> V=1.0, theta=0.0
% INFO    : Bus 21459	: V=0.9866266, theta=-50.273098 -> V=1.0, theta=0.0
% INFO    : Bus 21460	: V=0.9967623, theta=-48.736712 -> V=1.0, theta=0.0
% INFO    : Bus 21461	: V=0.9898357, theta=-49.857215 -> V=1.0, theta=0.0
% INFO    : Bus 21462	: V=0.9970582, theta=-48.645788 -> V=1.0, theta=0.0
% INFO    : Bus 21463	: V=0.9905102, theta=-49.694523 -> V=1.0, theta=0.0
% INFO    : Bus 21464	: V=0.9974932, theta=-48.512282 -> V=1.0, theta=0.0
% INFO    : Bus 21465	: V=0.9964151, theta=-48.889059 -> V=1.0, theta=0.0
% INFO    : Bus 21466	: V=0.9864496, theta=-50.278761 -> V=1.0, theta=0.0
% INFO    : Bus 21467	: V=0.9863544, theta=-50.334972 -> V=1.0, theta=0.0
% INFO    : Bus 21468	: V=0.9781995, theta=-51.447712 -> V=1.0, theta=0.0
% INFO    : Bus 21469	: V=0.9821515, theta=-50.911011 -> V=1.0, theta=0.0
% INFO    : Bus 21470	: V=0.9754532, theta=-51.540896 -> V=1.0, theta=0.0
% INFO    : Bus 21471	: V=0.984151, theta=-50.6494 -> V=1.0, theta=0.0
% INFO    : Bus 21472	: V=0.985943, theta=-50.396232 -> V=1.0, theta=0.0
% INFO    : Bus 21473	: V=0.9839142, theta=-50.427228 -> V=1.0, theta=0.0
% INFO    : Bus 21474	: V=0.9866908, theta=-50.217263 -> V=1.0, theta=0.0
% INFO    : Bus 21475	: V=0.9857048, theta=-50.432529 -> V=1.0, theta=0.0
% INFO    : Bus 21476	: V=0.9805203, theta=-51.385042 -> V=1.0, theta=0.0
% INFO    : Bus 21477	: V=0.9930165, theta=-49.553624 -> V=1.0, theta=0.0
% INFO    : Bus 21478	: V=0.9951347, theta=-49.15764 -> V=1.0, theta=0.0
% INFO    : Bus 21479	: V=0.9867862, theta=-50.276467 -> V=1.0, theta=0.0
% INFO    : Bus 21480	: V=0.9838814, theta=-50.518424 -> V=1.0, theta=0.0
% INFO    : Bus 21481	: V=0.9872922, theta=-50.099067 -> V=1.0, theta=0.0
% INFO    : Bus 21482	: V=0.9830645, theta=-50.549381 -> V=1.0, theta=0.0
% INFO    : Bus 21483	: V=1.0142051, theta=-44.489425 -> V=1.0, theta=0.0
% INFO    : Bus 21484	: V=0.9974983, theta=-48.453947 -> V=1.0, theta=0.0
% INFO    : Bus 21485	: V=0.9878775, theta=-50.041319 -> V=1.0, theta=0.0
% INFO    : Bus 21486	: V=0.9831571, theta=-50.840648 -> V=1.0, theta=0.0
% INFO    : Bus 21487	: V=1.0134515, theta=-44.689287 -> V=1.0, theta=0.0
% INFO    : Bus 21488	: V=0.9881173, theta=-50.061915 -> V=1.0, theta=0.0
% INFO    : Bus 21489	: V=0.9968894, theta=-48.789316 -> V=1.0, theta=0.0
% INFO    : Bus 21490	: V=0.9815179, theta=-51.049877 -> V=1.0, theta=0.0
% INFO    : Bus 21491	: V=0.976821, theta=-51.875472 -> V=1.0, theta=0.0
% INFO    : Bus 21492	: V=0.9761406, theta=-51.916861 -> V=1.0, theta=0.0
% INFO    : Bus 21493	: V=0.9792005, theta=-51.462547 -> V=1.0, theta=0.0
% INFO    : Bus 21494	: V=0.9774051, theta=-51.661415 -> V=1.0, theta=0.0
% INFO    : Bus 21495	: V=0.9781451, theta=-51.597169 -> V=1.0, theta=0.0
% INFO    : Bus 21496	: V=0.979624, theta=-51.423791 -> V=1.0, theta=0.0
% INFO    : Bus 21497	: V=0.9801996, theta=-51.36772 -> V=1.0, theta=0.0
% INFO    : Bus 21498	: V=0.9810061, theta=-51.299995 -> V=1.0, theta=0.0
% INFO    : Bus 21499	: V=0.9812874, theta=-51.164344 -> V=1.0, theta=0.0
% INFO    : Bus 21500	: V=0.9785513, theta=-51.855338 -> V=1.0, theta=0.0
% INFO    : Bus 21501	: V=0.9917835, theta=-49.666864 -> V=1.0, theta=0.0
% INFO    : Bus 21502	: V=0.9808343, theta=-51.354293 -> V=1.0, theta=0.0
% INFO    : Bus 21503	: V=0.9789257, theta=-51.528099 -> V=1.0, theta=0.0
% INFO    : Bus 21504	: V=0.9787467, theta=-51.552102 -> V=1.0, theta=0.0
% INFO    : Bus 21505	: V=0.9779279, theta=-51.629419 -> V=1.0, theta=0.0
% INFO    : Bus 21506	: V=0.9715083, theta=-52.493746 -> V=1.0, theta=0.0
% INFO    : Bus 21507	: V=0.9724318, theta=-52.47925 -> V=1.0, theta=0.0
% INFO    : Bus 21508	: V=0.9717133, theta=-52.472509 -> V=1.0, theta=0.0
% INFO    : Bus 21509	: V=0.9715878, theta=-52.437219 -> V=1.0, theta=0.0
% INFO    : Bus 21510	: V=0.9799641, theta=-51.438456 -> V=1.0, theta=0.0
% INFO    : Bus 21511	: V=0.9918831, theta=-49.65389 -> V=1.0, theta=0.0
% INFO    : Bus 21512	: V=0.9822854, theta=-51.164886 -> V=1.0, theta=0.0
% INFO    : Bus 21513	: V=0.9817159, theta=-51.175936 -> V=1.0, theta=0.0
% INFO    : Bus 21514	: V=0.982527, theta=-51.209981 -> V=1.0, theta=0.0
% INFO    : Bus 21515	: V=0.9819481, theta=-51.264177 -> V=1.0, theta=0.0
% INFO    : Bus 21516	: V=0.9815527, theta=-51.298238 -> V=1.0, theta=0.0
% INFO    : Bus 21517	: V=0.9814662, theta=-51.308985 -> V=1.0, theta=0.0
% INFO    : Bus 21518	: V=0.9746518, theta=-52.3943 -> V=1.0, theta=0.0
% INFO    : Bus 21519	: V=0.981643, theta=-51.306681 -> V=1.0, theta=0.0
% INFO    : Bus 21520	: V=0.9815092, theta=-51.310205 -> V=1.0, theta=0.0
% INFO    : Bus 21521	: V=0.991626, theta=-49.768625 -> V=1.0, theta=0.0
% INFO    : Bus 21522	: V=0.9914042, theta=-49.817838 -> V=1.0, theta=0.0
% INFO    : Bus 21523	: V=0.976403, theta=-52.312224 -> V=1.0, theta=0.0
% INFO    : Bus 21524	: V=0.9771355, theta=-52.440044 -> V=1.0, theta=0.0
% INFO    : Bus 21525	: V=0.9919888, theta=-49.699658 -> V=1.0, theta=0.0
% INFO    : Bus 21526	: V=0.9859348, theta=-50.830454 -> V=1.0, theta=0.0
% INFO    : Bus 21527	: V=0.9865255, theta=-50.769291 -> V=1.0, theta=0.0
% INFO    : Bus 21528	: V=0.9819259, theta=-51.472235 -> V=1.0, theta=0.0
% INFO    : Bus 21529	: V=0.9912655, theta=-49.793875 -> V=1.0, theta=0.0
% INFO    : Bus 21530	: V=0.9792282, theta=-51.63583 -> V=1.0, theta=0.0
% INFO    : Bus 21531	: V=0.987401, theta=-50.675223 -> V=1.0, theta=0.0
% INFO    : Bus 21532	: V=0.9788603, theta=-51.696656 -> V=1.0, theta=0.0
% INFO    : Bus 21533	: V=0.9777003, theta=-51.783596 -> V=1.0, theta=0.0
% INFO    : Bus 21534	: V=0.9770807, theta=-51.759435 -> V=1.0, theta=0.0
% INFO    : Bus 21535	: V=0.9746545, theta=-52.555682 -> V=1.0, theta=0.0
% INFO    : Bus 21536	: V=0.9934993, theta=-49.624275 -> V=1.0, theta=0.0
% INFO    : Bus 21537	: V=0.9767917, theta=-51.72222 -> V=1.0, theta=0.0
% INFO    : Bus 21538	: V=0.9934329, theta=-49.448958 -> V=1.0, theta=0.0
% INFO    : Bus 21539	: V=0.988026, theta=-50.61126 -> V=1.0, theta=0.0
% INFO    : Bus 21540	: V=0.9979988, theta=-48.941891 -> V=1.0, theta=0.0
% INFO    : Bus 21541	: V=0.9961683, theta=-49.020682 -> V=1.0, theta=0.0
% INFO    : Bus 21542	: V=0.9774599, theta=-51.680622 -> V=1.0, theta=0.0
% INFO    : Bus 21543	: V=0.9767469, theta=-51.740216 -> V=1.0, theta=0.0
% INFO    : Bus 21544	: V=0.9752833, theta=-51.877717 -> V=1.0, theta=0.0
% INFO    : Bus 21545	: V=0.9751386, theta=-51.843371 -> V=1.0, theta=0.0
% INFO    : Bus 21546	: V=0.9578992, theta=-53.872631 -> V=1.0, theta=0.0
% INFO    : Bus 21547	: V=0.9904972, theta=-49.964339 -> V=1.0, theta=0.0
% INFO    : Bus 21548	: V=0.9550391, theta=-54.022677 -> V=1.0, theta=0.0
% INFO    : Bus 21549	: V=0.9719888, theta=-52.160567 -> V=1.0, theta=0.0
% INFO    : Bus 21550	: V=0.9531841, theta=-54.164073 -> V=1.0, theta=0.0
% INFO    : Bus 21551	: V=0.9515972, theta=-54.2238 -> V=1.0, theta=0.0
% INFO    : Bus 21552	: V=0.9538441, theta=-53.97634 -> V=1.0, theta=0.0
% INFO    : Bus 21553	: V=0.9591782, theta=-53.736515 -> V=1.0, theta=0.0
% INFO    : Bus 21554	: V=0.9614513, theta=-53.636083 -> V=1.0, theta=0.0
% INFO    : Bus 21555	: V=0.975189, theta=-51.789166 -> V=1.0, theta=0.0
% INFO    : Bus 21556	: V=0.9786156, theta=-51.519219 -> V=1.0, theta=0.0
% INFO    : Bus 21557	: V=0.9767832, theta=-51.686083 -> V=1.0, theta=0.0
% INFO    : Bus 21558	: V=0.9909074, theta=-49.892438 -> V=1.0, theta=0.0
% INFO    : Bus 21559	: V=0.9818591, theta=-51.216439 -> V=1.0, theta=0.0
% INFO    : Bus 21560	: V=0.9806057, theta=-51.324062 -> V=1.0, theta=0.0
% INFO    : Bus 21561	: V=0.9919122, theta=-49.775724 -> V=1.0, theta=0.0
% INFO    : Bus 21562	: V=0.966271, theta=-53.267716 -> V=1.0, theta=0.0
% INFO    : Bus 21563	: V=0.9785513, theta=-51.436047 -> V=1.0, theta=0.0
% INFO    : Bus 21564	: V=0.9588492, theta=-53.774997 -> V=1.0, theta=0.0
% INFO    : Bus 21565	: V=0.9885984, theta=-50.185824 -> V=1.0, theta=0.0
% INFO    : Bus 21566	: V=0.9839969, theta=-50.879544 -> V=1.0, theta=0.0
% INFO    : Bus 21567	: V=0.9897429, theta=-50.318083 -> V=1.0, theta=0.0
% INFO    : Bus 21568	: V=0.9880596, theta=-50.431459 -> V=1.0, theta=0.0
% INFO    : Bus 21569	: V=0.9872183, theta=-50.472515 -> V=1.0, theta=0.0
% INFO    : Bus 21570	: V=1.0025115, theta=-48.717665 -> V=1.0, theta=0.0
% INFO    : Bus 21571	: V=0.9851313, theta=-50.914486 -> V=1.0, theta=0.0
% INFO    : Bus 21572	: V=0.9741284, theta=-51.874445 -> V=1.0, theta=0.0
% INFO    : Bus 21573	: V=0.982319, theta=-51.155889 -> V=1.0, theta=0.0
% INFO    : Bus 21574	: V=0.9833984, theta=-51.069522 -> V=1.0, theta=0.0
% INFO    : Bus 21575	: V=0.9755615, theta=-51.837344 -> V=1.0, theta=0.0
% INFO    : Bus 21576	: V=0.9764281, theta=-51.769871 -> V=1.0, theta=0.0
% INFO    : Bus 21577	: V=0.9869461, theta=-50.62623 -> V=1.0, theta=0.0
% INFO    : Bus 21578	: V=0.9859036, theta=-50.693855 -> V=1.0, theta=0.0
% INFO    : Bus 21579	: V=0.9848857, theta=-50.75051 -> V=1.0, theta=0.0
% INFO    : Bus 21580	: V=0.9714309, theta=-52.098598 -> V=1.0, theta=0.0
% INFO    : Bus 21581	: V=0.9705595, theta=-52.120967 -> V=1.0, theta=0.0
% INFO    : Bus 21582	: V=0.981818, theta=-51.018808 -> V=1.0, theta=0.0
% INFO    : Bus 21583	: V=0.9732384, theta=-52.002944 -> V=1.0, theta=0.0
% INFO    : Bus 21584	: V=0.9740875, theta=-51.952568 -> V=1.0, theta=0.0
% INFO    : Bus 21585	: V=0.9744847, theta=-51.908645 -> V=1.0, theta=0.0
% INFO    : Bus 21586	: V=0.9811215, theta=-51.053905 -> V=1.0, theta=0.0
% INFO    : Bus 21587	: V=0.9809142, theta=-51.087808 -> V=1.0, theta=0.0
% INFO    : Bus 21588	: V=0.9803568, theta=-51.128485 -> V=1.0, theta=0.0
% INFO    : Bus 21589	: V=0.9676028, theta=-52.555398 -> V=1.0, theta=0.0
% INFO    : Bus 21590	: V=0.9726742, theta=-52.127128 -> V=1.0, theta=0.0
% INFO    : Bus 21591	: V=0.9950283, theta=-49.470399 -> V=1.0, theta=0.0
% INFO    : Bus 21592	: V=0.9679867, theta=-52.274518 -> V=1.0, theta=0.0
% INFO    : Bus 21593	: V=0.9586372, theta=-53.108145 -> V=1.0, theta=0.0
% INFO    : Bus 21594	: V=0.9732646, theta=-51.681295 -> V=1.0, theta=0.0
% INFO    : Bus 21595	: V=0.9624399, theta=-52.961929 -> V=1.0, theta=0.0
% INFO    : Bus 21596	: V=0.9726778, theta=-52.096667 -> V=1.0, theta=0.0
% INFO    : Bus 21597	: V=0.9744576, theta=-51.596174 -> V=1.0, theta=0.0
% INFO    : Bus 21598	: V=0.9811226, theta=-51.148108 -> V=1.0, theta=0.0
% INFO    : Bus 21599	: V=0.9707554, theta=-52.296351 -> V=1.0, theta=0.0
% INFO    : Bus 21600	: V=0.995369, theta=-49.12044 -> V=1.0, theta=0.0
% INFO    : Bus 21601	: V=0.9876964, theta=-50.121047 -> V=1.0, theta=0.0
% INFO    : Bus 21602	: V=0.9820073, theta=-51.230398 -> V=1.0, theta=0.0
% INFO    : Bus 21603	: V=0.994385, theta=-49.283872 -> V=1.0, theta=0.0
% INFO    : Bus 21604	: V=0.9741372, theta=-54.652679 -> V=1.0, theta=0.0
% INFO    : Bus 21605	: V=0.9640316, theta=-56.790273 -> V=1.0, theta=0.0
% INFO    : Bus 21606	: V=0.9693624, theta=-57.310777 -> V=1.0, theta=0.0
% INFO    : Bus 21607	: V=0.9851291, theta=-56.126247 -> V=1.0, theta=0.0
% INFO    : Bus 21608	: V=0.9944405, theta=-54.463314 -> V=1.0, theta=0.0
% INFO    : Bus 21609	: V=0.9964949, theta=-54.097721 -> V=1.0, theta=0.0
% INFO    : Bus 21610	: V=0.9722019, theta=-57.202601 -> V=1.0, theta=0.0
% INFO    : Bus 21611	: V=0.9734953, theta=-57.568884 -> V=1.0, theta=0.0
% INFO    : Bus 21612	: V=0.9766874, theta=-57.070241 -> V=1.0, theta=0.0
% INFO    : Bus 21613	: V=0.9690162, theta=-57.457758 -> V=1.0, theta=0.0
% INFO    : Bus 21614	: V=0.9400069, theta=-61.9418 -> V=1.0, theta=0.0
% INFO    : Bus 21615	: V=0.9646294, theta=-57.122049 -> V=1.0, theta=0.0
% INFO    : Bus 21616	: V=0.9907013, theta=-45.027315 -> V=1.0, theta=0.0
% INFO    : Bus 21617	: V=0.9976606, theta=-43.787825 -> V=1.0, theta=0.0
% INFO    : Bus 21618	: V=0.9938114, theta=-44.320505 -> V=1.0, theta=0.0
% INFO    : Bus 21619	: V=0.9844605, theta=-54.390635 -> V=1.0, theta=0.0
% INFO    : Bus 21620	: V=0.9861453, theta=-53.69908 -> V=1.0, theta=0.0
% INFO    : Bus 21621	: V=0.9872355, theta=-53.486399 -> V=1.0, theta=0.0
% INFO    : Bus 21622	: V=0.9885978, theta=-54.333469 -> V=1.0, theta=0.0
% INFO    : Bus 21623	: V=0.9884575, theta=-54.447587 -> V=1.0, theta=0.0
% INFO    : Bus 21624	: V=0.9862674, theta=-53.897364 -> V=1.0, theta=0.0
% INFO    : Bus 21625	: V=0.9798159, theta=-54.681493 -> V=1.0, theta=0.0
% INFO    : Bus 21626	: V=0.9808683, theta=-54.348721 -> V=1.0, theta=0.0
% INFO    : Bus 21627	: V=0.9865594, theta=-53.637679 -> V=1.0, theta=0.0
% INFO    : Bus 21628	: V=0.9882477, theta=-53.185689 -> V=1.0, theta=0.0
% INFO    : Bus 21629	: V=0.9641517, theta=-49.126476 -> V=1.0, theta=0.0
% INFO    : Bus 21630	: V=0.9636851, theta=-49.255598 -> V=1.0, theta=0.0
% INFO    : Bus 21631	: V=0.9716047, theta=-48.144165 -> V=1.0, theta=0.0
% INFO    : Bus 21632	: V=0.9656181, theta=-49.056342 -> V=1.0, theta=0.0
% INFO    : Bus 21633	: V=0.9644444, theta=-49.103848 -> V=1.0, theta=0.0
% INFO    : Bus 21634	: V=0.9739884, theta=-48.158939 -> V=1.0, theta=0.0
% INFO    : Bus 21635	: V=0.967843, theta=-48.843977 -> V=1.0, theta=0.0
% INFO    : Bus 21636	: V=0.9754218, theta=-48.082195 -> V=1.0, theta=0.0
% INFO    : Bus 21637	: V=0.9722965, theta=-48.536021 -> V=1.0, theta=0.0
% INFO    : Bus 21638	: V=0.9653635, theta=-49.05693 -> V=1.0, theta=0.0
% INFO    : Bus 21639	: V=0.9642896, theta=-49.07958 -> V=1.0, theta=0.0
% INFO    : Bus 21640	: V=0.9875608, theta=-47.868514 -> V=1.0, theta=0.0
% INFO    : Bus 21641	: V=0.9846135, theta=-48.146665 -> V=1.0, theta=0.0
% INFO    : Bus 21642	: V=0.9659626, theta=-49.244354 -> V=1.0, theta=0.0
% INFO    : Bus 21643	: V=0.9695819, theta=-49.134391 -> V=1.0, theta=0.0
% INFO    : Bus 21644	: V=0.9795274, theta=-48.271807 -> V=1.0, theta=0.0
% INFO    : Bus 21645	: V=0.9787393, theta=-48.232792 -> V=1.0, theta=0.0
% INFO    : Bus 21646	: V=0.9786858, theta=-48.174796 -> V=1.0, theta=0.0
% INFO    : Bus 21647	: V=0.9724234, theta=-48.082742 -> V=1.0, theta=0.0
% INFO    : Bus 21648	: V=0.9737346, theta=-47.963734 -> V=1.0, theta=0.0
% INFO    : Bus 21649	: V=0.9758221, theta=-47.78087 -> V=1.0, theta=0.0
% INFO    : Bus 21650	: V=0.9812884, theta=-47.249801 -> V=1.0, theta=0.0
% INFO    : Bus 21651	: V=1.0053307, theta=-45.362697 -> V=1.0, theta=0.0
% INFO    : Bus 21652	: V=0.9930039, theta=-47.364278 -> V=1.0, theta=0.0
% INFO    : Bus 21653	: V=0.9906942, theta=-47.752007 -> V=1.0, theta=0.0
% INFO    : Bus 21654	: V=0.981629, theta=-48.369591 -> V=1.0, theta=0.0
% INFO    : Bus 21655	: V=0.9910133, theta=-48.372738 -> V=1.0, theta=0.0
% INFO    : Bus 21656	: V=0.9788697, theta=-48.359941 -> V=1.0, theta=0.0
% INFO    : Bus 21657	: V=0.9797276, theta=-47.921995 -> V=1.0, theta=0.0
% INFO    : Bus 21658	: V=0.9813415, theta=-47.602663 -> V=1.0, theta=0.0
% INFO    : Bus 21659	: V=0.9630641, theta=-49.204652 -> V=1.0, theta=0.0
% INFO    : Bus 21660	: V=0.9763668, theta=-50.501176 -> V=1.0, theta=0.0
% INFO    : Bus 21661	: V=0.986855, theta=-48.735676 -> V=1.0, theta=0.0
% INFO    : Bus 21662	: V=0.9901963, theta=-47.754847 -> V=1.0, theta=0.0
% INFO    : Bus 21663	: V=0.9808981, theta=-49.7896 -> V=1.0, theta=0.0
% INFO    : Bus 21664	: V=0.9802098, theta=-49.567857 -> V=1.0, theta=0.0
% INFO    : Bus 21665	: V=0.9808453, theta=-49.751688 -> V=1.0, theta=0.0
% INFO    : Bus 21666	: V=0.9904174, theta=-47.354418 -> V=1.0, theta=0.0
% INFO    : Bus 21667	: V=1.004206, theta=-44.059952 -> V=1.0, theta=0.0
% INFO    : Bus 21668	: V=0.9701486, theta=-50.539441 -> V=1.0, theta=0.0
% INFO    : Bus 21669	: V=0.9839144, theta=-51.146322 -> V=1.0, theta=0.0
% INFO    : Bus 21670	: V=0.9812194, theta=-51.124071 -> V=1.0, theta=0.0
% INFO    : Bus 21671	: V=0.9969216, theta=-49.800758 -> V=1.0, theta=0.0
% INFO    : Bus 21672	: V=0.9962677, theta=-49.798384 -> V=1.0, theta=0.0
% INFO    : Bus 21673	: V=0.9752688, theta=-49.798609 -> V=1.0, theta=0.0
% INFO    : Bus 21674	: V=0.967265, theta=-50.683803 -> V=1.0, theta=0.0
% INFO    : Bus 21675	: V=0.9977227, theta=-49.913154 -> V=1.0, theta=0.0
% INFO    : Bus 21676	: V=0.9930458, theta=-49.711367 -> V=1.0, theta=0.0
% INFO    : Bus 21677	: V=0.9986263, theta=-48.492889 -> V=1.0, theta=0.0
% INFO    : Bus 21678	: V=1.0061608, theta=-48.49183 -> V=1.0, theta=0.0
% INFO    : Bus 21679	: V=1.0026146, theta=-48.519296 -> V=1.0, theta=0.0
% INFO    : Bus 21680	: V=0.9953134, theta=-49.118994 -> V=1.0, theta=0.0
% INFO    : Bus 21681	: V=1.0047345, theta=-47.960327 -> V=1.0, theta=0.0
% INFO    : Bus 21682	: V=0.9937138, theta=-53.819193 -> V=1.0, theta=0.0
% INFO    : Bus 21683	: V=1.0048656, theta=-51.889676 -> V=1.0, theta=0.0
% INFO    : Bus 21684	: V=1.0077548, theta=-50.423638 -> V=1.0, theta=0.0
% INFO    : Bus 21685	: V=1.0186383, theta=-48.43399 -> V=1.0, theta=0.0
% INFO    : Bus 21686	: V=0.9532666, theta=-59.924418 -> V=1.0, theta=0.0
% INFO    : Bus 21687	: V=0.942695, theta=-61.572764 -> V=1.0, theta=0.0
% INFO    : Bus 21688	: V=0.9538634, theta=-59.85199 -> V=1.0, theta=0.0
% INFO    : Bus 21689	: V=0.9390938, theta=-61.600016 -> V=1.0, theta=0.0
% INFO    : Bus 21690	: V=0.9627039, theta=-56.501008 -> V=1.0, theta=0.0
% INFO    : Bus 21691	: V=0.9629818, theta=-56.483734 -> V=1.0, theta=0.0
% INFO    : Bus 21692	: V=0.9452488, theta=-60.547747 -> V=1.0, theta=0.0
% INFO    : Bus 21693	: V=0.9516384, theta=-59.739263 -> V=1.0, theta=0.0
% INFO    : Bus 21694	: V=0.9372014, theta=-62.175179 -> V=1.0, theta=0.0
% INFO    : Bus 21695	: V=0.9493117, theta=-60.354794 -> V=1.0, theta=0.0
% INFO    : Bus 21696	: V=0.9954966, theta=-44.606008 -> V=1.0, theta=0.0
% INFO    : Bus 21697	: V=1.0020704, theta=-44.526569 -> V=1.0, theta=0.0
% INFO    : Bus 21698	: V=0.9816383, theta=-47.505339 -> V=1.0, theta=0.0
% INFO    : Bus 21699	: V=0.9817964, theta=-46.257603 -> V=1.0, theta=0.0
% INFO    : Bus 21700	: V=0.9896244, theta=-45.04154 -> V=1.0, theta=0.0
% INFO    : Bus 21701	: V=0.9912776, theta=-45.248119 -> V=1.0, theta=0.0
% INFO    : Bus 21702	: V=0.9889366, theta=-45.680461 -> V=1.0, theta=0.0
% INFO    : Bus 21703	: V=0.9755, theta=-46.373376 -> V=1.0, theta=0.0
% INFO    : Bus 21704	: V=1.0001642, theta=-47.361825 -> V=1.0, theta=0.0
% INFO    : Bus 21705	: V=0.9898996, theta=-46.591633 -> V=1.0, theta=0.0
% INFO    : Bus 21706	: V=1.0014335, theta=-45.152641 -> V=1.0, theta=0.0
% INFO    : Bus 21707	: V=0.9995007, theta=-46.756059 -> V=1.0, theta=0.0
% INFO    : Bus 21708	: V=1.0082995, theta=-44.625878 -> V=1.0, theta=0.0
% INFO    : Bus 21709	: V=0.9974006, theta=-46.216102 -> V=1.0, theta=0.0
% INFO    : Bus 21710	: V=1.0007497, theta=-45.1786 -> V=1.0, theta=0.0
% INFO    : Bus 21711	: V=0.99836, theta=-45.677362 -> V=1.0, theta=0.0
% INFO    : Bus 21712	: V=0.97502, theta=-47.929396 -> V=1.0, theta=0.0
% INFO    : Bus 21713	: V=0.9893949, theta=-44.225089 -> V=1.0, theta=0.0
% INFO    : Bus 21714	: V=1.017187, theta=-41.888712 -> V=1.0, theta=0.0
% INFO    : Bus 21715	: V=1.0116602, theta=-42.136629 -> V=1.0, theta=0.0
% INFO    : Bus 21716	: V=0.9971114, theta=-43.840599 -> V=1.0, theta=0.0
% INFO    : Bus 21717	: V=0.9977319, theta=-43.877414 -> V=1.0, theta=0.0
% INFO    : Bus 21718	: V=1.006037, theta=-42.1143 -> V=1.0, theta=0.0
% INFO    : Bus 21719	: V=1.0159111, theta=-40.903118 -> V=1.0, theta=0.0
% INFO    : Bus 21720	: V=0.9989603, theta=-41.693621 -> V=1.0, theta=0.0
% INFO    : Bus 21721	: V=0.9991641, theta=-42.013704 -> V=1.0, theta=0.0
% INFO    : Bus 21722	: V=1.0073566, theta=-55.445974 -> V=1.0, theta=0.0
% INFO    : Bus 21723	: V=1.0146842, theta=-54.191992 -> V=1.0, theta=0.0
% INFO    : Bus 21724	: V=1.0103053, theta=-55.078586 -> V=1.0, theta=0.0
% INFO    : Bus 21725	: V=1.0163218, theta=-54.230098 -> V=1.0, theta=0.0
% INFO    : Bus 21726	: V=1.0183345, theta=-54.193403 -> V=1.0, theta=0.0
% INFO    : Bus 21727	: V=1.0029435, theta=-56.109768 -> V=1.0, theta=0.0
% INFO    : Bus 21728	: V=0.9933779, theta=-57.795104 -> V=1.0, theta=0.0
% INFO    : Bus 21729	: V=1.0023539, theta=-56.550458 -> V=1.0, theta=0.0
% INFO    : Bus 21730	: V=0.9821642, theta=-58.200236 -> V=1.0, theta=0.0
% INFO    : Bus 21731	: V=0.9967902, theta=-56.427629 -> V=1.0, theta=0.0
% INFO    : Bus 21732	: V=0.9798462, theta=-58.199572 -> V=1.0, theta=0.0
% INFO    : Bus 21733	: V=0.9818798, theta=-57.971161 -> V=1.0, theta=0.0
% INFO    : Bus 21734	: V=0.999029, theta=-56.320018 -> V=1.0, theta=0.0
% INFO    : Bus 21735	: V=0.9804547, theta=-58.286692 -> V=1.0, theta=0.0
% INFO    : Bus 21736	: V=0.978445, theta=-58.410897 -> V=1.0, theta=0.0
% INFO    : Bus 21737	: V=1.0003533, theta=-55.682448 -> V=1.0, theta=0.0
% INFO    : Bus 21738	: V=0.9776281, theta=-57.790361 -> V=1.0, theta=0.0
% INFO    : Bus 21739	: V=0.97524, theta=-57.36699 -> V=1.0, theta=0.0
% INFO    : Bus 21740	: V=0.9977258, theta=-55.791188 -> V=1.0, theta=0.0
% INFO    : Bus 21741	: V=0.9767877, theta=-57.657642 -> V=1.0, theta=0.0
% INFO    : Bus 21742	: V=0.9759721, theta=-57.66275 -> V=1.0, theta=0.0
% INFO    : Bus 21743	: V=0.9744115, theta=-57.783813 -> V=1.0, theta=0.0
% INFO    : Bus 21744	: V=0.9737221, theta=-57.657028 -> V=1.0, theta=0.0
% INFO    : Bus 21745	: V=0.9981688, theta=-55.64594 -> V=1.0, theta=0.0
% INFO    : Bus 21746	: V=0.9662983, theta=-58.852938 -> V=1.0, theta=0.0
% INFO    : Bus 21747	: V=0.9712674, theta=-58.728354 -> V=1.0, theta=0.0
% INFO    : Bus 21748	: V=0.9730816, theta=-57.111682 -> V=1.0, theta=0.0
% INFO    : Bus 21749	: V=0.9762592, theta=-56.787634 -> V=1.0, theta=0.0
% INFO    : Bus 21750	: V=0.9812908, theta=-56.312835 -> V=1.0, theta=0.0
% INFO    : Bus 21751	: V=1.0162167, theta=-52.354725 -> V=1.0, theta=0.0
% INFO    : Bus 21752	: V=1.0075603, theta=-55.989792 -> V=1.0, theta=0.0
% INFO    : Bus 21753	: V=1.0107706, theta=-55.633615 -> V=1.0, theta=0.0
% INFO    : Bus 21754	: V=0.9669271, theta=-42.75927 -> V=1.0, theta=0.0
% INFO    : Bus 21755	: V=0.9733059, theta=-44.675114 -> V=1.0, theta=0.0
% INFO    : Bus 21756	: V=0.981237, theta=-44.008982 -> V=1.0, theta=0.0
% INFO    : Bus 21757	: V=1.0011687, theta=-42.147066 -> V=1.0, theta=0.0
% INFO    : Bus 21758	: V=1.014928, theta=-40.050459 -> V=1.0, theta=0.0
% INFO    : Bus 21759	: V=0.9882545, theta=-43.815973 -> V=1.0, theta=0.0
% INFO    : Bus 21760	: V=0.989708, theta=-43.575975 -> V=1.0, theta=0.0
% INFO    : Bus 21761	: V=0.9932282, theta=-53.737193 -> V=1.0, theta=0.0
% INFO    : Bus 21762	: V=1.001406, theta=-53.162186 -> V=1.0, theta=0.0
% INFO    : Bus 21763	: V=1.0039916, theta=-52.905477 -> V=1.0, theta=0.0
% INFO    : Bus 21764	: V=1.0044767, theta=-52.268216 -> V=1.0, theta=0.0
% INFO    : Bus 21765	: V=0.96291, theta=-49.911901 -> V=1.0, theta=0.0
% INFO    : Bus 21766	: V=0.9597016, theta=-49.684192 -> V=1.0, theta=0.0
% INFO    : Bus 21767	: V=0.9707359, theta=-48.911393 -> V=1.0, theta=0.0
% INFO    : Bus 21768	: V=0.9702691, theta=-49.134683 -> V=1.0, theta=0.0
% INFO    : Bus 21769	: V=0.9682399, theta=-49.685419 -> V=1.0, theta=0.0
% INFO    : Bus 21770	: V=0.9787793, theta=-48.280281 -> V=1.0, theta=0.0
% INFO    : Bus 21771	: V=0.9767224, theta=-48.046377 -> V=1.0, theta=0.0
% INFO    : Bus 21772	: V=0.9575102, theta=-57.812802 -> V=1.0, theta=0.0
% INFO    : Bus 21773	: V=0.9552833, theta=-58.481782 -> V=1.0, theta=0.0
% INFO    : Bus 21774	: V=0.9594458, theta=-57.625429 -> V=1.0, theta=0.0
% INFO    : Bus 21775	: V=0.9572953, theta=-57.672561 -> V=1.0, theta=0.0
% INFO    : Bus 21776	: V=0.9574972, theta=-57.591797 -> V=1.0, theta=0.0
% INFO    : Bus 21777	: V=0.9604352, theta=-57.357135 -> V=1.0, theta=0.0
% INFO    : Bus 21778	: V=0.9844797, theta=-53.97608 -> V=1.0, theta=0.0
% INFO    : Bus 21779	: V=0.957465, theta=-57.217389 -> V=1.0, theta=0.0
% INFO    : Bus 21780	: V=0.9628812, theta=-48.824282 -> V=1.0, theta=0.0
% INFO    : Bus 21781	: V=0.9637934, theta=-48.74608 -> V=1.0, theta=0.0
% INFO    : Bus 21782	: V=0.9699691, theta=-48.096553 -> V=1.0, theta=0.0
% INFO    : Bus 21783	: V=0.9814585, theta=-46.945392 -> V=1.0, theta=0.0
% INFO    : Bus 21784	: V=0.9812532, theta=-46.655079 -> V=1.0, theta=0.0
% INFO    : Bus 21785	: V=0.9990625, theta=-45.237546 -> V=1.0, theta=0.0
% INFO    : Bus 21786	: V=0.9639954, theta=-52.8105 -> V=1.0, theta=0.0
% INFO    : Bus 21787	: V=0.9527012, theta=-54.868689 -> V=1.0, theta=0.0
% INFO    : Bus 21788	: V=0.9636366, theta=-52.911807 -> V=1.0, theta=0.0
% INFO    : Bus 21789	: V=0.9628207, theta=-52.887174 -> V=1.0, theta=0.0
% INFO    : Bus 21790	: V=0.9676983, theta=-52.622442 -> V=1.0, theta=0.0
% INFO    : Bus 21791	: V=0.9677382, theta=-56.195419 -> V=1.0, theta=0.0
% INFO    : Bus 21792	: V=0.9599423, theta=-57.099967 -> V=1.0, theta=0.0
% INFO    : Bus 21793	: V=0.9586221, theta=-57.146013 -> V=1.0, theta=0.0
% INFO    : Bus 21794	: V=0.9643733, theta=-56.297972 -> V=1.0, theta=0.0
% INFO    : Bus 21795	: V=0.9613186, theta=-57.04019 -> V=1.0, theta=0.0
% INFO    : Bus 21796	: V=0.9658351, theta=-56.295783 -> V=1.0, theta=0.0
% INFO    : Bus 21797	: V=0.9609117, theta=-57.105658 -> V=1.0, theta=0.0
% INFO    : Bus 21798	: V=0.9599703, theta=-57.140717 -> V=1.0, theta=0.0
% INFO    : Bus 21799	: V=0.9583575, theta=-57.284855 -> V=1.0, theta=0.0
% INFO    : Bus 21800	: V=0.9558599, theta=-57.558559 -> V=1.0, theta=0.0
% INFO    : Bus 21801	: V=0.9567259, theta=-57.451495 -> V=1.0, theta=0.0
% INFO    : Bus 21802	: V=0.9531975, theta=-57.802551 -> V=1.0, theta=0.0
% INFO    : Bus 21803	: V=0.9547249, theta=-57.68906 -> V=1.0, theta=0.0
% INFO    : Bus 21804	: V=0.954213, theta=-57.736745 -> V=1.0, theta=0.0
% INFO    : Bus 21805	: V=0.9554098, theta=-57.717001 -> V=1.0, theta=0.0
% INFO    : Bus 21806	: V=0.9564021, theta=-57.658185 -> V=1.0, theta=0.0
% INFO    : Bus 21807	: V=0.9551189, theta=-57.637881 -> V=1.0, theta=0.0
% INFO    : Bus 21808	: V=0.9669396, theta=-56.201931 -> V=1.0, theta=0.0
% INFO    : Bus 21809	: V=0.961847, theta=-57.057557 -> V=1.0, theta=0.0
% INFO    : Bus 21810	: V=0.9628903, theta=-56.96717 -> V=1.0, theta=0.0
% INFO    : Bus 21811	: V=0.9664493, theta=-56.272396 -> V=1.0, theta=0.0
% INFO    : Bus 21812	: V=0.9674181, theta=-56.214413 -> V=1.0, theta=0.0
% INFO    : Bus 21813	: V=0.9682865, theta=-56.152527 -> V=1.0, theta=0.0
% INFO    : Bus 21814	: V=0.9678784, theta=-56.585984 -> V=1.0, theta=0.0
% INFO    : Bus 21815	: V=0.9700837, theta=-56.007706 -> V=1.0, theta=0.0
% INFO    : Bus 21816	: V=0.9710163, theta=-56.001409 -> V=1.0, theta=0.0
% INFO    : Bus 21817	: V=0.9807656, theta=-53.903356 -> V=1.0, theta=0.0
% INFO    : Bus 21818	: V=0.9699836, theta=-56.126954 -> V=1.0, theta=0.0
% INFO    : Bus 21819	: V=0.9665252, theta=-56.230487 -> V=1.0, theta=0.0
% INFO    : Bus 21820	: V=0.9573882, theta=-57.588697 -> V=1.0, theta=0.0
% INFO    : Bus 21821	: V=0.9570698, theta=-57.602627 -> V=1.0, theta=0.0
% INFO    : Bus 21822	: V=0.9582649, theta=-57.489953 -> V=1.0, theta=0.0
% INFO    : Bus 21823	: V=0.956841, theta=-57.603721 -> V=1.0, theta=0.0
% INFO    : Bus 21824	: V=0.9666213, theta=-56.453623 -> V=1.0, theta=0.0
% INFO    : Bus 21825	: V=0.9621382, theta=-56.949068 -> V=1.0, theta=0.0
% INFO    : Bus 21826	: V=0.9653213, theta=-56.035499 -> V=1.0, theta=0.0
% INFO    : Bus 21827	: V=0.9651529, theta=-55.915402 -> V=1.0, theta=0.0
% INFO    : Bus 21828	: V=0.965806, theta=-55.771225 -> V=1.0, theta=0.0
% INFO    : Bus 21829	: V=0.9773138, theta=-53.786146 -> V=1.0, theta=0.0
% INFO    : Bus 21830	: V=0.9605315, theta=-56.985001 -> V=1.0, theta=0.0
% INFO    : Bus 21831	: V=0.9542705, theta=-57.996996 -> V=1.0, theta=0.0
% INFO    : Bus 21832	: V=0.9633421, theta=-56.563296 -> V=1.0, theta=0.0
% INFO    : Bus 21833	: V=0.9935451, theta=-53.764742 -> V=1.0, theta=0.0
% INFO    : Bus 21834	: V=0.989148, theta=-53.482672 -> V=1.0, theta=0.0
% INFO    : Bus 21835	: V=0.9636387, theta=-56.246591 -> V=1.0, theta=0.0
% INFO    : Bus 21836	: V=0.9726913, theta=-55.785877 -> V=1.0, theta=0.0
% INFO    : Bus 21837	: V=0.9563091, theta=-57.366371 -> V=1.0, theta=0.0
% INFO    : Bus 21838	: V=0.9552763, theta=-57.439488 -> V=1.0, theta=0.0
% INFO    : Bus 21839	: V=0.9512448, theta=-57.733108 -> V=1.0, theta=0.0
% INFO    : Bus 21840	: V=0.9609258, theta=-56.472786 -> V=1.0, theta=0.0
% INFO    : Bus 21841	: V=0.961584, theta=-56.423383 -> V=1.0, theta=0.0
% INFO    : Bus 21842	: V=0.9549888, theta=-57.125314 -> V=1.0, theta=0.0
% INFO    : Bus 21843	: V=0.9531406, theta=-57.393182 -> V=1.0, theta=0.0
% INFO    : Bus 21844	: V=0.9562737, theta=-57.079875 -> V=1.0, theta=0.0
% INFO    : Bus 21845	: V=0.9632152, theta=-55.416191 -> V=1.0, theta=0.0
% INFO    : Bus 21846	: V=0.9624638, theta=-55.48263 -> V=1.0, theta=0.0
% INFO    : Bus 21847	: V=0.9603977, theta=-55.703096 -> V=1.0, theta=0.0
% INFO    : Bus 21848	: V=0.9620068, theta=-55.533124 -> V=1.0, theta=0.0
% INFO    : Bus 21849	: V=0.9519675, theta=-57.895934 -> V=1.0, theta=0.0
% INFO    : Bus 21850	: V=0.9669913, theta=-55.381776 -> V=1.0, theta=0.0
% INFO    : Bus 21851	: V=0.9515295, theta=-57.618092 -> V=1.0, theta=0.0
% INFO    : Bus 21852	: V=0.948955, theta=-57.817682 -> V=1.0, theta=0.0
% INFO    : Bus 21853	: V=0.9504224, theta=-58.065639 -> V=1.0, theta=0.0
% INFO    : Bus 21854	: V=0.9500146, theta=-57.650355 -> V=1.0, theta=0.0
% INFO    : Bus 21855	: V=0.9764452, theta=-53.858523 -> V=1.0, theta=0.0
% INFO    : Bus 21856	: V=0.9768456, theta=-53.699943 -> V=1.0, theta=0.0
% INFO    : Bus 21857	: V=0.9654057, theta=-56.759038 -> V=1.0, theta=0.0
% INFO    : Bus 21858	: V=0.9679367, theta=-56.487304 -> V=1.0, theta=0.0
% INFO    : Bus 21859	: V=0.9666798, theta=-56.627517 -> V=1.0, theta=0.0
% INFO    : Bus 21860	: V=0.9713654, theta=-56.324846 -> V=1.0, theta=0.0
% INFO    : Bus 21861	: V=0.975154, theta=-56.211215 -> V=1.0, theta=0.0
% INFO    : Bus 21862	: V=1.0028453, theta=-54.371081 -> V=1.0, theta=0.0
% INFO    : Bus 21863	: V=1.0028576, theta=-54.351201 -> V=1.0, theta=0.0
% INFO    : Bus 21864	: V=0.9782271, theta=-55.978972 -> V=1.0, theta=0.0
% INFO    : Bus 21865	: V=0.9651792, theta=-56.247408 -> V=1.0, theta=0.0
% INFO    : Bus 21866	: V=0.9713531, theta=-47.78263 -> V=1.0, theta=0.0
% INFO    : Bus 21867	: V=0.9815818, theta=-46.607747 -> V=1.0, theta=0.0
% INFO    : Bus 21868	: V=0.9835392, theta=-46.613692 -> V=1.0, theta=0.0
% INFO    : Bus 21869	: V=0.9846778, theta=-46.381843 -> V=1.0, theta=0.0
% INFO    : Bus 21870	: V=0.9958968, theta=-45.352827 -> V=1.0, theta=0.0
% INFO    : Bus 21871	: V=0.9669948, theta=-53.354745 -> V=1.0, theta=0.0
% INFO    : Bus 21872	: V=0.9558988, theta=-54.271495 -> V=1.0, theta=0.0
% INFO    : Bus 21873	: V=0.9806166, theta=-51.141476 -> V=1.0, theta=0.0
% INFO    : Bus 21874	: V=0.9744921, theta=-51.955195 -> V=1.0, theta=0.0
% INFO    : Bus 21875	: V=0.9814833, theta=-50.823912 -> V=1.0, theta=0.0
% INFO    : Bus 21876	: V=0.9749971, theta=-51.976266 -> V=1.0, theta=0.0
% INFO    : Bus 21877	: V=0.975141, theta=-51.952055 -> V=1.0, theta=0.0
% INFO    : Bus 21878	: V=0.9821335, theta=-50.631151 -> V=1.0, theta=0.0
% INFO    : Bus 21879	: V=0.9834958, theta=-50.31781 -> V=1.0, theta=0.0
% INFO    : Bus 21880	: V=0.983847, theta=-49.824401 -> V=1.0, theta=0.0
% INFO    : Bus 21881	: V=1.010829, theta=-41.882699 -> V=1.0, theta=0.0
% INFO    : Bus 21882	: V=1.0141582, theta=-41.317869 -> V=1.0, theta=0.0
% INFO    : Bus 21883	: V=1.0137591, theta=-41.235156 -> V=1.0, theta=0.0
% INFO    : Bus 21884	: V=1.0015387, theta=-41.912385 -> V=1.0, theta=0.0
% INFO    : Bus 21885	: V=1.0117673, theta=-40.822833 -> V=1.0, theta=0.0
% INFO    : Bus 21886	: V=0.9961117, theta=-54.503952 -> V=1.0, theta=0.0
% INFO    : Bus 21887	: V=0.9974948, theta=-54.246853 -> V=1.0, theta=0.0
% INFO    : Bus 21888	: V=0.9965049, theta=-54.249295 -> V=1.0, theta=0.0
% INFO    : Bus 21889	: V=1.0037353, theta=-53.36337 -> V=1.0, theta=0.0
% INFO    : Bus 21890	: V=0.999354, theta=-53.938238 -> V=1.0, theta=0.0
% INFO    : Bus 21891	: V=1.003312, theta=-53.431482 -> V=1.0, theta=0.0
% INFO    : Bus 21892	: V=1.0045017, theta=-53.610663 -> V=1.0, theta=0.0
% INFO    : Bus 21893	: V=0.9480478, theta=-59.636548 -> V=1.0, theta=0.0
% INFO    : Bus 21894	: V=0.9462973, theta=-59.672126 -> V=1.0, theta=0.0
% INFO    : Bus 21895	: V=0.9344702, theta=-61.075137 -> V=1.0, theta=0.0
% INFO    : Bus 21896	: V=0.9417201, theta=-60.388669 -> V=1.0, theta=0.0
% INFO    : Bus 21897	: V=0.9503067, theta=-59.600463 -> V=1.0, theta=0.0
% INFO    : Bus 21898	: V=0.9447497, theta=-60.313277 -> V=1.0, theta=0.0
% INFO    : Bus 21899	: V=0.9393988, theta=-61.17116 -> V=1.0, theta=0.0
% INFO    : Bus 21900	: V=0.93883, theta=-61.136666 -> V=1.0, theta=0.0
% INFO    : Bus 21901	: V=0.9429679, theta=-61.330531 -> V=1.0, theta=0.0
% INFO    : Bus 21902	: V=1.0090187, theta=-42.879393 -> V=1.0, theta=0.0
% INFO    : Bus 21903	: V=1.0145941, theta=-41.942992 -> V=1.0, theta=0.0
% INFO    : Bus 21904	: V=1.0135006, theta=-42.085176 -> V=1.0, theta=0.0
% INFO    : Bus 21905	: V=1.0045548, theta=-43.19093 -> V=1.0, theta=0.0
% INFO    : Bus 21906	: V=1.0143141, theta=-42.18731 -> V=1.0, theta=0.0
% INFO    : Bus 21907	: V=1.015861, theta=-42.052791 -> V=1.0, theta=0.0
% INFO    : Bus 21908	: V=0.9874196, theta=-44.214215 -> V=1.0, theta=0.0
% INFO    : Bus 21909	: V=0.998272, theta=-43.964687 -> V=1.0, theta=0.0
% INFO    : Bus 21910	: V=0.9876431, theta=-51.174609 -> V=1.0, theta=0.0
% INFO    : Bus 21911	: V=0.9867848, theta=-51.220926 -> V=1.0, theta=0.0
% INFO    : Bus 21912	: V=0.9900637, theta=-50.65762 -> V=1.0, theta=0.0
% INFO    : Bus 21913	: V=0.9907226, theta=-50.618887 -> V=1.0, theta=0.0
% INFO    : Bus 21914	: V=0.9892362, theta=-50.704362 -> V=1.0, theta=0.0
% INFO    : Bus 21915	: V=0.9887276, theta=-50.70327 -> V=1.0, theta=0.0
% INFO    : Bus 21916	: V=0.984931, theta=-51.32324 -> V=1.0, theta=0.0
% INFO    : Bus 21917	: V=0.9851682, theta=-51.319257 -> V=1.0, theta=0.0
% INFO    : Bus 21918	: V=0.9839881, theta=-51.396346 -> V=1.0, theta=0.0
% INFO    : Bus 21919	: V=0.9902671, theta=-50.510301 -> V=1.0, theta=0.0
% INFO    : Bus 21920	: V=0.9902005, theta=-50.484176 -> V=1.0, theta=0.0
% INFO    : Bus 21921	: V=0.9885505, theta=-51.053189 -> V=1.0, theta=0.0
% INFO    : Bus 21922	: V=0.9902478, theta=-50.439672 -> V=1.0, theta=0.0
% INFO    : Bus 21923	: V=0.9903956, theta=-50.329332 -> V=1.0, theta=0.0
% INFO    : Bus 21924	: V=0.9988304, theta=-48.990325 -> V=1.0, theta=0.0
% INFO    : Bus 21925	: V=0.989037, theta=-50.723629 -> V=1.0, theta=0.0
% INFO    : Bus 21926	: V=0.9994694, theta=-49.257616 -> V=1.0, theta=0.0
% INFO    : Bus 21927	: V=0.9943683, theta=-50.659555 -> V=1.0, theta=0.0
% INFO    : Bus 21928	: V=0.9935818, theta=-50.663306 -> V=1.0, theta=0.0
% INFO    : Bus 21929	: V=0.9925136, theta=-50.652735 -> V=1.0, theta=0.0
% INFO    : Bus 21930	: V=0.9892, theta=-51.112625 -> V=1.0, theta=0.0
% INFO    : Bus 21931	: V=0.9916458, theta=-50.628533 -> V=1.0, theta=0.0
% INFO    : Bus 21932	: V=0.9902954, theta=-51.088702 -> V=1.0, theta=0.0
% INFO    : Bus 21933	: V=0.9977493, theta=-49.855225 -> V=1.0, theta=0.0
% INFO    : Bus 21934	: V=0.995801, theta=-50.941098 -> V=1.0, theta=0.0
% INFO    : Bus 21935	: V=0.987199, theta=-51.300787 -> V=1.0, theta=0.0
% INFO    : Bus 21936	: V=0.9967353, theta=-50.588381 -> V=1.0, theta=0.0
% INFO    : Bus 21937	: V=0.987609, theta=-51.238104 -> V=1.0, theta=0.0
% INFO    : Bus 21938	: V=0.9880994, theta=-51.204652 -> V=1.0, theta=0.0
% INFO    : Bus 21939	: V=0.9876898, theta=-51.210015 -> V=1.0, theta=0.0
% INFO    : Bus 21940	: V=1.0016705, theta=-47.130395 -> V=1.0, theta=0.0
% INFO    : Bus 21941	: V=0.9865395, theta=-50.436035 -> V=1.0, theta=0.0
% INFO    : Bus 21942	: V=0.9994175, theta=-49.267539 -> V=1.0, theta=0.0
% INFO    : Bus 21943	: V=0.9826347, theta=-51.250792 -> V=1.0, theta=0.0
% INFO    : Bus 21944	: V=0.9722499, theta=-52.636712 -> V=1.0, theta=0.0
% INFO    : Bus 21945	: V=0.9859309, theta=-49.835742 -> V=1.0, theta=0.0
% INFO    : Bus 21946	: V=0.9910418, theta=-50.51502 -> V=1.0, theta=0.0
% INFO    : Bus 21947	: V=0.9735964, theta=-55.354461 -> V=1.0, theta=0.0
% INFO    : Bus 21948	: V=0.9782932, theta=-53.842682 -> V=1.0, theta=0.0
% INFO    : Bus 21949	: V=0.9796356, theta=-53.300429 -> V=1.0, theta=0.0
% INFO    : Bus 21950	: V=0.9904094, theta=-52.107126 -> V=1.0, theta=0.0
% INFO    : Bus 21951	: V=0.9554622, theta=-53.174268 -> V=1.0, theta=0.0
% INFO    : Bus 21952	: V=0.955604, theta=-51.993225 -> V=1.0, theta=0.0
% INFO    : Bus 21953	: V=0.9877794, theta=-43.779765 -> V=1.0, theta=0.0
% INFO    : Bus 21954	: V=1.0000905, theta=-42.373084 -> V=1.0, theta=0.0
% INFO    : Bus 21955	: V=1.0010805, theta=-42.185311 -> V=1.0, theta=0.0
% INFO    : Bus 21956	: V=1.0013786, theta=-42.167252 -> V=1.0, theta=0.0
% INFO    : Bus 21957	: V=0.9892106, theta=-43.440508 -> V=1.0, theta=0.0
% INFO    : Bus 21958	: V=0.9929293, theta=-42.242649 -> V=1.0, theta=0.0
% INFO    : Bus 21959	: V=0.9884734, theta=-43.367532 -> V=1.0, theta=0.0
% INFO    : Bus 21960	: V=0.9880971, theta=-43.374308 -> V=1.0, theta=0.0
% INFO    : Bus 21961	: V=0.9871202, theta=-43.435815 -> V=1.0, theta=0.0
% INFO    : Bus 21962	: V=0.9879599, theta=-43.356699 -> V=1.0, theta=0.0
% INFO    : Bus 21963	: V=0.9902369, theta=-43.271664 -> V=1.0, theta=0.0
% INFO    : Bus 21964	: V=0.9912661, theta=-43.710531 -> V=1.0, theta=0.0
% INFO    : Bus 21965	: V=0.9903014, theta=-43.71873 -> V=1.0, theta=0.0
% INFO    : Bus 21966	: V=0.9897443, theta=-43.732773 -> V=1.0, theta=0.0
% INFO    : Bus 21967	: V=0.9898568, theta=-43.729033 -> V=1.0, theta=0.0
% INFO    : Bus 21968	: V=0.9926204, theta=-43.690363 -> V=1.0, theta=0.0
% INFO    : Bus 21969	: V=0.9941027, theta=-43.599974 -> V=1.0, theta=0.0
% INFO    : Bus 21970	: V=1.0158082, theta=-40.061615 -> V=1.0, theta=0.0
% INFO    : Bus 21971	: V=0.9927948, theta=-43.636485 -> V=1.0, theta=0.0
% INFO    : Bus 21972	: V=1.0024798, theta=-42.108628 -> V=1.0, theta=0.0
% INFO    : Bus 21973	: V=0.9883814, theta=-43.865469 -> V=1.0, theta=0.0
% INFO    : Bus 21974	: V=0.9890728, theta=-43.791535 -> V=1.0, theta=0.0
% INFO    : Bus 21975	: V=0.9906684, theta=-43.748987 -> V=1.0, theta=0.0
% INFO    : Bus 21976	: V=1.0052008, theta=-41.91438 -> V=1.0, theta=0.0
% INFO    : Bus 21977	: V=1.0062766, theta=-41.866724 -> V=1.0, theta=0.0
% INFO    : Bus 21978	: V=1.0092695, theta=-41.66363 -> V=1.0, theta=0.0
% INFO    : Bus 21979	: V=0.9918926, theta=-43.633683 -> V=1.0, theta=0.0
% INFO    : Bus 21980	: V=1.0103117, theta=-41.545979 -> V=1.0, theta=0.0
% INFO    : Bus 21981	: V=1.010214, theta=-41.537024 -> V=1.0, theta=0.0
% INFO    : Bus 21982	: V=0.9876845, theta=-43.898468 -> V=1.0, theta=0.0
% INFO    : Bus 21983	: V=0.9853292, theta=-43.938524 -> V=1.0, theta=0.0
% INFO    : Bus 21984	: V=0.9891082, theta=-43.767195 -> V=1.0, theta=0.0
% INFO    : Bus 21985	: V=0.9857935, theta=-43.454372 -> V=1.0, theta=0.0
% INFO    : Bus 21986	: V=0.9893165, theta=-43.384506 -> V=1.0, theta=0.0
% INFO    : Bus 21987	: V=0.9933523, theta=-42.197925 -> V=1.0, theta=0.0
% INFO    : Bus 21988	: V=0.9943368, theta=-42.10785 -> V=1.0, theta=0.0
% INFO    : Bus 21989	: V=0.9956255, theta=-41.997944 -> V=1.0, theta=0.0
% INFO    : Bus 21990	: V=0.987884, theta=-43.369433 -> V=1.0, theta=0.0
% INFO    : Bus 21991	: V=0.9861028, theta=-43.932488 -> V=1.0, theta=0.0
% INFO    : Bus 21992	: V=1.0163919, theta=-39.938788 -> V=1.0, theta=0.0
% INFO    : Bus 21993	: V=0.9797667, theta=-44.424875 -> V=1.0, theta=0.0
% INFO    : Bus 21994	: V=0.9969807, theta=-42.681482 -> V=1.0, theta=0.0
% INFO    : Bus 21995	: V=1.0159, theta=-39.683206 -> V=1.0, theta=0.0
% INFO    : Bus 21996	: V=1.0000821, theta=-42.39645 -> V=1.0, theta=0.0
% INFO    : Bus 21997	: V=1.0176433, theta=-39.791894 -> V=1.0, theta=0.0
% INFO    : Bus 21998	: V=0.9911742, theta=-43.628541 -> V=1.0, theta=0.0
% INFO    : Bus 21999	: V=0.986695, theta=-43.690404 -> V=1.0, theta=0.0
% INFO    : Bus 22000	: V=0.9863427, theta=-43.637558 -> V=1.0, theta=0.0
% INFO    : Bus 22001	: V=0.9848884, theta=-43.470236 -> V=1.0, theta=0.0
% INFO    : Bus 22002	: V=1.0121157, theta=-43.920987 -> V=1.0, theta=0.0
% INFO    : Bus 22003	: V=1.0139894, theta=-43.110248 -> V=1.0, theta=0.0
% INFO    : Bus 22004	: V=1.011088, theta=-43.673362 -> V=1.0, theta=0.0
% INFO    : Bus 22005	: V=1.0118003, theta=-43.650909 -> V=1.0, theta=0.0
% INFO    : Bus 22006	: V=1.0051909, theta=-44.600475 -> V=1.0, theta=0.0
% INFO    : Bus 22007	: V=1.0020676, theta=-44.702408 -> V=1.0, theta=0.0
% INFO    : Bus 22008	: V=1.0106844, theta=-43.777093 -> V=1.0, theta=0.0
% INFO    : Bus 22009	: V=1.0105946, theta=-43.78342 -> V=1.0, theta=0.0
% INFO    : Bus 22010	: V=1.0105123, theta=-43.788372 -> V=1.0, theta=0.0
% INFO    : Bus 22011	: V=1.0104806, theta=-43.787429 -> V=1.0, theta=0.0
% INFO    : Bus 22012	: V=1.0123242, theta=-43.608228 -> V=1.0, theta=0.0
% INFO    : Bus 22013	: V=1.0133191, theta=-43.539066 -> V=1.0, theta=0.0
% INFO    : Bus 22014	: V=1.0117993, theta=-43.674736 -> V=1.0, theta=0.0
% INFO    : Bus 22015	: V=1.0100808, theta=-43.833742 -> V=1.0, theta=0.0
% INFO    : Bus 22016	: V=1.0100733, theta=-43.87884 -> V=1.0, theta=0.0
% INFO    : Bus 22017	: V=1.0085757, theta=-43.857036 -> V=1.0, theta=0.0
% INFO    : Bus 22018	: V=1.0064146, theta=-44.459001 -> V=1.0, theta=0.0
% INFO    : Bus 22019	: V=1.0077764, theta=-43.854711 -> V=1.0, theta=0.0
% INFO    : Bus 22020	: V=1.0182146, theta=-42.516282 -> V=1.0, theta=0.0
% INFO    : Bus 22021	: V=1.0107462, theta=-43.735393 -> V=1.0, theta=0.0
% INFO    : Bus 22022	: V=1.0112446, theta=-43.666335 -> V=1.0, theta=0.0
% INFO    : Bus 22023	: V=0.9919556, theta=-45.594287 -> V=1.0, theta=0.0
% INFO    : Bus 22024	: V=1.0093524, theta=-43.983316 -> V=1.0, theta=0.0
% INFO    : Bus 22025	: V=0.9958422, theta=-45.376467 -> V=1.0, theta=0.0
% INFO    : Bus 22026	: V=1.0137632, theta=-43.492498 -> V=1.0, theta=0.0
% INFO    : Bus 22027	: V=1.01391, theta=-43.205611 -> V=1.0, theta=0.0
% INFO    : Bus 22028	: V=1.0123244, theta=-43.486828 -> V=1.0, theta=0.0
% INFO    : Bus 22029	: V=0.999293, theta=-45.325515 -> V=1.0, theta=0.0
% INFO    : Bus 22030	: V=1.0065344, theta=-43.810075 -> V=1.0, theta=0.0
% INFO    : Bus 22031	: V=1.0056913, theta=-43.607265 -> V=1.0, theta=0.0
% INFO    : Bus 22032	: V=1.0191834, theta=-42.022022 -> V=1.0, theta=0.0
% INFO    : Bus 22033	: V=1.0115316, theta=-43.642275 -> V=1.0, theta=0.0
% INFO    : Bus 22034	: V=1.0189642, theta=-42.367706 -> V=1.0, theta=0.0
% INFO    : Bus 22035	: V=0.9772201, theta=-55.182856 -> V=1.0, theta=0.0
% INFO    : Bus 22036	: V=0.9771591, theta=-55.202758 -> V=1.0, theta=0.0
% INFO    : Bus 22037	: V=0.9814742, theta=-54.66524 -> V=1.0, theta=0.0
% INFO    : Bus 22038	: V=0.9762478, theta=-55.72466 -> V=1.0, theta=0.0
% INFO    : Bus 22039	: V=0.9797071, theta=-55.161833 -> V=1.0, theta=0.0
% INFO    : Bus 22040	: V=0.9830488, theta=-55.030963 -> V=1.0, theta=0.0
% INFO    : Bus 22041	: V=0.9803123, theta=-55.075504 -> V=1.0, theta=0.0
% INFO    : Bus 22042	: V=0.9796335, theta=-55.092796 -> V=1.0, theta=0.0
% INFO    : Bus 22043	: V=1.0085113, theta=-47.346086 -> V=1.0, theta=0.0
% INFO    : Bus 22044	: V=0.9743252, theta=-48.435071 -> V=1.0, theta=0.0
% INFO    : Bus 22045	: V=0.998707, theta=-42.509176 -> V=1.0, theta=0.0
% INFO    : Bus 22046	: V=1.0028157, theta=-41.584502 -> V=1.0, theta=0.0
% INFO    : Bus 22047	: V=0.9773649, theta=-44.236203 -> V=1.0, theta=0.0
% INFO    : Bus 22048	: V=0.9823621, theta=-43.631262 -> V=1.0, theta=0.0
% INFO    : Bus 22049	: V=1.006864, theta=-41.033018 -> V=1.0, theta=0.0
% INFO    : Bus 22050	: V=1.0053862, theta=-41.237388 -> V=1.0, theta=0.0
% INFO    : Bus 22051	: V=0.9981619, theta=-41.796241 -> V=1.0, theta=0.0
% INFO    : Bus 22052	: V=1.0031957, theta=-41.368005 -> V=1.0, theta=0.0
% INFO    : Bus 22053	: V=1.0073156, theta=-41.013943 -> V=1.0, theta=0.0
% INFO    : Bus 22054	: V=0.987194, theta=-43.530456 -> V=1.0, theta=0.0
% INFO    : Bus 22055	: V=1.0006499, theta=-41.595609 -> V=1.0, theta=0.0
% INFO    : Bus 22056	: V=0.9835607, theta=-46.831559 -> V=1.0, theta=0.0
% INFO    : Bus 22057	: V=0.9807406, theta=-47.618689 -> V=1.0, theta=0.0
% INFO    : Bus 22058	: V=0.9900115, theta=-46.047633 -> V=1.0, theta=0.0
% INFO    : Bus 22059	: V=0.9853157, theta=-46.854218 -> V=1.0, theta=0.0
% INFO    : Bus 22060	: V=0.9844725, theta=-46.923006 -> V=1.0, theta=0.0
% INFO    : Bus 22061	: V=0.9974121, theta=-45.449038 -> V=1.0, theta=0.0
% INFO    : Bus 22062	: V=0.9852145, theta=-52.854508 -> V=1.0, theta=0.0
% INFO    : Bus 22063	: V=0.9725921, theta=-54.295759 -> V=1.0, theta=0.0
% INFO    : Bus 22064	: V=0.9740373, theta=-54.179013 -> V=1.0, theta=0.0
% INFO    : Bus 22065	: V=0.9889595, theta=-52.155373 -> V=1.0, theta=0.0
% INFO    : Bus 22066	: V=0.987588, theta=-52.559724 -> V=1.0, theta=0.0
% INFO    : Bus 22067	: V=0.9870228, theta=-52.749732 -> V=1.0, theta=0.0
% INFO    : Bus 22068	: V=0.9870811, theta=-52.708862 -> V=1.0, theta=0.0
% INFO    : Bus 22069	: V=0.9743712, theta=-54.089174 -> V=1.0, theta=0.0
% INFO    : Bus 22070	: V=0.9847496, theta=-52.84708 -> V=1.0, theta=0.0
% INFO    : Bus 22071	: V=0.9858187, theta=-53.066663 -> V=1.0, theta=0.0
% INFO    : Bus 22072	: V=0.9851995, theta=-53.402349 -> V=1.0, theta=0.0
% INFO    : Bus 22073	: V=0.9418455, theta=-57.837742 -> V=1.0, theta=0.0
% INFO    : Bus 22074	: V=0.941638, theta=-57.127346 -> V=1.0, theta=0.0
% INFO    : Bus 22075	: V=0.969946, theta=-54.191825 -> V=1.0, theta=0.0
% INFO    : Bus 22076	: V=0.958113, theta=-55.435366 -> V=1.0, theta=0.0
% INFO    : Bus 22077	: V=0.9905604, theta=-51.641694 -> V=1.0, theta=0.0
% INFO    : Bus 22078	: V=0.9891478, theta=-52.0412 -> V=1.0, theta=0.0
% INFO    : Bus 22079	: V=0.9419694, theta=-62.490635 -> V=1.0, theta=0.0
% INFO    : Bus 22080	: V=0.9641894, theta=-59.318157 -> V=1.0, theta=0.0
% INFO    : Bus 22081	: V=0.9711465, theta=-58.568985 -> V=1.0, theta=0.0
% INFO    : Bus 22082	: V=0.9711701, theta=-58.583041 -> V=1.0, theta=0.0
% INFO    : Bus 22083	: V=0.9725174, theta=-58.44052 -> V=1.0, theta=0.0
% INFO    : Bus 22084	: V=0.980487, theta=-57.384463 -> V=1.0, theta=0.0
% INFO    : Bus 22085	: V=0.9727608, theta=-58.077474 -> V=1.0, theta=0.0
% INFO    : Bus 22086	: V=0.9997173, theta=-52.777757 -> V=1.0, theta=0.0
% INFO    : Bus 22087	: V=1.0069784, theta=-51.391334 -> V=1.0, theta=0.0
% INFO    : Bus 22088	: V=1.0162925, theta=-49.622548 -> V=1.0, theta=0.0
% INFO    : Bus 22089	: V=1.0028823, theta=-51.962715 -> V=1.0, theta=0.0
% INFO    : Bus 22090	: V=1.0017039, theta=-52.343359 -> V=1.0, theta=0.0
% INFO    : Bus 22091	: V=1.0051627, theta=-52.018077 -> V=1.0, theta=0.0
% INFO    : Bus 22092	: V=1.0017499, theta=-52.444578 -> V=1.0, theta=0.0
% INFO    : Bus 22093	: V=0.9988553, theta=-51.543387 -> V=1.0, theta=0.0
% INFO    : Bus 22094	: V=0.9478591, theta=-60.856775 -> V=1.0, theta=0.0
% INFO    : Bus 22095	: V=0.9453693, theta=-61.896084 -> V=1.0, theta=0.0
% INFO    : Bus 22096	: V=0.9576776, theta=-58.966301 -> V=1.0, theta=0.0
% INFO    : Bus 22097	: V=0.9482692, theta=-60.775698 -> V=1.0, theta=0.0
% INFO    : Bus 22098	: V=0.951079, theta=-60.289763 -> V=1.0, theta=0.0
% INFO    : Bus 22099	: V=0.9458404, theta=-61.135601 -> V=1.0, theta=0.0
% INFO    : Bus 22100	: V=0.9424229, theta=-62.429473 -> V=1.0, theta=0.0
% INFO    : Bus 22101	: V=0.989879, theta=-33.432118 -> V=1.0, theta=0.0
% INFO    : Bus 22102	: V=0.9856855, theta=-33.707478 -> V=1.0, theta=0.0
% INFO    : Bus 22103	: V=0.9747008, theta=-33.960556 -> V=1.0, theta=0.0
% INFO    : Bus 22104	: V=0.9743861, theta=-33.610288 -> V=1.0, theta=0.0
% INFO    : Bus 22105	: V=0.9730249, theta=-34.273508 -> V=1.0, theta=0.0
% INFO    : Bus 22106	: V=1.05, theta=-30.743691 -> V=1.0, theta=0.0
% INFO    : Bus 22107	: V=0.9961911, theta=-32.01532 -> V=1.0, theta=0.0
% INFO    : Bus 22108	: V=1.0022428, theta=-32.001128 -> V=1.0, theta=0.0
% INFO    : Bus 22109	: V=1.0051892, theta=-43.4321 -> V=1.0, theta=0.0
% INFO    : Bus 22110	: V=1.0145761, theta=-42.073259 -> V=1.0, theta=0.0
% INFO    : Bus 22111	: V=0.9845651, theta=-45.187919 -> V=1.0, theta=0.0
% INFO    : Bus 22112	: V=0.9775505, theta=-46.182317 -> V=1.0, theta=0.0
% INFO    : Bus 22113	: V=0.9839027, theta=-46.302986 -> V=1.0, theta=0.0
% INFO    : Bus 22114	: V=0.9923016, theta=-46.440003 -> V=1.0, theta=0.0
% INFO    : Bus 22115	: V=1.0069228, theta=-44.56684 -> V=1.0, theta=0.0
% INFO    : Bus 22116	: V=0.9929926, theta=-46.296999 -> V=1.0, theta=0.0
% INFO    : Bus 22117	: V=1.0014803, theta=-44.248547 -> V=1.0, theta=0.0
% INFO    : Bus 22118	: V=1.0013352, theta=-44.602248 -> V=1.0, theta=0.0
% INFO    : Bus 22119	: V=0.9984809, theta=-47.301959 -> V=1.0, theta=0.0
% INFO    : Bus 22120	: V=0.9928353, theta=-46.286248 -> V=1.0, theta=0.0
% INFO    : Bus 22121	: V=0.9926112, theta=-46.98343 -> V=1.0, theta=0.0
% INFO    : Bus 22122	: V=1.0026165, theta=-46.02618 -> V=1.0, theta=0.0
% INFO    : Bus 22123	: V=0.9803421, theta=-48.552335 -> V=1.0, theta=0.0
% INFO    : Bus 22124	: V=0.9822169, theta=-48.286819 -> V=1.0, theta=0.0
% INFO    : Bus 22125	: V=0.980315, theta=-49.384242 -> V=1.0, theta=0.0
% INFO    : Bus 22126	: V=0.9782039, theta=-49.489057 -> V=1.0, theta=0.0
% INFO    : Bus 22127	: V=0.9765997, theta=-49.26954 -> V=1.0, theta=0.0
% INFO    : Bus 22128	: V=0.9754557, theta=-49.667294 -> V=1.0, theta=0.0
% INFO    : Bus 22129	: V=1.0073769, theta=-42.905701 -> V=1.0, theta=0.0
% INFO    : Bus 22130	: V=1.0157092, theta=-42.221784 -> V=1.0, theta=0.0
% INFO    : Bus 22131	: V=1.0020397, theta=-43.793176 -> V=1.0, theta=0.0
% INFO    : Bus 22132	: V=1.0055802, theta=-43.233117 -> V=1.0, theta=0.0
% INFO    : Bus 22133	: V=1.0080019, theta=-31.785 -> V=1.0, theta=0.0
% INFO    : Bus 22134	: V=1.0090127, theta=-30.983895 -> V=1.0, theta=0.0
% INFO    : Bus 22135	: V=1.0063844, theta=-32.49115 -> V=1.0, theta=0.0
% INFO    : Bus 22136	: V=1.0094219, theta=-32.368719 -> V=1.0, theta=0.0
% INFO    : Bus 22137	: V=1.0073631, theta=-32.342355 -> V=1.0, theta=0.0
% INFO    : Bus 22138	: V=1.0074841, theta=-32.366716 -> V=1.0, theta=0.0
% INFO    : Bus 22139	: V=1.0059659, theta=-32.290241 -> V=1.0, theta=0.0
% INFO    : Bus 22140	: V=1.0075667, theta=-32.353546 -> V=1.0, theta=0.0
% INFO    : Bus 22141	: V=0.9956887, theta=-33.042415 -> V=1.0, theta=0.0
% INFO    : Bus 22142	: V=0.9521409, theta=-33.955155 -> V=1.0, theta=0.0
% INFO    : Bus 22143	: V=0.9644433, theta=-33.147489 -> V=1.0, theta=0.0
% INFO    : Bus 22144	: V=0.9535259, theta=-33.975378 -> V=1.0, theta=0.0
% INFO    : Bus 22145	: V=0.9612182, theta=-33.699878 -> V=1.0, theta=0.0
% INFO    : Bus 22146	: V=0.9585016, theta=-33.839411 -> V=1.0, theta=0.0
% INFO    : Bus 22147	: V=0.9574924, theta=-33.882224 -> V=1.0, theta=0.0
% INFO    : Bus 22148	: V=0.9847879, theta=-32.202589 -> V=1.0, theta=0.0
% INFO    : Bus 22149	: V=0.9575626, theta=-34.520065 -> V=1.0, theta=0.0
% INFO    : Bus 22150	: V=0.9717277, theta=-34.017841 -> V=1.0, theta=0.0
% INFO    : Bus 22151	: V=0.9734443, theta=-33.980795 -> V=1.0, theta=0.0
% INFO    : Bus 22152	: V=0.9610197, theta=-34.33047 -> V=1.0, theta=0.0
% INFO    : Bus 22153	: V=0.9894411, theta=-32.645776 -> V=1.0, theta=0.0
% INFO    : Bus 22154	: V=1.0033537, theta=-32.892267 -> V=1.0, theta=0.0
% INFO    : Bus 22155	: V=0.9818623, theta=-33.238024 -> V=1.0, theta=0.0
% INFO    : Bus 22156	: V=0.9579534, theta=-45.906529 -> V=1.0, theta=0.0
% INFO    : Bus 22157	: V=0.9630872, theta=-45.204093 -> V=1.0, theta=0.0
% INFO    : Bus 22158	: V=0.9656062, theta=-46.343887 -> V=1.0, theta=0.0
% INFO    : Bus 22159	: V=0.9700725, theta=-48.831801 -> V=1.0, theta=0.0
% INFO    : Bus 22160	: V=0.9792338, theta=-46.647823 -> V=1.0, theta=0.0
% INFO    : Bus 22161	: V=0.9674079, theta=-50.040645 -> V=1.0, theta=0.0
% INFO    : Bus 22162	: V=0.9643448, theta=-50.2086 -> V=1.0, theta=0.0
% INFO    : Bus 22163	: V=0.9614687, theta=-50.051697 -> V=1.0, theta=0.0
% INFO    : Bus 22164	: V=0.9606672, theta=-49.717107 -> V=1.0, theta=0.0
% INFO    : Bus 22165	: V=0.9559292, theta=-47.261646 -> V=1.0, theta=0.0
% INFO    : Bus 22166	: V=0.9748302, theta=-46.958372 -> V=1.0, theta=0.0
% INFO    : Bus 22167	: V=1.0039062, theta=-32.727022 -> V=1.0, theta=0.0
% INFO    : Bus 22168	: V=1.008077, theta=-31.700658 -> V=1.0, theta=0.0
% INFO    : Bus 22169	: V=1.0096835, theta=-31.486661 -> V=1.0, theta=0.0
% INFO    : Bus 22170	: V=1.0085902, theta=-31.632464 -> V=1.0, theta=0.0
% INFO    : Bus 22171	: V=0.9999771, theta=-33.056171 -> V=1.0, theta=0.0
% INFO    : Bus 22172	: V=1.0000607, theta=-33.08388 -> V=1.0, theta=0.0
% INFO    : Bus 22173	: V=0.998843, theta=-33.304258 -> V=1.0, theta=0.0
% INFO    : Bus 22174	: V=1.0010023, theta=-32.877582 -> V=1.0, theta=0.0
% INFO    : Bus 22175	: V=1.0068133, theta=-31.929338 -> V=1.0, theta=0.0
% INFO    : Bus 22176	: V=1.0115314, theta=-31.23963 -> V=1.0, theta=0.0
% INFO    : Bus 22177	: V=1.0092021, theta=-31.505965 -> V=1.0, theta=0.0
% INFO    : Bus 22178	: V=1.0195339, theta=-29.624778 -> V=1.0, theta=0.0
% INFO    : Bus 22179	: V=1.0092435, theta=-31.850079 -> V=1.0, theta=0.0
% INFO    : Bus 22180	: V=0.9969012, theta=-33.583517 -> V=1.0, theta=0.0
% INFO    : Bus 22181	: V=1.0047389, theta=-32.688667 -> V=1.0, theta=0.0
% INFO    : Bus 22182	: V=1.0012388, theta=-33.571197 -> V=1.0, theta=0.0
% INFO    : Bus 22183	: V=0.9962764, theta=-33.129507 -> V=1.0, theta=0.0
% INFO    : Bus 22184	: V=1.0056462, theta=-32.028627 -> V=1.0, theta=0.0
% INFO    : Bus 22185	: V=1.0192328, theta=-29.664234 -> V=1.0, theta=0.0
% INFO    : Bus 22186	: V=1.0019019, theta=-32.500147 -> V=1.0, theta=0.0
% INFO    : Bus 22187	: V=0.9993376, theta=-33.529435 -> V=1.0, theta=0.0
% INFO    : Bus 22188	: V=0.9882509, theta=-33.531874 -> V=1.0, theta=0.0
% INFO    : Bus 22189	: V=0.9937061, theta=-32.363436 -> V=1.0, theta=0.0
% INFO    : Bus 22190	: V=0.9832775, theta=-33.544375 -> V=1.0, theta=0.0
% INFO    : Bus 22191	: V=1.0078384, theta=-31.736775 -> V=1.0, theta=0.0
% INFO    : Bus 22192	: V=1.0015906, theta=-32.748889 -> V=1.0, theta=0.0
% INFO    : Bus 22193	: V=0.969164, theta=-32.555028 -> V=1.0, theta=0.0
% INFO    : Bus 22194	: V=0.9726486, theta=-32.148602 -> V=1.0, theta=0.0
% INFO    : Bus 22195	: V=0.9692137, theta=-32.268727 -> V=1.0, theta=0.0
% INFO    : Bus 22196	: V=0.9702606, theta=-32.179295 -> V=1.0, theta=0.0
% INFO    : Bus 22197	: V=0.9786404, theta=-31.520799 -> V=1.0, theta=0.0
% INFO    : Bus 22198	: V=0.9902407, theta=-51.609646 -> V=1.0, theta=0.0
% INFO    : Bus 22199	: V=1.0106343, theta=-49.275611 -> V=1.0, theta=0.0
% INFO    : Bus 22200	: V=0.9900931, theta=-51.58849 -> V=1.0, theta=0.0
% INFO    : Bus 22201	: V=0.9903267, theta=-51.586895 -> V=1.0, theta=0.0
% INFO    : Bus 22202	: V=0.9912546, theta=-51.662928 -> V=1.0, theta=0.0
% INFO    : Bus 22203	: V=0.9971259, theta=-51.011289 -> V=1.0, theta=0.0
% INFO    : Bus 22204	: V=1.0098483, theta=-49.35956 -> V=1.0, theta=0.0
% INFO    : Bus 22205	: V=0.9966241, theta=-51.045283 -> V=1.0, theta=0.0
% INFO    : Bus 22206	: V=0.9924495, theta=-51.636492 -> V=1.0, theta=0.0
% INFO    : Bus 22207	: V=1.0022227, theta=-50.535387 -> V=1.0, theta=0.0
% INFO    : Bus 22208	: V=0.9915347, theta=-51.846659 -> V=1.0, theta=0.0
% INFO    : Bus 22209	: V=1.009089, theta=-49.423092 -> V=1.0, theta=0.0
% INFO    : Bus 22210	: V=0.9925952, theta=-51.910311 -> V=1.0, theta=0.0
% INFO    : Bus 22211	: V=0.9937523, theta=-51.943687 -> V=1.0, theta=0.0
% INFO    : Bus 22212	: V=0.9891652, theta=-52.009981 -> V=1.0, theta=0.0
% INFO    : Bus 22213	: V=0.9927931, theta=-51.628034 -> V=1.0, theta=0.0
% INFO    : Bus 22214	: V=0.9887285, theta=-51.769443 -> V=1.0, theta=0.0
% INFO    : Bus 22215	: V=0.995927, theta=-51.210161 -> V=1.0, theta=0.0
% INFO    : Bus 22216	: V=0.9886093, theta=-51.620901 -> V=1.0, theta=0.0
% INFO    : Bus 22217	: V=0.9875527, theta=-51.583827 -> V=1.0, theta=0.0
% INFO    : Bus 22218	: V=0.9826365, theta=-51.91456 -> V=1.0, theta=0.0
% INFO    : Bus 22219	: V=0.9869603, theta=-51.534063 -> V=1.0, theta=0.0
% INFO    : Bus 22220	: V=0.987702, theta=-51.023199 -> V=1.0, theta=0.0
% INFO    : Bus 22221	: V=0.9955237, theta=-50.485886 -> V=1.0, theta=0.0
% INFO    : Bus 22222	: V=1.0079971, theta=-49.606949 -> V=1.0, theta=0.0
% INFO    : Bus 22223	: V=0.9880436, theta=-51.658887 -> V=1.0, theta=0.0
% INFO    : Bus 22224	: V=0.9842579, theta=-52.067657 -> V=1.0, theta=0.0
% INFO    : Bus 22225	: V=0.9859511, theta=-52.64353 -> V=1.0, theta=0.0
% INFO    : Bus 22226	: V=0.997965, theta=-52.217035 -> V=1.0, theta=0.0
% INFO    : Bus 22227	: V=1.0059248, theta=-50.029611 -> V=1.0, theta=0.0
% INFO    : Bus 22228	: V=1.002167, theta=-52.887471 -> V=1.0, theta=0.0
% INFO    : Bus 22229	: V=1.0112768, theta=-53.957483 -> V=1.0, theta=0.0
% INFO    : Bus 22230	: V=1.0095421, theta=-53.960943 -> V=1.0, theta=0.0
% INFO    : Bus 22231	: V=0.9914438, theta=-53.377314 -> V=1.0, theta=0.0
% INFO    : Bus 22232	: V=0.9959387, theta=-52.556061 -> V=1.0, theta=0.0
% INFO    : Bus 22233	: V=0.9823269, theta=-53.776128 -> V=1.0, theta=0.0
% INFO    : Bus 22234	: V=0.9859561, theta=-52.873412 -> V=1.0, theta=0.0
% INFO    : Bus 22235	: V=0.9700126, theta=-55.170129 -> V=1.0, theta=0.0
% INFO    : Bus 22236	: V=0.9880474, theta=-52.512643 -> V=1.0, theta=0.0
% INFO    : Bus 22237	: V=0.9635286, theta=-55.696797 -> V=1.0, theta=0.0
% INFO    : Bus 22238	: V=0.9860433, theta=-52.838236 -> V=1.0, theta=0.0
% INFO    : Bus 22239	: V=0.985192, theta=-52.980233 -> V=1.0, theta=0.0
% INFO    : Bus 22240	: V=0.972675, theta=-54.333353 -> V=1.0, theta=0.0
% INFO    : Bus 22241	: V=0.9713217, theta=-54.579064 -> V=1.0, theta=0.0
% INFO    : Bus 22242	: V=0.9687731, theta=-54.862758 -> V=1.0, theta=0.0
% INFO    : Bus 22243	: V=0.9591482, theta=-56.53915 -> V=1.0, theta=0.0
% INFO    : Bus 22244	: V=0.9907546, theta=-52.042346 -> V=1.0, theta=0.0
% INFO    : Bus 22245	: V=0.9947965, theta=-51.710622 -> V=1.0, theta=0.0
% INFO    : Bus 22246	: V=0.9653145, theta=-54.828556 -> V=1.0, theta=0.0
% INFO    : Bus 22247	: V=0.9662431, theta=-54.434412 -> V=1.0, theta=0.0
% INFO    : Bus 22248	: V=0.9627379, theta=-54.940585 -> V=1.0, theta=0.0
% INFO    : Bus 22249	: V=0.9588492, theta=-57.332823 -> V=1.0, theta=0.0
% INFO    : Bus 22250	: V=0.958716, theta=-56.221591 -> V=1.0, theta=0.0
% INFO    : Bus 22251	: V=0.9566601, theta=-57.85828 -> V=1.0, theta=0.0
% INFO    : Bus 22252	: V=0.9513151, theta=-58.769007 -> V=1.0, theta=0.0
% INFO    : Bus 22253	: V=0.9495058, theta=-57.121586 -> V=1.0, theta=0.0
% INFO    : Bus 22254	: V=0.9612437, theta=-56.115437 -> V=1.0, theta=0.0
% INFO    : Bus 22255	: V=0.9652585, theta=-54.68678 -> V=1.0, theta=0.0
% INFO    : Bus 22256	: V=0.9631066, theta=-55.711755 -> V=1.0, theta=0.0
% INFO    : Bus 22257	: V=0.9879424, theta=-52.992248 -> V=1.0, theta=0.0
% INFO    : Bus 22258	: V=0.9601781, theta=-53.162287 -> V=1.0, theta=0.0
% INFO    : Bus 22259	: V=0.9651558, theta=-52.513787 -> V=1.0, theta=0.0
% INFO    : Bus 22260	: V=0.9609545, theta=-53.184172 -> V=1.0, theta=0.0
% INFO    : Bus 22261	: V=0.9603581, theta=-53.213688 -> V=1.0, theta=0.0
% INFO    : Bus 22262	: V=0.9593695, theta=-53.186244 -> V=1.0, theta=0.0
% INFO    : Bus 22263	: V=0.9604149, theta=-53.117842 -> V=1.0, theta=0.0
% INFO    : Bus 22264	: V=0.9612055, theta=-53.095337 -> V=1.0, theta=0.0
% INFO    : Bus 22265	: V=0.9657641, theta=-52.464389 -> V=1.0, theta=0.0
% INFO    : Bus 22266	: V=0.9668715, theta=-52.367309 -> V=1.0, theta=0.0
% INFO    : Bus 22267	: V=0.9631548, theta=-52.825099 -> V=1.0, theta=0.0
% INFO    : Bus 22268	: V=0.9615976, theta=-53.172024 -> V=1.0, theta=0.0
% INFO    : Bus 22269	: V=0.9690651, theta=-52.426842 -> V=1.0, theta=0.0
% INFO    : Bus 22270	: V=0.9610509, theta=-53.388399 -> V=1.0, theta=0.0
% INFO    : Bus 22271	: V=0.9614657, theta=-53.276209 -> V=1.0, theta=0.0
% INFO    : Bus 22272	: V=0.9606028, theta=-53.29819 -> V=1.0, theta=0.0
% INFO    : Bus 22273	: V=0.9607697, theta=-53.513695 -> V=1.0, theta=0.0
% INFO    : Bus 22274	: V=0.9582107, theta=-53.2557 -> V=1.0, theta=0.0
% INFO    : Bus 22275	: V=0.9585943, theta=-53.165737 -> V=1.0, theta=0.0
% INFO    : Bus 22276	: V=0.9585583, theta=-53.057989 -> V=1.0, theta=0.0
% INFO    : Bus 22277	: V=0.9577768, theta=-52.093675 -> V=1.0, theta=0.0
% INFO    : Bus 22278	: V=0.9585399, theta=-53.172663 -> V=1.0, theta=0.0
% INFO    : Bus 22279	: V=0.9609643, theta=-53.01285 -> V=1.0, theta=0.0
% INFO    : Bus 22280	: V=0.9679523, theta=-51.998793 -> V=1.0, theta=0.0
% INFO    : Bus 22281	: V=0.981568, theta=-51.557416 -> V=1.0, theta=0.0
% INFO    : Bus 22282	: V=0.9604978, theta=-53.598236 -> V=1.0, theta=0.0
% INFO    : Bus 22283	: V=0.9701385, theta=-53.90374 -> V=1.0, theta=0.0
% INFO    : Bus 22284	: V=0.9616842, theta=-53.807877 -> V=1.0, theta=0.0
% INFO    : Bus 22285	: V=0.9660798, theta=-53.604214 -> V=1.0, theta=0.0
% INFO    : Bus 22286	: V=0.9744392, theta=-53.909226 -> V=1.0, theta=0.0
% INFO    : Bus 22287	: V=0.9556307, theta=-52.358604 -> V=1.0, theta=0.0
% INFO    : Bus 22288	: V=0.9574883, theta=-52.271201 -> V=1.0, theta=0.0
% INFO    : Bus 22289	: V=0.9560619, theta=-52.309613 -> V=1.0, theta=0.0
% INFO    : Bus 22290	: V=0.9601576, theta=-51.927233 -> V=1.0, theta=0.0
% INFO    : Bus 22291	: V=0.9596155, theta=-52.278962 -> V=1.0, theta=0.0
% INFO    : Bus 22292	: V=0.96113, theta=-49.36267 -> V=1.0, theta=0.0
% INFO    : Bus 22293	: V=0.9600783, theta=-51.109446 -> V=1.0, theta=0.0
% INFO    : Bus 22294	: V=0.9613851, theta=-52.960438 -> V=1.0, theta=0.0
% INFO    : Bus 22295	: V=0.960659, theta=-52.296384 -> V=1.0, theta=0.0
% INFO    : Bus 22296	: V=0.9692831, theta=-52.48104 -> V=1.0, theta=0.0
% INFO    : Bus 22297	: V=0.9461456, theta=-57.688596 -> V=1.0, theta=0.0
% INFO    : Bus 22298	: V=0.9500706, theta=-57.445607 -> V=1.0, theta=0.0
% INFO    : Bus 22299	: V=0.9563806, theta=-56.456371 -> V=1.0, theta=0.0
% INFO    : Bus 22300	: V=0.9700859, theta=-54.609406 -> V=1.0, theta=0.0
% INFO    : Bus 22301	: V=0.9667008, theta=-54.180974 -> V=1.0, theta=0.0
% INFO    : Bus 22302	: V=0.9636538, theta=-53.912713 -> V=1.0, theta=0.0
% INFO    : Bus 22303	: V=0.9654676, theta=-55.145399 -> V=1.0, theta=0.0
% INFO    : Bus 22304	: V=0.9824562, theta=-52.042991 -> V=1.0, theta=0.0
% INFO    : Bus 22305	: V=0.9768529, theta=-52.692764 -> V=1.0, theta=0.0
% INFO    : Bus 22306	: V=0.9671313, theta=-54.089826 -> V=1.0, theta=0.0
% INFO    : Bus 22307	: V=0.9602141, theta=-54.788589 -> V=1.0, theta=0.0
% INFO    : Bus 22308	: V=0.9957051, theta=-30.194361 -> V=1.0, theta=0.0
% INFO    : Bus 22309	: V=0.9864835, theta=-30.929763 -> V=1.0, theta=0.0
% INFO    : Bus 22310	: V=0.9552198, theta=-33.509854 -> V=1.0, theta=0.0
% INFO    : Bus 22311	: V=0.971813, theta=-32.380082 -> V=1.0, theta=0.0
% INFO    : Bus 22312	: V=0.9924138, theta=-32.24881 -> V=1.0, theta=0.0
% INFO    : Bus 22313	: V=0.9528182, theta=-33.74772 -> V=1.0, theta=0.0
% INFO    : Bus 22314	: V=0.9560099, theta=-33.575569 -> V=1.0, theta=0.0
% INFO    : Bus 22315	: V=0.950181, theta=-34.208669 -> V=1.0, theta=0.0
% INFO    : Bus 22316	: V=0.9509845, theta=-34.185233 -> V=1.0, theta=0.0
% INFO    : Bus 22317	: V=0.9602915, theta=-32.892249 -> V=1.0, theta=0.0
% INFO    : Bus 22318	: V=0.955883, theta=-33.259799 -> V=1.0, theta=0.0
% INFO    : Bus 22319	: V=0.9550126, theta=-33.276225 -> V=1.0, theta=0.0
% INFO    : Bus 22320	: V=0.9742876, theta=-32.388181 -> V=1.0, theta=0.0
% INFO    : Bus 22321	: V=0.970448, theta=-32.39994 -> V=1.0, theta=0.0
% INFO    : Bus 22322	: V=0.9616874, theta=-32.617746 -> V=1.0, theta=0.0
% INFO    : Bus 22323	: V=0.9652658, theta=-32.265775 -> V=1.0, theta=0.0
% INFO    : Bus 22324	: V=0.9835365, theta=-31.605643 -> V=1.0, theta=0.0
% INFO    : Bus 22325	: V=0.9812398, theta=-31.416493 -> V=1.0, theta=0.0
% INFO    : Bus 22326	: V=0.9782286, theta=-31.635634 -> V=1.0, theta=0.0
% INFO    : Bus 22327	: V=1.0045598, theta=-30.174717 -> V=1.0, theta=0.0
% INFO    : Bus 22328	: V=1.0031889, theta=-30.386977 -> V=1.0, theta=0.0
% INFO    : Bus 22329	: V=1.0128182, theta=-28.559925 -> V=1.0, theta=0.0
% INFO    : Bus 22330	: V=1.0171854, theta=-28.550806 -> V=1.0, theta=0.0
% INFO    : Bus 22331	: V=1.0190441, theta=-28.480852 -> V=1.0, theta=0.0
% INFO    : Bus 22332	: V=1.0184417, theta=-28.480277 -> V=1.0, theta=0.0
% INFO    : Bus 22333	: V=1.0127421, theta=-29.292644 -> V=1.0, theta=0.0
% INFO    : Bus 22334	: V=0.9945775, theta=-31.316794 -> V=1.0, theta=0.0
% INFO    : Bus 22335	: V=0.9992389, theta=-31.960083 -> V=1.0, theta=0.0
% INFO    : Bus 22336	: V=0.9778576, theta=-32.044845 -> V=1.0, theta=0.0
% INFO    : Bus 22337	: V=1.0049914, theta=-30.749209 -> V=1.0, theta=0.0
% INFO    : Bus 22338	: V=0.9733307, theta=-32.682799 -> V=1.0, theta=0.0
% INFO    : Bus 22339	: V=0.9644688, theta=-32.877763 -> V=1.0, theta=0.0
% INFO    : Bus 22340	: V=0.987457, theta=-32.051675 -> V=1.0, theta=0.0
% INFO    : Bus 22341	: V=0.9691396, theta=-34.438446 -> V=1.0, theta=0.0
% INFO    : Bus 22342	: V=0.9681758, theta=-34.309274 -> V=1.0, theta=0.0
% INFO    : Bus 22343	: V=0.9720801, theta=-34.257239 -> V=1.0, theta=0.0
% INFO    : Bus 22344	: V=0.9920408, theta=-33.194016 -> V=1.0, theta=0.0
% INFO    : Bus 22345	: V=0.9900359, theta=-33.473876 -> V=1.0, theta=0.0
% INFO    : Bus 22346	: V=0.9779248, theta=-34.28114 -> V=1.0, theta=0.0
% INFO    : Bus 22347	: V=0.980699, theta=-33.747162 -> V=1.0, theta=0.0
% INFO    : Bus 22348	: V=0.9801407, theta=-34.330636 -> V=1.0, theta=0.0
% INFO    : Bus 22349	: V=0.9682751, theta=-34.54657 -> V=1.0, theta=0.0
% INFO    : Bus 22350	: V=0.9678804, theta=-34.498407 -> V=1.0, theta=0.0
% INFO    : Bus 22351	: V=0.9689021, theta=-34.58025 -> V=1.0, theta=0.0
% INFO    : Bus 22352	: V=0.9852523, theta=-41.029032 -> V=1.0, theta=0.0
% INFO    : Bus 22353	: V=0.9916158, theta=-40.252334 -> V=1.0, theta=0.0
% INFO    : Bus 22354	: V=0.9909717, theta=-40.310682 -> V=1.0, theta=0.0
% INFO    : Bus 22355	: V=0.9907254, theta=-40.497934 -> V=1.0, theta=0.0
% INFO    : Bus 22356	: V=0.9790573, theta=-41.514365 -> V=1.0, theta=0.0
% INFO    : Bus 22357	: V=0.9800572, theta=-41.505465 -> V=1.0, theta=0.0
% INFO    : Bus 22358	: V=0.9897255, theta=-40.845227 -> V=1.0, theta=0.0
% INFO    : Bus 22359	: V=0.9860379, theta=-41.276541 -> V=1.0, theta=0.0
% INFO    : Bus 22360	: V=0.968185, theta=-42.764002 -> V=1.0, theta=0.0
% INFO    : Bus 22361	: V=0.9854829, theta=-39.004347 -> V=1.0, theta=0.0
% INFO    : Bus 22362	: V=1.0034571, theta=-37.185228 -> V=1.0, theta=0.0
% INFO    : Bus 22363	: V=1.0030348, theta=-37.70733 -> V=1.0, theta=0.0
% INFO    : Bus 22364	: V=0.9906506, theta=-38.303897 -> V=1.0, theta=0.0
% INFO    : Bus 22365	: V=1.0163674, theta=-35.822959 -> V=1.0, theta=0.0
% INFO    : Bus 22366	: V=1.0013415, theta=-38.25383 -> V=1.0, theta=0.0
% INFO    : Bus 22367	: V=0.9964877, theta=-38.942393 -> V=1.0, theta=0.0
% INFO    : Bus 22368	: V=0.9949924, theta=-39.488628 -> V=1.0, theta=0.0
% INFO    : Bus 22369	: V=0.9941211, theta=-38.603613 -> V=1.0, theta=0.0
% INFO    : Bus 22370	: V=0.9890569, theta=-39.302921 -> V=1.0, theta=0.0
% INFO    : Bus 22371	: V=0.9851054, theta=-39.881716 -> V=1.0, theta=0.0
% INFO    : Bus 22372	: V=0.9838258, theta=-40.082612 -> V=1.0, theta=0.0
% INFO    : Bus 22373	: V=0.9797197, theta=-41.569768 -> V=1.0, theta=0.0
% INFO    : Bus 22374	: V=0.991465, theta=-31.89096 -> V=1.0, theta=0.0
% INFO    : Bus 22375	: V=0.9839777, theta=-33.183935 -> V=1.0, theta=0.0
% INFO    : Bus 22376	: V=0.9877773, theta=-33.384742 -> V=1.0, theta=0.0
% INFO    : Bus 22377	: V=0.9858185, theta=-32.724895 -> V=1.0, theta=0.0
% INFO    : Bus 22378	: V=0.9896093, theta=-32.821971 -> V=1.0, theta=0.0
% INFO    : Bus 22379	: V=1.0047593, theta=-31.811168 -> V=1.0, theta=0.0
% INFO    : Bus 22380	: V=1.0105457, theta=-31.216224 -> V=1.0, theta=0.0
% INFO    : Bus 22381	: V=1.0110361, theta=-30.801647 -> V=1.0, theta=0.0
% INFO    : Bus 22382	: V=1.0177956, theta=-30.033984 -> V=1.0, theta=0.0
% INFO    : Bus 22383	: V=1.0388874, theta=-30.715247 -> V=1.0, theta=0.0
% INFO    : Bus 22384	: V=1.0252835, theta=-30.364703 -> V=1.0, theta=0.0
% INFO    : Bus 22385	: V=1.0210012, theta=-31.625708 -> V=1.0, theta=0.0
% INFO    : Bus 22386	: V=1.0169104, theta=-30.168387 -> V=1.0, theta=0.0
% INFO    : Bus 22387	: V=1.0147305, theta=-30.412103 -> V=1.0, theta=0.0
% INFO    : Bus 22388	: V=1.0143028, theta=-30.411934 -> V=1.0, theta=0.0
% INFO    : Bus 22389	: V=1.0141088, theta=-30.599676 -> V=1.0, theta=0.0
% INFO    : Bus 22390	: V=0.9749525, theta=-34.195902 -> V=1.0, theta=0.0
% INFO    : Bus 22391	: V=0.9917342, theta=-34.021457 -> V=1.0, theta=0.0
% INFO    : Bus 22392	: V=1.0070407, theta=-33.341827 -> V=1.0, theta=0.0
% INFO    : Bus 22393	: V=0.9942522, theta=-34.78345 -> V=1.0, theta=0.0
% INFO    : Bus 22394	: V=0.9907265, theta=-34.891227 -> V=1.0, theta=0.0
% INFO    : Bus 22395	: V=0.9893709, theta=-34.951273 -> V=1.0, theta=0.0
% INFO    : Bus 22396	: V=0.9892349, theta=-34.899305 -> V=1.0, theta=0.0
% INFO    : Bus 22397	: V=0.9780216, theta=-42.049061 -> V=1.0, theta=0.0
% INFO    : Bus 22398	: V=0.9757999, theta=-42.470113 -> V=1.0, theta=0.0
% INFO    : Bus 22399	: V=0.9764392, theta=-42.260754 -> V=1.0, theta=0.0
% INFO    : Bus 22400	: V=0.9772248, theta=-42.240219 -> V=1.0, theta=0.0
% INFO    : Bus 22401	: V=0.9753741, theta=-42.469467 -> V=1.0, theta=0.0
% INFO    : Bus 22402	: V=0.9914948, theta=-41.852402 -> V=1.0, theta=0.0
% INFO    : Bus 22403	: V=0.9706085, theta=-43.122384 -> V=1.0, theta=0.0
% INFO    : Bus 22404	: V=0.9759465, theta=-43.009751 -> V=1.0, theta=0.0
% INFO    : Bus 22405	: V=0.9738574, theta=-42.486691 -> V=1.0, theta=0.0
% INFO    : Bus 22406	: V=0.9661294, theta=-43.074011 -> V=1.0, theta=0.0
% INFO    : Bus 22407	: V=0.965352, theta=-43.074802 -> V=1.0, theta=0.0
% INFO    : Bus 22408	: V=0.9664967, theta=-43.265275 -> V=1.0, theta=0.0
% INFO    : Bus 22409	: V=0.9691219, theta=-43.549449 -> V=1.0, theta=0.0
% INFO    : Bus 22410	: V=0.9689185, theta=-44.951001 -> V=1.0, theta=0.0
% INFO    : Bus 22411	: V=0.9696536, theta=-44.305528 -> V=1.0, theta=0.0
% INFO    : Bus 22412	: V=0.9713012, theta=-45.315614 -> V=1.0, theta=0.0
% INFO    : Bus 22413	: V=0.9606382, theta=-49.246561 -> V=1.0, theta=0.0
% INFO    : Bus 22414	: V=0.9710483, theta=-45.029405 -> V=1.0, theta=0.0
% INFO    : Bus 22415	: V=0.9696658, theta=-45.531624 -> V=1.0, theta=0.0
% INFO    : Bus 22416	: V=0.9637255, theta=-46.36195 -> V=1.0, theta=0.0
% INFO    : Bus 22417	: V=0.9639049, theta=-45.823833 -> V=1.0, theta=0.0
% INFO    : Bus 22418	: V=0.9646538, theta=-47.318643 -> V=1.0, theta=0.0
% INFO    : Bus 22419	: V=0.9643755, theta=-45.225042 -> V=1.0, theta=0.0
% INFO    : Bus 22420	: V=0.9607436, theta=-45.920371 -> V=1.0, theta=0.0
% INFO    : Bus 22421	: V=0.962428, theta=-45.400957 -> V=1.0, theta=0.0
% INFO    : Bus 22422	: V=0.9617084, theta=-45.470609 -> V=1.0, theta=0.0
% INFO    : Bus 22423	: V=0.9869705, theta=-42.794845 -> V=1.0, theta=0.0
% INFO    : Bus 22424	: V=0.9732361, theta=-44.36788 -> V=1.0, theta=0.0
% INFO    : Bus 22425	: V=0.9782947, theta=-32.390876 -> V=1.0, theta=0.0
% INFO    : Bus 22426	: V=0.9699321, theta=-32.117756 -> V=1.0, theta=0.0
% INFO    : Bus 22427	: V=0.9676579, theta=-32.391782 -> V=1.0, theta=0.0
% INFO    : Bus 22428	: V=0.9657308, theta=-32.695501 -> V=1.0, theta=0.0
% INFO    : Bus 22429	: V=0.9786461, theta=-31.879839 -> V=1.0, theta=0.0
% INFO    : Bus 22430	: V=0.9773825, theta=-31.694267 -> V=1.0, theta=0.0
% INFO    : Bus 22431	: V=0.9676624, theta=-32.72674 -> V=1.0, theta=0.0
% INFO    : Bus 22432	: V=0.9560507, theta=-33.233462 -> V=1.0, theta=0.0
% INFO    : Bus 22433	: V=0.9888696, theta=-37.704454 -> V=1.0, theta=0.0
% INFO    : Bus 22434	: V=0.9892459, theta=-37.7179 -> V=1.0, theta=0.0
% INFO    : Bus 22435	: V=0.9898825, theta=-37.526916 -> V=1.0, theta=0.0
% INFO    : Bus 22436	: V=0.989245, theta=-37.739077 -> V=1.0, theta=0.0
% INFO    : Bus 22437	: V=0.9887039, theta=-37.717016 -> V=1.0, theta=0.0
% INFO    : Bus 22438	: V=0.994056, theta=-37.514347 -> V=1.0, theta=0.0
% INFO    : Bus 22439	: V=0.9892612, theta=-37.618312 -> V=1.0, theta=0.0
% INFO    : Bus 22440	: V=0.9885453, theta=-37.810812 -> V=1.0, theta=0.0
% INFO    : Bus 22441	: V=0.9888471, theta=-37.688642 -> V=1.0, theta=0.0
% INFO    : Bus 22442	: V=0.9886779, theta=-37.737219 -> V=1.0, theta=0.0
% INFO    : Bus 22443	: V=0.9885945, theta=-37.76754 -> V=1.0, theta=0.0
% INFO    : Bus 22444	: V=0.9822337, theta=-38.268527 -> V=1.0, theta=0.0
% INFO    : Bus 22445	: V=0.9834854, theta=-38.025524 -> V=1.0, theta=0.0
% INFO    : Bus 22446	: V=0.9864225, theta=-37.964572 -> V=1.0, theta=0.0
% INFO    : Bus 22447	: V=0.9826261, theta=-38.117259 -> V=1.0, theta=0.0
% INFO    : Bus 22448	: V=0.9830841, theta=-38.07043 -> V=1.0, theta=0.0
% INFO    : Bus 22449	: V=0.9969847, theta=-37.354184 -> V=1.0, theta=0.0
% INFO    : Bus 22450	: V=0.994988, theta=-37.648048 -> V=1.0, theta=0.0
% INFO    : Bus 22451	: V=0.9949997, theta=-37.628216 -> V=1.0, theta=0.0
% INFO    : Bus 22452	: V=0.9943519, theta=-37.504959 -> V=1.0, theta=0.0
% INFO    : Bus 22453	: V=0.9912362, theta=-37.719928 -> V=1.0, theta=0.0
% INFO    : Bus 22454	: V=0.9866452, theta=-38.010295 -> V=1.0, theta=0.0
% INFO    : Bus 22455	: V=0.9946333, theta=-37.541604 -> V=1.0, theta=0.0
% INFO    : Bus 22456	: V=0.9886126, theta=-37.860182 -> V=1.0, theta=0.0
% INFO    : Bus 22457	: V=0.9926955, theta=-37.716343 -> V=1.0, theta=0.0
% INFO    : Bus 22458	: V=0.9822483, theta=-38.148288 -> V=1.0, theta=0.0
% INFO    : Bus 22459	: V=0.9838857, theta=-38.252704 -> V=1.0, theta=0.0
% INFO    : Bus 22460	: V=0.9868746, theta=-38.042352 -> V=1.0, theta=0.0
% INFO    : Bus 22461	: V=0.9903486, theta=-38.047214 -> V=1.0, theta=0.0
% INFO    : Bus 22462	: V=0.9850322, theta=-38.228934 -> V=1.0, theta=0.0
% INFO    : Bus 22463	: V=0.9838957, theta=-38.408752 -> V=1.0, theta=0.0
% INFO    : Bus 22464	: V=0.9796486, theta=-38.833144 -> V=1.0, theta=0.0
% INFO    : Bus 22465	: V=0.9828543, theta=-38.542095 -> V=1.0, theta=0.0
% INFO    : Bus 22466	: V=0.9801038, theta=-38.353834 -> V=1.0, theta=0.0
% INFO    : Bus 22467	: V=0.9813663, theta=-38.351869 -> V=1.0, theta=0.0
% INFO    : Bus 22468	: V=0.9820873, theta=-38.169289 -> V=1.0, theta=0.0
% INFO    : Bus 22469	: V=0.9803689, theta=-38.621081 -> V=1.0, theta=0.0
% INFO    : Bus 22470	: V=0.995328, theta=-36.376633 -> V=1.0, theta=0.0
% INFO    : Bus 22471	: V=0.9962827, theta=-36.107634 -> V=1.0, theta=0.0
% INFO    : Bus 22472	: V=0.9953221, theta=-36.370674 -> V=1.0, theta=0.0
% INFO    : Bus 22473	: V=0.9946117, theta=-36.553754 -> V=1.0, theta=0.0
% INFO    : Bus 22474	: V=0.9928548, theta=-36.539677 -> V=1.0, theta=0.0
% INFO    : Bus 22475	: V=0.9934663, theta=-36.783648 -> V=1.0, theta=0.0
% INFO    : Bus 22476	: V=0.9953468, theta=-36.208283 -> V=1.0, theta=0.0
% INFO    : Bus 22477	: V=0.9923186, theta=-36.6037 -> V=1.0, theta=0.0
% INFO    : Bus 22478	: V=0.9905904, theta=-37.377937 -> V=1.0, theta=0.0
% INFO    : Bus 22479	: V=0.9911272, theta=-37.244311 -> V=1.0, theta=0.0
% INFO    : Bus 22480	: V=0.9847469, theta=-37.79932 -> V=1.0, theta=0.0
% INFO    : Bus 22481	: V=0.9857307, theta=-37.624799 -> V=1.0, theta=0.0
% INFO    : Bus 22482	: V=0.9894791, theta=-37.225578 -> V=1.0, theta=0.0
% INFO    : Bus 22483	: V=0.9919262, theta=-37.100171 -> V=1.0, theta=0.0
% INFO    : Bus 22484	: V=0.9875087, theta=-37.362158 -> V=1.0, theta=0.0
% INFO    : Bus 22485	: V=0.9823376, theta=-38.114219 -> V=1.0, theta=0.0
% INFO    : Bus 22486	: V=0.9897967, theta=-36.986332 -> V=1.0, theta=0.0
% INFO    : Bus 22487	: V=0.9782654, theta=-37.795885 -> V=1.0, theta=0.0
% INFO    : Bus 22488	: V=0.9834324, theta=-37.986578 -> V=1.0, theta=0.0
% INFO    : Bus 22489	: V=0.9839006, theta=-38.03492 -> V=1.0, theta=0.0
% INFO    : Bus 22490	: V=0.9839874, theta=-37.948361 -> V=1.0, theta=0.0
% INFO    : Bus 22491	: V=0.981263, theta=-38.340307 -> V=1.0, theta=0.0
% INFO    : Bus 22492	: V=0.9757488, theta=-38.763755 -> V=1.0, theta=0.0
% INFO    : Bus 22493	: V=0.979121, theta=-38.54741 -> V=1.0, theta=0.0
% INFO    : Bus 22494	: V=0.9793967, theta=-38.660118 -> V=1.0, theta=0.0
% INFO    : Bus 22495	: V=0.9770003, theta=-39.009435 -> V=1.0, theta=0.0
% INFO    : Bus 22496	: V=0.9806526, theta=-39.72299 -> V=1.0, theta=0.0
% INFO    : Bus 22497	: V=0.9772957, theta=-39.907983 -> V=1.0, theta=0.0
% INFO    : Bus 22498	: V=0.9823335, theta=-39.35819 -> V=1.0, theta=0.0
% INFO    : Bus 22499	: V=0.9768874, theta=-39.785103 -> V=1.0, theta=0.0
% INFO    : Bus 22500	: V=0.9783365, theta=-39.46619 -> V=1.0, theta=0.0
% INFO    : Bus 22501	: V=0.9791051, theta=-39.200975 -> V=1.0, theta=0.0
% INFO    : Bus 22502	: V=0.9842875, theta=-38.998777 -> V=1.0, theta=0.0
% INFO    : Bus 22503	: V=0.9762403, theta=-39.800992 -> V=1.0, theta=0.0
% INFO    : Bus 22504	: V=0.9801124, theta=-38.93154 -> V=1.0, theta=0.0
% INFO    : Bus 22505	: V=0.9813971, theta=-38.746286 -> V=1.0, theta=0.0
% INFO    : Bus 22506	: V=0.9865866, theta=-38.589 -> V=1.0, theta=0.0
% INFO    : Bus 22507	: V=0.9818301, theta=-38.664459 -> V=1.0, theta=0.0
% INFO    : Bus 22508	: V=0.9849602, theta=-38.499432 -> V=1.0, theta=0.0
% INFO    : Bus 22509	: V=0.9838809, theta=-38.499462 -> V=1.0, theta=0.0
% INFO    : Bus 22510	: V=0.9876213, theta=-38.287317 -> V=1.0, theta=0.0
% INFO    : Bus 22511	: V=0.9845612, theta=-38.548208 -> V=1.0, theta=0.0
% INFO    : Bus 22512	: V=0.978906, theta=-39.240439 -> V=1.0, theta=0.0
% INFO    : Bus 22513	: V=0.9813302, theta=-38.814129 -> V=1.0, theta=0.0
% INFO    : Bus 22514	: V=0.9821877, theta=-38.608498 -> V=1.0, theta=0.0
% INFO    : Bus 22515	: V=0.9831638, theta=-38.600453 -> V=1.0, theta=0.0
% INFO    : Bus 22516	: V=0.984336, theta=-38.447889 -> V=1.0, theta=0.0
% INFO    : Bus 22517	: V=0.9827071, theta=-38.680728 -> V=1.0, theta=0.0
% INFO    : Bus 22518	: V=0.9846036, theta=-38.56871 -> V=1.0, theta=0.0
% INFO    : Bus 22519	: V=0.9880004, theta=-38.347448 -> V=1.0, theta=0.0
% INFO    : Bus 22520	: V=0.9943074, theta=-37.861795 -> V=1.0, theta=0.0
% INFO    : Bus 22521	: V=0.9867227, theta=-38.134596 -> V=1.0, theta=0.0
% INFO    : Bus 22522	: V=1.0079623, theta=-36.45354 -> V=1.0, theta=0.0
% INFO    : Bus 22523	: V=0.996425, theta=-37.37463 -> V=1.0, theta=0.0
% INFO    : Bus 22524	: V=1.0016483, theta=-36.949047 -> V=1.0, theta=0.0
% INFO    : Bus 22525	: V=0.9991667, theta=-37.424988 -> V=1.0, theta=0.0
% INFO    : Bus 22526	: V=1.0008856, theta=-37.304413 -> V=1.0, theta=0.0
% INFO    : Bus 22527	: V=1.0125243, theta=-36.028147 -> V=1.0, theta=0.0
% INFO    : Bus 22528	: V=0.9941091, theta=-37.282368 -> V=1.0, theta=0.0
% INFO    : Bus 22529	: V=0.9994856, theta=-37.190255 -> V=1.0, theta=0.0
% INFO    : Bus 22530	: V=0.9945085, theta=-37.148214 -> V=1.0, theta=0.0
% INFO    : Bus 22531	: V=0.9942448, theta=-37.208791 -> V=1.0, theta=0.0
% INFO    : Bus 22532	: V=0.993184, theta=-36.882115 -> V=1.0, theta=0.0
% INFO    : Bus 22533	: V=0.9911134, theta=-37.206698 -> V=1.0, theta=0.0
% INFO    : Bus 22534	: V=1.0035847, theta=-36.62122 -> V=1.0, theta=0.0
% INFO    : Bus 22535	: V=1.0015733, theta=-36.548549 -> V=1.0, theta=0.0
% INFO    : Bus 22536	: V=0.9952271, theta=-36.577564 -> V=1.0, theta=0.0
% INFO    : Bus 22537	: V=1.0007698, theta=-35.223549 -> V=1.0, theta=0.0
% INFO    : Bus 22538	: V=0.9966638, theta=-35.568275 -> V=1.0, theta=0.0
% INFO    : Bus 22539	: V=0.9995639, theta=-35.639197 -> V=1.0, theta=0.0
% INFO    : Bus 22540	: V=0.9664203, theta=-39.814856 -> V=1.0, theta=0.0
% INFO    : Bus 22541	: V=0.9769667, theta=-38.529808 -> V=1.0, theta=0.0
% INFO    : Bus 22542	: V=0.9792659, theta=-38.506372 -> V=1.0, theta=0.0
% INFO    : Bus 22543	: V=0.9663981, theta=-40.52666 -> V=1.0, theta=0.0
% INFO    : Bus 22544	: V=0.9730023, theta=-39.58145 -> V=1.0, theta=0.0
% INFO    : Bus 22545	: V=0.9759897, theta=-39.213357 -> V=1.0, theta=0.0
% INFO    : Bus 22546	: V=0.976812, theta=-39.277178 -> V=1.0, theta=0.0
% INFO    : Bus 22547	: V=0.9744728, theta=-39.783778 -> V=1.0, theta=0.0
% INFO    : Bus 22548	: V=0.9744836, theta=-39.632166 -> V=1.0, theta=0.0
% INFO    : Bus 22549	: V=0.9695142, theta=-41.042078 -> V=1.0, theta=0.0
% INFO    : Bus 22550	: V=0.9701438, theta=-40.602977 -> V=1.0, theta=0.0
% INFO    : Bus 22551	: V=0.9726275, theta=-40.014878 -> V=1.0, theta=0.0
% INFO    : Bus 22552	: V=0.9713371, theta=-40.298576 -> V=1.0, theta=0.0
% INFO    : Bus 22553	: V=0.967195, theta=-40.832802 -> V=1.0, theta=0.0
% INFO    : Bus 22554	: V=0.9705378, theta=-40.501238 -> V=1.0, theta=0.0
% INFO    : Bus 22555	: V=0.9703757, theta=-40.603413 -> V=1.0, theta=0.0
% INFO    : Bus 22556	: V=0.9697899, theta=-40.778401 -> V=1.0, theta=0.0
% INFO    : Bus 22557	: V=0.9721242, theta=-40.242929 -> V=1.0, theta=0.0
% INFO    : Bus 22558	: V=0.975228, theta=-39.943776 -> V=1.0, theta=0.0
% INFO    : Bus 22559	: V=0.9749996, theta=-40.002561 -> V=1.0, theta=0.0
% INFO    : Bus 22560	: V=0.9794976, theta=-38.625416 -> V=1.0, theta=0.0
% INFO    : Bus 22561	: V=0.9885328, theta=-37.80587 -> V=1.0, theta=0.0
% INFO    : Bus 22562	: V=0.9784672, theta=-38.837187 -> V=1.0, theta=0.0
% INFO    : Bus 22563	: V=0.9935879, theta=-37.57852 -> V=1.0, theta=0.0
% INFO    : Bus 22564	: V=0.9709552, theta=-34.248703 -> V=1.0, theta=0.0
% INFO    : Bus 22565	: V=0.9732017, theta=-34.08353 -> V=1.0, theta=0.0
% INFO    : Bus 22566	: V=0.9764621, theta=-34.062491 -> V=1.0, theta=0.0
% INFO    : Bus 22567	: V=0.9706485, theta=-34.438498 -> V=1.0, theta=0.0
% INFO    : Bus 22568	: V=0.970839, theta=-34.35739 -> V=1.0, theta=0.0
% INFO    : Bus 22569	: V=0.9744578, theta=-34.184595 -> V=1.0, theta=0.0
% INFO    : Bus 22570	: V=0.9700303, theta=-34.403049 -> V=1.0, theta=0.0
% INFO    : Bus 22571	: V=0.9828753, theta=-34.279055 -> V=1.0, theta=0.0
% INFO    : Bus 22572	: V=0.9809412, theta=-33.901012 -> V=1.0, theta=0.0
% INFO    : Bus 22573	: V=0.9862746, theta=-34.055383 -> V=1.0, theta=0.0
% INFO    : Bus 22574	: V=1.0107243, theta=-32.916214 -> V=1.0, theta=0.0
% INFO    : Bus 22575	: V=0.9787985, theta=-34.054719 -> V=1.0, theta=0.0
% INFO    : Bus 22576	: V=1.0020309, theta=-33.52762 -> V=1.0, theta=0.0
% INFO    : Bus 22577	: V=0.9768241, theta=-34.230241 -> V=1.0, theta=0.0
% INFO    : Bus 22578	: V=0.9749924, theta=-34.246772 -> V=1.0, theta=0.0
% INFO    : Bus 22579	: V=0.9865284, theta=-33.533321 -> V=1.0, theta=0.0
% INFO    : Bus 22580	: V=0.972758, theta=-33.084984 -> V=1.0, theta=0.0
% INFO    : Bus 22581	: V=0.9628191, theta=-33.585633 -> V=1.0, theta=0.0
% INFO    : Bus 22582	: V=0.9778138, theta=-33.13859 -> V=1.0, theta=0.0
% INFO    : Bus 22583	: V=0.960584, theta=-33.242526 -> V=1.0, theta=0.0
% INFO    : Bus 22584	: V=0.9564742, theta=-33.837897 -> V=1.0, theta=0.0
% INFO    : Bus 22585	: V=0.9572372, theta=-33.438851 -> V=1.0, theta=0.0
% INFO    : Bus 22586	: V=0.9627333, theta=-33.347946 -> V=1.0, theta=0.0
% INFO    : Bus 22587	: V=0.9656734, theta=-33.051778 -> V=1.0, theta=0.0
% INFO    : Bus 22588	: V=0.9591315, theta=-33.762805 -> V=1.0, theta=0.0
% INFO    : Bus 22589	: V=0.9575319, theta=-33.746347 -> V=1.0, theta=0.0
% INFO    : Bus 22590	: V=0.9644014, theta=-33.336913 -> V=1.0, theta=0.0
% INFO    : Bus 22591	: V=0.9919676, theta=-30.146713 -> V=1.0, theta=0.0
% INFO    : Bus 22592	: V=0.9762081, theta=-32.155383 -> V=1.0, theta=0.0
% INFO    : Bus 22593	: V=0.9651638, theta=-33.145678 -> V=1.0, theta=0.0
% INFO    : Bus 22594	: V=0.9652445, theta=-33.116521 -> V=1.0, theta=0.0
% INFO    : Bus 22595	: V=0.9617874, theta=-33.441979 -> V=1.0, theta=0.0
% INFO    : Bus 22596	: V=0.9851054, theta=-36.371892 -> V=1.0, theta=0.0
% INFO    : Bus 22597	: V=0.9947759, theta=-34.819021 -> V=1.0, theta=0.0
% INFO    : Bus 22598	: V=0.9950092, theta=-34.85387 -> V=1.0, theta=0.0
% INFO    : Bus 22599	: V=0.9952921, theta=-34.803131 -> V=1.0, theta=0.0
% INFO    : Bus 22600	: V=0.9952702, theta=-34.890131 -> V=1.0, theta=0.0
% INFO    : Bus 22601	: V=0.9872133, theta=-35.727674 -> V=1.0, theta=0.0
% INFO    : Bus 22602	: V=0.9977885, theta=-34.329413 -> V=1.0, theta=0.0
% INFO    : Bus 22603	: V=1.0050312, theta=-36.571438 -> V=1.0, theta=0.0
% INFO    : Bus 22604	: V=0.9941856, theta=-37.59086 -> V=1.0, theta=0.0
% INFO    : Bus 22605	: V=0.9996527, theta=-36.95269 -> V=1.0, theta=0.0
% INFO    : Bus 22606	: V=0.9782584, theta=-52.909065 -> V=1.0, theta=0.0
% INFO    : Bus 22607	: V=0.9804034, theta=-53.668879 -> V=1.0, theta=0.0
% INFO    : Bus 22608	: V=0.9790098, theta=-54.023955 -> V=1.0, theta=0.0
% INFO    : Bus 22609	: V=0.9596647, theta=-57.836481 -> V=1.0, theta=0.0
% INFO    : Bus 22610	: V=0.9788739, theta=-53.9303 -> V=1.0, theta=0.0
% INFO    : Bus 22611	: V=0.9647173, theta=-54.75393 -> V=1.0, theta=0.0
% INFO    : Bus 22612	: V=0.9674385, theta=-56.068791 -> V=1.0, theta=0.0
% INFO    : Bus 22613	: V=0.9657231, theta=-56.234671 -> V=1.0, theta=0.0
% INFO    : Bus 22614	: V=0.959451, theta=-56.793677 -> V=1.0, theta=0.0
% INFO    : Bus 22615	: V=0.9585653, theta=-56.205624 -> V=1.0, theta=0.0
% INFO    : Bus 22616	: V=0.9572223, theta=-57.051238 -> V=1.0, theta=0.0
% INFO    : Bus 22617	: V=0.9402873, theta=-62.783381 -> V=1.0, theta=0.0
% INFO    : Bus 22618	: V=0.9731743, theta=-35.117798 -> V=1.0, theta=0.0
% INFO    : Bus 22619	: V=0.9707994, theta=-35.598492 -> V=1.0, theta=0.0
% INFO    : Bus 22620	: V=0.9780756, theta=-35.486548 -> V=1.0, theta=0.0
% INFO    : Bus 22621	: V=0.9862212, theta=-34.213514 -> V=1.0, theta=0.0
% INFO    : Bus 22622	: V=0.9757237, theta=-34.971188 -> V=1.0, theta=0.0
% INFO    : Bus 22623	: V=0.9784082, theta=-34.691958 -> V=1.0, theta=0.0
% INFO    : Bus 22624	: V=0.9917773, theta=-33.889346 -> V=1.0, theta=0.0
% INFO    : Bus 22625	: V=0.9745402, theta=-34.966364 -> V=1.0, theta=0.0
% INFO    : Bus 22626	: V=0.9866445, theta=-33.873908 -> V=1.0, theta=0.0
% INFO    : Bus 22627	: V=0.9906889, theta=-33.067436 -> V=1.0, theta=0.0
% INFO    : Bus 22628	: V=0.9904082, theta=-34.617964 -> V=1.0, theta=0.0
% INFO    : Bus 22629	: V=1.0103415, theta=-33.711778 -> V=1.0, theta=0.0
% INFO    : Bus 22630	: V=0.9838755, theta=-35.169996 -> V=1.0, theta=0.0
% INFO    : Bus 22631	: V=0.9708328, theta=-36.197243 -> V=1.0, theta=0.0
% INFO    : Bus 22632	: V=0.9718895, theta=-36.183625 -> V=1.0, theta=0.0
% INFO    : Bus 22633	: V=0.97963, theta=-36.108791 -> V=1.0, theta=0.0
% INFO    : Bus 22634	: V=0.9737002, theta=-36.790908 -> V=1.0, theta=0.0
% INFO    : Bus 22635	: V=0.9675017, theta=-36.240357 -> V=1.0, theta=0.0
% INFO    : Bus 22636	: V=0.9993946, theta=-35.051913 -> V=1.0, theta=0.0
% INFO    : Bus 22637	: V=0.9887134, theta=-35.224188 -> V=1.0, theta=0.0
% INFO    : Bus 22638	: V=0.9842814, theta=-35.542756 -> V=1.0, theta=0.0
% INFO    : Bus 22639	: V=1.0165781, theta=-32.951358 -> V=1.0, theta=0.0
% INFO    : Bus 22640	: V=0.9799841, theta=-41.586108 -> V=1.0, theta=0.0
% INFO    : Bus 22641	: V=0.9827042, theta=-41.555688 -> V=1.0, theta=0.0
% INFO    : Bus 22642	: V=0.9840312, theta=-41.458749 -> V=1.0, theta=0.0
% INFO    : Bus 22643	: V=0.9830443, theta=-41.486181 -> V=1.0, theta=0.0
% INFO    : Bus 22644	: V=0.9815185, theta=-41.54804 -> V=1.0, theta=0.0
% INFO    : Bus 22645	: V=0.9819411, theta=-41.600698 -> V=1.0, theta=0.0
% INFO    : Bus 22646	: V=0.9845458, theta=-41.45375 -> V=1.0, theta=0.0
% INFO    : Bus 22647	: V=0.9852477, theta=-41.3867 -> V=1.0, theta=0.0
% INFO    : Bus 22648	: V=0.996931, theta=-39.983411 -> V=1.0, theta=0.0
% INFO    : Bus 22649	: V=0.9859109, theta=-41.397229 -> V=1.0, theta=0.0
% INFO    : Bus 22650	: V=0.9892186, theta=-41.297805 -> V=1.0, theta=0.0
% INFO    : Bus 22651	: V=0.996491, theta=-40.028627 -> V=1.0, theta=0.0
% INFO    : Bus 22652	: V=0.9966195, theta=-40.011748 -> V=1.0, theta=0.0
% INFO    : Bus 22653	: V=0.996938, theta=-39.980836 -> V=1.0, theta=0.0
% INFO    : Bus 22654	: V=0.9973275, theta=-39.946048 -> V=1.0, theta=0.0
% INFO    : Bus 22655	: V=0.9888867, theta=-41.34017 -> V=1.0, theta=0.0
% INFO    : Bus 22656	: V=0.989448, theta=-41.177595 -> V=1.0, theta=0.0
% INFO    : Bus 22657	: V=0.980272, theta=-41.585047 -> V=1.0, theta=0.0
% INFO    : Bus 22658	: V=0.9805534, theta=-41.548598 -> V=1.0, theta=0.0
% INFO    : Bus 22659	: V=0.9903268, theta=-40.650985 -> V=1.0, theta=0.0
% INFO    : Bus 22660	: V=0.9821863, theta=-41.629152 -> V=1.0, theta=0.0
% INFO    : Bus 22661	: V=0.9831984, theta=-41.504325 -> V=1.0, theta=0.0
% INFO    : Bus 22662	: V=0.9794099, theta=-41.939754 -> V=1.0, theta=0.0
% INFO    : Bus 22663	: V=0.9826516, theta=-41.782981 -> V=1.0, theta=0.0
% INFO    : Bus 22664	: V=0.9831407, theta=-41.70937 -> V=1.0, theta=0.0
% INFO    : Bus 22665	: V=0.9839482, theta=-41.604201 -> V=1.0, theta=0.0
% INFO    : Bus 22666	: V=0.9795216, theta=-41.590464 -> V=1.0, theta=0.0
% INFO    : Bus 22667	: V=0.980274, theta=-41.566332 -> V=1.0, theta=0.0
% INFO    : Bus 22668	: V=0.9822837, theta=-41.586519 -> V=1.0, theta=0.0
% INFO    : Bus 22669	: V=0.9831603, theta=-41.641944 -> V=1.0, theta=0.0
% INFO    : Bus 22670	: V=0.9799547, theta=-41.673547 -> V=1.0, theta=0.0
% INFO    : Bus 22671	: V=0.986553, theta=-41.5893 -> V=1.0, theta=0.0
% INFO    : Bus 22672	: V=0.9825976, theta=-41.697671 -> V=1.0, theta=0.0
% INFO    : Bus 22673	: V=0.9815962, theta=-41.97681 -> V=1.0, theta=0.0
% INFO    : Bus 22674	: V=0.9908779, theta=-41.402461 -> V=1.0, theta=0.0
% INFO    : Bus 22675	: V=0.9807181, theta=-41.692277 -> V=1.0, theta=0.0
% INFO    : Bus 22676	: V=0.9829931, theta=-41.887586 -> V=1.0, theta=0.0
% INFO    : Bus 22677	: V=0.9822539, theta=-41.932549 -> V=1.0, theta=0.0
% INFO    : Bus 22678	: V=0.9802079, theta=-41.684524 -> V=1.0, theta=0.0
% INFO    : Bus 22679	: V=0.9819885, theta=-41.951006 -> V=1.0, theta=0.0
% INFO    : Bus 22680	: V=0.9818207, theta=-41.962563 -> V=1.0, theta=0.0
% INFO    : Bus 22681	: V=0.9814254, theta=-41.511528 -> V=1.0, theta=0.0
% INFO    : Bus 22682	: V=0.9816808, theta=-41.67069 -> V=1.0, theta=0.0
% INFO    : Bus 22683	: V=0.9823046, theta=-41.478668 -> V=1.0, theta=0.0
% INFO    : Bus 22684	: V=0.9799043, theta=-41.904069 -> V=1.0, theta=0.0
% INFO    : Bus 22685	: V=0.9789226, theta=-41.903102 -> V=1.0, theta=0.0
% INFO    : Bus 22686	: V=0.9799636, theta=-42.110452 -> V=1.0, theta=0.0
% INFO    : Bus 22687	: V=0.9809577, theta=-41.740575 -> V=1.0, theta=0.0
% INFO    : Bus 22688	: V=0.9833418, theta=-41.807681 -> V=1.0, theta=0.0
% INFO    : Bus 22689	: V=0.9764435, theta=-42.403638 -> V=1.0, theta=0.0
% INFO    : Bus 22690	: V=0.9802476, theta=-42.104274 -> V=1.0, theta=0.0
% INFO    : Bus 22691	: V=0.9802698, theta=-42.118226 -> V=1.0, theta=0.0
% INFO    : Bus 22692	: V=0.9790883, theta=-42.103671 -> V=1.0, theta=0.0
% INFO    : Bus 22693	: V=0.990024, theta=-40.894494 -> V=1.0, theta=0.0
% INFO    : Bus 22694	: V=0.9819743, theta=-41.91527 -> V=1.0, theta=0.0
% INFO    : Bus 22695	: V=1.0179791, theta=-36.811379 -> V=1.0, theta=0.0
% INFO    : Bus 22696	: V=0.9888456, theta=-40.955018 -> V=1.0, theta=0.0
% INFO    : Bus 22697	: V=0.9896409, theta=-40.952679 -> V=1.0, theta=0.0
% INFO    : Bus 22698	: V=0.9784866, theta=-42.852776 -> V=1.0, theta=0.0
% INFO    : Bus 22699	: V=0.9935959, theta=-40.479981 -> V=1.0, theta=0.0
% INFO    : Bus 22700	: V=0.9851323, theta=-41.12184 -> V=1.0, theta=0.0
% INFO    : Bus 22701	: V=0.975623, theta=-42.449357 -> V=1.0, theta=0.0
% INFO    : Bus 22702	: V=0.9734761, theta=-42.696767 -> V=1.0, theta=0.0
% INFO    : Bus 22703	: V=0.9735028, theta=-42.742114 -> V=1.0, theta=0.0
% INFO    : Bus 22704	: V=0.9763944, theta=-45.275329 -> V=1.0, theta=0.0
% INFO    : Bus 22705	: V=0.9701565, theta=-45.305145 -> V=1.0, theta=0.0
% INFO    : Bus 22706	: V=0.9759443, theta=-45.481002 -> V=1.0, theta=0.0
% INFO    : Bus 22707	: V=0.9791245, theta=-43.543968 -> V=1.0, theta=0.0
% INFO    : Bus 22708	: V=0.9894362, theta=-41.219007 -> V=1.0, theta=0.0
% INFO    : Bus 22709	: V=0.9885038, theta=-41.390991 -> V=1.0, theta=0.0
% INFO    : Bus 22710	: V=0.9766213, theta=-43.77526 -> V=1.0, theta=0.0
% INFO    : Bus 22711	: V=0.9713604, theta=-45.419453 -> V=1.0, theta=0.0
% INFO    : Bus 22712	: V=0.9829031, theta=-41.528913 -> V=1.0, theta=0.0
% INFO    : Bus 22713	: V=0.9832314, theta=-41.486212 -> V=1.0, theta=0.0
% INFO    : Bus 22714	: V=0.9859884, theta=-41.358749 -> V=1.0, theta=0.0
% INFO    : Bus 22715	: V=0.9913993, theta=-40.454958 -> V=1.0, theta=0.0
% INFO    : Bus 22716	: V=0.9862542, theta=-41.383291 -> V=1.0, theta=0.0
% INFO    : Bus 22717	: V=0.9883451, theta=-41.469529 -> V=1.0, theta=0.0
% INFO    : Bus 22718	: V=0.9893883, theta=-41.338984 -> V=1.0, theta=0.0
% INFO    : Bus 22719	: V=0.9817751, theta=-41.669222 -> V=1.0, theta=0.0
% INFO    : Bus 22720	: V=0.9777176, theta=-44.372918 -> V=1.0, theta=0.0
% INFO    : Bus 22721	: V=0.9850551, theta=-39.751903 -> V=1.0, theta=0.0
% INFO    : Bus 22722	: V=0.9605652, theta=-40.824868 -> V=1.0, theta=0.0
% INFO    : Bus 22723	: V=0.9592861, theta=-40.837987 -> V=1.0, theta=0.0
% INFO    : Bus 22724	: V=0.9651545, theta=-41.280897 -> V=1.0, theta=0.0
% INFO    : Bus 22725	: V=0.9650758, theta=-43.342785 -> V=1.0, theta=0.0
% INFO    : Bus 22726	: V=0.9672435, theta=-43.854549 -> V=1.0, theta=0.0
% INFO    : Bus 22727	: V=0.9745864, theta=-41.515541 -> V=1.0, theta=0.0
% INFO    : Bus 22728	: V=0.9711122, theta=-42.497948 -> V=1.0, theta=0.0
% INFO    : Bus 22729	: V=0.9796772, theta=-40.871573 -> V=1.0, theta=0.0
% INFO    : Bus 22730	: V=0.9782964, theta=-41.223565 -> V=1.0, theta=0.0
% INFO    : Bus 22731	: V=0.9759248, theta=-41.821556 -> V=1.0, theta=0.0
% INFO    : Bus 22732	: V=0.971006, theta=-41.733457 -> V=1.0, theta=0.0
% INFO    : Bus 22733	: V=0.9712478, theta=-41.72187 -> V=1.0, theta=0.0
% INFO    : Bus 22734	: V=0.9691679, theta=-34.029958 -> V=1.0, theta=0.0
% INFO    : Bus 22735	: V=0.9592248, theta=-34.911779 -> V=1.0, theta=0.0
% INFO    : Bus 22736	: V=0.9727181, theta=-34.451149 -> V=1.0, theta=0.0
% INFO    : Bus 22737	: V=0.9731458, theta=-34.61511 -> V=1.0, theta=0.0
% INFO    : Bus 22738	: V=0.9561005, theta=-35.278286 -> V=1.0, theta=0.0
% INFO    : Bus 22739	: V=0.9570773, theta=-34.749513 -> V=1.0, theta=0.0
% INFO    : Bus 22740	: V=0.9622668, theta=-34.229387 -> V=1.0, theta=0.0
% INFO    : Bus 22741	: V=0.9583688, theta=-34.227362 -> V=1.0, theta=0.0
% INFO    : Bus 22742	: V=0.9626145, theta=-34.38089 -> V=1.0, theta=0.0
% INFO    : Bus 22743	: V=1.0114644, theta=-32.638247 -> V=1.0, theta=0.0
% INFO    : Bus 22744	: V=0.9780804, theta=-34.540106 -> V=1.0, theta=0.0
% INFO    : Bus 22745	: V=0.9770824, theta=-34.655088 -> V=1.0, theta=0.0
% INFO    : Bus 22746	: V=0.9774042, theta=-34.726052 -> V=1.0, theta=0.0
% INFO    : Bus 22747	: V=0.9837706, theta=-34.608463 -> V=1.0, theta=0.0
% INFO    : Bus 22748	: V=0.9841311, theta=-34.208581 -> V=1.0, theta=0.0
% INFO    : Bus 22749	: V=0.9778377, theta=-35.202037 -> V=1.0, theta=0.0
% INFO    : Bus 22750	: V=0.9762491, theta=-34.869745 -> V=1.0, theta=0.0
% INFO    : Bus 22751	: V=0.9827, theta=-34.756824 -> V=1.0, theta=0.0
% INFO    : Bus 22752	: V=0.9865039, theta=-34.591459 -> V=1.0, theta=0.0
% INFO    : Bus 22753	: V=0.9871108, theta=-34.587729 -> V=1.0, theta=0.0
% INFO    : Bus 22754	: V=0.9965747, theta=-33.708626 -> V=1.0, theta=0.0
% INFO    : Bus 22755	: V=0.9858749, theta=-34.582819 -> V=1.0, theta=0.0
% INFO    : Bus 22756	: V=0.995385, theta=-34.212807 -> V=1.0, theta=0.0
% INFO    : Bus 22757	: V=0.9844201, theta=-34.393129 -> V=1.0, theta=0.0
% INFO    : Bus 22758	: V=0.9873816, theta=-34.292272 -> V=1.0, theta=0.0
% INFO    : Bus 22759	: V=1.0112896, theta=-31.666093 -> V=1.0, theta=0.0
% INFO    : Bus 22760	: V=0.9879703, theta=-34.370673 -> V=1.0, theta=0.0
% INFO    : Bus 22761	: V=0.9871, theta=-34.541736 -> V=1.0, theta=0.0
% INFO    : Bus 22762	: V=0.9800202, theta=-34.955521 -> V=1.0, theta=0.0
% INFO    : Bus 22763	: V=1.0149341, theta=-47.933303 -> V=1.0, theta=0.0
% INFO    : Bus 22764	: V=1.015787, theta=-47.909871 -> V=1.0, theta=0.0
% INFO    : Bus 22765	: V=1.0081764, theta=-48.528329 -> V=1.0, theta=0.0
% INFO    : Bus 22766	: V=1.0024442, theta=-48.613107 -> V=1.0, theta=0.0
% INFO    : Bus 22767	: V=1.004795, theta=-48.714666 -> V=1.0, theta=0.0
% INFO    : Bus 22768	: V=1.0044196, theta=-48.966568 -> V=1.0, theta=0.0
% INFO    : Bus 22769	: V=1.0030458, theta=-48.803484 -> V=1.0, theta=0.0
% INFO    : Bus 22770	: V=1.002951, theta=-48.870852 -> V=1.0, theta=0.0
% INFO    : Bus 22771	: V=1.0027839, theta=-48.921897 -> V=1.0, theta=0.0
% INFO    : Bus 22772	: V=1.0183376, theta=-48.016502 -> V=1.0, theta=0.0
% INFO    : Bus 22773	: V=1.003097, theta=-48.971325 -> V=1.0, theta=0.0
% INFO    : Bus 22774	: V=1.0165439, theta=-48.143077 -> V=1.0, theta=0.0
% INFO    : Bus 22775	: V=1.0035536, theta=-48.953482 -> V=1.0, theta=0.0
% INFO    : Bus 22776	: V=1.0017379, theta=-49.00386 -> V=1.0, theta=0.0
% INFO    : Bus 22777	: V=1.0007062, theta=-48.819757 -> V=1.0, theta=0.0
% INFO    : Bus 22778	: V=0.999911, theta=-48.821279 -> V=1.0, theta=0.0
% INFO    : Bus 22779	: V=1.0059629, theta=-48.746811 -> V=1.0, theta=0.0
% INFO    : Bus 22780	: V=1.0118761, theta=-48.282916 -> V=1.0, theta=0.0
% INFO    : Bus 22781	: V=0.9943627, theta=-47.895518 -> V=1.0, theta=0.0
% INFO    : Bus 22782	: V=1.0137558, theta=-47.916606 -> V=1.0, theta=0.0
% INFO    : Bus 22783	: V=1.0027699, theta=-48.323101 -> V=1.0, theta=0.0
% INFO    : Bus 22784	: V=1.0177087, theta=-47.839555 -> V=1.0, theta=0.0
% INFO    : Bus 22785	: V=0.9988263, theta=-49.018301 -> V=1.0, theta=0.0
% INFO    : Bus 22786	: V=1.0107202, theta=-48.504856 -> V=1.0, theta=0.0
% INFO    : Bus 22787	: V=1.0060774, theta=-49.053439 -> V=1.0, theta=0.0
% INFO    : Bus 22788	: V=1.0008233, theta=-49.765625 -> V=1.0, theta=0.0
% INFO    : Bus 22789	: V=0.9998263, theta=-49.683204 -> V=1.0, theta=0.0
% INFO    : Bus 22790	: V=0.9921451, theta=-52.06157 -> V=1.0, theta=0.0
% INFO    : Bus 22791	: V=0.9740483, theta=-51.204063 -> V=1.0, theta=0.0
% INFO    : Bus 22792	: V=0.9787315, theta=-51.927866 -> V=1.0, theta=0.0
% INFO    : Bus 22793	: V=0.9599022, theta=-49.387005 -> V=1.0, theta=0.0
% INFO    : Bus 22794	: V=0.9607426, theta=-47.095959 -> V=1.0, theta=0.0
% INFO    : Bus 22795	: V=0.9815909, theta=-46.593593 -> V=1.0, theta=0.0
% INFO    : Bus 22796	: V=0.9868931, theta=-48.529799 -> V=1.0, theta=0.0
% INFO    : Bus 22797	: V=0.9755702, theta=-48.544464 -> V=1.0, theta=0.0
% INFO    : Bus 22798	: V=0.9827601, theta=-52.56762 -> V=1.0, theta=0.0
% INFO    : Bus 22799	: V=1.000679, theta=-48.922838 -> V=1.0, theta=0.0
% INFO    : Bus 22800	: V=1.0048557, theta=-48.712518 -> V=1.0, theta=0.0
% INFO    : Bus 22801	: V=0.9661422, theta=-52.277318 -> V=1.0, theta=0.0
% INFO    : Bus 22802	: V=0.9654754, theta=-52.298046 -> V=1.0, theta=0.0
% INFO    : Bus 22803	: V=0.9657755, theta=-52.243657 -> V=1.0, theta=0.0
% INFO    : Bus 22804	: V=0.9734807, theta=-51.4793 -> V=1.0, theta=0.0
% INFO    : Bus 22805	: V=0.9656425, theta=-52.223179 -> V=1.0, theta=0.0
% INFO    : Bus 22806	: V=0.9643494, theta=-52.339802 -> V=1.0, theta=0.0
% INFO    : Bus 22807	: V=0.9750309, theta=-51.687232 -> V=1.0, theta=0.0
% INFO    : Bus 22808	: V=0.9758129, theta=-51.724723 -> V=1.0, theta=0.0
% INFO    : Bus 22809	: V=0.9642661, theta=-52.40206 -> V=1.0, theta=0.0
% INFO    : Bus 22810	: V=0.963924, theta=-52.437893 -> V=1.0, theta=0.0
% INFO    : Bus 22811	: V=0.9632579, theta=-52.219602 -> V=1.0, theta=0.0
% INFO    : Bus 22812	: V=0.9732835, theta=-51.256949 -> V=1.0, theta=0.0
% INFO    : Bus 22813	: V=0.9631206, theta=-52.044746 -> V=1.0, theta=0.0
% INFO    : Bus 22814	: V=0.964763, theta=-52.225354 -> V=1.0, theta=0.0
% INFO    : Bus 22815	: V=0.9637985, theta=-52.358385 -> V=1.0, theta=0.0
% INFO    : Bus 22816	: V=0.9640996, theta=-52.073388 -> V=1.0, theta=0.0
% INFO    : Bus 22817	: V=0.9644021, theta=-52.192821 -> V=1.0, theta=0.0
% INFO    : Bus 22818	: V=0.9646946, theta=-52.222863 -> V=1.0, theta=0.0
% INFO    : Bus 22819	: V=0.9655396, theta=-52.257301 -> V=1.0, theta=0.0
% INFO    : Bus 22820	: V=0.9665193, theta=-52.285406 -> V=1.0, theta=0.0
% INFO    : Bus 22821	: V=0.9641695, theta=-52.472525 -> V=1.0, theta=0.0
% INFO    : Bus 22822	: V=0.9653866, theta=-52.496391 -> V=1.0, theta=0.0
% INFO    : Bus 22823	: V=0.9871681, theta=-51.143748 -> V=1.0, theta=0.0
% INFO    : Bus 22824	: V=0.9703407, theta=-52.440262 -> V=1.0, theta=0.0
% INFO    : Bus 22825	: V=0.9756453, theta=-51.727396 -> V=1.0, theta=0.0
% INFO    : Bus 22826	: V=0.9880405, theta=-51.09747 -> V=1.0, theta=0.0
% INFO    : Bus 22827	: V=0.978545, theta=-52.007664 -> V=1.0, theta=0.0
% INFO    : Bus 22828	: V=0.9654723, theta=-52.456413 -> V=1.0, theta=0.0
% INFO    : Bus 22829	: V=0.9898695, theta=-50.656797 -> V=1.0, theta=0.0
% INFO    : Bus 22830	: V=0.9655865, theta=-52.370015 -> V=1.0, theta=0.0
% INFO    : Bus 22831	: V=0.9648539, theta=-52.414439 -> V=1.0, theta=0.0
% INFO    : Bus 22832	: V=0.9650344, theta=-52.435251 -> V=1.0, theta=0.0
% INFO    : Bus 22833	: V=0.9888992, theta=-50.866193 -> V=1.0, theta=0.0
% INFO    : Bus 22834	: V=0.9777501, theta=-52.477164 -> V=1.0, theta=0.0
% INFO    : Bus 22835	: V=0.9741859, theta=-52.005744 -> V=1.0, theta=0.0
% INFO    : Bus 22836	: V=0.9720005, theta=-51.877726 -> V=1.0, theta=0.0
% INFO    : Bus 22837	: V=0.9694006, theta=-51.452939 -> V=1.0, theta=0.0
% INFO    : Bus 22838	: V=0.9717484, theta=-50.747771 -> V=1.0, theta=0.0
% INFO    : Bus 22839	: V=0.9735313, theta=-50.582236 -> V=1.0, theta=0.0
% INFO    : Bus 22840	: V=0.9641613, theta=-51.942665 -> V=1.0, theta=0.0
% INFO    : Bus 22841	: V=0.9769379, theta=-50.232866 -> V=1.0, theta=0.0
% INFO    : Bus 22842	: V=0.9642891, theta=-52.001704 -> V=1.0, theta=0.0
% INFO    : Bus 22843	: V=0.9691316, theta=-51.538659 -> V=1.0, theta=0.0
% INFO    : Bus 22844	: V=0.9720035, theta=-51.819262 -> V=1.0, theta=0.0
% INFO    : Bus 22845	: V=0.9814946, theta=-50.8101 -> V=1.0, theta=0.0
% INFO    : Bus 22846	: V=0.9925633, theta=-50.091599 -> V=1.0, theta=0.0
% INFO    : Bus 22847	: V=0.9910398, theta=-50.40831 -> V=1.0, theta=0.0
% INFO    : Bus 22848	: V=0.9874397, theta=-51.167538 -> V=1.0, theta=0.0
% INFO    : Bus 22849	: V=0.9692985, theta=-52.949642 -> V=1.0, theta=0.0
% INFO    : Bus 22850	: V=0.9768957, theta=-52.019876 -> V=1.0, theta=0.0
% INFO    : Bus 22851	: V=0.9623907, theta=-52.252971 -> V=1.0, theta=0.0
% INFO    : Bus 22852	: V=0.9624342, theta=-52.249269 -> V=1.0, theta=0.0
% INFO    : Bus 22853	: V=0.9702181, theta=-53.198856 -> V=1.0, theta=0.0
% INFO    : Bus 22854	: V=0.9707104, theta=-52.946454 -> V=1.0, theta=0.0
% INFO    : Bus 22855	: V=0.9662033, theta=-53.402925 -> V=1.0, theta=0.0
% INFO    : Bus 22856	: V=0.9751312, theta=-52.126544 -> V=1.0, theta=0.0
% INFO    : Bus 22857	: V=0.9797735, theta=-51.860576 -> V=1.0, theta=0.0
% INFO    : Bus 22858	: V=0.9737583, theta=-33.745178 -> V=1.0, theta=0.0
% INFO    : Bus 22859	: V=0.9894942, theta=-33.059661 -> V=1.0, theta=0.0
% INFO    : Bus 22860	: V=0.98748, theta=-32.816444 -> V=1.0, theta=0.0
% INFO    : Bus 22861	: V=0.979363, theta=-32.675964 -> V=1.0, theta=0.0
% INFO    : Bus 22862	: V=0.9855956, theta=-32.817646 -> V=1.0, theta=0.0
% INFO    : Bus 22863	: V=0.9644553, theta=-44.179248 -> V=1.0, theta=0.0
% INFO    : Bus 22864	: V=0.9640372, theta=-44.242614 -> V=1.0, theta=0.0
% INFO    : Bus 22865	: V=0.9619734, theta=-44.429907 -> V=1.0, theta=0.0
% INFO    : Bus 22866	: V=0.9637535, theta=-44.276108 -> V=1.0, theta=0.0
% INFO    : Bus 22867	: V=0.9640341, theta=-44.30651 -> V=1.0, theta=0.0
% INFO    : Bus 22868	: V=0.9705945, theta=-44.02757 -> V=1.0, theta=0.0
% INFO    : Bus 22869	: V=0.9667785, theta=-44.365239 -> V=1.0, theta=0.0
% INFO    : Bus 22870	: V=0.9759261, theta=-43.726692 -> V=1.0, theta=0.0
% INFO    : Bus 22871	: V=0.9751295, theta=-43.76803 -> V=1.0, theta=0.0
% INFO    : Bus 22872	: V=0.9663879, theta=-44.447247 -> V=1.0, theta=0.0
% INFO    : Bus 22873	: V=0.9642793, theta=-44.547348 -> V=1.0, theta=0.0
% INFO    : Bus 22874	: V=0.9636432, theta=-44.547154 -> V=1.0, theta=0.0
% INFO    : Bus 22875	: V=0.968415, theta=-44.505447 -> V=1.0, theta=0.0
% INFO    : Bus 22876	: V=0.9746435, theta=-43.792732 -> V=1.0, theta=0.0
% INFO    : Bus 22877	: V=0.9887078, theta=-42.867796 -> V=1.0, theta=0.0
% INFO    : Bus 22878	: V=0.9890243, theta=-42.83135 -> V=1.0, theta=0.0
% INFO    : Bus 22879	: V=0.9771267, theta=-43.685189 -> V=1.0, theta=0.0
% INFO    : Bus 22880	: V=0.9777061, theta=-43.647857 -> V=1.0, theta=0.0
% INFO    : Bus 22881	: V=0.9785701, theta=-43.591533 -> V=1.0, theta=0.0
% INFO    : Bus 22882	: V=0.9688101, theta=-44.463026 -> V=1.0, theta=0.0
% INFO    : Bus 22883	: V=0.9678656, theta=-44.537519 -> V=1.0, theta=0.0
% INFO    : Bus 22884	: V=0.9678294, theta=-44.560223 -> V=1.0, theta=0.0
% INFO    : Bus 22885	: V=0.9754318, theta=-44.009395 -> V=1.0, theta=0.0
% INFO    : Bus 22886	: V=0.96287, theta=-44.630186 -> V=1.0, theta=0.0
% INFO    : Bus 22887	: V=0.9750126, theta=-44.039908 -> V=1.0, theta=0.0
% INFO    : Bus 22888	: V=0.9682993, theta=-44.611228 -> V=1.0, theta=0.0
% INFO    : Bus 22889	: V=0.9875517, theta=-42.959581 -> V=1.0, theta=0.0
% INFO    : Bus 22890	: V=0.9635627, theta=-44.722677 -> V=1.0, theta=0.0
% INFO    : Bus 22891	: V=0.9701017, theta=-44.615322 -> V=1.0, theta=0.0
% INFO    : Bus 22892	: V=0.9682095, theta=-44.599861 -> V=1.0, theta=0.0
% INFO    : Bus 22893	: V=0.9685724, theta=-44.61874 -> V=1.0, theta=0.0
% INFO    : Bus 22894	: V=0.9693343, theta=-44.626173 -> V=1.0, theta=0.0
% INFO    : Bus 22895	: V=0.9674926, theta=-44.653347 -> V=1.0, theta=0.0
% INFO    : Bus 22896	: V=0.9671349, theta=-44.674132 -> V=1.0, theta=0.0
% INFO    : Bus 22897	: V=0.9639648, theta=-44.829975 -> V=1.0, theta=0.0
% INFO    : Bus 22898	: V=0.9649925, theta=-44.828453 -> V=1.0, theta=0.0
% INFO    : Bus 22899	: V=0.9872386, theta=-42.984283 -> V=1.0, theta=0.0
% INFO    : Bus 22900	: V=0.9746586, theta=-44.129888 -> V=1.0, theta=0.0
% INFO    : Bus 22901	: V=0.9679831, theta=-44.717973 -> V=1.0, theta=0.0
% INFO    : Bus 22902	: V=0.9688141, theta=-44.680962 -> V=1.0, theta=0.0
% INFO    : Bus 22903	: V=0.9675543, theta=-44.718714 -> V=1.0, theta=0.0
% INFO    : Bus 22904	: V=0.9744353, theta=-44.143745 -> V=1.0, theta=0.0
% INFO    : Bus 22905	: V=0.9649412, theta=-44.951262 -> V=1.0, theta=0.0
% INFO    : Bus 22906	: V=0.9645131, theta=-45.004685 -> V=1.0, theta=0.0
% INFO    : Bus 22907	: V=0.9759771, theta=-44.059223 -> V=1.0, theta=0.0
% INFO    : Bus 22908	: V=0.9638068, theta=-45.102341 -> V=1.0, theta=0.0
% INFO    : Bus 22909	: V=0.9630237, theta=-45.156936 -> V=1.0, theta=0.0
% INFO    : Bus 22910	: V=0.9627705, theta=-40.267689 -> V=1.0, theta=0.0
% INFO    : Bus 22911	: V=0.9657319, theta=-40.156897 -> V=1.0, theta=0.0
% INFO    : Bus 22912	: V=0.9673531, theta=-40.515636 -> V=1.0, theta=0.0
% INFO    : Bus 22913	: V=0.9715609, theta=-39.752881 -> V=1.0, theta=0.0
% INFO    : Bus 22914	: V=0.9687696, theta=-40.20742 -> V=1.0, theta=0.0
% INFO    : Bus 22915	: V=0.969775, theta=-40.592079 -> V=1.0, theta=0.0
% INFO    : Bus 22916	: V=0.9685602, theta=-40.626393 -> V=1.0, theta=0.0
% INFO    : Bus 22917	: V=0.9622249, theta=-41.850151 -> V=1.0, theta=0.0
% INFO    : Bus 22918	: V=0.9652822, theta=-40.978501 -> V=1.0, theta=0.0
% INFO    : Bus 22919	: V=0.9635488, theta=-41.291171 -> V=1.0, theta=0.0
% INFO    : Bus 22920	: V=0.9647769, theta=-40.862192 -> V=1.0, theta=0.0
% INFO    : Bus 22921	: V=0.9632333, theta=-41.609374 -> V=1.0, theta=0.0
% INFO    : Bus 22922	: V=0.9636725, theta=-42.241407 -> V=1.0, theta=0.0
% INFO    : Bus 22923	: V=0.965179, theta=-42.803189 -> V=1.0, theta=0.0
% INFO    : Bus 22924	: V=0.9610089, theta=-43.446389 -> V=1.0, theta=0.0
% INFO    : Bus 22925	: V=0.9621907, theta=-43.164718 -> V=1.0, theta=0.0
% INFO    : Bus 22926	: V=0.957759, theta=-43.962781 -> V=1.0, theta=0.0
% INFO    : Bus 22927	: V=0.9592869, theta=-43.895858 -> V=1.0, theta=0.0
% INFO    : Bus 22928	: V=0.9619202, theta=-44.029936 -> V=1.0, theta=0.0
% INFO    : Bus 22929	: V=0.9603391, theta=-44.005787 -> V=1.0, theta=0.0
% INFO    : Bus 22930	: V=0.9605539, theta=-43.914522 -> V=1.0, theta=0.0
% INFO    : Bus 22931	: V=0.968363, theta=-42.981368 -> V=1.0, theta=0.0
% INFO    : Bus 22932	: V=0.9709106, theta=-43.364704 -> V=1.0, theta=0.0
% INFO    : Bus 22933	: V=0.9660086, theta=-43.776008 -> V=1.0, theta=0.0
% INFO    : Bus 22934	: V=0.9652789, theta=-43.988783 -> V=1.0, theta=0.0
% INFO    : Bus 22935	: V=0.9906294, theta=-42.670045 -> V=1.0, theta=0.0
% INFO    : Bus 22936	: V=0.9934547, theta=-42.424267 -> V=1.0, theta=0.0
% INFO    : Bus 22937	: V=0.9739697, theta=-43.803157 -> V=1.0, theta=0.0
% INFO    : Bus 22938	: V=0.9702687, theta=-44.00619 -> V=1.0, theta=0.0
% INFO    : Bus 22939	: V=0.9611598, theta=-44.172772 -> V=1.0, theta=0.0
% INFO    : Bus 22940	: V=0.9622288, theta=-44.386427 -> V=1.0, theta=0.0
% INFO    : Bus 22941	: V=0.967226, theta=-44.603973 -> V=1.0, theta=0.0
% INFO    : Bus 22942	: V=0.9783824, theta=-43.770085 -> V=1.0, theta=0.0
% INFO    : Bus 22943	: V=0.9743053, theta=-44.124268 -> V=1.0, theta=0.0
% INFO    : Bus 22944	: V=0.9785137, theta=-43.872379 -> V=1.0, theta=0.0
% INFO    : Bus 22945	: V=0.9749169, theta=-43.952217 -> V=1.0, theta=0.0
% INFO    : Bus 22946	: V=0.9768879, theta=-43.282395 -> V=1.0, theta=0.0
% INFO    : Bus 22947	: V=0.9755711, theta=-44.073856 -> V=1.0, theta=0.0
% INFO    : Bus 22948	: V=0.9767711, theta=-44.01673 -> V=1.0, theta=0.0
% INFO    : Bus 22949	: V=0.992002, theta=-42.81762 -> V=1.0, theta=0.0
% INFO    : Bus 22950	: V=0.9661941, theta=-44.678616 -> V=1.0, theta=0.0
% INFO    : Bus 22951	: V=0.975041, theta=-44.057991 -> V=1.0, theta=0.0
% INFO    : Bus 22952	: V=0.9672127, theta=-44.702218 -> V=1.0, theta=0.0
% INFO    : Bus 22953	: V=0.9784335, theta=-43.91379 -> V=1.0, theta=0.0
% INFO    : Bus 22954	: V=0.9681382, theta=-44.875638 -> V=1.0, theta=0.0
% INFO    : Bus 22955	: V=0.9689075, theta=-44.872926 -> V=1.0, theta=0.0
% INFO    : Bus 22956	: V=0.9666465, theta=-45.095845 -> V=1.0, theta=0.0
% INFO    : Bus 22957	: V=0.9908056, theta=-42.816551 -> V=1.0, theta=0.0
% INFO    : Bus 22958	: V=0.9627957, theta=-45.133414 -> V=1.0, theta=0.0
% INFO    : Bus 22959	: V=0.9620435, theta=-45.137396 -> V=1.0, theta=0.0
% INFO    : Bus 22960	: V=0.9614997, theta=-45.153949 -> V=1.0, theta=0.0
% INFO    : Bus 22961	: V=0.9626541, theta=-45.151207 -> V=1.0, theta=0.0
% INFO    : Bus 22962	: V=0.9629969, theta=-45.147102 -> V=1.0, theta=0.0
% INFO    : Bus 22963	: V=0.9623656, theta=-45.232943 -> V=1.0, theta=0.0
% INFO    : Bus 22964	: V=0.9784849, theta=-43.720714 -> V=1.0, theta=0.0
% INFO    : Bus 22965	: V=0.9788553, theta=-43.697938 -> V=1.0, theta=0.0
% INFO    : Bus 22966	: V=0.9775459, theta=-43.837567 -> V=1.0, theta=0.0
% INFO    : Bus 22967	: V=0.9772591, theta=-43.872638 -> V=1.0, theta=0.0
% INFO    : Bus 22968	: V=0.9768654, theta=-43.876638 -> V=1.0, theta=0.0
% INFO    : Bus 22969	: V=0.9763823, theta=-43.941225 -> V=1.0, theta=0.0
% INFO    : Bus 22970	: V=0.9745041, theta=-44.1414 -> V=1.0, theta=0.0
% INFO    : Bus 22971	: V=0.9752853, theta=-44.043325 -> V=1.0, theta=0.0
% INFO    : Bus 22972	: V=0.97624, theta=-43.955346 -> V=1.0, theta=0.0
% INFO    : Bus 22973	: V=0.9758117, theta=-43.993703 -> V=1.0, theta=0.0
% INFO    : Bus 22974	: V=0.9692026, theta=-44.614631 -> V=1.0, theta=0.0
% INFO    : Bus 22975	: V=0.9666218, theta=-44.982287 -> V=1.0, theta=0.0
% INFO    : Bus 22976	: V=0.9646807, theta=-45.079773 -> V=1.0, theta=0.0
% INFO    : Bus 22977	: V=0.9742328, theta=-44.187533 -> V=1.0, theta=0.0
% INFO    : Bus 22978	: V=0.9759334, theta=-44.164927 -> V=1.0, theta=0.0
% INFO    : Bus 22979	: V=0.9721664, theta=-44.658778 -> V=1.0, theta=0.0
% INFO    : Bus 22980	: V=0.965111, theta=-44.963338 -> V=1.0, theta=0.0
% INFO    : Bus 22981	: V=0.9698445, theta=-44.882516 -> V=1.0, theta=0.0
% INFO    : Bus 22982	: V=0.9839318, theta=-43.758517 -> V=1.0, theta=0.0
% INFO    : Bus 22983	: V=0.9618578, theta=-45.323156 -> V=1.0, theta=0.0
% INFO    : Bus 22984	: V=0.961311, theta=-45.324009 -> V=1.0, theta=0.0
% INFO    : Bus 22985	: V=0.9602314, theta=-45.418503 -> V=1.0, theta=0.0
% INFO    : Bus 22986	: V=0.9565692, theta=-45.671653 -> V=1.0, theta=0.0
% INFO    : Bus 22987	: V=0.9559397, theta=-45.961597 -> V=1.0, theta=0.0
% INFO    : Bus 22988	: V=0.9580519, theta=-45.659189 -> V=1.0, theta=0.0
% INFO    : Bus 22989	: V=0.9718621, theta=-45.373857 -> V=1.0, theta=0.0
% INFO    : Bus 22990	: V=0.978312, theta=-44.089862 -> V=1.0, theta=0.0
% INFO    : Bus 22991	: V=0.9624893, theta=-35.683178 -> V=1.0, theta=0.0
% INFO    : Bus 22992	: V=0.984077, theta=-35.643276 -> V=1.0, theta=0.0
% INFO    : Bus 22993	: V=1.0053329, theta=-29.612545 -> V=1.0, theta=0.0
% INFO    : Bus 22994	: V=0.9984932, theta=-30.934498 -> V=1.0, theta=0.0
% INFO    : Bus 22995	: V=1.0004373, theta=-29.69367 -> V=1.0, theta=0.0
% INFO    : Bus 22996	: V=1.0006082, theta=-30.394891 -> V=1.0, theta=0.0
% INFO    : Bus 22997	: V=0.9698233, theta=-37.79872 -> V=1.0, theta=0.0
% INFO    : Bus 22998	: V=0.9760167, theta=-37.200217 -> V=1.0, theta=0.0
% INFO    : Bus 22999	: V=0.9858256, theta=-37.75104 -> V=1.0, theta=0.0
% INFO    : Bus 23000	: V=0.9882189, theta=-37.246443 -> V=1.0, theta=0.0
% INFO    : Bus 23001	: V=0.9775184, theta=-37.707034 -> V=1.0, theta=0.0
% INFO    : Bus 23002	: V=0.9754665, theta=-37.759788 -> V=1.0, theta=0.0
% INFO    : Bus 23003	: V=0.9742008, theta=-38.161973 -> V=1.0, theta=0.0
% INFO    : Bus 23004	: V=0.985917, theta=-38.373116 -> V=1.0, theta=0.0
% INFO    : Bus 23005	: V=0.98622, theta=-38.097543 -> V=1.0, theta=0.0
% INFO    : Bus 23006	: V=0.9867571, theta=-37.874421 -> V=1.0, theta=0.0
% INFO    : Bus 23007	: V=0.983571, theta=-39.398559 -> V=1.0, theta=0.0
% INFO    : Bus 23008	: V=0.9827068, theta=-38.964376 -> V=1.0, theta=0.0
% INFO    : Bus 23009	: V=0.9856691, theta=-38.926782 -> V=1.0, theta=0.0
% INFO    : Bus 23010	: V=0.9953265, theta=-37.264623 -> V=1.0, theta=0.0
% INFO    : Bus 23011	: V=0.9817667, theta=-39.41666 -> V=1.0, theta=0.0
% INFO    : Bus 23012	: V=0.9809668, theta=-39.693601 -> V=1.0, theta=0.0
% INFO    : Bus 23013	: V=0.9817793, theta=-39.866833 -> V=1.0, theta=0.0
% INFO    : Bus 23014	: V=0.9877686, theta=-39.153974 -> V=1.0, theta=0.0
% INFO    : Bus 23015	: V=0.986491, theta=-40.114187 -> V=1.0, theta=0.0
% INFO    : Bus 23016	: V=0.9862964, theta=-40.263121 -> V=1.0, theta=0.0
% INFO    : Bus 23017	: V=0.9790278, theta=-40.611665 -> V=1.0, theta=0.0
% INFO    : Bus 23018	: V=0.9814379, theta=-40.192417 -> V=1.0, theta=0.0
% INFO    : Bus 23019	: V=0.9808033, theta=-40.039231 -> V=1.0, theta=0.0
% INFO    : Bus 23020	: V=0.9869355, theta=-38.068946 -> V=1.0, theta=0.0
% INFO    : Bus 23021	: V=0.9470482, theta=-35.273439 -> V=1.0, theta=0.0
% INFO    : Bus 23022	: V=0.9517606, theta=-35.111472 -> V=1.0, theta=0.0
% INFO    : Bus 23023	: V=0.9492634, theta=-35.174575 -> V=1.0, theta=0.0
% INFO    : Bus 23024	: V=0.9588265, theta=-32.797092 -> V=1.0, theta=0.0
% INFO    : Bus 23025	: V=0.9523928, theta=-34.965982 -> V=1.0, theta=0.0
% INFO    : Bus 23026	: V=0.9597576, theta=-34.454013 -> V=1.0, theta=0.0
% INFO    : Bus 23027	: V=0.9614022, theta=-54.185227 -> V=1.0, theta=0.0
% INFO    : Bus 23028	: V=0.9730475, theta=-53.818852 -> V=1.0, theta=0.0
% INFO    : Bus 23029	: V=0.9816302, theta=-53.456735 -> V=1.0, theta=0.0
% INFO    : Bus 23030	: V=0.9856342, theta=-53.340166 -> V=1.0, theta=0.0
% INFO    : Bus 23031	: V=0.9683472, theta=-54.996687 -> V=1.0, theta=0.0
% INFO    : Bus 23032	: V=0.9713572, theta=-55.23079 -> V=1.0, theta=0.0
% INFO    : Bus 23033	: V=0.9655216, theta=-55.622092 -> V=1.0, theta=0.0
% INFO    : Bus 23034	: V=0.9703926, theta=-54.344891 -> V=1.0, theta=0.0
% INFO    : Bus 23035	: V=0.9629953, theta=-54.36345 -> V=1.0, theta=0.0
% INFO    : Bus 23036	: V=0.9622035, theta=-55.742281 -> V=1.0, theta=0.0
% INFO    : Bus 23037	: V=0.9874986, theta=-53.997077 -> V=1.0, theta=0.0
% INFO    : Bus 23038	: V=0.9627223, theta=-55.881399 -> V=1.0, theta=0.0
% INFO    : Bus 23039	: V=0.9680435, theta=-55.549413 -> V=1.0, theta=0.0
% INFO    : Bus 23040	: V=0.9710022, theta=-55.034807 -> V=1.0, theta=0.0
% INFO    : Bus 23041	: V=0.9714347, theta=-54.928925 -> V=1.0, theta=0.0
% INFO    : Bus 23042	: V=0.9583571, theta=-56.186431 -> V=1.0, theta=0.0
% INFO    : Bus 23043	: V=0.9738187, theta=-55.336024 -> V=1.0, theta=0.0
% INFO    : Bus 23044	: V=0.9787974, theta=-55.376396 -> V=1.0, theta=0.0
% INFO    : Bus 23045	: V=0.9726735, theta=-55.455964 -> V=1.0, theta=0.0
% INFO    : Bus 23046	: V=0.9611391, theta=-55.355247 -> V=1.0, theta=0.0
% INFO    : Bus 23047	: V=0.9692871, theta=-55.09827 -> V=1.0, theta=0.0
% INFO    : Bus 23048	: V=0.9639965, theta=-54.24593 -> V=1.0, theta=0.0
% INFO    : Bus 23049	: V=0.9662184, theta=-54.053741 -> V=1.0, theta=0.0
% INFO    : Bus 23050	: V=0.969791, theta=-41.081634 -> V=1.0, theta=0.0
% INFO    : Bus 23051	: V=0.9630476, theta=-41.274736 -> V=1.0, theta=0.0
% INFO    : Bus 23052	: V=0.9697484, theta=-41.347873 -> V=1.0, theta=0.0
% INFO    : Bus 23053	: V=0.9698318, theta=-41.741066 -> V=1.0, theta=0.0
% INFO    : Bus 23054	: V=0.9668778, theta=-42.030345 -> V=1.0, theta=0.0
% INFO    : Bus 23055	: V=0.9665475, theta=-43.325408 -> V=1.0, theta=0.0
% INFO    : Bus 23056	: V=0.9653603, theta=-43.120904 -> V=1.0, theta=0.0
% INFO    : Bus 23057	: V=0.9662427, theta=-43.620486 -> V=1.0, theta=0.0
% INFO    : Bus 23058	: V=0.9660023, theta=-44.047479 -> V=1.0, theta=0.0
% INFO    : Bus 23059	: V=0.9698936, theta=-42.295665 -> V=1.0, theta=0.0
% INFO    : Bus 23060	: V=0.9665669, theta=-42.876271 -> V=1.0, theta=0.0
% INFO    : Bus 23061	: V=0.9682233, theta=-42.643051 -> V=1.0, theta=0.0
% INFO    : Bus 23062	: V=0.9668056, theta=-42.932195 -> V=1.0, theta=0.0
% INFO    : Bus 23063	: V=0.9610772, theta=-41.661949 -> V=1.0, theta=0.0
% INFO    : Bus 23064	: V=0.9681929, theta=-42.516714 -> V=1.0, theta=0.0
% INFO    : Bus 23065	: V=0.9709728, theta=-42.902327 -> V=1.0, theta=0.0
% INFO    : Bus 23066	: V=0.9705218, theta=-42.928942 -> V=1.0, theta=0.0
% INFO    : Bus 23067	: V=0.9686799, theta=-44.066367 -> V=1.0, theta=0.0
% INFO    : Bus 23068	: V=0.9685376, theta=-43.397467 -> V=1.0, theta=0.0
% INFO    : Bus 23069	: V=0.9661576, theta=-43.626814 -> V=1.0, theta=0.0
% INFO    : Bus 23070	: V=0.9670219, theta=-43.147625 -> V=1.0, theta=0.0
% INFO    : Bus 23071	: V=0.9639893, theta=-43.999897 -> V=1.0, theta=0.0
% INFO    : Bus 23072	: V=0.9674774, theta=-43.700886 -> V=1.0, theta=0.0
% INFO    : Bus 23073	: V=0.967262, theta=-44.729361 -> V=1.0, theta=0.0
% INFO    : Bus 23074	: V=0.967179, theta=-43.82759 -> V=1.0, theta=0.0
% INFO    : Bus 23075	: V=0.9685364, theta=-45.500485 -> V=1.0, theta=0.0
% INFO    : Bus 23076	: V=0.9671705, theta=-45.203313 -> V=1.0, theta=0.0
% INFO    : Bus 23077	: V=0.9691825, theta=-46.132637 -> V=1.0, theta=0.0
% INFO    : Bus 23078	: V=0.9705568, theta=-46.605755 -> V=1.0, theta=0.0
% INFO    : Bus 23079	: V=0.9712754, theta=-46.707112 -> V=1.0, theta=0.0
% INFO    : Bus 23080	: V=0.9712744, theta=-46.586516 -> V=1.0, theta=0.0
% INFO    : Bus 23081	: V=0.965764, theta=-44.380792 -> V=1.0, theta=0.0
% INFO    : Bus 23082	: V=0.9662281, theta=-43.077006 -> V=1.0, theta=0.0
% INFO    : Bus 23083	: V=0.9629146, theta=-44.583236 -> V=1.0, theta=0.0
% INFO    : Bus 23084	: V=0.9656772, theta=-43.187148 -> V=1.0, theta=0.0
% INFO    : Bus 23085	: V=0.966533, theta=-44.290984 -> V=1.0, theta=0.0
% INFO    : Bus 23086	: V=0.9619846, theta=-45.145178 -> V=1.0, theta=0.0
% INFO    : Bus 23087	: V=0.9623754, theta=-44.907298 -> V=1.0, theta=0.0
% INFO    : Bus 23088	: V=0.9667754, theta=-44.164987 -> V=1.0, theta=0.0
% INFO    : Bus 23089	: V=0.9627378, theta=-45.123274 -> V=1.0, theta=0.0
% INFO    : Bus 23090	: V=0.962007, theta=-45.183239 -> V=1.0, theta=0.0
% INFO    : Bus 23091	: V=0.9662811, theta=-43.987225 -> V=1.0, theta=0.0
% INFO    : Bus 23092	: V=0.9622652, theta=-44.601456 -> V=1.0, theta=0.0
% INFO    : Bus 23093	: V=0.9654224, theta=-44.307207 -> V=1.0, theta=0.0
% INFO    : Bus 23094	: V=0.9661264, theta=-43.811916 -> V=1.0, theta=0.0
% INFO    : Bus 23095	: V=0.9669189, theta=-43.96549 -> V=1.0, theta=0.0
% INFO    : Bus 23096	: V=0.9668239, theta=-44.052083 -> V=1.0, theta=0.0
% INFO    : Bus 23097	: V=0.9667685, theta=-44.138341 -> V=1.0, theta=0.0
% INFO    : Bus 23098	: V=0.9614064, theta=-45.200846 -> V=1.0, theta=0.0
% INFO    : Bus 23099	: V=0.9691015, theta=-45.543346 -> V=1.0, theta=0.0
% INFO    : Bus 23100	: V=0.9687763, theta=-46.133617 -> V=1.0, theta=0.0
% INFO    : Bus 23101	: V=0.963744, theta=-46.384437 -> V=1.0, theta=0.0
% INFO    : Bus 23102	: V=0.9649787, theta=-46.348549 -> V=1.0, theta=0.0
% INFO    : Bus 23103	: V=0.968081, theta=-46.575597 -> V=1.0, theta=0.0
% INFO    : Bus 23104	: V=0.9679486, theta=-46.446083 -> V=1.0, theta=0.0
% INFO    : Bus 23105	: V=0.9694293, theta=-44.273807 -> V=1.0, theta=0.0
% INFO    : Bus 23106	: V=0.9610874, theta=-45.204268 -> V=1.0, theta=0.0
% INFO    : Bus 23107	: V=0.9687018, theta=-45.780486 -> V=1.0, theta=0.0
% INFO    : Bus 23108	: V=0.9689157, theta=-45.765253 -> V=1.0, theta=0.0
% INFO    : Bus 23109	: V=0.9708236, theta=-45.531994 -> V=1.0, theta=0.0
% INFO    : Bus 23110	: V=0.9696527, theta=-45.919506 -> V=1.0, theta=0.0
% INFO    : Bus 23111	: V=1.0104399, theta=-31.913047 -> V=1.0, theta=0.0
% INFO    : Bus 23112	: V=1.0003149, theta=-32.322379 -> V=1.0, theta=0.0
% INFO    : Bus 23113	: V=0.9644118, theta=-32.825722 -> V=1.0, theta=0.0
% INFO    : Bus 23114	: V=0.9826594, theta=-32.606847 -> V=1.0, theta=0.0
% INFO    : Bus 23115	: V=1.0079867, theta=-32.007413 -> V=1.0, theta=0.0
% INFO    : Bus 23116	: V=0.977305, theta=-32.538203 -> V=1.0, theta=0.0
% INFO    : Bus 23117	: V=0.956998, theta=-32.803136 -> V=1.0, theta=0.0
% INFO    : Bus 23118	: V=0.9845029, theta=-41.459391 -> V=1.0, theta=0.0
% INFO    : Bus 23119	: V=0.9969211, theta=-39.828099 -> V=1.0, theta=0.0
% INFO    : Bus 23120	: V=1.0054241, theta=-40.571507 -> V=1.0, theta=0.0
% INFO    : Bus 23121	: V=0.9910356, theta=-40.746307 -> V=1.0, theta=0.0
% INFO    : Bus 23122	: V=0.9862761, theta=-40.929279 -> V=1.0, theta=0.0
% INFO    : Bus 23123	: V=0.9782821, theta=-41.330111 -> V=1.0, theta=0.0
% INFO    : Bus 23124	: V=0.9831265, theta=-41.812883 -> V=1.0, theta=0.0
% INFO    : Bus 23125	: V=0.9800664, theta=-42.163683 -> V=1.0, theta=0.0
% INFO    : Bus 23126	: V=0.9729084, theta=-42.496272 -> V=1.0, theta=0.0
% INFO    : Bus 23127	: V=0.9825978, theta=-42.341189 -> V=1.0, theta=0.0
% INFO    : Bus 23128	: V=0.9775159, theta=-42.638827 -> V=1.0, theta=0.0
% INFO    : Bus 23129	: V=1.0055503, theta=-40.612881 -> V=1.0, theta=0.0
% INFO    : Bus 23130	: V=0.9951239, theta=-41.398528 -> V=1.0, theta=0.0
% INFO    : Bus 23131	: V=1.0068379, theta=-40.61561 -> V=1.0, theta=0.0
% INFO    : Bus 23132	: V=1.0059632, theta=-40.7538 -> V=1.0, theta=0.0
% INFO    : Bus 23133	: V=1.0016237, theta=-41.508817 -> V=1.0, theta=0.0
% INFO    : Bus 23134	: V=0.9905798, theta=-42.164165 -> V=1.0, theta=0.0
% INFO    : Bus 23135	: V=0.9769501, theta=-43.422928 -> V=1.0, theta=0.0
% INFO    : Bus 23136	: V=0.9953669, theta=-41.631998 -> V=1.0, theta=0.0
% INFO    : Bus 23137	: V=0.9932114, theta=-42.071722 -> V=1.0, theta=0.0
% INFO    : Bus 23138	: V=1.0047147, theta=-40.958245 -> V=1.0, theta=0.0
% INFO    : Bus 23139	: V=0.9954596, theta=-41.713707 -> V=1.0, theta=0.0
% INFO    : Bus 23140	: V=0.9889077, theta=-42.319161 -> V=1.0, theta=0.0
% INFO    : Bus 23141	: V=1.0009787, theta=-41.666284 -> V=1.0, theta=0.0
% INFO    : Bus 23142	: V=0.972, theta=-43.491995 -> V=1.0, theta=0.0
% INFO    : Bus 23143	: V=0.9671123, theta=-43.774027 -> V=1.0, theta=0.0
% INFO    : Bus 23144	: V=0.9670586, theta=-43.823774 -> V=1.0, theta=0.0
% INFO    : Bus 23145	: V=0.9683111, theta=-43.843673 -> V=1.0, theta=0.0
% INFO    : Bus 23146	: V=1.000287, theta=-41.845377 -> V=1.0, theta=0.0
% INFO    : Bus 23147	: V=0.9999626, theta=-41.934327 -> V=1.0, theta=0.0
% INFO    : Bus 23148	: V=0.9701784, theta=-43.938801 -> V=1.0, theta=0.0
% INFO    : Bus 23149	: V=0.9693075, theta=-43.914542 -> V=1.0, theta=0.0
% INFO    : Bus 23150	: V=0.9714772, theta=-43.969991 -> V=1.0, theta=0.0
% INFO    : Bus 23151	: V=0.9706969, theta=-43.957969 -> V=1.0, theta=0.0
% INFO    : Bus 23152	: V=0.971642, theta=-43.351472 -> V=1.0, theta=0.0
% INFO    : Bus 23153	: V=0.9701442, theta=-43.463236 -> V=1.0, theta=0.0
% INFO    : Bus 23154	: V=0.970692, theta=-43.384542 -> V=1.0, theta=0.0
% INFO    : Bus 23155	: V=0.9781883, theta=-42.519455 -> V=1.0, theta=0.0
% INFO    : Bus 23156	: V=0.9694108, theta=-43.304198 -> V=1.0, theta=0.0
% INFO    : Bus 23157	: V=0.9694747, theta=-43.97381 -> V=1.0, theta=0.0
% INFO    : Bus 23158	: V=0.9734975, theta=-43.964628 -> V=1.0, theta=0.0
% INFO    : Bus 23159	: V=0.9716112, theta=-43.978161 -> V=1.0, theta=0.0
% INFO    : Bus 23160	: V=0.9673452, theta=-43.897655 -> V=1.0, theta=0.0
% INFO    : Bus 23161	: V=0.9654599, theta=-43.934092 -> V=1.0, theta=0.0
% INFO    : Bus 23162	: V=0.9825232, theta=-42.709438 -> V=1.0, theta=0.0
% INFO    : Bus 23163	: V=0.9820919, theta=-42.841849 -> V=1.0, theta=0.0
% INFO    : Bus 23164	: V=0.9821365, theta=-42.902208 -> V=1.0, theta=0.0
% INFO    : Bus 23165	: V=0.9681814, theta=-44.014571 -> V=1.0, theta=0.0
% INFO    : Bus 23166	: V=0.9689619, theta=-44.020232 -> V=1.0, theta=0.0
% INFO    : Bus 23167	: V=0.9693303, theta=-44.041657 -> V=1.0, theta=0.0
% INFO    : Bus 23168	: V=0.9707279, theta=-44.019496 -> V=1.0, theta=0.0
% INFO    : Bus 23169	: V=0.9712581, theta=-44.031177 -> V=1.0, theta=0.0
% INFO    : Bus 23170	: V=0.9756172, theta=-43.938666 -> V=1.0, theta=0.0
% INFO    : Bus 23171	: V=0.9696661, theta=-44.038701 -> V=1.0, theta=0.0
% INFO    : Bus 23172	: V=0.9710842, theta=-44.01171 -> V=1.0, theta=0.0
% INFO    : Bus 23173	: V=0.9857721, theta=-43.074903 -> V=1.0, theta=0.0
% INFO    : Bus 23174	: V=0.9761294, theta=-43.900714 -> V=1.0, theta=0.0
% INFO    : Bus 23175	: V=0.9793887, theta=-43.783928 -> V=1.0, theta=0.0
% INFO    : Bus 23176	: V=0.980771, theta=-43.82279 -> V=1.0, theta=0.0
% INFO    : Bus 23177	: V=0.990716, theta=-43.138237 -> V=1.0, theta=0.0
% INFO    : Bus 23178	: V=0.9772361, theta=-43.937153 -> V=1.0, theta=0.0
% INFO    : Bus 23179	: V=0.9995953, theta=-42.312534 -> V=1.0, theta=0.0
% INFO    : Bus 23180	: V=0.9900876, theta=-43.160301 -> V=1.0, theta=0.0
% INFO    : Bus 23181	: V=0.9994153, theta=-42.344706 -> V=1.0, theta=0.0
% INFO    : Bus 23182	: V=0.9994067, theta=-42.376126 -> V=1.0, theta=0.0
% INFO    : Bus 23183	: V=0.9995117, theta=-42.382677 -> V=1.0, theta=0.0
% INFO    : Bus 23184	: V=0.9892724, theta=-43.331164 -> V=1.0, theta=0.0
% INFO    : Bus 23185	: V=0.9908611, theta=-43.246409 -> V=1.0, theta=0.0
% INFO    : Bus 23186	: V=0.9866511, theta=-43.536029 -> V=1.0, theta=0.0
% INFO    : Bus 23187	: V=0.9855289, theta=-43.582508 -> V=1.0, theta=0.0
% INFO    : Bus 23188	: V=0.981584, theta=-43.829039 -> V=1.0, theta=0.0
% INFO    : Bus 23189	: V=0.9882161, theta=-43.334734 -> V=1.0, theta=0.0
% INFO    : Bus 23190	: V=1.0002376, theta=-42.360247 -> V=1.0, theta=0.0
% INFO    : Bus 23191	: V=0.9907051, theta=-43.345856 -> V=1.0, theta=0.0
% INFO    : Bus 23192	: V=0.9878958, theta=-43.500899 -> V=1.0, theta=0.0
% INFO    : Bus 23193	: V=0.975239, theta=-43.939584 -> V=1.0, theta=0.0
% INFO    : Bus 23194	: V=0.9755156, theta=-43.937389 -> V=1.0, theta=0.0
% INFO    : Bus 23195	: V=0.9882224, theta=-42.830338 -> V=1.0, theta=0.0
% INFO    : Bus 23196	: V=0.9740762, theta=-43.934942 -> V=1.0, theta=0.0
% INFO    : Bus 23197	: V=0.9858129, theta=-43.233321 -> V=1.0, theta=0.0
% INFO    : Bus 23198	: V=0.9873951, theta=-43.208081 -> V=1.0, theta=0.0
% INFO    : Bus 23199	: V=0.984857, theta=-43.254023 -> V=1.0, theta=0.0
% INFO    : Bus 23200	: V=0.9845395, theta=-43.254843 -> V=1.0, theta=0.0
% INFO    : Bus 23201	: V=0.9843335, theta=-43.252145 -> V=1.0, theta=0.0
% INFO    : Bus 23202	: V=0.9796317, theta=-43.764359 -> V=1.0, theta=0.0
% INFO    : Bus 23203	: V=0.9851567, theta=-43.163421 -> V=1.0, theta=0.0
% INFO    : Bus 23204	: V=0.9841626, theta=-43.241617 -> V=1.0, theta=0.0
% INFO    : Bus 23205	: V=0.9789592, theta=-43.853726 -> V=1.0, theta=0.0
% INFO    : Bus 23206	: V=0.9791846, theta=-43.906852 -> V=1.0, theta=0.0
% INFO    : Bus 23207	: V=0.9805318, theta=-43.865312 -> V=1.0, theta=0.0
% INFO    : Bus 23208	: V=0.9777171, theta=-44.012158 -> V=1.0, theta=0.0
% INFO    : Bus 23209	: V=0.9786197, theta=-43.817178 -> V=1.0, theta=0.0
% INFO    : Bus 23210	: V=0.9847219, theta=-43.27132 -> V=1.0, theta=0.0
% INFO    : Bus 23211	: V=0.9847736, theta=-43.228695 -> V=1.0, theta=0.0
% INFO    : Bus 23212	: V=0.9847504, theta=-43.205196 -> V=1.0, theta=0.0
% INFO    : Bus 23213	: V=0.9785783, theta=-43.60194 -> V=1.0, theta=0.0
% INFO    : Bus 23214	: V=0.9856401, theta=-43.138434 -> V=1.0, theta=0.0
% INFO    : Bus 23215	: V=0.9866632, theta=-43.063466 -> V=1.0, theta=0.0
% INFO    : Bus 23216	: V=0.999615, theta=-41.959965 -> V=1.0, theta=0.0
% INFO    : Bus 23217	: V=0.9762578, theta=-43.920566 -> V=1.0, theta=0.0
% INFO    : Bus 23218	: V=0.9864904, theta=-43.008247 -> V=1.0, theta=0.0
% INFO    : Bus 23219	: V=0.9776466, theta=-43.65188 -> V=1.0, theta=0.0
% INFO    : Bus 23220	: V=0.9873645, theta=-42.980403 -> V=1.0, theta=0.0
% INFO    : Bus 23221	: V=0.9850273, theta=-43.157058 -> V=1.0, theta=0.0
% INFO    : Bus 23222	: V=0.9855719, theta=-43.11663 -> V=1.0, theta=0.0
% INFO    : Bus 23223	: V=0.9876739, theta=-42.86205 -> V=1.0, theta=0.0
% INFO    : Bus 23224	: V=0.9815935, theta=-43.348335 -> V=1.0, theta=0.0
% INFO    : Bus 23225	: V=0.9797997, theta=-43.28006 -> V=1.0, theta=0.0
% INFO    : Bus 23226	: V=0.982496, theta=-43.265804 -> V=1.0, theta=0.0
% INFO    : Bus 23227	: V=0.979604, theta=-43.484524 -> V=1.0, theta=0.0
% INFO    : Bus 23228	: V=0.9789384, theta=-43.549965 -> V=1.0, theta=0.0
% INFO    : Bus 23229	: V=0.9785038, theta=-43.573796 -> V=1.0, theta=0.0
% INFO    : Bus 23230	: V=0.9730219, theta=-44.19844 -> V=1.0, theta=0.0
% INFO    : Bus 23231	: V=0.973201, theta=-44.197841 -> V=1.0, theta=0.0
% INFO    : Bus 23232	: V=0.9736529, theta=-44.19603 -> V=1.0, theta=0.0
% INFO    : Bus 23233	: V=0.9746026, theta=-44.081406 -> V=1.0, theta=0.0
% INFO    : Bus 23234	: V=0.9735271, theta=-44.306489 -> V=1.0, theta=0.0
% INFO    : Bus 23235	: V=0.9733187, theta=-44.291943 -> V=1.0, theta=0.0
% INFO    : Bus 23236	: V=0.9732756, theta=-44.27157 -> V=1.0, theta=0.0
% INFO    : Bus 23237	: V=0.972767, theta=-44.33814 -> V=1.0, theta=0.0
% INFO    : Bus 23238	: V=0.9732771, theta=-44.364635 -> V=1.0, theta=0.0
% INFO    : Bus 23239	: V=0.9729315, theta=-44.383152 -> V=1.0, theta=0.0
% INFO    : Bus 23240	: V=0.9724252, theta=-44.373613 -> V=1.0, theta=0.0
% INFO    : Bus 23241	: V=0.9721416, theta=-44.404412 -> V=1.0, theta=0.0
% INFO    : Bus 23242	: V=0.9719533, theta=-44.431737 -> V=1.0, theta=0.0
% INFO    : Bus 23243	: V=0.9722236, theta=-44.42272 -> V=1.0, theta=0.0
% INFO    : Bus 23244	: V=0.9725833, theta=-44.409496 -> V=1.0, theta=0.0
% INFO    : Bus 23245	: V=0.9725535, theta=-44.532123 -> V=1.0, theta=0.0
% INFO    : Bus 23246	: V=0.9719092, theta=-44.456662 -> V=1.0, theta=0.0
% INFO    : Bus 23247	: V=0.9721899, theta=-44.471985 -> V=1.0, theta=0.0
% INFO    : Bus 23248	: V=0.9713299, theta=-44.48183 -> V=1.0, theta=0.0
% INFO    : Bus 23249	: V=0.9712702, theta=-44.476241 -> V=1.0, theta=0.0
% INFO    : Bus 23250	: V=0.9719725, theta=-44.476541 -> V=1.0, theta=0.0
% INFO    : Bus 23251	: V=0.9710435, theta=-44.477016 -> V=1.0, theta=0.0
% INFO    : Bus 23252	: V=0.9722502, theta=-44.480201 -> V=1.0, theta=0.0
% INFO    : Bus 23253	: V=0.9986635, theta=-42.45162 -> V=1.0, theta=0.0
% INFO    : Bus 23254	: V=0.9790357, theta=-43.968922 -> V=1.0, theta=0.0
% INFO    : Bus 23255	: V=0.9811616, theta=-43.860221 -> V=1.0, theta=0.0
% INFO    : Bus 23256	: V=0.9852776, theta=-43.453209 -> V=1.0, theta=0.0
% INFO    : Bus 23257	: V=0.9784556, theta=-43.842687 -> V=1.0, theta=0.0
% INFO    : Bus 23258	: V=0.9741523, theta=-44.329293 -> V=1.0, theta=0.0
% INFO    : Bus 23259	: V=0.9844398, theta=-43.531979 -> V=1.0, theta=0.0
% INFO    : Bus 23260	: V=0.9752012, theta=-44.32102 -> V=1.0, theta=0.0
% INFO    : Bus 23261	: V=0.974866, theta=-44.369826 -> V=1.0, theta=0.0
% INFO    : Bus 23262	: V=0.9748066, theta=-44.416568 -> V=1.0, theta=0.0
% INFO    : Bus 23263	: V=0.9749841, theta=-44.352483 -> V=1.0, theta=0.0
% INFO    : Bus 23264	: V=0.9732132, theta=-44.422227 -> V=1.0, theta=0.0
% INFO    : Bus 23265	: V=0.9736285, theta=-44.41995 -> V=1.0, theta=0.0
% INFO    : Bus 23266	: V=0.974871, theta=-44.389775 -> V=1.0, theta=0.0
% INFO    : Bus 23267	: V=0.987008, theta=-43.701802 -> V=1.0, theta=0.0
% INFO    : Bus 23268	: V=0.9872992, theta=-43.693002 -> V=1.0, theta=0.0
% INFO    : Bus 23269	: V=0.9747999, theta=-44.42521 -> V=1.0, theta=0.0
% INFO    : Bus 23270	: V=0.9742155, theta=-44.466594 -> V=1.0, theta=0.0
% INFO    : Bus 23271	: V=0.9735828, theta=-44.440001 -> V=1.0, theta=0.0
% INFO    : Bus 23272	: V=0.9736152, theta=-44.464611 -> V=1.0, theta=0.0
% INFO    : Bus 23273	: V=0.97377, theta=-44.498211 -> V=1.0, theta=0.0
% INFO    : Bus 23274	: V=0.975667, theta=-44.443276 -> V=1.0, theta=0.0
% INFO    : Bus 23275	: V=0.9875926, theta=-43.684501 -> V=1.0, theta=0.0
% INFO    : Bus 23276	: V=0.9729106, theta=-44.529448 -> V=1.0, theta=0.0
% INFO    : Bus 23277	: V=0.9739846, theta=-44.522462 -> V=1.0, theta=0.0
% INFO    : Bus 23278	: V=0.9768221, theta=-44.463436 -> V=1.0, theta=0.0
% INFO    : Bus 23279	: V=0.9776258, theta=-44.472416 -> V=1.0, theta=0.0
% INFO    : Bus 23280	: V=0.9742111, theta=-44.526114 -> V=1.0, theta=0.0
% INFO    : Bus 23281	: V=0.9728865, theta=-44.528688 -> V=1.0, theta=0.0
% INFO    : Bus 23282	: V=0.9731372, theta=-44.528246 -> V=1.0, theta=0.0
% INFO    : Bus 23283	: V=0.9759775, theta=-44.523875 -> V=1.0, theta=0.0
% INFO    : Bus 23284	: V=0.9774448, theta=-44.521862 -> V=1.0, theta=0.0
% INFO    : Bus 23285	: V=0.9783806, theta=-44.482351 -> V=1.0, theta=0.0
% INFO    : Bus 23286	: V=0.9824414, theta=-43.919923 -> V=1.0, theta=0.0
% INFO    : Bus 23287	: V=0.987161, theta=-43.47901 -> V=1.0, theta=0.0
% INFO    : Bus 23288	: V=0.9850634, theta=-43.927552 -> V=1.0, theta=0.0
% INFO    : Bus 23289	: V=0.9848026, theta=-43.92706 -> V=1.0, theta=0.0
% INFO    : Bus 23290	: V=0.9862048, theta=-43.780631 -> V=1.0, theta=0.0
% INFO    : Bus 23291	: V=0.9906427, theta=-43.404429 -> V=1.0, theta=0.0
% INFO    : Bus 23292	: V=0.9906567, theta=-43.444916 -> V=1.0, theta=0.0
% INFO    : Bus 23293	: V=0.9869418, theta=-43.618863 -> V=1.0, theta=0.0
% INFO    : Bus 23294	: V=0.9851464, theta=-44.039993 -> V=1.0, theta=0.0
% INFO    : Bus 23295	: V=0.98996, theta=-43.54667 -> V=1.0, theta=0.0
% INFO    : Bus 23296	: V=0.991432, theta=-43.428921 -> V=1.0, theta=0.0
% INFO    : Bus 23297	: V=0.9848523, theta=-43.986872 -> V=1.0, theta=0.0
% INFO    : Bus 23298	: V=0.9847609, theta=-44.032461 -> V=1.0, theta=0.0
% INFO    : Bus 23299	: V=0.9838706, theta=-43.902173 -> V=1.0, theta=0.0
% INFO    : Bus 23300	: V=0.9874319, theta=-43.556261 -> V=1.0, theta=0.0
% INFO    : Bus 23301	: V=0.9875603, theta=-43.58867 -> V=1.0, theta=0.0
% INFO    : Bus 23302	: V=0.9849239, theta=-44.041912 -> V=1.0, theta=0.0
% INFO    : Bus 23303	: V=0.9852535, theta=-44.049513 -> V=1.0, theta=0.0
% INFO    : Bus 23304	: V=0.9831252, theta=-44.285672 -> V=1.0, theta=0.0
% INFO    : Bus 23305	: V=0.9838139, theta=-44.216849 -> V=1.0, theta=0.0
% INFO    : Bus 23306	: V=0.9913033, theta=-43.444809 -> V=1.0, theta=0.0
% INFO    : Bus 23307	: V=0.9892131, theta=-43.66573 -> V=1.0, theta=0.0
% INFO    : Bus 23308	: V=0.9889532, theta=-43.724006 -> V=1.0, theta=0.0
% INFO    : Bus 23309	: V=0.9831828, theta=-44.334034 -> V=1.0, theta=0.0
% INFO    : Bus 23310	: V=0.9887922, theta=-43.692536 -> V=1.0, theta=0.0
% INFO    : Bus 23311	: V=0.9819055, theta=-44.416509 -> V=1.0, theta=0.0
% INFO    : Bus 23312	: V=0.9859702, theta=-44.053467 -> V=1.0, theta=0.0
% INFO    : Bus 23313	: V=0.98807, theta=-43.669802 -> V=1.0, theta=0.0
% INFO    : Bus 23314	: V=0.9893753, theta=-43.700087 -> V=1.0, theta=0.0
% INFO    : Bus 23315	: V=0.980384, theta=-44.614053 -> V=1.0, theta=0.0
% INFO    : Bus 23316	: V=0.981267, theta=-44.558063 -> V=1.0, theta=0.0
% INFO    : Bus 23317	: V=0.9821971, theta=-44.449804 -> V=1.0, theta=0.0
% INFO    : Bus 23318	: V=0.980666, theta=-44.741129 -> V=1.0, theta=0.0
% INFO    : Bus 23319	: V=0.9817031, theta=-44.6624 -> V=1.0, theta=0.0
% INFO    : Bus 23320	: V=0.9952451, theta=-43.595838 -> V=1.0, theta=0.0
% INFO    : Bus 23321	: V=0.9859765, theta=-44.369998 -> V=1.0, theta=0.0
% INFO    : Bus 23322	: V=0.9865031, theta=-44.365426 -> V=1.0, theta=0.0
% INFO    : Bus 23323	: V=0.9793652, theta=-44.487517 -> V=1.0, theta=0.0
% INFO    : Bus 23324	: V=0.9877394, theta=-43.624501 -> V=1.0, theta=0.0
% INFO    : Bus 23325	: V=0.9811273, theta=-44.485698 -> V=1.0, theta=0.0
% INFO    : Bus 23326	: V=0.9804574, theta=-44.556566 -> V=1.0, theta=0.0
% INFO    : Bus 23327	: V=1.0024528, theta=-41.359283 -> V=1.0, theta=0.0
% INFO    : Bus 23328	: V=0.9918176, theta=-43.788526 -> V=1.0, theta=0.0
% INFO    : Bus 23329	: V=1.0031258, theta=-42.709179 -> V=1.0, theta=0.0
% INFO    : Bus 23330	: V=1.0150567, theta=-41.211824 -> V=1.0, theta=0.0
% INFO    : Bus 23331	: V=0.9887702, theta=-42.725808 -> V=1.0, theta=0.0
% INFO    : Bus 23332	: V=0.9825843, theta=-44.593278 -> V=1.0, theta=0.0
% INFO    : Bus 23333	: V=1.0010391, theta=-42.563652 -> V=1.0, theta=0.0
% INFO    : Bus 23334	: V=0.9848323, theta=-30.569602 -> V=1.0, theta=0.0
% INFO    : Bus 23335	: V=0.9833365, theta=-31.001973 -> V=1.0, theta=0.0
% INFO    : Bus 23336	: V=0.9870833, theta=-30.574544 -> V=1.0, theta=0.0
% INFO    : Bus 23337	: V=0.9919919, theta=-30.018625 -> V=1.0, theta=0.0
% INFO    : Bus 23338	: V=0.9934425, theta=-30.084584 -> V=1.0, theta=0.0
% INFO    : Bus 23339	: V=1.0047009, theta=-29.600246 -> V=1.0, theta=0.0
% INFO    : Bus 23340	: V=1.0071455, theta=-27.978011 -> V=1.0, theta=0.0
% INFO    : Bus 23341	: V=0.9948952, theta=-29.378043 -> V=1.0, theta=0.0
% INFO    : Bus 23342	: V=0.9966684, theta=-29.418526 -> V=1.0, theta=0.0
% INFO    : Bus 23343	: V=1.029928, theta=-30.65661 -> V=1.0, theta=0.0
% INFO    : Bus 23344	: V=1.0310926, theta=-30.668092 -> V=1.0, theta=0.0
% INFO    : Bus 23345	: V=1.0378109, theta=-30.606113 -> V=1.0, theta=0.0
% INFO    : Bus 23346	: V=1.0384826, theta=-30.578634 -> V=1.0, theta=0.0
% INFO    : Bus 23347	: V=1.0392078, theta=-30.55663 -> V=1.0, theta=0.0
% INFO    : Bus 23348	: V=1.0407759, theta=-30.50949 -> V=1.0, theta=0.0
% INFO    : Bus 23349	: V=1.0310544, theta=-30.522331 -> V=1.0, theta=0.0
% INFO    : Bus 23350	: V=1.02709, theta=-30.608683 -> V=1.0, theta=0.0
% INFO    : Bus 23351	: V=0.9983799, theta=-31.935091 -> V=1.0, theta=0.0
% INFO    : Bus 23352	: V=1.0121518, theta=-31.307961 -> V=1.0, theta=0.0
% INFO    : Bus 23353	: V=1.0176691, theta=-31.610793 -> V=1.0, theta=0.0
% INFO    : Bus 23354	: V=1.0140324, theta=-31.724909 -> V=1.0, theta=0.0
% INFO    : Bus 23355	: V=1.0109386, theta=-31.77803 -> V=1.0, theta=0.0
% INFO    : Bus 23356	: V=1.0104887, theta=-31.884179 -> V=1.0, theta=0.0
% INFO    : Bus 23357	: V=1.0078418, theta=-31.855757 -> V=1.0, theta=0.0
% INFO    : Bus 23358	: V=1.0076896, theta=-31.804945 -> V=1.0, theta=0.0
% INFO    : Bus 23359	: V=1.0068617, theta=-31.946309 -> V=1.0, theta=0.0
% INFO    : Bus 23360	: V=1.0024511, theta=-31.863976 -> V=1.0, theta=0.0
% INFO    : Bus 23361	: V=0.9993451, theta=-32.426777 -> V=1.0, theta=0.0
% INFO    : Bus 23362	: V=1.0046915, theta=-31.652944 -> V=1.0, theta=0.0
% INFO    : Bus 23363	: V=1.0012219, theta=-31.663234 -> V=1.0, theta=0.0
% INFO    : Bus 23364	: V=1.0080393, theta=-31.450077 -> V=1.0, theta=0.0
% INFO    : Bus 23365	: V=1.027209, theta=-30.739276 -> V=1.0, theta=0.0
% INFO    : Bus 23366	: V=1.0218185, theta=-31.828709 -> V=1.0, theta=0.0
% INFO    : Bus 23367	: V=1.00957, theta=-28.827803 -> V=1.0, theta=0.0
% INFO    : Bus 23368	: V=1.0132572, theta=-27.564682 -> V=1.0, theta=0.0
% INFO    : Bus 23369	: V=1.0097033, theta=-27.427491 -> V=1.0, theta=0.0
% INFO    : Bus 23370	: V=1.0178067, theta=-26.350879 -> V=1.0, theta=0.0
% INFO    : Bus 23371	: V=1.0197067, theta=-25.256797 -> V=1.0, theta=0.0
% INFO    : Bus 23372	: V=1.0163169, theta=-26.299441 -> V=1.0, theta=0.0
% INFO    : Bus 23373	: V=1.0057947, theta=-28.463439 -> V=1.0, theta=0.0
% INFO    : Bus 23374	: V=1.0099459, theta=-27.055663 -> V=1.0, theta=0.0
% INFO    : Bus 23375	: V=0.9716989, theta=-35.380388 -> V=1.0, theta=0.0
% INFO    : Bus 23376	: V=0.9743498, theta=-35.358241 -> V=1.0, theta=0.0
% INFO    : Bus 23377	: V=0.9780951, theta=-34.482294 -> V=1.0, theta=0.0
% INFO    : Bus 23378	: V=0.9821533, theta=-34.288218 -> V=1.0, theta=0.0
% INFO    : Bus 23379	: V=0.9856571, theta=-34.182038 -> V=1.0, theta=0.0
% INFO    : Bus 23380	: V=0.9828388, theta=-34.445893 -> V=1.0, theta=0.0
% INFO    : Bus 23381	: V=0.9863576, theta=-33.784549 -> V=1.0, theta=0.0
% INFO    : Bus 23382	: V=0.9802366, theta=-36.407119 -> V=1.0, theta=0.0
% INFO    : Bus 23383	: V=0.9829569, theta=-34.542046 -> V=1.0, theta=0.0
% INFO    : Bus 23384	: V=0.976772, theta=-36.365501 -> V=1.0, theta=0.0
% INFO    : Bus 23385	: V=0.9815227, theta=-34.450802 -> V=1.0, theta=0.0
% INFO    : Bus 23386	: V=1.0001624, theta=-32.648296 -> V=1.0, theta=0.0
% INFO    : Bus 23387	: V=1.0143217, theta=-32.21162 -> V=1.0, theta=0.0
% INFO    : Bus 23388	: V=1.009175, theta=-33.122312 -> V=1.0, theta=0.0
% INFO    : Bus 23389	: V=1.0140066, theta=-32.957134 -> V=1.0, theta=0.0
% INFO    : Bus 23390	: V=1.0194887, theta=-32.699209 -> V=1.0, theta=0.0
% INFO    : Bus 23391	: V=1.0225583, theta=-32.577898 -> V=1.0, theta=0.0
% INFO    : Bus 23392	: V=1.0349021, theta=-31.545492 -> V=1.0, theta=0.0
% INFO    : Bus 23393	: V=1.0068338, theta=-33.281458 -> V=1.0, theta=0.0
% INFO    : Bus 23394	: V=1.0071457, theta=-33.231952 -> V=1.0, theta=0.0
% INFO    : Bus 23395	: V=1.0064018, theta=-33.296559 -> V=1.0, theta=0.0
% INFO    : Bus 23396	: V=0.9974157, theta=-33.772061 -> V=1.0, theta=0.0
% INFO    : Bus 23397	: V=1.0089474, theta=-33.081484 -> V=1.0, theta=0.0
% INFO    : Bus 23398	: V=1.0201939, theta=-31.898964 -> V=1.0, theta=0.0
% INFO    : Bus 23399	: V=1.0032456, theta=-33.382047 -> V=1.0, theta=0.0
% INFO    : Bus 23400	: V=1.0061911, theta=-33.305635 -> V=1.0, theta=0.0
% INFO    : Bus 23401	: V=1.0060815, theta=-33.30768 -> V=1.0, theta=0.0
% INFO    : Bus 23402	: V=0.9954772, theta=-33.835377 -> V=1.0, theta=0.0
% INFO    : Bus 23403	: V=0.9855763, theta=-33.920524 -> V=1.0, theta=0.0
% INFO    : Bus 23404	: V=0.995442, theta=-33.826676 -> V=1.0, theta=0.0
% INFO    : Bus 23405	: V=1.003796, theta=-33.608563 -> V=1.0, theta=0.0
% INFO    : Bus 23406	: V=1.0063195, theta=-33.392858 -> V=1.0, theta=0.0
% INFO    : Bus 23407	: V=0.9986417, theta=-34.275219 -> V=1.0, theta=0.0
% INFO    : Bus 23408	: V=1.0011219, theta=-33.933354 -> V=1.0, theta=0.0
% INFO    : Bus 23409	: V=0.9808345, theta=-34.48724 -> V=1.0, theta=0.0
% INFO    : Bus 23410	: V=0.9850069, theta=-34.35507 -> V=1.0, theta=0.0
% INFO    : Bus 23411	: V=0.9877373, theta=-34.153746 -> V=1.0, theta=0.0
% INFO    : Bus 23412	: V=0.9773715, theta=-33.039553 -> V=1.0, theta=0.0
% INFO    : Bus 23413	: V=0.9938438, theta=-32.02607 -> V=1.0, theta=0.0
% INFO    : Bus 23414	: V=0.9920414, theta=-32.488116 -> V=1.0, theta=0.0
% INFO    : Bus 23415	: V=0.978811, theta=-33.259209 -> V=1.0, theta=0.0
% INFO    : Bus 23416	: V=1.0023003, theta=-45.57846 -> V=1.0, theta=0.0
% INFO    : Bus 23417	: V=1.0013045, theta=-45.764594 -> V=1.0, theta=0.0
% INFO    : Bus 23418	: V=1.0016674, theta=-47.232557 -> V=1.0, theta=0.0
% INFO    : Bus 23419	: V=0.9882291, theta=-48.852905 -> V=1.0, theta=0.0
% INFO    : Bus 23420	: V=0.9875359, theta=-49.26438 -> V=1.0, theta=0.0
% INFO    : Bus 23421	: V=0.9731952, theta=-50.548563 -> V=1.0, theta=0.0
% INFO    : Bus 23422	: V=0.9566531, theta=-53.175202 -> V=1.0, theta=0.0
% INFO    : Bus 23423	: V=0.9589142, theta=-53.682685 -> V=1.0, theta=0.0
% INFO    : Bus 23424	: V=0.9831814, theta=-50.250609 -> V=1.0, theta=0.0
% INFO    : Bus 23425	: V=0.9810246, theta=-50.901174 -> V=1.0, theta=0.0
% INFO    : Bus 23426	: V=0.985685, theta=-49.911379 -> V=1.0, theta=0.0
% INFO    : Bus 23427	: V=1.0059927, theta=-47.978589 -> V=1.0, theta=0.0
% INFO    : Bus 23428	: V=1.0038278, theta=-48.360321 -> V=1.0, theta=0.0
% INFO    : Bus 23429	: V=0.9856438, theta=-50.025933 -> V=1.0, theta=0.0
% INFO    : Bus 23430	: V=0.9896399, theta=-49.89617 -> V=1.0, theta=0.0
% INFO    : Bus 23431	: V=0.9913309, theta=-49.792806 -> V=1.0, theta=0.0
% INFO    : Bus 23432	: V=1.0102024, theta=-47.655077 -> V=1.0, theta=0.0
% INFO    : Bus 23433	: V=0.991748, theta=-50.008215 -> V=1.0, theta=0.0
% INFO    : Bus 23434	: V=0.988657, theta=-50.073806 -> V=1.0, theta=0.0
% INFO    : Bus 23435	: V=0.9873948, theta=-50.097956 -> V=1.0, theta=0.0
% INFO    : Bus 23436	: V=0.9872027, theta=-50.083342 -> V=1.0, theta=0.0
% INFO    : Bus 23437	: V=0.9871768, theta=-50.138514 -> V=1.0, theta=0.0
% INFO    : Bus 23438	: V=0.9867329, theta=-50.175727 -> V=1.0, theta=0.0
% INFO    : Bus 23439	: V=1.0009535, theta=-49.809879 -> V=1.0, theta=0.0
% INFO    : Bus 23440	: V=0.9904039, theta=-50.362192 -> V=1.0, theta=0.0
% INFO    : Bus 23441	: V=0.9952928, theta=-50.647865 -> V=1.0, theta=0.0
% INFO    : Bus 23442	: V=0.9938812, theta=-50.648649 -> V=1.0, theta=0.0
% INFO    : Bus 23443	: V=0.9719319, theta=-52.5929 -> V=1.0, theta=0.0
% INFO    : Bus 23444	: V=0.959368, theta=-54.007065 -> V=1.0, theta=0.0
% INFO    : Bus 23445	: V=0.9512016, theta=-57.341359 -> V=1.0, theta=0.0
% INFO    : Bus 23446	: V=0.9674881, theta=-54.144624 -> V=1.0, theta=0.0
% INFO    : Bus 23447	: V=0.9848294, theta=-52.926663 -> V=1.0, theta=0.0
% INFO    : Bus 23448	: V=0.9616404, theta=-55.230954 -> V=1.0, theta=0.0
% INFO    : Bus 23449	: V=0.9733094, theta=-54.491246 -> V=1.0, theta=0.0
% INFO    : Bus 23450	: V=1.0123516, theta=-49.177884 -> V=1.0, theta=0.0
% INFO    : Bus 23451	: V=1.0028481, theta=-50.377286 -> V=1.0, theta=0.0
% INFO    : Bus 23452	: V=0.9704788, theta=-54.138997 -> V=1.0, theta=0.0
% INFO    : Bus 23453	: V=0.9667849, theta=-54.692673 -> V=1.0, theta=0.0
% INFO    : Bus 23454	: V=0.9806466, theta=-36.997171 -> V=1.0, theta=0.0
% INFO    : Bus 23455	: V=0.9790851, theta=-37.49336 -> V=1.0, theta=0.0
% INFO    : Bus 23456	: V=0.9756634, theta=-38.136751 -> V=1.0, theta=0.0
% INFO    : Bus 23457	: V=0.9764299, theta=-37.405823 -> V=1.0, theta=0.0
% INFO    : Bus 23458	: V=0.9684248, theta=-38.016389 -> V=1.0, theta=0.0
% INFO    : Bus 23459	: V=0.9675707, theta=-39.065904 -> V=1.0, theta=0.0
% INFO    : Bus 23460	: V=0.9703333, theta=-39.256036 -> V=1.0, theta=0.0
% INFO    : Bus 23461	: V=0.9781089, theta=-38.713627 -> V=1.0, theta=0.0
% INFO    : Bus 23462	: V=0.9844397, theta=-38.453953 -> V=1.0, theta=0.0
% INFO    : Bus 23463	: V=0.9970512, theta=-37.215984 -> V=1.0, theta=0.0
% INFO    : Bus 23464	: V=0.9812918, theta=-38.870031 -> V=1.0, theta=0.0
% INFO    : Bus 23465	: V=0.9769202, theta=-39.180608 -> V=1.0, theta=0.0
% INFO    : Bus 23466	: V=0.9756874, theta=-39.323549 -> V=1.0, theta=0.0
% INFO    : Bus 23467	: V=1.0088172, theta=-31.351884 -> V=1.0, theta=0.0
% INFO    : Bus 23468	: V=1.0041679, theta=-30.701373 -> V=1.0, theta=0.0
% INFO    : Bus 23469	: V=0.9936891, theta=-31.720966 -> V=1.0, theta=0.0
% INFO    : Bus 23470	: V=0.9964962, theta=-31.164321 -> V=1.0, theta=0.0
% INFO    : Bus 23471	: V=0.9962404, theta=-31.11498 -> V=1.0, theta=0.0
% INFO    : Bus 23472	: V=0.9750529, theta=-38.406024 -> V=1.0, theta=0.0
% INFO    : Bus 23473	: V=0.9749433, theta=-38.387029 -> V=1.0, theta=0.0
% INFO    : Bus 23474	: V=0.975295, theta=-38.400109 -> V=1.0, theta=0.0
% INFO    : Bus 23475	: V=0.9981214, theta=-35.992726 -> V=1.0, theta=0.0
% INFO    : Bus 23476	: V=0.9756257, theta=-38.364934 -> V=1.0, theta=0.0
% INFO    : Bus 23477	: V=0.9745713, theta=-38.398772 -> V=1.0, theta=0.0
% INFO    : Bus 23478	: V=0.9745163, theta=-38.384829 -> V=1.0, theta=0.0
% INFO    : Bus 23479	: V=0.9868084, theta=-37.587806 -> V=1.0, theta=0.0
% INFO    : Bus 23480	: V=0.9865627, theta=-37.460232 -> V=1.0, theta=0.0
% INFO    : Bus 23481	: V=0.9829342, theta=-37.615726 -> V=1.0, theta=0.0
% INFO    : Bus 23482	: V=0.9835123, theta=-37.580159 -> V=1.0, theta=0.0
% INFO    : Bus 23483	: V=0.9750726, theta=-38.384514 -> V=1.0, theta=0.0
% INFO    : Bus 23484	: V=0.9738377, theta=-38.3055 -> V=1.0, theta=0.0
% INFO    : Bus 23485	: V=0.9856548, theta=-36.769609 -> V=1.0, theta=0.0
% INFO    : Bus 23486	: V=0.9748631, theta=-37.861462 -> V=1.0, theta=0.0
% INFO    : Bus 23487	: V=0.9850434, theta=-37.076403 -> V=1.0, theta=0.0
% INFO    : Bus 23488	: V=0.9742783, theta=-38.578141 -> V=1.0, theta=0.0
% INFO    : Bus 23489	: V=0.9764737, theta=-38.385745 -> V=1.0, theta=0.0
% INFO    : Bus 23490	: V=0.9775333, theta=-38.257163 -> V=1.0, theta=0.0
% INFO    : Bus 23491	: V=0.974565, theta=-38.390828 -> V=1.0, theta=0.0
% INFO    : Bus 23492	: V=0.9871065, theta=-37.723293 -> V=1.0, theta=0.0
% INFO    : Bus 23493	: V=0.9762656, theta=-38.679266 -> V=1.0, theta=0.0
% INFO    : Bus 23494	: V=0.9776116, theta=-38.516366 -> V=1.0, theta=0.0
% INFO    : Bus 23495	: V=0.9899936, theta=-37.84118 -> V=1.0, theta=0.0
% INFO    : Bus 23496	: V=0.9790617, theta=-38.376329 -> V=1.0, theta=0.0
% INFO    : Bus 23497	: V=1.0006739, theta=-37.064399 -> V=1.0, theta=0.0
% INFO    : Bus 23498	: V=0.9773335, theta=-38.310001 -> V=1.0, theta=0.0
% INFO    : Bus 23499	: V=0.9837884, theta=-38.89812 -> V=1.0, theta=0.0
% INFO    : Bus 23500	: V=0.9737523, theta=-39.359172 -> V=1.0, theta=0.0
% INFO    : Bus 23501	: V=0.970177, theta=-38.914016 -> V=1.0, theta=0.0
% INFO    : Bus 23502	: V=0.9803501, theta=-37.873205 -> V=1.0, theta=0.0
% INFO    : Bus 23503	: V=0.9702215, theta=-38.647703 -> V=1.0, theta=0.0
% INFO    : Bus 23504	: V=0.9786218, theta=-36.917541 -> V=1.0, theta=0.0
% INFO    : Bus 23505	: V=0.9853725, theta=-36.479758 -> V=1.0, theta=0.0
% INFO    : Bus 23506	: V=0.9879872, theta=-35.801134 -> V=1.0, theta=0.0
% INFO    : Bus 23507	: V=0.9868826, theta=-35.780609 -> V=1.0, theta=0.0
% INFO    : Bus 23508	: V=0.9895981, theta=-35.05525 -> V=1.0, theta=0.0
% INFO    : Bus 23509	: V=0.9778669, theta=-35.668378 -> V=1.0, theta=0.0
% INFO    : Bus 23510	: V=0.9804925, theta=-35.009196 -> V=1.0, theta=0.0
% INFO    : Bus 23511	: V=0.9886901, theta=-34.741882 -> V=1.0, theta=0.0
% INFO    : Bus 23512	: V=0.9738895, theta=-38.312351 -> V=1.0, theta=0.0
% INFO    : Bus 23513	: V=0.975775, theta=-38.382516 -> V=1.0, theta=0.0
% INFO    : Bus 23514	: V=0.9928183, theta=-32.120944 -> V=1.0, theta=0.0
% INFO    : Bus 23515	: V=0.9749864, theta=-35.788499 -> V=1.0, theta=0.0
% INFO    : Bus 23516	: V=0.9710938, theta=-37.578883 -> V=1.0, theta=0.0
% INFO    : Bus 23517	: V=0.9783962, theta=-37.389191 -> V=1.0, theta=0.0
% INFO    : Bus 23518	: V=0.9738227, theta=-36.55024 -> V=1.0, theta=0.0
% INFO    : Bus 23519	: V=0.9879825, theta=-35.780597 -> V=1.0, theta=0.0
% INFO    : Bus 23520	: V=0.9950937, theta=-36.162033 -> V=1.0, theta=0.0
% INFO    : Bus 23521	: V=0.9756797, theta=-37.200812 -> V=1.0, theta=0.0
% INFO    : Bus 23522	: V=0.9642694, theta=-38.698119 -> V=1.0, theta=0.0
% INFO    : Bus 23523	: V=0.9699523, theta=-38.654774 -> V=1.0, theta=0.0
% INFO    : Bus 23524	: V=0.9751222, theta=-38.928147 -> V=1.0, theta=0.0
% INFO    : Bus 23525	: V=0.9716639, theta=-41.578519 -> V=1.0, theta=0.0
% INFO    : Bus 23526	: V=0.9740541, theta=-41.576093 -> V=1.0, theta=0.0
% INFO    : Bus 23527	: V=0.993054, theta=-39.45817 -> V=1.0, theta=0.0
% INFO    : Bus 23528	: V=0.9788339, theta=-41.038857 -> V=1.0, theta=0.0
% INFO    : Bus 23529	: V=0.9806001, theta=-41.669964 -> V=1.0, theta=0.0
% INFO    : Bus 23530	: V=0.9750308, theta=-42.024291 -> V=1.0, theta=0.0
% INFO    : Bus 23531	: V=0.9744996, theta=-42.226525 -> V=1.0, theta=0.0
% INFO    : Bus 23532	: V=0.9787806, theta=-40.506215 -> V=1.0, theta=0.0
% INFO    : Bus 23533	: V=0.9765675, theta=-41.506391 -> V=1.0, theta=0.0
% INFO    : Bus 23534	: V=0.9751526, theta=-41.585001 -> V=1.0, theta=0.0
% INFO    : Bus 23535	: V=0.978001, theta=-40.676891 -> V=1.0, theta=0.0
% INFO    : Bus 23536	: V=0.967885, theta=-41.357031 -> V=1.0, theta=0.0
% INFO    : Bus 23537	: V=0.9771722, theta=-40.869226 -> V=1.0, theta=0.0
% INFO    : Bus 23538	: V=0.9727827, theta=-41.025811 -> V=1.0, theta=0.0
% INFO    : Bus 23539	: V=0.9751687, theta=-41.105692 -> V=1.0, theta=0.0
% INFO    : Bus 23540	: V=0.9719038, theta=-41.702967 -> V=1.0, theta=0.0
% INFO    : Bus 23541	: V=0.9732368, theta=-42.024759 -> V=1.0, theta=0.0
% INFO    : Bus 23542	: V=0.973206, theta=-41.913425 -> V=1.0, theta=0.0
% INFO    : Bus 23543	: V=0.9764206, theta=-41.798764 -> V=1.0, theta=0.0
% INFO    : Bus 23544	: V=0.9762168, theta=-41.929305 -> V=1.0, theta=0.0
% INFO    : Bus 23545	: V=0.9760639, theta=-42.092784 -> V=1.0, theta=0.0
% INFO    : Bus 23546	: V=0.9704177, theta=-41.657084 -> V=1.0, theta=0.0
% INFO    : Bus 23547	: V=0.9750133, theta=-41.957756 -> V=1.0, theta=0.0
% INFO    : Bus 23548	: V=0.9689307, theta=-42.766634 -> V=1.0, theta=0.0
% INFO    : Bus 23549	: V=0.9746719, theta=-42.334152 -> V=1.0, theta=0.0
% INFO    : Bus 23550	: V=0.9693805, theta=-42.885294 -> V=1.0, theta=0.0
% INFO    : Bus 23551	: V=0.9701945, theta=-42.732081 -> V=1.0, theta=0.0
% INFO    : Bus 23552	: V=0.9698116, theta=-42.972238 -> V=1.0, theta=0.0
% INFO    : Bus 23553	: V=0.9691976, theta=-43.142586 -> V=1.0, theta=0.0
% INFO    : Bus 23554	: V=0.9753871, theta=-42.338594 -> V=1.0, theta=0.0
% INFO    : Bus 23555	: V=0.9747792, theta=-42.270777 -> V=1.0, theta=0.0
% INFO    : Bus 23556	: V=0.9726329, theta=-42.698369 -> V=1.0, theta=0.0
% INFO    : Bus 23557	: V=0.9688798, theta=-43.114222 -> V=1.0, theta=0.0
% INFO    : Bus 23558	: V=0.9775448, theta=-42.281447 -> V=1.0, theta=0.0
% INFO    : Bus 23559	: V=0.9781814, theta=-42.084093 -> V=1.0, theta=0.0
% INFO    : Bus 23560	: V=0.9735017, theta=-42.419857 -> V=1.0, theta=0.0
% INFO    : Bus 23561	: V=0.9713102, theta=-42.817015 -> V=1.0, theta=0.0
% INFO    : Bus 23562	: V=0.9686599, theta=-43.196563 -> V=1.0, theta=0.0
% INFO    : Bus 23563	: V=0.9775293, theta=-42.207811 -> V=1.0, theta=0.0
% INFO    : Bus 23564	: V=0.9786467, theta=-41.997278 -> V=1.0, theta=0.0
% INFO    : Bus 23565	: V=0.9762351, theta=-42.555704 -> V=1.0, theta=0.0
% INFO    : Bus 23566	: V=0.9756877, theta=-42.394575 -> V=1.0, theta=0.0
% INFO    : Bus 23567	: V=0.972393, theta=-42.528935 -> V=1.0, theta=0.0
% INFO    : Bus 23568	: V=0.9711075, theta=-43.3256 -> V=1.0, theta=0.0
% INFO    : Bus 23569	: V=0.9769974, theta=-42.676529 -> V=1.0, theta=0.0
% INFO    : Bus 23570	: V=0.973193, theta=-43.161859 -> V=1.0, theta=0.0
% INFO    : Bus 23571	: V=0.9753846, theta=-43.360807 -> V=1.0, theta=0.0
% INFO    : Bus 23572	: V=0.9788606, theta=-42.772108 -> V=1.0, theta=0.0
% INFO    : Bus 23573	: V=0.9726351, theta=-42.483523 -> V=1.0, theta=0.0
% INFO    : Bus 23574	: V=0.9725496, theta=-42.747463 -> V=1.0, theta=0.0
% INFO    : Bus 23575	: V=0.9725909, theta=-42.569048 -> V=1.0, theta=0.0
% INFO    : Bus 23576	: V=0.9727913, theta=-42.340681 -> V=1.0, theta=0.0
% INFO    : Bus 23577	: V=0.9720934, theta=-42.288167 -> V=1.0, theta=0.0
% INFO    : Bus 23578	: V=0.9714044, theta=-42.471209 -> V=1.0, theta=0.0
% INFO    : Bus 23579	: V=0.9739809, theta=-43.204568 -> V=1.0, theta=0.0
% INFO    : Bus 23580	: V=0.972746, theta=-43.606575 -> V=1.0, theta=0.0
% INFO    : Bus 23581	: V=0.9647376, theta=-44.467117 -> V=1.0, theta=0.0
% INFO    : Bus 23582	: V=0.9734091, theta=-43.028749 -> V=1.0, theta=0.0
% INFO    : Bus 23583	: V=0.9749116, theta=-43.90351 -> V=1.0, theta=0.0
% INFO    : Bus 23584	: V=0.973322, theta=-43.390843 -> V=1.0, theta=0.0
% INFO    : Bus 23585	: V=0.9736646, theta=-44.181529 -> V=1.0, theta=0.0
% INFO    : Bus 23586	: V=0.9959562, theta=-42.271095 -> V=1.0, theta=0.0
% INFO    : Bus 23587	: V=0.9754847, theta=-43.38689 -> V=1.0, theta=0.0
% INFO    : Bus 23588	: V=0.9741731, theta=-43.978065 -> V=1.0, theta=0.0
% INFO    : Bus 23589	: V=0.9829721, theta=-42.903509 -> V=1.0, theta=0.0
% INFO    : Bus 23590	: V=0.9866057, theta=-42.914231 -> V=1.0, theta=0.0
% INFO    : Bus 23591	: V=0.9732321, theta=-44.073642 -> V=1.0, theta=0.0
% INFO    : Bus 23592	: V=0.9756926, theta=-44.23732 -> V=1.0, theta=0.0
% INFO    : Bus 23593	: V=0.9807503, theta=-44.129781 -> V=1.0, theta=0.0
% INFO    : Bus 23594	: V=0.9758823, theta=-44.320284 -> V=1.0, theta=0.0
% INFO    : Bus 23595	: V=0.9735301, theta=-43.341772 -> V=1.0, theta=0.0
% INFO    : Bus 23596	: V=0.9727042, theta=-43.77806 -> V=1.0, theta=0.0
% INFO    : Bus 23597	: V=0.9729057, theta=-44.140216 -> V=1.0, theta=0.0
% INFO    : Bus 23598	: V=0.9716468, theta=-43.547664 -> V=1.0, theta=0.0
% INFO    : Bus 23599	: V=0.9755612, theta=-44.929958 -> V=1.0, theta=0.0
% INFO    : Bus 23600	: V=0.9829683, theta=-44.541955 -> V=1.0, theta=0.0
% INFO    : Bus 23601	: V=0.974168, theta=-44.282204 -> V=1.0, theta=0.0
% INFO    : Bus 23602	: V=0.9737267, theta=-45.401544 -> V=1.0, theta=0.0
% INFO    : Bus 23603	: V=0.9755134, theta=-45.37428 -> V=1.0, theta=0.0
% INFO    : Bus 23604	: V=0.9840693, theta=-44.595994 -> V=1.0, theta=0.0
% INFO    : Bus 23605	: V=0.9750058, theta=-45.448284 -> V=1.0, theta=0.0
% INFO    : Bus 23606	: V=0.9773811, theta=-44.457682 -> V=1.0, theta=0.0
% INFO    : Bus 23607	: V=0.9768985, theta=-44.71488 -> V=1.0, theta=0.0
% INFO    : Bus 23608	: V=0.976886, theta=-45.162934 -> V=1.0, theta=0.0
% INFO    : Bus 23609	: V=0.9750844, theta=-45.409454 -> V=1.0, theta=0.0
% INFO    : Bus 23610	: V=0.9761868, theta=-45.377609 -> V=1.0, theta=0.0
% INFO    : Bus 23611	: V=0.9742247, theta=-45.519544 -> V=1.0, theta=0.0
% INFO    : Bus 23612	: V=0.9711753, theta=-45.41406 -> V=1.0, theta=0.0
% INFO    : Bus 23613	: V=0.9758978, theta=-44.203375 -> V=1.0, theta=0.0
% INFO    : Bus 23614	: V=0.9776178, theta=-43.967132 -> V=1.0, theta=0.0
% INFO    : Bus 23615	: V=0.9743408, theta=-44.380089 -> V=1.0, theta=0.0
% INFO    : Bus 23616	: V=0.9720144, theta=-45.448402 -> V=1.0, theta=0.0
% INFO    : Bus 23617	: V=0.9957317, theta=-41.282719 -> V=1.0, theta=0.0
% INFO    : Bus 23618	: V=0.9743748, theta=-43.228195 -> V=1.0, theta=0.0
% INFO    : Bus 23619	: V=0.9946203, theta=-40.607128 -> V=1.0, theta=0.0
% INFO    : Bus 23620	: V=0.9773427, theta=-42.580568 -> V=1.0, theta=0.0
% INFO    : Bus 23621	: V=0.9723542, theta=-43.904854 -> V=1.0, theta=0.0
% INFO    : Bus 23622	: V=0.9726481, theta=-43.861383 -> V=1.0, theta=0.0
% INFO    : Bus 23623	: V=0.9791368, theta=-43.239099 -> V=1.0, theta=0.0
% INFO    : Bus 23624	: V=0.9736877, theta=-42.974043 -> V=1.0, theta=0.0
% INFO    : Bus 23625	: V=0.969055, theta=-43.387457 -> V=1.0, theta=0.0
% INFO    : Bus 23626	: V=0.9689257, theta=-43.387804 -> V=1.0, theta=0.0
% INFO    : Bus 23627	: V=0.9687005, theta=-43.403504 -> V=1.0, theta=0.0
% INFO    : Bus 23628	: V=0.968985, theta=-43.397159 -> V=1.0, theta=0.0
% INFO    : Bus 23629	: V=0.9750017, theta=-42.896335 -> V=1.0, theta=0.0
% INFO    : Bus 23630	: V=0.9720019, theta=-43.479475 -> V=1.0, theta=0.0
% INFO    : Bus 23631	: V=0.9742487, theta=-42.969798 -> V=1.0, theta=0.0
% INFO    : Bus 23632	: V=0.970191, theta=-43.748688 -> V=1.0, theta=0.0
% INFO    : Bus 23633	: V=0.9707106, theta=-43.805242 -> V=1.0, theta=0.0
% INFO    : Bus 23634	: V=0.9705406, theta=-43.810084 -> V=1.0, theta=0.0
% INFO    : Bus 23635	: V=0.9739308, theta=-43.007141 -> V=1.0, theta=0.0
% INFO    : Bus 23636	: V=0.9792572, theta=-43.435188 -> V=1.0, theta=0.0
% INFO    : Bus 23637	: V=0.9707268, theta=-43.867933 -> V=1.0, theta=0.0
% INFO    : Bus 23638	: V=0.9704839, theta=-43.892172 -> V=1.0, theta=0.0
% INFO    : Bus 23639	: V=0.9706911, theta=-43.868643 -> V=1.0, theta=0.0
% INFO    : Bus 23640	: V=0.9700424, theta=-44.1246 -> V=1.0, theta=0.0
% INFO    : Bus 23641	: V=0.9691143, theta=-43.160078 -> V=1.0, theta=0.0
% INFO    : Bus 23642	: V=0.973846, theta=-42.564199 -> V=1.0, theta=0.0
% INFO    : Bus 23643	: V=0.9747672, theta=-42.531472 -> V=1.0, theta=0.0
% INFO    : Bus 23644	: V=0.9749394, theta=-42.651148 -> V=1.0, theta=0.0
% INFO    : Bus 23645	: V=0.9742416, theta=-42.748799 -> V=1.0, theta=0.0
% INFO    : Bus 23646	: V=0.9697807, theta=-43.425526 -> V=1.0, theta=0.0
% INFO    : Bus 23647	: V=0.9712957, theta=-43.641398 -> V=1.0, theta=0.0
% INFO    : Bus 23648	: V=0.97057, theta=-43.640662 -> V=1.0, theta=0.0
% INFO    : Bus 23649	: V=0.9730492, theta=-42.925847 -> V=1.0, theta=0.0
% INFO    : Bus 23650	: V=0.9708729, theta=-43.660168 -> V=1.0, theta=0.0
% INFO    : Bus 23651	: V=0.9713297, theta=-43.684974 -> V=1.0, theta=0.0
% INFO    : Bus 23652	: V=0.9727187, theta=-43.979496 -> V=1.0, theta=0.0
% INFO    : Bus 23653	: V=0.9725354, theta=-43.866428 -> V=1.0, theta=0.0
% INFO    : Bus 23654	: V=0.9731862, theta=-42.959728 -> V=1.0, theta=0.0
% INFO    : Bus 23655	: V=0.971029, theta=-43.762084 -> V=1.0, theta=0.0
% INFO    : Bus 23656	: V=0.9717328, theta=-43.742245 -> V=1.0, theta=0.0
% INFO    : Bus 23657	: V=0.9718123, theta=-43.596923 -> V=1.0, theta=0.0
% INFO    : Bus 23658	: V=0.9736345, theta=-42.844622 -> V=1.0, theta=0.0
% INFO    : Bus 23659	: V=0.9706171, theta=-43.690716 -> V=1.0, theta=0.0
% INFO    : Bus 23660	: V=0.9787083, theta=-43.375093 -> V=1.0, theta=0.0
% INFO    : Bus 23661	: V=0.9699482, theta=-44.135618 -> V=1.0, theta=0.0
% INFO    : Bus 23662	: V=0.9695619, theta=-44.523206 -> V=1.0, theta=0.0
% INFO    : Bus 23663	: V=0.9718597, theta=-44.080772 -> V=1.0, theta=0.0
% INFO    : Bus 23664	: V=0.9784191, theta=-43.491494 -> V=1.0, theta=0.0
% INFO    : Bus 23665	: V=0.978019, theta=-43.69545 -> V=1.0, theta=0.0
% INFO    : Bus 23666	: V=0.9701727, theta=-44.644607 -> V=1.0, theta=0.0
% INFO    : Bus 23667	: V=0.9714667, theta=-44.836578 -> V=1.0, theta=0.0
% INFO    : Bus 23668	: V=0.9710569, theta=-44.817966 -> V=1.0, theta=0.0
% INFO    : Bus 23669	: V=0.9724375, theta=-44.737621 -> V=1.0, theta=0.0
% INFO    : Bus 23670	: V=0.9765961, theta=-44.199792 -> V=1.0, theta=0.0
% INFO    : Bus 23671	: V=0.9773956, theta=-43.905565 -> V=1.0, theta=0.0
% INFO    : Bus 23672	: V=0.9727618, theta=-44.60503 -> V=1.0, theta=0.0
% INFO    : Bus 23673	: V=0.9765809, theta=-44.311814 -> V=1.0, theta=0.0
% INFO    : Bus 23674	: V=0.9720109, theta=-44.691467 -> V=1.0, theta=0.0
% INFO    : Bus 23675	: V=0.9732579, theta=-44.591111 -> V=1.0, theta=0.0
% INFO    : Bus 23676	: V=0.9731186, theta=-44.567482 -> V=1.0, theta=0.0
% INFO    : Bus 23677	: V=0.9713741, theta=-44.803127 -> V=1.0, theta=0.0
% INFO    : Bus 23678	: V=0.9717368, theta=-44.800888 -> V=1.0, theta=0.0
% INFO    : Bus 23679	: V=0.9706508, theta=-43.98819 -> V=1.0, theta=0.0
% INFO    : Bus 23680	: V=0.9733847, theta=-43.711775 -> V=1.0, theta=0.0
% INFO    : Bus 23681	: V=0.970674, theta=-44.085117 -> V=1.0, theta=0.0
% INFO    : Bus 23682	: V=0.9734133, theta=-44.306727 -> V=1.0, theta=0.0
% INFO    : Bus 23683	: V=0.9730181, theta=-44.135845 -> V=1.0, theta=0.0
% INFO    : Bus 23684	: V=0.9710737, theta=-44.247381 -> V=1.0, theta=0.0
% INFO    : Bus 23685	: V=0.9748755, theta=-43.69169 -> V=1.0, theta=0.0
% INFO    : Bus 23686	: V=0.9784169, theta=-43.553777 -> V=1.0, theta=0.0
% INFO    : Bus 23687	: V=0.9722305, theta=-44.347241 -> V=1.0, theta=0.0
% INFO    : Bus 23688	: V=0.9729064, theta=-44.450121 -> V=1.0, theta=0.0
% INFO    : Bus 23689	: V=0.9762915, theta=-44.572691 -> V=1.0, theta=0.0
% INFO    : Bus 23690	: V=0.9741901, theta=-44.82851 -> V=1.0, theta=0.0
% INFO    : Bus 23691	: V=0.9725663, theta=-44.84043 -> V=1.0, theta=0.0
% INFO    : Bus 23692	: V=0.9736343, theta=-44.67693 -> V=1.0, theta=0.0
% INFO    : Bus 23693	: V=0.9897069, theta=-42.86421 -> V=1.0, theta=0.0
% INFO    : Bus 23694	: V=0.9804631, theta=-44.232411 -> V=1.0, theta=0.0
% INFO    : Bus 23695	: V=0.9881466, theta=-43.015649 -> V=1.0, theta=0.0
% INFO    : Bus 23696	: V=0.988745, theta=-42.945269 -> V=1.0, theta=0.0
% INFO    : Bus 23697	: V=0.9875718, theta=-43.037955 -> V=1.0, theta=0.0
% INFO    : Bus 23698	: V=0.9791082, theta=-44.582015 -> V=1.0, theta=0.0
% INFO    : Bus 23699	: V=0.9753642, theta=-44.781617 -> V=1.0, theta=0.0
% INFO    : Bus 23700	: V=0.973882, theta=-44.671569 -> V=1.0, theta=0.0
% INFO    : Bus 23701	: V=0.9707757, theta=-45.147495 -> V=1.0, theta=0.0
% INFO    : Bus 23702	: V=0.9765503, theta=-44.414827 -> V=1.0, theta=0.0
% INFO    : Bus 23703	: V=0.9716766, theta=-44.882583 -> V=1.0, theta=0.0
% INFO    : Bus 23704	: V=0.9713778, theta=-45.078128 -> V=1.0, theta=0.0
% INFO    : Bus 23705	: V=0.9705982, theta=-45.299465 -> V=1.0, theta=0.0
% INFO    : Bus 23706	: V=0.9723519, theta=-45.350705 -> V=1.0, theta=0.0
% INFO    : Bus 23707	: V=0.9725084, theta=-45.299611 -> V=1.0, theta=0.0
% INFO    : Bus 23708	: V=0.970598, theta=-44.952052 -> V=1.0, theta=0.0
% INFO    : Bus 23709	: V=0.9765568, theta=-44.516599 -> V=1.0, theta=0.0
% INFO    : Bus 23710	: V=0.971311, theta=-45.339043 -> V=1.0, theta=0.0
% INFO    : Bus 23711	: V=0.9709802, theta=-45.323284 -> V=1.0, theta=0.0
% INFO    : Bus 23712	: V=0.9712661, theta=-45.249741 -> V=1.0, theta=0.0
% INFO    : Bus 23713	: V=0.9722106, theta=-45.39025 -> V=1.0, theta=0.0
% INFO    : Bus 23714	: V=0.9710783, theta=-45.366407 -> V=1.0, theta=0.0
% INFO    : Bus 23715	: V=0.9715063, theta=-45.334064 -> V=1.0, theta=0.0
% INFO    : Bus 23716	: V=0.9703871, theta=-45.247993 -> V=1.0, theta=0.0
% INFO    : Bus 23717	: V=0.9705522, theta=-45.329194 -> V=1.0, theta=0.0
% INFO    : Bus 23718	: V=0.9696029, theta=-45.441307 -> V=1.0, theta=0.0
% INFO    : Bus 23719	: V=0.9771521, theta=-44.717144 -> V=1.0, theta=0.0
% INFO    : Bus 23720	: V=0.9736394, theta=-45.436994 -> V=1.0, theta=0.0
% INFO    : Bus 23721	: V=0.97885, theta=-44.900508 -> V=1.0, theta=0.0
% INFO    : Bus 23722	: V=0.9727005, theta=-45.353413 -> V=1.0, theta=0.0
% INFO    : Bus 23723	: V=0.9703081, theta=-45.424102 -> V=1.0, theta=0.0
% INFO    : Bus 23724	: V=0.9706351, theta=-45.446429 -> V=1.0, theta=0.0
% INFO    : Bus 23725	: V=0.9710738, theta=-45.442715 -> V=1.0, theta=0.0
% INFO    : Bus 23726	: V=0.9710305, theta=-45.481216 -> V=1.0, theta=0.0
% INFO    : Bus 23727	: V=0.9729557, theta=-45.391973 -> V=1.0, theta=0.0
% INFO    : Bus 23728	: V=0.9792864, theta=-44.883182 -> V=1.0, theta=0.0
% INFO    : Bus 23729	: V=0.9754544, theta=-45.335334 -> V=1.0, theta=0.0
% INFO    : Bus 23730	: V=0.9761273, theta=-45.363293 -> V=1.0, theta=0.0
% INFO    : Bus 23731	: V=0.9767321, theta=-45.218764 -> V=1.0, theta=0.0
% INFO    : Bus 23732	: V=0.9745024, theta=-45.000916 -> V=1.0, theta=0.0
% INFO    : Bus 23733	: V=0.9747984, theta=-44.90519 -> V=1.0, theta=0.0
% INFO    : Bus 23734	: V=0.9781038, theta=-44.770987 -> V=1.0, theta=0.0
% INFO    : Bus 23735	: V=0.9771064, theta=-44.953747 -> V=1.0, theta=0.0
% INFO    : Bus 23736	: V=0.9742811, theta=-45.022598 -> V=1.0, theta=0.0
% INFO    : Bus 23737	: V=0.9737487, theta=-45.142117 -> V=1.0, theta=0.0
% INFO    : Bus 23738	: V=0.9732732, theta=-45.229868 -> V=1.0, theta=0.0
% INFO    : Bus 23739	: V=0.9746583, theta=-45.345442 -> V=1.0, theta=0.0
% INFO    : Bus 23740	: V=0.9747006, theta=-45.260127 -> V=1.0, theta=0.0
% INFO    : Bus 23741	: V=0.9755404, theta=-45.180776 -> V=1.0, theta=0.0
% INFO    : Bus 23742	: V=0.9862679, theta=-44.881612 -> V=1.0, theta=0.0
% INFO    : Bus 23743	: V=0.9760704, theta=-45.344691 -> V=1.0, theta=0.0
% INFO    : Bus 23744	: V=0.9851749, theta=-44.906871 -> V=1.0, theta=0.0
% INFO    : Bus 23745	: V=0.9789924, theta=-44.441015 -> V=1.0, theta=0.0
% INFO    : Bus 23746	: V=0.979819, theta=-44.560649 -> V=1.0, theta=0.0
% INFO    : Bus 23747	: V=0.9782309, theta=-44.691 -> V=1.0, theta=0.0
% INFO    : Bus 23748	: V=0.9873437, theta=-44.790878 -> V=1.0, theta=0.0
% INFO    : Bus 23749	: V=0.9768009, theta=-45.274325 -> V=1.0, theta=0.0
% INFO    : Bus 23750	: V=0.9770013, theta=-45.372553 -> V=1.0, theta=0.0
% INFO    : Bus 23751	: V=0.9765454, theta=-44.898204 -> V=1.0, theta=0.0
% INFO    : Bus 23752	: V=0.9775606, theta=-44.931117 -> V=1.0, theta=0.0
% INFO    : Bus 23753	: V=0.9770987, theta=-45.117038 -> V=1.0, theta=0.0
% INFO    : Bus 23754	: V=0.9712831, theta=-45.058037 -> V=1.0, theta=0.0
% INFO    : Bus 23755	: V=0.9709389, theta=-45.033324 -> V=1.0, theta=0.0
% INFO    : Bus 23756	: V=0.9707936, theta=-45.113759 -> V=1.0, theta=0.0
% INFO    : Bus 23757	: V=0.9707534, theta=-45.181381 -> V=1.0, theta=0.0
% INFO    : Bus 23758	: V=0.9708726, theta=-45.130856 -> V=1.0, theta=0.0
% INFO    : Bus 23759	: V=0.9706184, theta=-45.240036 -> V=1.0, theta=0.0
% INFO    : Bus 23760	: V=0.9740013, theta=-45.16085 -> V=1.0, theta=0.0
% INFO    : Bus 23761	: V=0.9737797, theta=-45.161224 -> V=1.0, theta=0.0
% INFO    : Bus 23762	: V=0.9735387, theta=-45.162731 -> V=1.0, theta=0.0
% INFO    : Bus 23763	: V=0.9713234, theta=-45.339722 -> V=1.0, theta=0.0
% INFO    : Bus 23764	: V=0.9722949, theta=-45.329141 -> V=1.0, theta=0.0
% INFO    : Bus 23765	: V=0.9843218, theta=-44.868294 -> V=1.0, theta=0.0
% INFO    : Bus 23766	: V=0.9704905, theta=-45.243171 -> V=1.0, theta=0.0
% INFO    : Bus 23767	: V=0.9751375, theta=-45.220583 -> V=1.0, theta=0.0
% INFO    : Bus 23768	: V=1.0023071, theta=-42.83982 -> V=1.0, theta=0.0
% INFO    : Bus 23769	: V=0.9800712, theta=-44.581537 -> V=1.0, theta=0.0
% INFO    : Bus 23770	: V=0.9777063, theta=-44.896425 -> V=1.0, theta=0.0
% INFO    : Bus 23771	: V=0.9765213, theta=-45.095571 -> V=1.0, theta=0.0
% INFO    : Bus 23772	: V=0.9784605, theta=-44.933947 -> V=1.0, theta=0.0
% INFO    : Bus 23773	: V=0.9813097, theta=-44.646143 -> V=1.0, theta=0.0
% INFO    : Bus 23774	: V=1.003107, theta=-42.9317 -> V=1.0, theta=0.0
% INFO    : Bus 23775	: V=0.978283, theta=-44.843095 -> V=1.0, theta=0.0
% INFO    : Bus 23776	: V=0.978764, theta=-44.841 -> V=1.0, theta=0.0
% INFO    : Bus 23777	: V=0.9798512, theta=-44.798094 -> V=1.0, theta=0.0
% INFO    : Bus 23778	: V=0.9899389, theta=-43.867637 -> V=1.0, theta=0.0
% INFO    : Bus 23779	: V=0.9739629, theta=-44.591067 -> V=1.0, theta=0.0
% INFO    : Bus 23780	: V=0.973723, theta=-44.666125 -> V=1.0, theta=0.0
% INFO    : Bus 23781	: V=0.9756209, theta=-44.509938 -> V=1.0, theta=0.0
% INFO    : Bus 23782	: V=0.9734779, theta=-44.723994 -> V=1.0, theta=0.0
% INFO    : Bus 23783	: V=0.9859518, theta=-43.745291 -> V=1.0, theta=0.0
% INFO    : Bus 23784	: V=0.9853954, theta=-43.821754 -> V=1.0, theta=0.0
% INFO    : Bus 23785	: V=0.9856904, theta=-43.771023 -> V=1.0, theta=0.0
% INFO    : Bus 23786	: V=0.9839232, theta=-44.254145 -> V=1.0, theta=0.0
% INFO    : Bus 23787	: V=0.9830386, theta=-44.322492 -> V=1.0, theta=0.0
% INFO    : Bus 23788	: V=0.982013, theta=-44.395886 -> V=1.0, theta=0.0
% INFO    : Bus 23789	: V=0.9893256, theta=-43.762993 -> V=1.0, theta=0.0
% INFO    : Bus 23790	: V=0.9719852, theta=-44.815866 -> V=1.0, theta=0.0
% INFO    : Bus 23791	: V=0.9749865, theta=-44.510355 -> V=1.0, theta=0.0
% INFO    : Bus 23792	: V=0.9733212, theta=-44.795163 -> V=1.0, theta=0.0
% INFO    : Bus 23793	: V=0.9713207, theta=-44.894186 -> V=1.0, theta=0.0
% INFO    : Bus 23794	: V=0.9710549, theta=-44.917953 -> V=1.0, theta=0.0
% INFO    : Bus 23795	: V=0.9711037, theta=-44.950797 -> V=1.0, theta=0.0
% INFO    : Bus 23796	: V=0.9717554, theta=-44.983626 -> V=1.0, theta=0.0
% INFO    : Bus 23797	: V=0.973139, theta=-44.89527 -> V=1.0, theta=0.0
% INFO    : Bus 23798	: V=0.9749552, theta=-44.848778 -> V=1.0, theta=0.0
% INFO    : Bus 23799	: V=0.9749655, theta=-44.849535 -> V=1.0, theta=0.0
% INFO    : Bus 23800	: V=0.9734091, theta=-44.917761 -> V=1.0, theta=0.0
% INFO    : Bus 23801	: V=0.9738827, theta=-44.944999 -> V=1.0, theta=0.0
% INFO    : Bus 23802	: V=0.9755441, theta=-44.847821 -> V=1.0, theta=0.0
% INFO    : Bus 23803	: V=0.9823497, theta=-44.356289 -> V=1.0, theta=0.0
% INFO    : Bus 23804	: V=0.9772569, theta=-44.842826 -> V=1.0, theta=0.0
% INFO    : Bus 23805	: V=0.9754503, theta=-44.979378 -> V=1.0, theta=0.0
% INFO    : Bus 23806	: V=0.9776913, theta=-44.83992 -> V=1.0, theta=0.0
% INFO    : Bus 23807	: V=0.9813075, theta=-44.474848 -> V=1.0, theta=0.0
% INFO    : Bus 23808	: V=0.9776052, theta=-44.873164 -> V=1.0, theta=0.0
% INFO    : Bus 23809	: V=0.9746432, theta=-45.070914 -> V=1.0, theta=0.0
% INFO    : Bus 23810	: V=0.9702603, theta=-45.250044 -> V=1.0, theta=0.0
% INFO    : Bus 23811	: V=0.9764812, theta=-42.186901 -> V=1.0, theta=0.0
% INFO    : Bus 23812	: V=0.9771945, theta=-42.1423 -> V=1.0, theta=0.0
% INFO    : Bus 23813	: V=0.9726107, theta=-42.91749 -> V=1.0, theta=0.0
% INFO    : Bus 23814	: V=0.9761456, theta=-42.339098 -> V=1.0, theta=0.0
% INFO    : Bus 23815	: V=0.9750994, theta=-42.448102 -> V=1.0, theta=0.0
% INFO    : Bus 23816	: V=0.9703083, theta=-43.306912 -> V=1.0, theta=0.0
% INFO    : Bus 23817	: V=0.9698663, theta=-43.294699 -> V=1.0, theta=0.0
% INFO    : Bus 23818	: V=0.9690157, theta=-43.34596 -> V=1.0, theta=0.0
% INFO    : Bus 23819	: V=0.9700107, theta=-43.327328 -> V=1.0, theta=0.0
% INFO    : Bus 23820	: V=0.9708012, theta=-43.202325 -> V=1.0, theta=0.0
% INFO    : Bus 23821	: V=0.9744646, theta=-42.5137 -> V=1.0, theta=0.0
% INFO    : Bus 23822	: V=0.9739954, theta=-42.572645 -> V=1.0, theta=0.0
% INFO    : Bus 23823	: V=0.9728958, theta=-43.13511 -> V=1.0, theta=0.0
% INFO    : Bus 23824	: V=0.9734377, theta=-43.132016 -> V=1.0, theta=0.0
% INFO    : Bus 23825	: V=0.9781571, theta=-42.816971 -> V=1.0, theta=0.0
% INFO    : Bus 23826	: V=0.9722175, theta=-43.225762 -> V=1.0, theta=0.0
% INFO    : Bus 23827	: V=0.9735359, theta=-42.627147 -> V=1.0, theta=0.0
% INFO    : Bus 23828	: V=0.9705143, theta=-43.430078 -> V=1.0, theta=0.0
% INFO    : Bus 23829	: V=0.9697676, theta=-43.672475 -> V=1.0, theta=0.0
% INFO    : Bus 23830	: V=0.9683302, theta=-43.462596 -> V=1.0, theta=0.0
% INFO    : Bus 23831	: V=0.9696007, theta=-43.936665 -> V=1.0, theta=0.0
% INFO    : Bus 23832	: V=0.9723016, theta=-43.948381 -> V=1.0, theta=0.0
% INFO    : Bus 23833	: V=0.9697453, theta=-43.682927 -> V=1.0, theta=0.0
% INFO    : Bus 23834	: V=0.9703912, theta=-43.795694 -> V=1.0, theta=0.0
% INFO    : Bus 23835	: V=0.9707119, theta=-43.430151 -> V=1.0, theta=0.0
% INFO    : Bus 23836	: V=0.978192, theta=-42.976179 -> V=1.0, theta=0.0
% INFO    : Bus 23837	: V=0.9786142, theta=-43.192864 -> V=1.0, theta=0.0
% INFO    : Bus 23838	: V=0.9784396, theta=-43.121994 -> V=1.0, theta=0.0
% INFO    : Bus 23839	: V=0.9712484, theta=-43.78747 -> V=1.0, theta=0.0
% INFO    : Bus 23840	: V=0.9751619, theta=-43.934471 -> V=1.0, theta=0.0
% INFO    : Bus 23841	: V=0.9752266, theta=-43.905722 -> V=1.0, theta=0.0
% INFO    : Bus 23842	: V=0.9737266, theta=-43.898296 -> V=1.0, theta=0.0
% INFO    : Bus 23843	: V=0.9729286, theta=-43.836773 -> V=1.0, theta=0.0
% INFO    : Bus 23844	: V=0.9788745, theta=-43.269714 -> V=1.0, theta=0.0
% INFO    : Bus 23845	: V=0.9793105, theta=-43.35454 -> V=1.0, theta=0.0
% INFO    : Bus 23846	: V=0.973604, theta=-44.335855 -> V=1.0, theta=0.0
% INFO    : Bus 23847	: V=0.9781939, theta=-43.783387 -> V=1.0, theta=0.0
% INFO    : Bus 23848	: V=0.9803757, theta=-43.457961 -> V=1.0, theta=0.0
% INFO    : Bus 23849	: V=0.9818327, theta=-43.464827 -> V=1.0, theta=0.0
% INFO    : Bus 23850	: V=0.9833999, theta=-43.459913 -> V=1.0, theta=0.0
% INFO    : Bus 23851	: V=0.9794623, theta=-43.962075 -> V=1.0, theta=0.0
% INFO    : Bus 23852	: V=0.9853552, theta=-43.444383 -> V=1.0, theta=0.0
% INFO    : Bus 23853	: V=0.9876656, theta=-43.413783 -> V=1.0, theta=0.0
% INFO    : Bus 23854	: V=0.9852636, theta=-43.666588 -> V=1.0, theta=0.0
% INFO    : Bus 23855	: V=0.9773415, theta=-44.272649 -> V=1.0, theta=0.0
% INFO    : Bus 23856	: V=0.9814707, theta=-43.815747 -> V=1.0, theta=0.0
% INFO    : Bus 23857	: V=0.9786115, theta=-43.835835 -> V=1.0, theta=0.0
% INFO    : Bus 23858	: V=0.9794582, theta=-43.854607 -> V=1.0, theta=0.0
% INFO    : Bus 23859	: V=0.9791516, theta=-43.900647 -> V=1.0, theta=0.0
% INFO    : Bus 23860	: V=0.9872655, theta=-43.381865 -> V=1.0, theta=0.0
% INFO    : Bus 23861	: V=0.9869175, theta=-43.518686 -> V=1.0, theta=0.0
% INFO    : Bus 23862	: V=0.9930698, theta=-32.1985 -> V=1.0, theta=0.0
% INFO    : Bus 23863	: V=1.0067987, theta=-28.70599 -> V=1.0, theta=0.0
% INFO    : Bus 23864	: V=1.0031527, theta=-29.519784 -> V=1.0, theta=0.0
% INFO    : Bus 23865	: V=0.9810506, theta=-34.35267 -> V=1.0, theta=0.0
% INFO    : Bus 23866	: V=1.0093312, theta=-28.044402 -> V=1.0, theta=0.0
% INFO    : Bus 23867	: V=0.993625, theta=-32.127606 -> V=1.0, theta=0.0
% INFO    : Bus 23868	: V=0.9997713, theta=-30.765963 -> V=1.0, theta=0.0
% INFO    : Bus 23869	: V=0.9725111, theta=-33.341628 -> V=1.0, theta=0.0
% INFO    : Bus 23870	: V=0.9741453, theta=-33.5671 -> V=1.0, theta=0.0
% INFO    : Bus 23871	: V=0.9609511, theta=-34.198381 -> V=1.0, theta=0.0
% INFO    : Bus 23872	: V=0.9655929, theta=-34.134266 -> V=1.0, theta=0.0
% INFO    : Bus 23873	: V=0.9794758, theta=-33.26254 -> V=1.0, theta=0.0
% INFO    : Bus 23874	: V=0.9734617, theta=-33.880211 -> V=1.0, theta=0.0
% INFO    : Bus 23875	: V=0.9638615, theta=-34.162953 -> V=1.0, theta=0.0
% INFO    : Bus 23876	: V=1.0073635, theta=-32.74142 -> V=1.0, theta=0.0
% INFO    : Bus 23877	: V=1.0483934, theta=-30.891459 -> V=1.0, theta=0.0
% INFO    : Bus 23878	: V=1.0146642, theta=-31.525617 -> V=1.0, theta=0.0
% INFO    : Bus 23879	: V=0.9709864, theta=-33.857292 -> V=1.0, theta=0.0
% INFO    : Bus 23880	: V=0.9965386, theta=-31.127506 -> V=1.0, theta=0.0
% INFO    : Bus 23881	: V=0.9968646, theta=-32.092915 -> V=1.0, theta=0.0
% INFO    : Bus 23882	: V=0.977696, theta=-33.291649 -> V=1.0, theta=0.0
% INFO    : Bus 23883	: V=0.9968839, theta=-32.832148 -> V=1.0, theta=0.0
% INFO    : Bus 23884	: V=0.9994265, theta=-31.819362 -> V=1.0, theta=0.0
% INFO    : Bus 23885	: V=0.9893032, theta=-31.835759 -> V=1.0, theta=0.0
% INFO    : Bus 23886	: V=0.9820578, theta=-32.714598 -> V=1.0, theta=0.0
% INFO    : Bus 23887	: V=0.9764279, theta=-32.941351 -> V=1.0, theta=0.0
% INFO    : Bus 23888	: V=0.9842916, theta=-32.415673 -> V=1.0, theta=0.0
% INFO    : Bus 23889	: V=0.9789558, theta=-32.823671 -> V=1.0, theta=0.0
% INFO    : Bus 23890	: V=1.0157884, theta=-28.812805 -> V=1.0, theta=0.0
% INFO    : Bus 23891	: V=1.0157282, theta=-28.559703 -> V=1.0, theta=0.0
% INFO    : Bus 23892	: V=1.0196013, theta=-28.210934 -> V=1.0, theta=0.0
% INFO    : Bus 23893	: V=1.0084775, theta=-29.573738 -> V=1.0, theta=0.0
% INFO    : Bus 23894	: V=1.007901, theta=-28.778725 -> V=1.0, theta=0.0
% INFO    : Bus 23895	: V=1.0039778, theta=-28.764291 -> V=1.0, theta=0.0
% INFO    : Bus 23896	: V=0.9753192, theta=-40.525432 -> V=1.0, theta=0.0
% INFO    : Bus 23897	: V=0.982923, theta=-40.873361 -> V=1.0, theta=0.0
% INFO    : Bus 23898	: V=0.9915046, theta=-39.690427 -> V=1.0, theta=0.0
% INFO    : Bus 23899	: V=0.995852, theta=-39.020966 -> V=1.0, theta=0.0
% INFO    : Bus 23900	: V=0.9903447, theta=-38.78779 -> V=1.0, theta=0.0
% INFO    : Bus 23901	: V=1.000497, theta=-38.393213 -> V=1.0, theta=0.0
% INFO    : Bus 23902	: V=1.0040348, theta=-37.878093 -> V=1.0, theta=0.0
% INFO    : Bus 23903	: V=1.0001406, theta=-38.841543 -> V=1.0, theta=0.0
% INFO    : Bus 23904	: V=1.0034523, theta=-38.206992 -> V=1.0, theta=0.0
% INFO    : Bus 23905	: V=0.9977514, theta=-38.837123 -> V=1.0, theta=0.0
% INFO    : Bus 23906	: V=1.0025799, theta=-39.272114 -> V=1.0, theta=0.0
% INFO    : Bus 23907	: V=1.0075922, theta=-38.603537 -> V=1.0, theta=0.0
% INFO    : Bus 23908	: V=0.9938288, theta=-40.572638 -> V=1.0, theta=0.0
% INFO    : Bus 23909	: V=0.9955367, theta=-40.79457 -> V=1.0, theta=0.0
% INFO    : Bus 23910	: V=1.0129696, theta=-39.288817 -> V=1.0, theta=0.0
% INFO    : Bus 23911	: V=0.9761698, theta=-43.470333 -> V=1.0, theta=0.0
% INFO    : Bus 23912	: V=0.9786602, theta=-43.775424 -> V=1.0, theta=0.0
% INFO    : Bus 23913	: V=0.9814346, theta=-43.428016 -> V=1.0, theta=0.0
% INFO    : Bus 23914	: V=0.9855344, theta=-43.184853 -> V=1.0, theta=0.0
% INFO    : Bus 23915	: V=0.9830182, theta=-43.103162 -> V=1.0, theta=0.0
% INFO    : Bus 23916	: V=0.9823173, theta=-43.335718 -> V=1.0, theta=0.0
% INFO    : Bus 23917	: V=0.9868873, theta=-43.134436 -> V=1.0, theta=0.0
% INFO    : Bus 23918	: V=0.9901747, theta=-42.99878 -> V=1.0, theta=0.0
% INFO    : Bus 23919	: V=0.9886161, theta=-43.061421 -> V=1.0, theta=0.0
% INFO    : Bus 23920	: V=0.9839015, theta=-42.757043 -> V=1.0, theta=0.0
% INFO    : Bus 23921	: V=0.9977636, theta=-42.636669 -> V=1.0, theta=0.0
% INFO    : Bus 23922	: V=1.0063425, theta=-41.638721 -> V=1.0, theta=0.0
% INFO    : Bus 23923	: V=1.0115221, theta=-41.518175 -> V=1.0, theta=0.0
% INFO    : Bus 23924	: V=1.0090631, theta=-42.163119 -> V=1.0, theta=0.0
% INFO    : Bus 23925	: V=1.0092038, theta=-42.440759 -> V=1.0, theta=0.0
% INFO    : Bus 23926	: V=1.0094335, theta=-42.16417 -> V=1.0, theta=0.0
% INFO    : Bus 23927	: V=1.0025126, theta=-43.26421 -> V=1.0, theta=0.0
% INFO    : Bus 23928	: V=1.0032351, theta=-43.203837 -> V=1.0, theta=0.0
% INFO    : Bus 23929	: V=1.007973, theta=-42.990997 -> V=1.0, theta=0.0
% INFO    : Bus 23930	: V=1.0053806, theta=-43.438579 -> V=1.0, theta=0.0
% INFO    : Bus 23931	: V=1.0058874, theta=-43.168693 -> V=1.0, theta=0.0
% INFO    : Bus 23932	: V=1.0191376, theta=-41.361044 -> V=1.0, theta=0.0
% INFO    : Bus 23933	: V=0.9825686, theta=-43.367233 -> V=1.0, theta=0.0
% INFO    : Bus 23934	: V=1.0162835, theta=-41.780808 -> V=1.0, theta=0.0
% INFO    : Bus 23935	: V=1.0070324, theta=-42.433964 -> V=1.0, theta=0.0
% INFO    : Bus 23936	: V=0.9846021, theta=-40.613829 -> V=1.0, theta=0.0
% INFO    : Bus 23937	: V=0.9834443, theta=-43.214157 -> V=1.0, theta=0.0
% INFO    : Bus 23938	: V=0.9839438, theta=-43.285029 -> V=1.0, theta=0.0
% INFO    : Bus 23939	: V=0.9836537, theta=-41.975127 -> V=1.0, theta=0.0
% INFO    : Bus 23940	: V=0.991235, theta=-42.113371 -> V=1.0, theta=0.0
% INFO    : Bus 23941	: V=0.9858176, theta=-42.261532 -> V=1.0, theta=0.0
% INFO    : Bus 23942	: V=0.9842693, theta=-42.702541 -> V=1.0, theta=0.0
% INFO    : Bus 23943	: V=1.009465, theta=-42.545053 -> V=1.0, theta=0.0
% INFO    : Bus 23944	: V=1.0174542, theta=-41.415536 -> V=1.0, theta=0.0
% INFO    : Bus 23945	: V=1.0047071, theta=-43.485202 -> V=1.0, theta=0.0
% INFO    : Bus 23946	: V=1.0053774, theta=-43.453944 -> V=1.0, theta=0.0
% INFO    : Bus 23947	: V=1.0082405, theta=-42.727842 -> V=1.0, theta=0.0
% INFO    : Bus 23948	: V=1.0086351, theta=-42.48878 -> V=1.0, theta=0.0
% INFO    : Bus 23949	: V=1.0150411, theta=-28.737282 -> V=1.0, theta=0.0
% INFO    : Bus 23950	: V=1.0000987, theta=-30.701355 -> V=1.0, theta=0.0
% INFO    : Bus 23951	: V=0.9993582, theta=-30.087722 -> V=1.0, theta=0.0
% INFO    : Bus 23952	: V=1.0061159, theta=-29.496977 -> V=1.0, theta=0.0
% INFO    : Bus 23953	: V=0.9856807, theta=-30.841966 -> V=1.0, theta=0.0
% INFO    : Bus 23954	: V=0.9820365, theta=-30.867667 -> V=1.0, theta=0.0
% INFO    : Bus 23955	: V=0.9743394, theta=-33.787721 -> V=1.0, theta=0.0
% INFO    : Bus 23956	: V=0.973805, theta=-33.703982 -> V=1.0, theta=0.0
% INFO    : Bus 23957	: V=0.9760125, theta=-33.819393 -> V=1.0, theta=0.0
% INFO    : Bus 23958	: V=0.9798593, theta=-33.722883 -> V=1.0, theta=0.0
% INFO    : Bus 23959	: V=0.9741678, theta=-33.86454 -> V=1.0, theta=0.0
% INFO    : Bus 23960	: V=0.971296, theta=-33.948925 -> V=1.0, theta=0.0
% INFO    : Bus 23961	: V=0.9757432, theta=-33.901759 -> V=1.0, theta=0.0
% INFO    : Bus 23962	: V=0.9701126, theta=-34.150348 -> V=1.0, theta=0.0
% INFO    : Bus 23963	: V=0.9712134, theta=-34.175103 -> V=1.0, theta=0.0
% INFO    : Bus 23964	: V=0.9677156, theta=-34.104494 -> V=1.0, theta=0.0
% INFO    : Bus 23965	: V=1.0081266, theta=-32.980973 -> V=1.0, theta=0.0
% INFO    : Bus 23966	: V=0.9974171, theta=-34.26317 -> V=1.0, theta=0.0
% INFO    : Bus 23967	: V=1.0015725, theta=-34.094458 -> V=1.0, theta=0.0
% INFO    : Bus 23968	: V=1.0014213, theta=-34.131138 -> V=1.0, theta=0.0
% INFO    : Bus 23969	: V=1.0011742, theta=-34.171841 -> V=1.0, theta=0.0
% INFO    : Bus 23970	: V=0.9983658, theta=-34.432676 -> V=1.0, theta=0.0
% INFO    : Bus 23971	: V=1.0008462, theta=-34.243955 -> V=1.0, theta=0.0
% INFO    : Bus 23972	: V=1.0011007, theta=-34.242064 -> V=1.0, theta=0.0
% INFO    : Bus 23973	: V=0.9984304, theta=-34.491751 -> V=1.0, theta=0.0
% INFO    : Bus 23974	: V=0.9985683, theta=-34.419579 -> V=1.0, theta=0.0
% INFO    : Bus 23975	: V=1.0014363, theta=-34.109866 -> V=1.0, theta=0.0
% INFO    : Bus 23976	: V=1.0015568, theta=-34.087739 -> V=1.0, theta=0.0
% INFO    : Bus 23977	: V=1.0028026, theta=-33.934104 -> V=1.0, theta=0.0
% INFO    : Bus 23978	: V=1.0023406, theta=-33.993428 -> V=1.0, theta=0.0
% INFO    : Bus 23979	: V=1.0020019, theta=-34.042216 -> V=1.0, theta=0.0
% INFO    : Bus 23980	: V=1.0019227, theta=-34.040746 -> V=1.0, theta=0.0
% INFO    : Bus 23981	: V=0.9991124, theta=-34.269942 -> V=1.0, theta=0.0
% INFO    : Bus 23982	: V=1.0027541, theta=-33.938727 -> V=1.0, theta=0.0
% INFO    : Bus 23983	: V=1.0077736, theta=-33.191729 -> V=1.0, theta=0.0
% INFO    : Bus 23984	: V=1.0101534, theta=-33.003019 -> V=1.0, theta=0.0
% INFO    : Bus 23985	: V=0.996419, theta=-33.890861 -> V=1.0, theta=0.0
% INFO    : Bus 23986	: V=1.008767, theta=-33.119305 -> V=1.0, theta=0.0
% INFO    : Bus 23987	: V=0.9985019, theta=-34.106544 -> V=1.0, theta=0.0
% INFO    : Bus 23988	: V=1.0022451, theta=-33.842356 -> V=1.0, theta=0.0
% INFO    : Bus 23989	: V=0.9988829, theta=-34.210183 -> V=1.0, theta=0.0
% INFO    : Bus 23990	: V=1.0079257, theta=-33.183107 -> V=1.0, theta=0.0
% INFO    : Bus 23991	: V=1.0082244, theta=-33.16315 -> V=1.0, theta=0.0
% INFO    : Bus 23992	: V=1.0017148, theta=-34.06628 -> V=1.0, theta=0.0
% INFO    : Bus 23993	: V=1.0021317, theta=-34.007677 -> V=1.0, theta=0.0
% INFO    : Bus 23994	: V=0.9989473, theta=-34.356227 -> V=1.0, theta=0.0
% INFO    : Bus 23995	: V=1.0022198, theta=-33.784302 -> V=1.0, theta=0.0
% INFO    : Bus 23996	: V=1.0087863, theta=-32.711355 -> V=1.0, theta=0.0
% INFO    : Bus 23997	: V=1.0065855, theta=-33.412049 -> V=1.0, theta=0.0
% INFO    : Bus 23998	: V=0.9980619, theta=-34.095963 -> V=1.0, theta=0.0
% INFO    : Bus 23999	: V=1.0076676, theta=-33.313361 -> V=1.0, theta=0.0
% INFO    : Bus 24000	: V=1.0071923, theta=-33.605172 -> V=1.0, theta=0.0
% INFO    : Bus 24001	: V=1.0012313, theta=-34.364646 -> V=1.0, theta=0.0
% INFO    : Bus 24002	: V=1.0055307, theta=-33.800629 -> V=1.0, theta=0.0
% INFO    : Bus 24003	: V=0.9966506, theta=-34.502158 -> V=1.0, theta=0.0
% INFO    : Bus 24004	: V=0.99919, theta=-34.7953 -> V=1.0, theta=0.0
% INFO    : Bus 24005	: V=0.9931447, theta=-34.510734 -> V=1.0, theta=0.0
% INFO    : Bus 24006	: V=0.9990213, theta=-34.586435 -> V=1.0, theta=0.0
% INFO    : Bus 24007	: V=0.9977058, theta=-34.852472 -> V=1.0, theta=0.0
% INFO    : Bus 24008	: V=1.0012163, theta=-34.175056 -> V=1.0, theta=0.0
% INFO    : Bus 24009	: V=1.0027224, theta=-34.002114 -> V=1.0, theta=0.0
% INFO    : Bus 24010	: V=0.9991168, theta=-34.60526 -> V=1.0, theta=0.0
% INFO    : Bus 24011	: V=0.9988061, theta=-34.726363 -> V=1.0, theta=0.0
% INFO    : Bus 24012	: V=1.0017126, theta=-33.882232 -> V=1.0, theta=0.0
% INFO    : Bus 24013	: V=0.9942342, theta=-35.672003 -> V=1.0, theta=0.0
% INFO    : Bus 24014	: V=0.9902274, theta=-36.574113 -> V=1.0, theta=0.0
% INFO    : Bus 24015	: V=0.9866199, theta=-37.339341 -> V=1.0, theta=0.0
% INFO    : Bus 24016	: V=0.990207, theta=-36.09151 -> V=1.0, theta=0.0
% INFO    : Bus 24017	: V=0.9836158, theta=-37.264855 -> V=1.0, theta=0.0
% INFO    : Bus 24018	: V=0.9919347, theta=-35.089835 -> V=1.0, theta=0.0
% INFO    : Bus 24019	: V=1.0008087, theta=-35.189717 -> V=1.0, theta=0.0
% INFO    : Bus 24020	: V=0.9985561, theta=-35.503064 -> V=1.0, theta=0.0
% INFO    : Bus 24021	: V=1.0156628, theta=-38.070956 -> V=1.0, theta=0.0
% INFO    : Bus 24022	: V=0.9997152, theta=-39.385807 -> V=1.0, theta=0.0
% INFO    : Bus 24023	: V=0.998109, theta=-39.431398 -> V=1.0, theta=0.0
% INFO    : Bus 24024	: V=0.9962839, theta=-39.466952 -> V=1.0, theta=0.0
% INFO    : Bus 24025	: V=1.0004339, theta=-39.376401 -> V=1.0, theta=0.0
% INFO    : Bus 24026	: V=0.9998534, theta=-39.37692 -> V=1.0, theta=0.0
% INFO    : Bus 24027	: V=0.9941894, theta=-39.462854 -> V=1.0, theta=0.0
% INFO    : Bus 24028	: V=0.9936885, theta=-39.464323 -> V=1.0, theta=0.0
% INFO    : Bus 24029	: V=0.9926061, theta=-39.385618 -> V=1.0, theta=0.0
% INFO    : Bus 24030	: V=0.9917086, theta=-39.390151 -> V=1.0, theta=0.0
% INFO    : Bus 24031	: V=0.9946681, theta=-38.85104 -> V=1.0, theta=0.0
% INFO    : Bus 24032	: V=0.9951387, theta=-38.86536 -> V=1.0, theta=0.0
% INFO    : Bus 24033	: V=0.9963713, theta=-38.62589 -> V=1.0, theta=0.0
% INFO    : Bus 24034	: V=0.9935541, theta=-39.096495 -> V=1.0, theta=0.0
% INFO    : Bus 24035	: V=1.0007078, theta=-37.959638 -> V=1.0, theta=0.0
% INFO    : Bus 24036	: V=0.9960939, theta=-38.638979 -> V=1.0, theta=0.0
% INFO    : Bus 24037	: V=0.9973181, theta=-38.433377 -> V=1.0, theta=0.0
% INFO    : Bus 24038	: V=0.9965388, theta=-39.530898 -> V=1.0, theta=0.0
% INFO    : Bus 24039	: V=0.9964693, theta=-39.380345 -> V=1.0, theta=0.0
% INFO    : Bus 24040	: V=0.9952534, theta=-39.036815 -> V=1.0, theta=0.0
% INFO    : Bus 24041	: V=1.0136934, theta=-37.921422 -> V=1.0, theta=0.0
% INFO    : Bus 24042	: V=1.009755, theta=-39.069564 -> V=1.0, theta=0.0
% INFO    : Bus 24043	: V=1.0105869, theta=-38.955018 -> V=1.0, theta=0.0
% INFO    : Bus 24044	: V=1.0154472, theta=-38.741832 -> V=1.0, theta=0.0
% INFO    : Bus 24045	: V=1.0155208, theta=-38.890179 -> V=1.0, theta=0.0
% INFO    : Bus 24046	: V=1.0081637, theta=-39.540733 -> V=1.0, theta=0.0
% INFO    : Bus 24047	: V=1.0052305, theta=-39.655472 -> V=1.0, theta=0.0
% INFO    : Bus 24048	: V=1.0168002, theta=-39.444868 -> V=1.0, theta=0.0
% INFO    : Bus 24049	: V=1.0158425, theta=-39.030937 -> V=1.0, theta=0.0
% INFO    : Bus 24050	: V=1.0167997, theta=-39.326571 -> V=1.0, theta=0.0
% INFO    : Bus 24051	: V=1.0135515, theta=-39.415616 -> V=1.0, theta=0.0
% INFO    : Bus 24052	: V=1.0063082, theta=-39.876823 -> V=1.0, theta=0.0
% INFO    : Bus 24053	: V=1.0091924, theta=-39.666543 -> V=1.0, theta=0.0
% INFO    : Bus 24054	: V=0.9994376, theta=-40.956213 -> V=1.0, theta=0.0
% INFO    : Bus 24055	: V=1.0000746, theta=-40.432701 -> V=1.0, theta=0.0
% INFO    : Bus 24056	: V=0.9995447, theta=-40.458603 -> V=1.0, theta=0.0
% INFO    : Bus 24057	: V=1.0101605, theta=-40.222984 -> V=1.0, theta=0.0
% INFO    : Bus 24058	: V=1.0010368, theta=-41.010172 -> V=1.0, theta=0.0
% INFO    : Bus 24059	: V=1.0078698, theta=-39.811666 -> V=1.0, theta=0.0
% INFO    : Bus 24060	: V=1.0057992, theta=-39.974832 -> V=1.0, theta=0.0
% INFO    : Bus 24061	: V=1.0044669, theta=-39.17252 -> V=1.0, theta=0.0
% INFO    : Bus 24062	: V=1.0083279, theta=-36.255186 -> V=1.0, theta=0.0
% INFO    : Bus 24063	: V=0.9966455, theta=-37.975584 -> V=1.0, theta=0.0
% INFO    : Bus 24064	: V=0.9891749, theta=-37.677764 -> V=1.0, theta=0.0
% INFO    : Bus 24065	: V=1.0091422, theta=-36.241843 -> V=1.0, theta=0.0
% INFO    : Bus 24066	: V=0.9858848, theta=-39.488892 -> V=1.0, theta=0.0
% INFO    : Bus 24067	: V=0.9843748, theta=-39.732986 -> V=1.0, theta=0.0
% INFO    : Bus 24068	: V=0.9910038, theta=-38.501055 -> V=1.0, theta=0.0
% INFO    : Bus 24069	: V=0.9969433, theta=-39.274702 -> V=1.0, theta=0.0
% INFO    : Bus 24070	: V=0.9393166, theta=-56.414353 -> V=1.0, theta=0.0
% INFO    : Bus 24071	: V=0.9437337, theta=-56.742278 -> V=1.0, theta=0.0
% INFO    : Bus 24072	: V=0.9518062, theta=-56.024291 -> V=1.0, theta=0.0
% INFO    : Bus 24073	: V=0.937448, theta=-56.47068 -> V=1.0, theta=0.0
% INFO    : Bus 24074	: V=0.9449864, theta=-59.007115 -> V=1.0, theta=0.0
% INFO    : Bus 24075	: V=0.9544285, theta=-57.454087 -> V=1.0, theta=0.0
% INFO    : Bus 24076	: V=0.9553282, theta=-57.371162 -> V=1.0, theta=0.0
% INFO    : Bus 24077	: V=0.9465445, theta=-58.649801 -> V=1.0, theta=0.0
% INFO    : Bus 24078	: V=0.9481749, theta=-55.358462 -> V=1.0, theta=0.0
% INFO    : Bus 24079	: V=0.9560046, theta=-55.719481 -> V=1.0, theta=0.0
% INFO    : Bus 24080	: V=0.9444247, theta=-57.667189 -> V=1.0, theta=0.0
% INFO    : Bus 24081	: V=0.9551596, theta=-55.51021 -> V=1.0, theta=0.0
% INFO    : Bus 24082	: V=0.0, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 24083	: V=0.9496522, theta=-56.81962 -> V=1.0, theta=0.0
% INFO    : Bus 24084	: V=0.948393, theta=-57.401036 -> V=1.0, theta=0.0
% INFO    : Bus 24085	: V=0.9612305, theta=-56.571362 -> V=1.0, theta=0.0
% INFO    : Bus 24086	: V=0.9469653, theta=-57.782566 -> V=1.0, theta=0.0
% INFO    : Bus 24087	: V=1.0116838, theta=-33.951194 -> V=1.0, theta=0.0
% INFO    : Bus 24088	: V=0.9976498, theta=-35.284779 -> V=1.0, theta=0.0
% INFO    : Bus 24089	: V=0.9912253, theta=-35.29945 -> V=1.0, theta=0.0
% INFO    : Bus 24090	: V=1.0073665, theta=-34.737477 -> V=1.0, theta=0.0
% INFO    : Bus 24091	: V=0.9933458, theta=-36.078154 -> V=1.0, theta=0.0
% INFO    : Bus 24092	: V=0.989499, theta=-36.428073 -> V=1.0, theta=0.0
% INFO    : Bus 24093	: V=0.9985347, theta=-37.97143 -> V=1.0, theta=0.0
% INFO    : Bus 24094	: V=0.9883822, theta=-36.580174 -> V=1.0, theta=0.0
% INFO    : Bus 24095	: V=0.9919327, theta=-35.984784 -> V=1.0, theta=0.0
% INFO    : Bus 24096	: V=0.9998758, theta=-34.30936 -> V=1.0, theta=0.0
% INFO    : Bus 24097	: V=0.9761293, theta=-36.810651 -> V=1.0, theta=0.0
% INFO    : Bus 24098	: V=0.991224, theta=-36.784618 -> V=1.0, theta=0.0
% INFO    : Bus 24099	: V=1.0148367, theta=-32.539081 -> V=1.0, theta=0.0
% INFO    : Bus 24100	: V=0.9997664, theta=-32.402235 -> V=1.0, theta=0.0
% INFO    : Bus 24101	: V=1.0158983, theta=-31.612955 -> V=1.0, theta=0.0
% INFO    : Bus 24102	: V=0.9625014, theta=-39.226197 -> V=1.0, theta=0.0
% INFO    : Bus 24103	: V=0.9840052, theta=-38.529107 -> V=1.0, theta=0.0
% INFO    : Bus 24104	: V=0.9802593, theta=-39.213065 -> V=1.0, theta=0.0
% INFO    : Bus 24105	: V=0.9671396, theta=-40.471765 -> V=1.0, theta=0.0
% INFO    : Bus 24106	: V=0.9672184, theta=-40.471562 -> V=1.0, theta=0.0
% INFO    : Bus 24107	: V=0.9675779, theta=-40.446753 -> V=1.0, theta=0.0
% INFO    : Bus 24108	: V=0.9674283, theta=-40.450232 -> V=1.0, theta=0.0
% INFO    : Bus 24109	: V=0.9677418, theta=-40.449657 -> V=1.0, theta=0.0
% INFO    : Bus 24110	: V=0.968191, theta=-41.559777 -> V=1.0, theta=0.0
% INFO    : Bus 24111	: V=0.9659996, theta=-41.026355 -> V=1.0, theta=0.0
% INFO    : Bus 24112	: V=0.9690067, theta=-40.819701 -> V=1.0, theta=0.0
% INFO    : Bus 24113	: V=0.9735721, theta=-40.943348 -> V=1.0, theta=0.0
% INFO    : Bus 24114	: V=0.9683739, theta=-41.260953 -> V=1.0, theta=0.0
% INFO    : Bus 24115	: V=0.9718468, theta=-39.916939 -> V=1.0, theta=0.0
% INFO    : Bus 24116	: V=0.9738997, theta=-39.349842 -> V=1.0, theta=0.0
% INFO    : Bus 24117	: V=0.9694094, theta=-40.758319 -> V=1.0, theta=0.0
% INFO    : Bus 24118	: V=0.9652764, theta=-40.670907 -> V=1.0, theta=0.0
% INFO    : Bus 24119	: V=0.9731104, theta=-35.983329 -> V=1.0, theta=0.0
% INFO    : Bus 24120	: V=0.9840962, theta=-35.202913 -> V=1.0, theta=0.0
% INFO    : Bus 24121	: V=1.0019724, theta=-32.945091 -> V=1.0, theta=0.0
% INFO    : Bus 24122	: V=0.9742986, theta=-36.015826 -> V=1.0, theta=0.0
% INFO    : Bus 24123	: V=0.9795297, theta=-36.004851 -> V=1.0, theta=0.0
% INFO    : Bus 24124	: V=0.9981922, theta=-33.669102 -> V=1.0, theta=0.0
% INFO    : Bus 24125	: V=0.9963291, theta=-34.031627 -> V=1.0, theta=0.0
% INFO    : Bus 24126	: V=0.9973183, theta=-33.526965 -> V=1.0, theta=0.0
% INFO    : Bus 24127	: V=0.9807048, theta=-36.643992 -> V=1.0, theta=0.0
% INFO    : Bus 24128	: V=0.9929271, theta=-35.241143 -> V=1.0, theta=0.0
% INFO    : Bus 24129	: V=0.9767058, theta=-36.67222 -> V=1.0, theta=0.0
% INFO    : Bus 24130	: V=0.9910864, theta=-36.199502 -> V=1.0, theta=0.0
% INFO    : Bus 24131	: V=0.9863811, theta=-36.59905 -> V=1.0, theta=0.0
% INFO    : Bus 24132	: V=0.9757629, theta=-50.284324 -> V=1.0, theta=0.0
% INFO    : Bus 24133	: V=0.995453, theta=-47.889978 -> V=1.0, theta=0.0
% INFO    : Bus 24134	: V=1.0021755, theta=-47.847887 -> V=1.0, theta=0.0
% INFO    : Bus 24135	: V=1.0034241, theta=-48.003118 -> V=1.0, theta=0.0
% INFO    : Bus 24136	: V=0.9893425, theta=-48.532134 -> V=1.0, theta=0.0
% INFO    : Bus 24137	: V=1.0078967, theta=-49.683635 -> V=1.0, theta=0.0
% INFO    : Bus 24138	: V=0.9722419, theta=-51.061151 -> V=1.0, theta=0.0
% INFO    : Bus 24139	: V=0.9956528, theta=-49.542512 -> V=1.0, theta=0.0
% INFO    : Bus 24140	: V=0.989524, theta=-50.74394 -> V=1.0, theta=0.0
% INFO    : Bus 24141	: V=0.9946858, theta=-49.642641 -> V=1.0, theta=0.0
% INFO    : Bus 24142	: V=0.98326, theta=-51.655737 -> V=1.0, theta=0.0
% INFO    : Bus 24143	: V=0.9725101, theta=-52.345619 -> V=1.0, theta=0.0
% INFO    : Bus 24144	: V=0.9999631, theta=-48.809193 -> V=1.0, theta=0.0
% INFO    : Bus 24145	: V=0.9834033, theta=-50.730172 -> V=1.0, theta=0.0
% INFO    : Bus 24146	: V=0.9970333, theta=-49.753826 -> V=1.0, theta=0.0
% INFO    : Bus 24147	: V=0.973677, theta=-50.363661 -> V=1.0, theta=0.0
% INFO    : Bus 24148	: V=0.9714477, theta=-50.819122 -> V=1.0, theta=0.0
% INFO    : Bus 24149	: V=0.9705235, theta=-50.85842 -> V=1.0, theta=0.0
% INFO    : Bus 24150	: V=0.9697086, theta=-50.867862 -> V=1.0, theta=0.0
% INFO    : Bus 24151	: V=0.9691669, theta=-50.881953 -> V=1.0, theta=0.0
% INFO    : Bus 24152	: V=0.9687407, theta=-50.906008 -> V=1.0, theta=0.0
% INFO    : Bus 24153	: V=0.9692023, theta=-50.849195 -> V=1.0, theta=0.0
% INFO    : Bus 24154	: V=0.9709971, theta=-50.827021 -> V=1.0, theta=0.0
% INFO    : Bus 24155	: V=0.9704638, theta=-50.851603 -> V=1.0, theta=0.0
% INFO    : Bus 24156	: V=0.9702422, theta=-50.823263 -> V=1.0, theta=0.0
% INFO    : Bus 24157	: V=0.9704381, theta=-50.691555 -> V=1.0, theta=0.0
% INFO    : Bus 24158	: V=0.9688849, theta=-50.813807 -> V=1.0, theta=0.0
% INFO    : Bus 24159	: V=0.9727156, theta=-50.346085 -> V=1.0, theta=0.0
% INFO    : Bus 24160	: V=0.967853, theta=-50.85334 -> V=1.0, theta=0.0
% INFO    : Bus 24161	: V=0.9681357, theta=-50.853672 -> V=1.0, theta=0.0
% INFO    : Bus 24162	: V=0.968319, theta=-50.848615 -> V=1.0, theta=0.0
% INFO    : Bus 24163	: V=0.9750908, theta=-50.271527 -> V=1.0, theta=0.0
% INFO    : Bus 24164	: V=0.968055, theta=-50.859827 -> V=1.0, theta=0.0
% INFO    : Bus 24165	: V=0.9681121, theta=-50.861549 -> V=1.0, theta=0.0
% INFO    : Bus 24166	: V=0.968134, theta=-50.876145 -> V=1.0, theta=0.0
% INFO    : Bus 24167	: V=0.9690735, theta=-50.8812 -> V=1.0, theta=0.0
% INFO    : Bus 24168	: V=0.9680858, theta=-50.886682 -> V=1.0, theta=0.0
% INFO    : Bus 24169	: V=0.9680995, theta=-50.86993 -> V=1.0, theta=0.0
% INFO    : Bus 24170	: V=0.9678287, theta=-50.909363 -> V=1.0, theta=0.0
% INFO    : Bus 24171	: V=0.9676141, theta=-50.921049 -> V=1.0, theta=0.0
% INFO    : Bus 24172	: V=0.9674375, theta=-50.933007 -> V=1.0, theta=0.0
% INFO    : Bus 24173	: V=0.9673622, theta=-50.92695 -> V=1.0, theta=0.0
% INFO    : Bus 24174	: V=0.9740419, theta=-50.679466 -> V=1.0, theta=0.0
% INFO    : Bus 24175	: V=0.9694904, theta=-50.852568 -> V=1.0, theta=0.0
% INFO    : Bus 24176	: V=0.970298, theta=-50.78529 -> V=1.0, theta=0.0
% INFO    : Bus 24177	: V=0.9715569, theta=-50.730491 -> V=1.0, theta=0.0
% INFO    : Bus 24178	: V=0.9741326, theta=-50.656964 -> V=1.0, theta=0.0
% INFO    : Bus 24179	: V=0.9686124, theta=-50.970276 -> V=1.0, theta=0.0
% INFO    : Bus 24180	: V=0.967802, theta=-50.914104 -> V=1.0, theta=0.0
% INFO    : Bus 24181	: V=0.9733833, theta=-50.106032 -> V=1.0, theta=0.0
% INFO    : Bus 24182	: V=0.9822193, theta=-48.251783 -> V=1.0, theta=0.0
% INFO    : Bus 24183	: V=0.9789347, theta=-48.52155 -> V=1.0, theta=0.0
% INFO    : Bus 24184	: V=0.9746237, theta=-50.130676 -> V=1.0, theta=0.0
% INFO    : Bus 24185	: V=0.9742825, theta=-50.070207 -> V=1.0, theta=0.0
% INFO    : Bus 24186	: V=0.9706879, theta=-49.798862 -> V=1.0, theta=0.0
% INFO    : Bus 24187	: V=0.9722082, theta=-50.036551 -> V=1.0, theta=0.0
% INFO    : Bus 24188	: V=0.9713189, theta=-49.931078 -> V=1.0, theta=0.0
% INFO    : Bus 24189	: V=0.9709169, theta=-49.771035 -> V=1.0, theta=0.0
% INFO    : Bus 24190	: V=0.9715571, theta=-49.624354 -> V=1.0, theta=0.0
% INFO    : Bus 24191	: V=0.9732184, theta=-49.445937 -> V=1.0, theta=0.0
% INFO    : Bus 24192	: V=0.9729894, theta=-49.446976 -> V=1.0, theta=0.0
% INFO    : Bus 24193	: V=0.9707585, theta=-49.933021 -> V=1.0, theta=0.0
% INFO    : Bus 24194	: V=0.9710924, theta=-49.932668 -> V=1.0, theta=0.0
% INFO    : Bus 24195	: V=0.9707342, theta=-49.936568 -> V=1.0, theta=0.0
% INFO    : Bus 24196	: V=0.9826568, theta=-48.979724 -> V=1.0, theta=0.0
% INFO    : Bus 24197	: V=0.978688, theta=-48.678684 -> V=1.0, theta=0.0
% INFO    : Bus 24198	: V=0.9797825, theta=-48.919859 -> V=1.0, theta=0.0
% INFO    : Bus 24199	: V=0.9795653, theta=-48.520459 -> V=1.0, theta=0.0
% INFO    : Bus 24200	: V=0.9820427, theta=-48.817913 -> V=1.0, theta=0.0
% INFO    : Bus 24201	: V=0.9809511, theta=-48.832054 -> V=1.0, theta=0.0
% INFO    : Bus 24202	: V=0.9853925, theta=-49.027682 -> V=1.0, theta=0.0
% INFO    : Bus 24203	: V=0.9811078, theta=-48.832942 -> V=1.0, theta=0.0
% INFO    : Bus 24204	: V=1.0017237, theta=-47.491219 -> V=1.0, theta=0.0
% INFO    : Bus 24205	: V=0.9856737, theta=-49.216968 -> V=1.0, theta=0.0
% INFO    : Bus 24206	: V=0.9869394, theta=-49.307482 -> V=1.0, theta=0.0
% INFO    : Bus 24207	: V=0.9975005, theta=-48.240774 -> V=1.0, theta=0.0
% INFO    : Bus 24208	: V=0.973839, theta=-50.3656 -> V=1.0, theta=0.0
% INFO    : Bus 24209	: V=0.9733961, theta=-50.425109 -> V=1.0, theta=0.0
% INFO    : Bus 24210	: V=0.9742989, theta=-50.63557 -> V=1.0, theta=0.0
% INFO    : Bus 24211	: V=0.974347, theta=-50.625908 -> V=1.0, theta=0.0
% INFO    : Bus 24212	: V=0.9676139, theta=-50.95427 -> V=1.0, theta=0.0
% INFO    : Bus 24213	: V=0.9678825, theta=-50.930519 -> V=1.0, theta=0.0
% INFO    : Bus 24214	: V=0.9757993, theta=-50.255094 -> V=1.0, theta=0.0
% INFO    : Bus 24215	: V=0.9674833, theta=-51.086143 -> V=1.0, theta=0.0
% INFO    : Bus 24216	: V=0.979527, theta=-50.244016 -> V=1.0, theta=0.0
% INFO    : Bus 24217	: V=0.96867, theta=-50.950254 -> V=1.0, theta=0.0
% INFO    : Bus 24218	: V=0.9956612, theta=-48.335433 -> V=1.0, theta=0.0
% INFO    : Bus 24219	: V=0.9720494, theta=-50.821089 -> V=1.0, theta=0.0
% INFO    : Bus 24220	: V=0.9840408, theta=-49.7321 -> V=1.0, theta=0.0
% INFO    : Bus 24221	: V=0.9731132, theta=-50.488238 -> V=1.0, theta=0.0
% INFO    : Bus 24222	: V=0.957262, theta=-52.999982 -> V=1.0, theta=0.0
% INFO    : Bus 24223	: V=0.9574018, theta=-51.537918 -> V=1.0, theta=0.0
% INFO    : Bus 24224	: V=0.9587944, theta=-51.808263 -> V=1.0, theta=0.0
% INFO    : Bus 24225	: V=0.9679367, theta=-51.130393 -> V=1.0, theta=0.0
% INFO    : Bus 24226	: V=0.9756072, theta=-50.779902 -> V=1.0, theta=0.0
% INFO    : Bus 24227	: V=0.9627806, theta=-52.23902 -> V=1.0, theta=0.0
% INFO    : Bus 24228	: V=0.9687244, theta=-50.886634 -> V=1.0, theta=0.0
% INFO    : Bus 24229	: V=0.962565, theta=-52.87232 -> V=1.0, theta=0.0
% INFO    : Bus 24230	: V=0.9722089, theta=-53.58244 -> V=1.0, theta=0.0
% INFO    : Bus 24231	: V=0.9671371, theta=-54.032543 -> V=1.0, theta=0.0
% INFO    : Bus 24232	: V=0.9683061, theta=-48.097163 -> V=1.0, theta=0.0
% INFO    : Bus 24233	: V=0.9726469, theta=-46.979863 -> V=1.0, theta=0.0
% INFO    : Bus 24234	: V=0.9850066, theta=-49.514297 -> V=1.0, theta=0.0
% INFO    : Bus 24235	: V=0.9730781, theta=-49.441604 -> V=1.0, theta=0.0
% INFO    : Bus 24236	: V=0.9899507, theta=-49.367389 -> V=1.0, theta=0.0
% INFO    : Bus 24237	: V=0.9706208, theta=-49.586814 -> V=1.0, theta=0.0
% INFO    : Bus 24238	: V=0.9663524, theta=-50.896134 -> V=1.0, theta=0.0
% INFO    : Bus 24239	: V=0.9654404, theta=-49.717408 -> V=1.0, theta=0.0
% INFO    : Bus 24240	: V=0.9787223, theta=-50.021458 -> V=1.0, theta=0.0
% INFO    : Bus 24241	: V=0.9760013, theta=-50.225858 -> V=1.0, theta=0.0
% INFO    : Bus 24242	: V=0.9721223, theta=-47.195181 -> V=1.0, theta=0.0
% INFO    : Bus 24243	: V=0.9760132, theta=-45.995217 -> V=1.0, theta=0.0
% INFO    : Bus 24244	: V=0.969999, theta=-46.40288 -> V=1.0, theta=0.0
% INFO    : Bus 24245	: V=0.9715414, theta=-46.290071 -> V=1.0, theta=0.0
% INFO    : Bus 24246	: V=0.9824194, theta=-48.819019 -> V=1.0, theta=0.0
% INFO    : Bus 24247	: V=0.978387, theta=-44.50447 -> V=1.0, theta=0.0
% INFO    : Bus 24248	: V=0.9797712, theta=-44.485707 -> V=1.0, theta=0.0
% INFO    : Bus 24249	: V=0.9808287, theta=-44.463416 -> V=1.0, theta=0.0
% INFO    : Bus 24250	: V=0.9833545, theta=-44.49189 -> V=1.0, theta=0.0
% INFO    : Bus 24251	: V=0.9822424, theta=-44.336737 -> V=1.0, theta=0.0
% INFO    : Bus 24252	: V=0.9807442, theta=-44.408996 -> V=1.0, theta=0.0
% INFO    : Bus 24253	: V=0.9794828, theta=-44.413647 -> V=1.0, theta=0.0
% INFO    : Bus 24254	: V=0.9804665, theta=-44.361329 -> V=1.0, theta=0.0
% INFO    : Bus 24255	: V=0.9807704, theta=-44.360803 -> V=1.0, theta=0.0
% INFO    : Bus 24256	: V=0.9805755, theta=-44.36181 -> V=1.0, theta=0.0
% INFO    : Bus 24257	: V=0.9839625, theta=-44.236277 -> V=1.0, theta=0.0
% INFO    : Bus 24258	: V=0.9852918, theta=-44.165997 -> V=1.0, theta=0.0
% INFO    : Bus 24259	: V=1.0007303, theta=-42.990452 -> V=1.0, theta=0.0
% INFO    : Bus 24260	: V=0.9873352, theta=-43.962263 -> V=1.0, theta=0.0
% INFO    : Bus 24261	: V=0.9883827, theta=-43.825568 -> V=1.0, theta=0.0
% INFO    : Bus 24262	: V=0.9831094, theta=-43.818183 -> V=1.0, theta=0.0
% INFO    : Bus 24263	: V=0.9906726, theta=-43.754595 -> V=1.0, theta=0.0
% INFO    : Bus 24264	: V=0.993031, theta=-43.662418 -> V=1.0, theta=0.0
% INFO    : Bus 24265	: V=0.9939225, theta=-43.652122 -> V=1.0, theta=0.0
% INFO    : Bus 24266	: V=1.0012373, theta=-42.970583 -> V=1.0, theta=0.0
% INFO    : Bus 24267	: V=0.979867, theta=-44.481016 -> V=1.0, theta=0.0
% INFO    : Bus 24268	: V=0.9916421, theta=-43.851115 -> V=1.0, theta=0.0
% INFO    : Bus 24269	: V=0.9829124, theta=-44.492768 -> V=1.0, theta=0.0
% INFO    : Bus 24270	: V=0.9809475, theta=-44.486872 -> V=1.0, theta=0.0
% INFO    : Bus 24271	: V=0.9920422, theta=-43.936848 -> V=1.0, theta=0.0
% INFO    : Bus 24272	: V=0.9922397, theta=-43.930386 -> V=1.0, theta=0.0
% INFO    : Bus 24273	: V=0.9884425, theta=-44.146233 -> V=1.0, theta=0.0
% INFO    : Bus 24274	: V=0.9882998, theta=-44.146021 -> V=1.0, theta=0.0
% INFO    : Bus 24275	: V=0.9841702, theta=-44.249636 -> V=1.0, theta=0.0
% INFO    : Bus 24276	: V=0.9882083, theta=-44.135971 -> V=1.0, theta=0.0
% INFO    : Bus 24277	: V=0.9884714, theta=-44.136976 -> V=1.0, theta=0.0
% INFO    : Bus 24278	: V=0.9882334, theta=-44.138671 -> V=1.0, theta=0.0
% INFO    : Bus 24279	: V=0.9887033, theta=-44.539901 -> V=1.0, theta=0.0
% INFO    : Bus 24280	: V=0.9939655, theta=-43.989091 -> V=1.0, theta=0.0
% INFO    : Bus 24281	: V=0.9848366, theta=-44.554153 -> V=1.0, theta=0.0
% INFO    : Bus 24282	: V=0.9835015, theta=-44.57437 -> V=1.0, theta=0.0
% INFO    : Bus 24283	: V=0.9835723, theta=-44.612869 -> V=1.0, theta=0.0
% INFO    : Bus 24284	: V=0.9932693, theta=-43.969966 -> V=1.0, theta=0.0
% INFO    : Bus 24285	: V=0.9926423, theta=-43.948757 -> V=1.0, theta=0.0
% INFO    : Bus 24286	: V=0.995113, theta=-44.00576 -> V=1.0, theta=0.0
% INFO    : Bus 24287	: V=0.9956149, theta=-43.622017 -> V=1.0, theta=0.0
% INFO    : Bus 24288	: V=0.9834048, theta=-44.685983 -> V=1.0, theta=0.0
% INFO    : Bus 24289	: V=0.9825411, theta=-44.745152 -> V=1.0, theta=0.0
% INFO    : Bus 24290	: V=0.9936317, theta=-44.068823 -> V=1.0, theta=0.0
% INFO    : Bus 24291	: V=0.9831357, theta=-44.71354 -> V=1.0, theta=0.0
% INFO    : Bus 24292	: V=0.9829895, theta=-44.684289 -> V=1.0, theta=0.0
% INFO    : Bus 24293	: V=0.9831252, theta=-44.649348 -> V=1.0, theta=0.0
% INFO    : Bus 24294	: V=0.9805927, theta=-44.744786 -> V=1.0, theta=0.0
% INFO    : Bus 24295	: V=0.9809683, theta=-44.746796 -> V=1.0, theta=0.0
% INFO    : Bus 24296	: V=0.9818091, theta=-44.749713 -> V=1.0, theta=0.0
% INFO    : Bus 24297	: V=0.9783451, theta=-45.015437 -> V=1.0, theta=0.0
% INFO    : Bus 24298	: V=0.9788715, theta=-45.011649 -> V=1.0, theta=0.0
% INFO    : Bus 24299	: V=0.9779365, theta=-45.03741 -> V=1.0, theta=0.0
% INFO    : Bus 24300	: V=0.9780096, theta=-45.020797 -> V=1.0, theta=0.0
% INFO    : Bus 24301	: V=0.9776834, theta=-45.021814 -> V=1.0, theta=0.0
% INFO    : Bus 24302	: V=0.9781748, theta=-45.047533 -> V=1.0, theta=0.0
% INFO    : Bus 24303	: V=0.9778069, theta=-45.091857 -> V=1.0, theta=0.0
% INFO    : Bus 24304	: V=0.97749, theta=-45.045232 -> V=1.0, theta=0.0
% INFO    : Bus 24305	: V=0.9784019, theta=-44.991808 -> V=1.0, theta=0.0
% INFO    : Bus 24306	: V=0.9801368, theta=-44.99081 -> V=1.0, theta=0.0
% INFO    : Bus 24307	: V=0.9820745, theta=-44.95937 -> V=1.0, theta=0.0
% INFO    : Bus 24308	: V=0.9844242, theta=-44.751043 -> V=1.0, theta=0.0
% INFO    : Bus 24309	: V=0.9855813, theta=-44.767086 -> V=1.0, theta=0.0
% INFO    : Bus 24310	: V=1.009094, theta=-42.991331 -> V=1.0, theta=0.0
% INFO    : Bus 24311	: V=0.9868839, theta=-44.671633 -> V=1.0, theta=0.0
% INFO    : Bus 24312	: V=0.9837459, theta=-44.750743 -> V=1.0, theta=0.0
% INFO    : Bus 24313	: V=0.9831913, theta=-44.929307 -> V=1.0, theta=0.0
% INFO    : Bus 24314	: V=0.9874518, theta=-44.666839 -> V=1.0, theta=0.0
% INFO    : Bus 24315	: V=0.9874674, theta=-44.080891 -> V=1.0, theta=0.0
% INFO    : Bus 24316	: V=0.991138, theta=-44.006138 -> V=1.0, theta=0.0
% INFO    : Bus 24317	: V=0.9940285, theta=-43.859759 -> V=1.0, theta=0.0
% INFO    : Bus 24318	: V=1.0017509, theta=-42.948618 -> V=1.0, theta=0.0
% INFO    : Bus 24319	: V=0.9970691, theta=-43.523911 -> V=1.0, theta=0.0
% INFO    : Bus 24320	: V=1.0030921, theta=-42.875066 -> V=1.0, theta=0.0
% INFO    : Bus 24321	: V=1.0146912, theta=-42.041555 -> V=1.0, theta=0.0
% INFO    : Bus 24322	: V=1.0169628, theta=-41.883497 -> V=1.0, theta=0.0
% INFO    : Bus 24323	: V=1.0037307, theta=-42.851807 -> V=1.0, theta=0.0
% INFO    : Bus 24324	: V=1.0052824, theta=-42.612617 -> V=1.0, theta=0.0
% INFO    : Bus 24325	: V=0.9951552, theta=-43.9707 -> V=1.0, theta=0.0
% INFO    : Bus 24326	: V=0.9930458, theta=-44.103469 -> V=1.0, theta=0.0
% INFO    : Bus 24327	: V=0.9902823, theta=-44.391569 -> V=1.0, theta=0.0
% INFO    : Bus 24328	: V=0.9897314, theta=-44.114157 -> V=1.0, theta=0.0
% INFO    : Bus 24329	: V=0.9916369, theta=-44.239471 -> V=1.0, theta=0.0
% INFO    : Bus 24330	: V=0.9928823, theta=-44.214426 -> V=1.0, theta=0.0
% INFO    : Bus 24331	: V=0.9947139, theta=-44.098097 -> V=1.0, theta=0.0
% INFO    : Bus 24332	: V=0.9949932, theta=-44.051631 -> V=1.0, theta=0.0
% INFO    : Bus 24333	: V=0.9951913, theta=-44.024288 -> V=1.0, theta=0.0
% INFO    : Bus 24334	: V=1.0007718, theta=-43.675738 -> V=1.0, theta=0.0
% INFO    : Bus 24335	: V=0.9894561, theta=-44.474296 -> V=1.0, theta=0.0
% INFO    : Bus 24336	: V=0.9872623, theta=-44.567781 -> V=1.0, theta=0.0
% INFO    : Bus 24337	: V=0.995571, theta=-44.08626 -> V=1.0, theta=0.0
% INFO    : Bus 24338	: V=0.9879038, theta=-44.561389 -> V=1.0, theta=0.0
% INFO    : Bus 24339	: V=0.9914194, theta=-44.300486 -> V=1.0, theta=0.0
% INFO    : Bus 24340	: V=0.9962675, theta=-44.052288 -> V=1.0, theta=0.0
% INFO    : Bus 24341	: V=0.9946659, theta=-44.240644 -> V=1.0, theta=0.0
% INFO    : Bus 24342	: V=0.9941792, theta=-44.261153 -> V=1.0, theta=0.0
% INFO    : Bus 24343	: V=0.994148, theta=-44.241837 -> V=1.0, theta=0.0
% INFO    : Bus 24344	: V=0.9900353, theta=-44.395492 -> V=1.0, theta=0.0
% INFO    : Bus 24345	: V=0.9935552, theta=-44.306863 -> V=1.0, theta=0.0
% INFO    : Bus 24346	: V=0.9932769, theta=-44.339343 -> V=1.0, theta=0.0
% INFO    : Bus 24347	: V=0.9931901, theta=-44.339298 -> V=1.0, theta=0.0
% INFO    : Bus 24348	: V=0.99342, theta=-44.376557 -> V=1.0, theta=0.0
% INFO    : Bus 24349	: V=0.9939161, theta=-44.375843 -> V=1.0, theta=0.0
% INFO    : Bus 24350	: V=0.9979118, theta=-44.150385 -> V=1.0, theta=0.0
% INFO    : Bus 24351	: V=0.9950769, theta=-44.048143 -> V=1.0, theta=0.0
% INFO    : Bus 24352	: V=0.9962937, theta=-44.112982 -> V=1.0, theta=0.0
% INFO    : Bus 24353	: V=0.9959089, theta=-44.099228 -> V=1.0, theta=0.0
% INFO    : Bus 24354	: V=0.9885184, theta=-44.496777 -> V=1.0, theta=0.0
% INFO    : Bus 24355	: V=0.9886206, theta=-44.49593 -> V=1.0, theta=0.0
% INFO    : Bus 24356	: V=0.9918742, theta=-44.091718 -> V=1.0, theta=0.0
% INFO    : Bus 24357	: V=0.9941422, theta=-44.239989 -> V=1.0, theta=0.0
% INFO    : Bus 24358	: V=0.9985702, theta=-44.166557 -> V=1.0, theta=0.0
% INFO    : Bus 24359	: V=0.9988372, theta=-44.169069 -> V=1.0, theta=0.0
% INFO    : Bus 24360	: V=0.9992952, theta=-44.187016 -> V=1.0, theta=0.0
% INFO    : Bus 24361	: V=0.9997665, theta=-44.192853 -> V=1.0, theta=0.0
% INFO    : Bus 24362	: V=1.0012134, theta=-44.178539 -> V=1.0, theta=0.0
% INFO    : Bus 24363	: V=1.0013392, theta=-44.143605 -> V=1.0, theta=0.0
% INFO    : Bus 24364	: V=0.9952057, theta=-44.440983 -> V=1.0, theta=0.0
% INFO    : Bus 24365	: V=0.9998581, theta=-44.17591 -> V=1.0, theta=0.0
% INFO    : Bus 24366	: V=0.9942926, theta=-44.316935 -> V=1.0, theta=0.0
% INFO    : Bus 24367	: V=0.9922187, theta=-44.445314 -> V=1.0, theta=0.0
% INFO    : Bus 24368	: V=0.9998569, theta=-44.163228 -> V=1.0, theta=0.0
% INFO    : Bus 24369	: V=0.9985577, theta=-44.548825 -> V=1.0, theta=0.0
% INFO    : Bus 24370	: V=0.9977347, theta=-44.579167 -> V=1.0, theta=0.0
% INFO    : Bus 24371	: V=0.9981058, theta=-44.183678 -> V=1.0, theta=0.0
% INFO    : Bus 24372	: V=0.9895646, theta=-44.639888 -> V=1.0, theta=0.0
% INFO    : Bus 24373	: V=0.9988979, theta=-44.178479 -> V=1.0, theta=0.0
% INFO    : Bus 24374	: V=1.0030401, theta=-44.109815 -> V=1.0, theta=0.0
% INFO    : Bus 24375	: V=1.0001113, theta=-44.403945 -> V=1.0, theta=0.0
% INFO    : Bus 24376	: V=0.9988909, theta=-44.439399 -> V=1.0, theta=0.0
% INFO    : Bus 24377	: V=0.9974198, theta=-44.452759 -> V=1.0, theta=0.0
% INFO    : Bus 24378	: V=1.0025993, theta=-44.343115 -> V=1.0, theta=0.0
% INFO    : Bus 24379	: V=1.0141379, theta=-43.125473 -> V=1.0, theta=0.0
% INFO    : Bus 24380	: V=1.000956, theta=-44.554224 -> V=1.0, theta=0.0
% INFO    : Bus 24381	: V=1.0149682, theta=-43.115401 -> V=1.0, theta=0.0
% INFO    : Bus 24382	: V=1.0078638, theta=-44.005032 -> V=1.0, theta=0.0
% INFO    : Bus 24383	: V=1.0187547, theta=-43.04964 -> V=1.0, theta=0.0
% INFO    : Bus 24384	: V=1.0004116, theta=-44.688278 -> V=1.0, theta=0.0
% INFO    : Bus 24385	: V=0.9997885, theta=-44.710685 -> V=1.0, theta=0.0
% INFO    : Bus 24386	: V=1.0193214, theta=-43.000037 -> V=1.0, theta=0.0
% INFO    : Bus 24387	: V=1.016671, theta=-43.090081 -> V=1.0, theta=0.0
% INFO    : Bus 24388	: V=0.9997033, theta=-44.508334 -> V=1.0, theta=0.0
% INFO    : Bus 24389	: V=0.9998907, theta=-44.508043 -> V=1.0, theta=0.0
% INFO    : Bus 24390	: V=1.0042566, theta=-44.066165 -> V=1.0, theta=0.0
% INFO    : Bus 24391	: V=1.0047053, theta=-44.0376 -> V=1.0, theta=0.0
% INFO    : Bus 24392	: V=1.0036982, theta=-44.06998 -> V=1.0, theta=0.0
% INFO    : Bus 24393	: V=1.0152469, theta=-43.076201 -> V=1.0, theta=0.0
% INFO    : Bus 24394	: V=1.0010079, theta=-44.453435 -> V=1.0, theta=0.0
% INFO    : Bus 24395	: V=1.0007912, theta=-44.453991 -> V=1.0, theta=0.0
% INFO    : Bus 24396	: V=1.0136953, theta=-43.083134 -> V=1.0, theta=0.0
% INFO    : Bus 24397	: V=1.0026315, theta=-44.102455 -> V=1.0, theta=0.0
% INFO    : Bus 24398	: V=1.0005566, theta=-44.174236 -> V=1.0, theta=0.0
% INFO    : Bus 24399	: V=0.9968834, theta=-44.640585 -> V=1.0, theta=0.0
% INFO    : Bus 24400	: V=0.9980644, theta=-44.601656 -> V=1.0, theta=0.0
% INFO    : Bus 24401	: V=0.9781877, theta=-45.199017 -> V=1.0, theta=0.0
% INFO    : Bus 24402	: V=0.9771603, theta=-45.25402 -> V=1.0, theta=0.0
% INFO    : Bus 24403	: V=0.9788706, theta=-45.231073 -> V=1.0, theta=0.0
% INFO    : Bus 24404	: V=0.9798235, theta=-45.197588 -> V=1.0, theta=0.0
% INFO    : Bus 24405	: V=0.9798068, theta=-45.206268 -> V=1.0, theta=0.0
% INFO    : Bus 24406	: V=0.9872211, theta=-44.966251 -> V=1.0, theta=0.0
% INFO    : Bus 24407	: V=0.9871492, theta=-44.963518 -> V=1.0, theta=0.0
% INFO    : Bus 24408	: V=0.9884457, theta=-44.840752 -> V=1.0, theta=0.0
% INFO    : Bus 24409	: V=0.9846891, theta=-44.935161 -> V=1.0, theta=0.0
% INFO    : Bus 24410	: V=0.9868294, theta=-44.9624 -> V=1.0, theta=0.0
% INFO    : Bus 24411	: V=0.9869777, theta=-44.963431 -> V=1.0, theta=0.0
% INFO    : Bus 24412	: V=0.9809395, theta=-45.133748 -> V=1.0, theta=0.0
% INFO    : Bus 24413	: V=0.979765, theta=-45.187063 -> V=1.0, theta=0.0
% INFO    : Bus 24414	: V=0.9785035, theta=-45.232842 -> V=1.0, theta=0.0
% INFO    : Bus 24415	: V=0.9807019, theta=-45.106399 -> V=1.0, theta=0.0
% INFO    : Bus 24416	: V=0.9806828, theta=-45.083186 -> V=1.0, theta=0.0
% INFO    : Bus 24417	: V=0.9824909, theta=-44.982889 -> V=1.0, theta=0.0
% INFO    : Bus 24418	: V=0.9836543, theta=-44.939696 -> V=1.0, theta=0.0
% INFO    : Bus 24419	: V=0.9850472, theta=-44.87884 -> V=1.0, theta=0.0
% INFO    : Bus 24420	: V=0.9963468, theta=-44.184313 -> V=1.0, theta=0.0
% INFO    : Bus 24421	: V=0.9865623, theta=-44.840075 -> V=1.0, theta=0.0
% INFO    : Bus 24422	: V=0.9970484, theta=-44.18929 -> V=1.0, theta=0.0
% INFO    : Bus 24423	: V=0.9882657, theta=-44.833335 -> V=1.0, theta=0.0
% INFO    : Bus 24424	: V=0.9899722, theta=-44.830501 -> V=1.0, theta=0.0
% INFO    : Bus 24425	: V=0.9897939, theta=-44.830379 -> V=1.0, theta=0.0
% INFO    : Bus 24426	: V=0.9910076, theta=-44.836742 -> V=1.0, theta=0.0
% INFO    : Bus 24427	: V=0.9922255, theta=-44.844961 -> V=1.0, theta=0.0
% INFO    : Bus 24428	: V=0.9955145, theta=-44.694024 -> V=1.0, theta=0.0
% INFO    : Bus 24429	: V=1.0015187, theta=-44.152068 -> V=1.0, theta=0.0
% INFO    : Bus 24430	: V=0.996079, theta=-44.162913 -> V=1.0, theta=0.0
% INFO    : Bus 24431	: V=0.987367, theta=-45.085006 -> V=1.0, theta=0.0
% INFO    : Bus 24432	: V=0.9840423, theta=-45.196497 -> V=1.0, theta=0.0
% INFO    : Bus 24433	: V=0.9838166, theta=-45.244628 -> V=1.0, theta=0.0
% INFO    : Bus 24434	: V=0.9848494, theta=-45.234484 -> V=1.0, theta=0.0
% INFO    : Bus 24435	: V=0.9971958, theta=-44.304702 -> V=1.0, theta=0.0
% INFO    : Bus 24436	: V=0.999093, theta=-44.230105 -> V=1.0, theta=0.0
% INFO    : Bus 24437	: V=0.9885415, theta=-45.087433 -> V=1.0, theta=0.0
% INFO    : Bus 24438	: V=0.9944743, theta=-44.501722 -> V=1.0, theta=0.0
% INFO    : Bus 24439	: V=0.9837918, theta=-45.273603 -> V=1.0, theta=0.0
% INFO    : Bus 24440	: V=0.9823684, theta=-45.31111 -> V=1.0, theta=0.0
% INFO    : Bus 24441	: V=0.9822487, theta=-45.341628 -> V=1.0, theta=0.0
% INFO    : Bus 24442	: V=0.9839236, theta=-45.305297 -> V=1.0, theta=0.0
% INFO    : Bus 24443	: V=0.9859647, theta=-45.233752 -> V=1.0, theta=0.0
% INFO    : Bus 24444	: V=0.9947385, theta=-44.497851 -> V=1.0, theta=0.0
% INFO    : Bus 24445	: V=0.9861845, theta=-45.200547 -> V=1.0, theta=0.0
% INFO    : Bus 24446	: V=0.9769166, theta=-45.298316 -> V=1.0, theta=0.0
% INFO    : Bus 24447	: V=0.9767027, theta=-45.335158 -> V=1.0, theta=0.0
% INFO    : Bus 24448	: V=0.9779017, theta=-45.292529 -> V=1.0, theta=0.0
% INFO    : Bus 24449	: V=0.9791068, theta=-45.266107 -> V=1.0, theta=0.0
% INFO    : Bus 24450	: V=0.9801118, theta=-45.206422 -> V=1.0, theta=0.0
% INFO    : Bus 24451	: V=0.992582, theta=-44.440849 -> V=1.0, theta=0.0
% INFO    : Bus 24452	: V=0.9807744, theta=-45.201456 -> V=1.0, theta=0.0
% INFO    : Bus 24453	: V=0.9769047, theta=-45.357156 -> V=1.0, theta=0.0
% INFO    : Bus 24454	: V=0.9770172, theta=-45.387791 -> V=1.0, theta=0.0
% INFO    : Bus 24455	: V=0.9774621, theta=-45.385079 -> V=1.0, theta=0.0
% INFO    : Bus 24456	: V=0.9784582, theta=-45.373179 -> V=1.0, theta=0.0
% INFO    : Bus 24457	: V=0.9805802, theta=-45.37698 -> V=1.0, theta=0.0
% INFO    : Bus 24458	: V=0.9777714, theta=-45.437581 -> V=1.0, theta=0.0
% INFO    : Bus 24459	: V=0.97663, theta=-45.451677 -> V=1.0, theta=0.0
% INFO    : Bus 24460	: V=0.9738155, theta=-45.429242 -> V=1.0, theta=0.0
% INFO    : Bus 24461	: V=0.9769382, theta=-45.435882 -> V=1.0, theta=0.0
% INFO    : Bus 24462	: V=0.9775063, theta=-45.422107 -> V=1.0, theta=0.0
% INFO    : Bus 24463	: V=0.9762686, theta=-45.137108 -> V=1.0, theta=0.0
% INFO    : Bus 24464	: V=0.9760743, theta=-45.138577 -> V=1.0, theta=0.0
% INFO    : Bus 24465	: V=0.9774827, theta=-45.14261 -> V=1.0, theta=0.0
% INFO    : Bus 24466	: V=0.9768598, theta=-45.211665 -> V=1.0, theta=0.0
% INFO    : Bus 24467	: V=0.9758782, theta=-45.279936 -> V=1.0, theta=0.0
% INFO    : Bus 24468	: V=0.9747962, theta=-45.271369 -> V=1.0, theta=0.0
% INFO    : Bus 24469	: V=0.9735809, theta=-45.295646 -> V=1.0, theta=0.0
% INFO    : Bus 24470	: V=0.9742528, theta=-45.274922 -> V=1.0, theta=0.0
% INFO    : Bus 24471	: V=0.9748009, theta=-45.255786 -> V=1.0, theta=0.0
% INFO    : Bus 24472	: V=0.9751378, theta=-45.221347 -> V=1.0, theta=0.0
% INFO    : Bus 24473	: V=0.9746937, theta=-45.252772 -> V=1.0, theta=0.0
% INFO    : Bus 24474	: V=0.9726922, theta=-45.330945 -> V=1.0, theta=0.0
% INFO    : Bus 24475	: V=0.97311, theta=-45.326329 -> V=1.0, theta=0.0
% INFO    : Bus 24476	: V=0.9731471, theta=-45.363636 -> V=1.0, theta=0.0
% INFO    : Bus 24477	: V=0.973688, theta=-45.400807 -> V=1.0, theta=0.0
% INFO    : Bus 24478	: V=0.9730797, theta=-45.403826 -> V=1.0, theta=0.0
% INFO    : Bus 24479	: V=0.9727738, theta=-45.372643 -> V=1.0, theta=0.0
% INFO    : Bus 24480	: V=0.971814, theta=-45.459739 -> V=1.0, theta=0.0
% INFO    : Bus 24481	: V=0.9725137, theta=-45.468509 -> V=1.0, theta=0.0
% INFO    : Bus 24482	: V=0.973274, theta=-45.456329 -> V=1.0, theta=0.0
% INFO    : Bus 24483	: V=0.9737619, theta=-45.463654 -> V=1.0, theta=0.0
% INFO    : Bus 24484	: V=0.9737595, theta=-45.469954 -> V=1.0, theta=0.0
% INFO    : Bus 24485	: V=0.974256, theta=-45.470808 -> V=1.0, theta=0.0
% INFO    : Bus 24486	: V=0.9729253, theta=-45.491598 -> V=1.0, theta=0.0
% INFO    : Bus 24487	: V=0.9720138, theta=-45.49225 -> V=1.0, theta=0.0
% INFO    : Bus 24488	: V=0.9737896, theta=-45.417586 -> V=1.0, theta=0.0
% INFO    : Bus 24489	: V=0.9738279, theta=-45.432247 -> V=1.0, theta=0.0
% INFO    : Bus 24490	: V=0.9742876, theta=-45.464966 -> V=1.0, theta=0.0
% INFO    : Bus 24491	: V=0.9745046, theta=-45.453613 -> V=1.0, theta=0.0
% INFO    : Bus 24492	: V=0.976679, theta=-45.37615 -> V=1.0, theta=0.0
% INFO    : Bus 24493	: V=0.9752932, theta=-45.427825 -> V=1.0, theta=0.0
% INFO    : Bus 24494	: V=0.9740714, theta=-45.409155 -> V=1.0, theta=0.0
% INFO    : Bus 24495	: V=0.97384, theta=-45.3976 -> V=1.0, theta=0.0
% INFO    : Bus 24496	: V=0.9741056, theta=-45.392814 -> V=1.0, theta=0.0
% INFO    : Bus 24497	: V=0.9746139, theta=-45.47042 -> V=1.0, theta=0.0
% INFO    : Bus 24498	: V=0.9762895, theta=-45.475298 -> V=1.0, theta=0.0
% INFO    : Bus 24499	: V=0.9766324, theta=-45.473961 -> V=1.0, theta=0.0
% INFO    : Bus 24500	: V=0.9775356, theta=-45.461086 -> V=1.0, theta=0.0
% INFO    : Bus 24501	: V=0.9791341, theta=-45.409691 -> V=1.0, theta=0.0
% INFO    : Bus 24502	: V=0.9784764, theta=-45.435269 -> V=1.0, theta=0.0
% INFO    : Bus 24503	: V=0.9901189, theta=-44.726342 -> V=1.0, theta=0.0
% INFO    : Bus 24504	: V=0.9793897, theta=-45.409811 -> V=1.0, theta=0.0
% INFO    : Bus 24505	: V=0.9768043, theta=-45.449339 -> V=1.0, theta=0.0
% INFO    : Bus 24506	: V=0.9756135, theta=-45.475732 -> V=1.0, theta=0.0
% INFO    : Bus 24507	: V=0.9749514, theta=-45.474277 -> V=1.0, theta=0.0
% INFO    : Bus 24508	: V=0.9768442, theta=-45.413134 -> V=1.0, theta=0.0
% INFO    : Bus 24509	: V=0.9769879, theta=-45.447271 -> V=1.0, theta=0.0
% INFO    : Bus 24510	: V=0.9774258, theta=-45.43813 -> V=1.0, theta=0.0
% INFO    : Bus 24511	: V=0.9781432, theta=-45.429522 -> V=1.0, theta=0.0
% INFO    : Bus 24512	: V=0.9794825, theta=-45.409972 -> V=1.0, theta=0.0
% INFO    : Bus 24513	: V=0.97849, theta=-45.437777 -> V=1.0, theta=0.0
% INFO    : Bus 24514	: V=0.9790746, theta=-45.444063 -> V=1.0, theta=0.0
% INFO    : Bus 24515	: V=0.979819, theta=-45.41755 -> V=1.0, theta=0.0
% INFO    : Bus 24516	: V=0.9792908, theta=-45.406268 -> V=1.0, theta=0.0
% INFO    : Bus 24517	: V=0.9779425, theta=-45.409723 -> V=1.0, theta=0.0
% INFO    : Bus 24518	: V=0.9788653, theta=-45.306557 -> V=1.0, theta=0.0
% INFO    : Bus 24519	: V=0.979403, theta=-45.410631 -> V=1.0, theta=0.0
% INFO    : Bus 24520	: V=0.9805394, theta=-45.388664 -> V=1.0, theta=0.0
% INFO    : Bus 24521	: V=0.9825477, theta=-45.340961 -> V=1.0, theta=0.0
% INFO    : Bus 24522	: V=0.9840941, theta=-45.314881 -> V=1.0, theta=0.0
% INFO    : Bus 24523	: V=0.9844563, theta=-45.327914 -> V=1.0, theta=0.0
% INFO    : Bus 24524	: V=0.9863242, theta=-45.288871 -> V=1.0, theta=0.0
% INFO    : Bus 24525	: V=0.9822551, theta=-45.422853 -> V=1.0, theta=0.0
% INFO    : Bus 24526	: V=0.9813424, theta=-45.419498 -> V=1.0, theta=0.0
% INFO    : Bus 24527	: V=0.9800102, theta=-45.444934 -> V=1.0, theta=0.0
% INFO    : Bus 24528	: V=0.9794498, theta=-45.441655 -> V=1.0, theta=0.0
% INFO    : Bus 24529	: V=0.9794055, theta=-45.492941 -> V=1.0, theta=0.0
% INFO    : Bus 24530	: V=0.9794072, theta=-45.534172 -> V=1.0, theta=0.0
% INFO    : Bus 24531	: V=0.979822, theta=-45.491033 -> V=1.0, theta=0.0
% INFO    : Bus 24532	: V=0.9790538, theta=-45.448006 -> V=1.0, theta=0.0
% INFO    : Bus 24533	: V=0.9789832, theta=-45.469813 -> V=1.0, theta=0.0
% INFO    : Bus 24534	: V=0.979097, theta=-45.491328 -> V=1.0, theta=0.0
% INFO    : Bus 24535	: V=0.9792684, theta=-45.437856 -> V=1.0, theta=0.0
% INFO    : Bus 24536	: V=0.9796231, theta=-45.43094 -> V=1.0, theta=0.0
% INFO    : Bus 24537	: V=0.9795642, theta=-45.42267 -> V=1.0, theta=0.0
% INFO    : Bus 24538	: V=1.0122026, theta=-42.215112 -> V=1.0, theta=0.0
% INFO    : Bus 24539	: V=1.0090324, theta=-42.43866 -> V=1.0, theta=0.0
% INFO    : Bus 24540	: V=0.9958325, theta=-43.550693 -> V=1.0, theta=0.0
% INFO    : Bus 24541	: V=0.9934233, theta=-43.698635 -> V=1.0, theta=0.0
% INFO    : Bus 24542	: V=0.9925209, theta=-43.731341 -> V=1.0, theta=0.0
% INFO    : Bus 24543	: V=0.988961, theta=-43.77952 -> V=1.0, theta=0.0
% INFO    : Bus 24544	: V=0.9897346, theta=-43.779187 -> V=1.0, theta=0.0
% INFO    : Bus 24545	: V=0.989394, theta=-43.780072 -> V=1.0, theta=0.0
% INFO    : Bus 24546	: V=0.9742116, theta=-44.438376 -> V=1.0, theta=0.0
% INFO    : Bus 24547	: V=0.9824267, theta=-43.803273 -> V=1.0, theta=0.0
% INFO    : Bus 24548	: V=0.9741292, theta=-44.467488 -> V=1.0, theta=0.0
% INFO    : Bus 24549	: V=0.973995, theta=-44.473223 -> V=1.0, theta=0.0
% INFO    : Bus 24550	: V=0.9743611, theta=-44.477929 -> V=1.0, theta=0.0
% INFO    : Bus 24551	: V=0.9761083, theta=-44.450753 -> V=1.0, theta=0.0
% INFO    : Bus 24552	: V=0.9774743, theta=-44.437787 -> V=1.0, theta=0.0
% INFO    : Bus 24553	: V=0.9730379, theta=-44.482895 -> V=1.0, theta=0.0
% INFO    : Bus 24554	: V=0.9719222, theta=-44.484461 -> V=1.0, theta=0.0
% INFO    : Bus 24555	: V=0.984682, theta=-44.816791 -> V=1.0, theta=0.0
% INFO    : Bus 24556	: V=0.9834383, theta=-44.911234 -> V=1.0, theta=0.0
% INFO    : Bus 24557	: V=0.9841724, theta=-44.868559 -> V=1.0, theta=0.0
% INFO    : Bus 24558	: V=0.9849805, theta=-44.816902 -> V=1.0, theta=0.0
% INFO    : Bus 24559	: V=0.9858994, theta=-44.764919 -> V=1.0, theta=0.0
% INFO    : Bus 24560	: V=0.9857029, theta=-44.720526 -> V=1.0, theta=0.0
% INFO    : Bus 24561	: V=0.9785591, theta=-45.066128 -> V=1.0, theta=0.0
% INFO    : Bus 24562	: V=0.9783518, theta=-45.17263 -> V=1.0, theta=0.0
% INFO    : Bus 24563	: V=0.9784495, theta=-45.172528 -> V=1.0, theta=0.0
% INFO    : Bus 24564	: V=0.9808804, theta=-45.057145 -> V=1.0, theta=0.0
% INFO    : Bus 24565	: V=0.979381, theta=-45.093728 -> V=1.0, theta=0.0
% INFO    : Bus 24566	: V=0.9822735, theta=-44.985971 -> V=1.0, theta=0.0
% INFO    : Bus 24567	: V=0.9812154, theta=-45.031211 -> V=1.0, theta=0.0
% INFO    : Bus 24568	: V=0.9805331, theta=-44.890175 -> V=1.0, theta=0.0
% INFO    : Bus 24569	: V=0.9815598, theta=-44.887046 -> V=1.0, theta=0.0
% INFO    : Bus 24570	: V=0.9777433, theta=-45.346135 -> V=1.0, theta=0.0
% INFO    : Bus 24571	: V=0.9769872, theta=-45.368044 -> V=1.0, theta=0.0
% INFO    : Bus 24572	: V=0.9894117, theta=-44.792034 -> V=1.0, theta=0.0
% INFO    : Bus 24573	: V=0.9828005, theta=-45.135667 -> V=1.0, theta=0.0
% INFO    : Bus 24574	: V=0.9850241, theta=-45.102924 -> V=1.0, theta=0.0
% INFO    : Bus 24575	: V=0.9899781, theta=-44.783813 -> V=1.0, theta=0.0
% INFO    : Bus 24576	: V=1.0006921, theta=-43.910912 -> V=1.0, theta=0.0
% INFO    : Bus 24577	: V=0.9898623, theta=-44.851145 -> V=1.0, theta=0.0
% INFO    : Bus 24578	: V=0.990729, theta=-44.783152 -> V=1.0, theta=0.0
% INFO    : Bus 24579	: V=0.9806539, theta=-45.449267 -> V=1.0, theta=0.0
% INFO    : Bus 24580	: V=0.9810475, theta=-45.49203 -> V=1.0, theta=0.0
% INFO    : Bus 24581	: V=0.9846755, theta=-45.356221 -> V=1.0, theta=0.0
% INFO    : Bus 24582	: V=0.977932, theta=-45.323953 -> V=1.0, theta=0.0
% INFO    : Bus 24583	: V=0.9795139, theta=-45.310815 -> V=1.0, theta=0.0
% INFO    : Bus 24584	: V=0.9781974, theta=-45.358091 -> V=1.0, theta=0.0
% INFO    : Bus 24585	: V=0.9786409, theta=-45.359502 -> V=1.0, theta=0.0
% INFO    : Bus 24586	: V=0.9903446, theta=-44.731176 -> V=1.0, theta=0.0
% INFO    : Bus 24587	: V=0.9807873, theta=-45.306273 -> V=1.0, theta=0.0
% INFO    : Bus 24588	: V=0.9815259, theta=-45.224917 -> V=1.0, theta=0.0
% INFO    : Bus 24589	: V=0.9797981, theta=-45.292111 -> V=1.0, theta=0.0
% INFO    : Bus 24590	: V=0.981889, theta=-45.210192 -> V=1.0, theta=0.0
% INFO    : Bus 24591	: V=0.9838782, theta=-44.867631 -> V=1.0, theta=0.0
% INFO    : Bus 24592	: V=0.9859067, theta=-44.817318 -> V=1.0, theta=0.0
% INFO    : Bus 24593	: V=0.9879559, theta=-44.752428 -> V=1.0, theta=0.0
% INFO    : Bus 24594	: V=0.9857518, theta=-45.03417 -> V=1.0, theta=0.0
% INFO    : Bus 24595	: V=0.9833251, theta=-45.149649 -> V=1.0, theta=0.0
% INFO    : Bus 24596	: V=0.990416, theta=-44.734523 -> V=1.0, theta=0.0
% INFO    : Bus 24597	: V=0.9823871, theta=-45.250217 -> V=1.0, theta=0.0
% INFO    : Bus 24598	: V=0.9829228, theta=-45.25672 -> V=1.0, theta=0.0
% INFO    : Bus 24599	: V=0.9912521, theta=-44.706031 -> V=1.0, theta=0.0
% INFO    : Bus 24600	: V=1.0007543, theta=-43.535735 -> V=1.0, theta=0.0
% INFO    : Bus 24601	: V=0.9862523, theta=-45.033926 -> V=1.0, theta=0.0
% INFO    : Bus 24602	: V=0.985784, theta=-45.059392 -> V=1.0, theta=0.0
% INFO    : Bus 24603	: V=1.0129016, theta=-41.42737 -> V=1.0, theta=0.0
% INFO    : Bus 24604	: V=0.9932593, theta=-44.720172 -> V=1.0, theta=0.0
% INFO    : Bus 24605	: V=1.0003255, theta=-43.617664 -> V=1.0, theta=0.0
% INFO    : Bus 24606	: V=0.9899396, theta=-45.032115 -> V=1.0, theta=0.0
% INFO    : Bus 24607	: V=0.9904276, theta=-45.029838 -> V=1.0, theta=0.0
% INFO    : Bus 24608	: V=0.9895439, theta=-45.102146 -> V=1.0, theta=0.0
% INFO    : Bus 24609	: V=0.9915306, theta=-44.751701 -> V=1.0, theta=0.0
% INFO    : Bus 24610	: V=0.9883976, theta=-45.201518 -> V=1.0, theta=0.0
% INFO    : Bus 24611	: V=0.9910263, theta=-44.783279 -> V=1.0, theta=0.0
% INFO    : Bus 24612	: V=0.9855592, theta=-45.341635 -> V=1.0, theta=0.0
% INFO    : Bus 24613	: V=0.9762049, theta=-45.452804 -> V=1.0, theta=0.0
% INFO    : Bus 24614	: V=0.9762666, theta=-45.499338 -> V=1.0, theta=0.0
% INFO    : Bus 24615	: V=0.9775777, theta=-45.563487 -> V=1.0, theta=0.0
% INFO    : Bus 24616	: V=0.9796682, theta=-45.578278 -> V=1.0, theta=0.0
% INFO    : Bus 24617	: V=0.9792543, theta=-45.751507 -> V=1.0, theta=0.0
% INFO    : Bus 24618	: V=0.9771979, theta=-45.749147 -> V=1.0, theta=0.0
% INFO    : Bus 24619	: V=0.9911108, theta=-44.818237 -> V=1.0, theta=0.0
% INFO    : Bus 24620	: V=0.9825871, theta=-45.373844 -> V=1.0, theta=0.0
% INFO    : Bus 24621	: V=0.9852574, theta=-45.888806 -> V=1.0, theta=0.0
% INFO    : Bus 24622	: V=0.9825412, theta=-45.779742 -> V=1.0, theta=0.0
% INFO    : Bus 24623	: V=0.982779, theta=-45.646194 -> V=1.0, theta=0.0
% INFO    : Bus 24624	: V=0.9914504, theta=-44.825693 -> V=1.0, theta=0.0
% INFO    : Bus 24625	: V=0.9830567, theta=-45.713682 -> V=1.0, theta=0.0
% INFO    : Bus 24626	: V=0.9842044, theta=-45.653377 -> V=1.0, theta=0.0
% INFO    : Bus 24627	: V=0.9929528, theta=-44.763053 -> V=1.0, theta=0.0
% INFO    : Bus 24628	: V=0.9929393, theta=-44.789112 -> V=1.0, theta=0.0
% INFO    : Bus 24629	: V=0.9860788, theta=-45.598127 -> V=1.0, theta=0.0
% INFO    : Bus 24630	: V=1.0009285, theta=-43.835875 -> V=1.0, theta=0.0
% INFO    : Bus 24631	: V=0.9938112, theta=-44.808389 -> V=1.0, theta=0.0
% INFO    : Bus 24632	: V=0.9993096, theta=-43.799241 -> V=1.0, theta=0.0
% INFO    : Bus 24633	: V=0.9870031, theta=-45.971168 -> V=1.0, theta=0.0
% INFO    : Bus 24634	: V=0.9856337, theta=-46.062519 -> V=1.0, theta=0.0
% INFO    : Bus 24635	: V=0.985352, theta=-46.062228 -> V=1.0, theta=0.0
% INFO    : Bus 24636	: V=0.9865371, theta=-45.821781 -> V=1.0, theta=0.0
% INFO    : Bus 24637	: V=0.9844365, theta=-45.823493 -> V=1.0, theta=0.0
% INFO    : Bus 24638	: V=0.9856377, theta=-45.940874 -> V=1.0, theta=0.0
% INFO    : Bus 24639	: V=0.986283, theta=-46.055249 -> V=1.0, theta=0.0
% INFO    : Bus 24640	: V=0.9859405, theta=-46.055903 -> V=1.0, theta=0.0
% INFO    : Bus 24641	: V=0.9992177, theta=-43.815312 -> V=1.0, theta=0.0
% INFO    : Bus 24642	: V=0.9898097, theta=-46.275256 -> V=1.0, theta=0.0
% INFO    : Bus 24643	: V=0.9877581, theta=-46.607624 -> V=1.0, theta=0.0
% INFO    : Bus 24644	: V=0.9874989, theta=-46.605967 -> V=1.0, theta=0.0
% INFO    : Bus 24645	: V=0.9844725, theta=-47.110976 -> V=1.0, theta=0.0
% INFO    : Bus 24646	: V=0.984465, theta=-47.236976 -> V=1.0, theta=0.0
% INFO    : Bus 24647	: V=0.9863543, theta=-46.477608 -> V=1.0, theta=0.0
% INFO    : Bus 24648	: V=0.9831766, theta=-45.991046 -> V=1.0, theta=0.0
% INFO    : Bus 24649	: V=0.9840868, theta=-46.670467 -> V=1.0, theta=0.0
% INFO    : Bus 24650	: V=0.9903266, theta=-46.424809 -> V=1.0, theta=0.0
% INFO    : Bus 24651	: V=0.98146, theta=-46.043748 -> V=1.0, theta=0.0
% INFO    : Bus 24652	: V=0.9900592, theta=-45.474518 -> V=1.0, theta=0.0
% INFO    : Bus 24653	: V=0.9854356, theta=-45.539089 -> V=1.0, theta=0.0
% INFO    : Bus 24654	: V=0.9928751, theta=-44.716046 -> V=1.0, theta=0.0
% INFO    : Bus 24655	: V=0.9894455, theta=-45.684826 -> V=1.0, theta=0.0
% INFO    : Bus 24656	: V=0.981167, theta=-46.02777 -> V=1.0, theta=0.0
% INFO    : Bus 24657	: V=0.9809054, theta=-45.927706 -> V=1.0, theta=0.0
% INFO    : Bus 24658	: V=0.9812727, theta=-45.876338 -> V=1.0, theta=0.0
% INFO    : Bus 24659	: V=0.9787456, theta=-46.026933 -> V=1.0, theta=0.0
% INFO    : Bus 24660	: V=0.9800173, theta=-46.053712 -> V=1.0, theta=0.0
% INFO    : Bus 24661	: V=0.9891798, theta=-45.950774 -> V=1.0, theta=0.0
% INFO    : Bus 24662	: V=1.0024236, theta=-44.025088 -> V=1.0, theta=0.0
% INFO    : Bus 24663	: V=0.9781424, theta=-46.158617 -> V=1.0, theta=0.0
% INFO    : Bus 24664	: V=0.9775651, theta=-46.152061 -> V=1.0, theta=0.0
% INFO    : Bus 24665	: V=0.9778253, theta=-46.125293 -> V=1.0, theta=0.0
% INFO    : Bus 24666	: V=0.9849145, theta=-45.383569 -> V=1.0, theta=0.0
% INFO    : Bus 24667	: V=0.9877481, theta=-45.283461 -> V=1.0, theta=0.0
% INFO    : Bus 24668	: V=0.9876671, theta=-45.309265 -> V=1.0, theta=0.0
% INFO    : Bus 24669	: V=0.9907767, theta=-44.927245 -> V=1.0, theta=0.0
% INFO    : Bus 24670	: V=0.98718, theta=-45.289725 -> V=1.0, theta=0.0
% INFO    : Bus 24671	: V=0.9857244, theta=-45.580534 -> V=1.0, theta=0.0
% INFO    : Bus 24672	: V=0.9840131, theta=-45.681246 -> V=1.0, theta=0.0
% INFO    : Bus 24673	: V=0.983405, theta=-45.76214 -> V=1.0, theta=0.0
% INFO    : Bus 24674	: V=0.9813913, theta=-45.911248 -> V=1.0, theta=0.0
% INFO    : Bus 24675	: V=0.980585, theta=-46.009399 -> V=1.0, theta=0.0
% INFO    : Bus 24676	: V=0.9809779, theta=-45.900762 -> V=1.0, theta=0.0
% INFO    : Bus 24677	: V=0.9793216, theta=-46.025529 -> V=1.0, theta=0.0
% INFO    : Bus 24678	: V=0.9795474, theta=-45.994675 -> V=1.0, theta=0.0
% INFO    : Bus 24679	: V=0.9848244, theta=-45.465073 -> V=1.0, theta=0.0
% INFO    : Bus 24680	: V=0.9843747, theta=-45.683089 -> V=1.0, theta=0.0
% INFO    : Bus 24681	: V=0.984375, theta=-45.405247 -> V=1.0, theta=0.0
% INFO    : Bus 24682	: V=0.9826793, theta=-45.645152 -> V=1.0, theta=0.0
% INFO    : Bus 24683	: V=0.9890679, theta=-45.14796 -> V=1.0, theta=0.0
% INFO    : Bus 24684	: V=0.9898159, theta=-45.058346 -> V=1.0, theta=0.0
% INFO    : Bus 24685	: V=0.9841454, theta=-45.704901 -> V=1.0, theta=0.0
% INFO    : Bus 24686	: V=0.9833688, theta=-45.768218 -> V=1.0, theta=0.0
% INFO    : Bus 24687	: V=0.9886947, theta=-45.19091 -> V=1.0, theta=0.0
% INFO    : Bus 24688	: V=0.9826239, theta=-45.649125 -> V=1.0, theta=0.0
% INFO    : Bus 24689	: V=0.9803431, theta=-45.91124 -> V=1.0, theta=0.0
% INFO    : Bus 24690	: V=0.9874996, theta=-45.250817 -> V=1.0, theta=0.0
% INFO    : Bus 24691	: V=0.9787004, theta=-45.983254 -> V=1.0, theta=0.0
% INFO    : Bus 24692	: V=0.9789471, theta=-46.019746 -> V=1.0, theta=0.0
% INFO    : Bus 24693	: V=0.988389, theta=-45.236711 -> V=1.0, theta=0.0
% INFO    : Bus 24694	: V=0.978376, theta=-46.104124 -> V=1.0, theta=0.0
% INFO    : Bus 24695	: V=0.9777008, theta=-46.083145 -> V=1.0, theta=0.0
% INFO    : Bus 24696	: V=0.9879438, theta=-45.312845 -> V=1.0, theta=0.0
% INFO    : Bus 24697	: V=0.9769481, theta=-46.091131 -> V=1.0, theta=0.0
% INFO    : Bus 24698	: V=0.9797533, theta=-45.56055 -> V=1.0, theta=0.0
% INFO    : Bus 24699	: V=0.9794086, theta=-45.59603 -> V=1.0, theta=0.0
% INFO    : Bus 24700	: V=0.9799818, theta=-45.561451 -> V=1.0, theta=0.0
% INFO    : Bus 24701	: V=0.9808132, theta=-45.528053 -> V=1.0, theta=0.0
% INFO    : Bus 24702	: V=0.982786, theta=-45.460696 -> V=1.0, theta=0.0
% INFO    : Bus 24703	: V=0.9802258, theta=-45.567035 -> V=1.0, theta=0.0
% INFO    : Bus 24704	: V=0.9793381, theta=-45.624751 -> V=1.0, theta=0.0
% INFO    : Bus 24705	: V=0.9881355, theta=-45.097634 -> V=1.0, theta=0.0
% INFO    : Bus 24706	: V=0.9788859, theta=-45.892935 -> V=1.0, theta=0.0
% INFO    : Bus 24707	: V=0.9886591, theta=-45.333966 -> V=1.0, theta=0.0
% INFO    : Bus 24708	: V=0.9800125, theta=-45.926139 -> V=1.0, theta=0.0
% INFO    : Bus 24709	: V=0.9787982, theta=-45.911335 -> V=1.0, theta=0.0
% INFO    : Bus 24710	: V=0.9806629, theta=-45.931529 -> V=1.0, theta=0.0
% INFO    : Bus 24711	: V=0.9808445, theta=-45.925039 -> V=1.0, theta=0.0
% INFO    : Bus 24712	: V=0.9877877, theta=-45.161093 -> V=1.0, theta=0.0
% INFO    : Bus 24713	: V=0.9875944, theta=-45.196516 -> V=1.0, theta=0.0
% INFO    : Bus 24714	: V=0.9903568, theta=-45.14121 -> V=1.0, theta=0.0
% INFO    : Bus 24715	: V=0.9914674, theta=-45.131476 -> V=1.0, theta=0.0
% INFO    : Bus 24716	: V=1.0172521, theta=-43.031469 -> V=1.0, theta=0.0
% INFO    : Bus 24717	: V=1.0168397, theta=-43.054977 -> V=1.0, theta=0.0
% INFO    : Bus 24718	: V=0.987956, theta=-45.153177 -> V=1.0, theta=0.0
% INFO    : Bus 24719	: V=0.9884174, theta=-44.958443 -> V=1.0, theta=0.0
% INFO    : Bus 24720	: V=0.9959821, theta=-44.492647 -> V=1.0, theta=0.0
% INFO    : Bus 24721	: V=0.9968358, theta=-44.470163 -> V=1.0, theta=0.0
% INFO    : Bus 24722	: V=0.9990469, theta=-44.40472 -> V=1.0, theta=0.0
% INFO    : Bus 24723	: V=0.9924951, theta=-45.063707 -> V=1.0, theta=0.0
% INFO    : Bus 24724	: V=0.9960115, theta=-45.016166 -> V=1.0, theta=0.0
% INFO    : Bus 24725	: V=0.9909015, theta=-45.169106 -> V=1.0, theta=0.0
% INFO    : Bus 24726	: V=0.9787632, theta=-45.682558 -> V=1.0, theta=0.0
% INFO    : Bus 24727	: V=0.9780721, theta=-45.687033 -> V=1.0, theta=0.0
% INFO    : Bus 24728	: V=0.9791862, theta=-45.703001 -> V=1.0, theta=0.0
% INFO    : Bus 24729	: V=0.9802171, theta=-45.719644 -> V=1.0, theta=0.0
% INFO    : Bus 24730	: V=0.9799326, theta=-45.723457 -> V=1.0, theta=0.0
% INFO    : Bus 24731	: V=0.9792085, theta=-45.799638 -> V=1.0, theta=0.0
% INFO    : Bus 24732	: V=0.9792854, theta=-45.871756 -> V=1.0, theta=0.0
% INFO    : Bus 24733	: V=0.9787682, theta=-45.848651 -> V=1.0, theta=0.0
% INFO    : Bus 24734	: V=0.9981586, theta=-44.654596 -> V=1.0, theta=0.0
% INFO    : Bus 24735	: V=0.9883548, theta=-45.398721 -> V=1.0, theta=0.0
% INFO    : Bus 24736	: V=0.9884371, theta=-45.396641 -> V=1.0, theta=0.0
% INFO    : Bus 24737	: V=1.0018218, theta=-44.565452 -> V=1.0, theta=0.0
% INFO    : Bus 24738	: V=0.9918164, theta=-45.596131 -> V=1.0, theta=0.0
% INFO    : Bus 24739	: V=0.9880525, theta=-45.637049 -> V=1.0, theta=0.0
% INFO    : Bus 24740	: V=0.9886646, theta=-45.658873 -> V=1.0, theta=0.0
% INFO    : Bus 24741	: V=0.9899274, theta=-45.627371 -> V=1.0, theta=0.0
% INFO    : Bus 24742	: V=0.993248, theta=-45.55119 -> V=1.0, theta=0.0
% INFO    : Bus 24743	: V=0.9923935, theta=-45.588228 -> V=1.0, theta=0.0
% INFO    : Bus 24744	: V=0.9918011, theta=-45.587051 -> V=1.0, theta=0.0
% INFO    : Bus 24745	: V=0.9994309, theta=-45.246493 -> V=1.0, theta=0.0
% INFO    : Bus 24746	: V=0.9964551, theta=-45.362103 -> V=1.0, theta=0.0
% INFO    : Bus 24747	: V=0.9954315, theta=-45.387228 -> V=1.0, theta=0.0
% INFO    : Bus 24748	: V=0.9937002, theta=-45.552853 -> V=1.0, theta=0.0
% INFO    : Bus 24749	: V=0.9949828, theta=-45.484053 -> V=1.0, theta=0.0
% INFO    : Bus 24750	: V=0.9971536, theta=-45.399226 -> V=1.0, theta=0.0
% INFO    : Bus 24751	: V=1.0025619, theta=-44.762714 -> V=1.0, theta=0.0
% INFO    : Bus 24752	: V=0.9990333, theta=-45.354453 -> V=1.0, theta=0.0
% INFO    : Bus 24753	: V=0.9946239, theta=-45.521749 -> V=1.0, theta=0.0
% INFO    : Bus 24754	: V=0.9962012, theta=-45.507106 -> V=1.0, theta=0.0
% INFO    : Bus 24755	: V=0.9991908, theta=-45.37788 -> V=1.0, theta=0.0
% INFO    : Bus 24756	: V=1.0186325, theta=-43.039014 -> V=1.0, theta=0.0
% INFO    : Bus 24757	: V=1.0056271, theta=-44.308907 -> V=1.0, theta=0.0
% INFO    : Bus 24758	: V=1.0024187, theta=-44.610016 -> V=1.0, theta=0.0
% INFO    : Bus 24759	: V=1.0017598, theta=-44.641356 -> V=1.0, theta=0.0
% INFO    : Bus 24760	: V=1.0027351, theta=-44.681931 -> V=1.0, theta=0.0
% INFO    : Bus 24761	: V=1.0049656, theta=-44.464733 -> V=1.0, theta=0.0
% INFO    : Bus 24762	: V=1.0028157, theta=-44.685181 -> V=1.0, theta=0.0
% INFO    : Bus 24763	: V=1.0029927, theta=-44.688717 -> V=1.0, theta=0.0
% INFO    : Bus 24764	: V=1.003642, theta=-44.611709 -> V=1.0, theta=0.0
% INFO    : Bus 24765	: V=0.9953487, theta=-44.707141 -> V=1.0, theta=0.0
% INFO    : Bus 24766	: V=1.0170685, theta=-43.596052 -> V=1.0, theta=0.0
% INFO    : Bus 24767	: V=1.0005238, theta=-45.274139 -> V=1.0, theta=0.0
% INFO    : Bus 24768	: V=1.0002705, theta=-45.360333 -> V=1.0, theta=0.0
% INFO    : Bus 24769	: V=0.9986719, theta=-45.409292 -> V=1.0, theta=0.0
% INFO    : Bus 24770	: V=0.9976354, theta=-45.458497 -> V=1.0, theta=0.0
% INFO    : Bus 24771	: V=0.9986483, theta=-45.414102 -> V=1.0, theta=0.0
% INFO    : Bus 24772	: V=0.9996591, theta=-45.408272 -> V=1.0, theta=0.0
% INFO    : Bus 24773	: V=0.9978895, theta=-45.466853 -> V=1.0, theta=0.0
% INFO    : Bus 24774	: V=1.0018922, theta=-45.038093 -> V=1.0, theta=0.0
% INFO    : Bus 24775	: V=0.9937972, theta=-45.635887 -> V=1.0, theta=0.0
% INFO    : Bus 24776	: V=0.9957571, theta=-45.55918 -> V=1.0, theta=0.0
% INFO    : Bus 24777	: V=0.9971626, theta=-45.471438 -> V=1.0, theta=0.0
% INFO    : Bus 24778	: V=0.9915875, theta=-45.656471 -> V=1.0, theta=0.0
% INFO    : Bus 24779	: V=0.9955392, theta=-45.573526 -> V=1.0, theta=0.0
% INFO    : Bus 24780	: V=0.99647, theta=-45.504657 -> V=1.0, theta=0.0
% INFO    : Bus 24781	: V=0.9964406, theta=-45.538792 -> V=1.0, theta=0.0
% INFO    : Bus 24782	: V=1.0021311, theta=-45.208696 -> V=1.0, theta=0.0
% INFO    : Bus 24783	: V=0.9805824, theta=-45.933812 -> V=1.0, theta=0.0
% INFO    : Bus 24784	: V=0.9893994, theta=-45.342971 -> V=1.0, theta=0.0
% INFO    : Bus 24785	: V=0.9913066, theta=-45.377234 -> V=1.0, theta=0.0
% INFO    : Bus 24786	: V=0.9801388, theta=-45.970643 -> V=1.0, theta=0.0
% INFO    : Bus 24787	: V=0.9869834, theta=-45.698485 -> V=1.0, theta=0.0
% INFO    : Bus 24788	: V=0.9875678, theta=-45.733766 -> V=1.0, theta=0.0
% INFO    : Bus 24789	: V=0.9811559, theta=-45.957375 -> V=1.0, theta=0.0
% INFO    : Bus 24790	: V=1.0052915, theta=-44.493905 -> V=1.0, theta=0.0
% INFO    : Bus 24791	: V=0.9905598, theta=-45.713962 -> V=1.0, theta=0.0
% INFO    : Bus 24792	: V=0.9857506, theta=-45.864125 -> V=1.0, theta=0.0
% INFO    : Bus 24793	: V=0.9868878, theta=-45.796991 -> V=1.0, theta=0.0
% INFO    : Bus 24794	: V=0.987339, theta=-45.826196 -> V=1.0, theta=0.0
% INFO    : Bus 24795	: V=0.9854664, theta=-45.929787 -> V=1.0, theta=0.0
% INFO    : Bus 24796	: V=1.0066702, theta=-44.573054 -> V=1.0, theta=0.0
% INFO    : Bus 24797	: V=0.9909297, theta=-45.775567 -> V=1.0, theta=0.0
% INFO    : Bus 24798	: V=0.9948381, theta=-45.493969 -> V=1.0, theta=0.0
% INFO    : Bus 24799	: V=0.9894162, theta=-45.879444 -> V=1.0, theta=0.0
% INFO    : Bus 24800	: V=0.9916334, theta=-45.774468 -> V=1.0, theta=0.0
% INFO    : Bus 24801	: V=0.9868592, theta=-46.052419 -> V=1.0, theta=0.0
% INFO    : Bus 24802	: V=0.9767249, theta=-46.22762 -> V=1.0, theta=0.0
% INFO    : Bus 24803	: V=0.9780042, theta=-46.219879 -> V=1.0, theta=0.0
% INFO    : Bus 24804	: V=0.9791498, theta=-46.364541 -> V=1.0, theta=0.0
% INFO    : Bus 24805	: V=0.9855574, theta=-45.688244 -> V=1.0, theta=0.0
% INFO    : Bus 24806	: V=0.9844181, theta=-45.775085 -> V=1.0, theta=0.0
% INFO    : Bus 24807	: V=1.0070092, theta=-44.540944 -> V=1.0, theta=0.0
% INFO    : Bus 24808	: V=0.9783248, theta=-46.916436 -> V=1.0, theta=0.0
% INFO    : Bus 24809	: V=0.9990873, theta=-47.202633 -> V=1.0, theta=0.0
% INFO    : Bus 24810	: V=0.9922717, theta=-46.862928 -> V=1.0, theta=0.0
% INFO    : Bus 24811	: V=0.9825331, theta=-47.139615 -> V=1.0, theta=0.0
% INFO    : Bus 24812	: V=0.9927027, theta=-46.975801 -> V=1.0, theta=0.0
% INFO    : Bus 24813	: V=0.9879644, theta=-48.178597 -> V=1.0, theta=0.0
% INFO    : Bus 24814	: V=0.992732, theta=-48.181054 -> V=1.0, theta=0.0
% INFO    : Bus 24815	: V=0.9799728, theta=-47.110774 -> V=1.0, theta=0.0
% INFO    : Bus 24816	: V=0.9877653, theta=-48.85749 -> V=1.0, theta=0.0
% INFO    : Bus 24817	: V=0.9920925, theta=-48.711359 -> V=1.0, theta=0.0
% INFO    : Bus 24818	: V=0.9843149, theta=-47.059534 -> V=1.0, theta=0.0
% INFO    : Bus 24819	: V=0.9789791, theta=-47.448469 -> V=1.0, theta=0.0
% INFO    : Bus 24820	: V=0.9889727, theta=-46.681816 -> V=1.0, theta=0.0
% INFO    : Bus 24821	: V=0.9935263, theta=-45.770145 -> V=1.0, theta=0.0
% INFO    : Bus 24822	: V=1.0093482, theta=-44.832279 -> V=1.0, theta=0.0
% INFO    : Bus 24823	: V=0.9893595, theta=-45.968943 -> V=1.0, theta=0.0
% INFO    : Bus 24824	: V=0.9931231, theta=-46.358244 -> V=1.0, theta=0.0
% INFO    : Bus 24825	: V=1.0010184, theta=-45.678314 -> V=1.0, theta=0.0
% INFO    : Bus 24826	: V=0.9984696, theta=-46.159363 -> V=1.0, theta=0.0
% INFO    : Bus 24827	: V=0.9966406, theta=-45.99007 -> V=1.0, theta=0.0
% INFO    : Bus 24828	: V=1.0110244, theta=-44.936208 -> V=1.0, theta=0.0
% INFO    : Bus 24829	: V=0.9962495, theta=-46.09114 -> V=1.0, theta=0.0
% INFO    : Bus 24830	: V=0.9965837, theta=-46.110934 -> V=1.0, theta=0.0
% INFO    : Bus 24831	: V=0.9984623, theta=-45.641938 -> V=1.0, theta=0.0
% INFO    : Bus 24832	: V=1.0044953, theta=-45.194247 -> V=1.0, theta=0.0
% INFO    : Bus 24833	: V=0.9994336, theta=-45.581397 -> V=1.0, theta=0.0
% INFO    : Bus 24834	: V=1.0010374, theta=-45.56516 -> V=1.0, theta=0.0
% INFO    : Bus 24835	: V=1.0143787, theta=-44.481208 -> V=1.0, theta=0.0
% INFO    : Bus 24836	: V=1.0128432, theta=-44.688192 -> V=1.0, theta=0.0
% INFO    : Bus 24837	: V=1.0021991, theta=-45.098416 -> V=1.0, theta=0.0
% INFO    : Bus 24838	: V=1.0022948, theta=-45.255588 -> V=1.0, theta=0.0
% INFO    : Bus 24839	: V=1.0029446, theta=-45.283815 -> V=1.0, theta=0.0
% INFO    : Bus 24840	: V=1.0044128, theta=-45.55189 -> V=1.0, theta=0.0
% INFO    : Bus 24841	: V=1.002581, theta=-45.469221 -> V=1.0, theta=0.0
% INFO    : Bus 24842	: V=1.0006792, theta=-45.566468 -> V=1.0, theta=0.0
% INFO    : Bus 24843	: V=1.0053434, theta=-45.231307 -> V=1.0, theta=0.0
% INFO    : Bus 24844	: V=1.0033138, theta=-45.443649 -> V=1.0, theta=0.0
% INFO    : Bus 24845	: V=1.0009066, theta=-46.27758 -> V=1.0, theta=0.0
% INFO    : Bus 24846	: V=1.0009404, theta=-46.466986 -> V=1.0, theta=0.0
% INFO    : Bus 24847	: V=1.002213, theta=-44.124767 -> V=1.0, theta=0.0
% INFO    : Bus 24848	: V=0.9867155, theta=-44.67434 -> V=1.0, theta=0.0
% INFO    : Bus 24849	: V=0.9974097, theta=-43.821614 -> V=1.0, theta=0.0
% INFO    : Bus 24850	: V=0.9960135, theta=-44.453007 -> V=1.0, theta=0.0
% INFO    : Bus 24851	: V=0.9823712, theta=-46.351501 -> V=1.0, theta=0.0
% INFO    : Bus 24852	: V=1.0007721, theta=-43.675756 -> V=1.0, theta=0.0
% INFO    : Bus 24853	: V=1.0197486, theta=-42.993648 -> V=1.0, theta=0.0
% INFO    : Bus 24854	: V=1.0188523, theta=-43.002209 -> V=1.0, theta=0.0
% INFO    : Bus 24855	: V=0.9964537, theta=-43.798107 -> V=1.0, theta=0.0
% INFO    : Bus 24856	: V=0.9880343, theta=-31.74304 -> V=1.0, theta=0.0
% INFO    : Bus 24857	: V=0.9671703, theta=-32.813959 -> V=1.0, theta=0.0
% INFO    : Bus 24858	: V=1.0001398, theta=-30.524356 -> V=1.0, theta=0.0
% INFO    : Bus 24859	: V=0.9982013, theta=-30.983963 -> V=1.0, theta=0.0
% INFO    : Bus 24860	: V=0.996727, theta=-31.405914 -> V=1.0, theta=0.0
% INFO    : Bus 24861	: V=0.9961354, theta=-31.600424 -> V=1.0, theta=0.0
% INFO    : Bus 24862	: V=1.0014242, theta=-29.867814 -> V=1.0, theta=0.0
% INFO    : Bus 24863	: V=0.9972254, theta=-31.180372 -> V=1.0, theta=0.0
% INFO    : Bus 24864	: V=1.0090575, theta=-42.311659 -> V=1.0, theta=0.0
% INFO    : Bus 24865	: V=1.0066953, theta=-42.843959 -> V=1.0, theta=0.0
% INFO    : Bus 24866	: V=0.9933233, theta=-41.274186 -> V=1.0, theta=0.0
% INFO    : Bus 24867	: V=1.0062612, theta=-40.190579 -> V=1.0, theta=0.0
% INFO    : Bus 24868	: V=1.0088897, theta=-40.77578 -> V=1.0, theta=0.0
% INFO    : Bus 24869	: V=1.0192899, theta=-39.047797 -> V=1.0, theta=0.0
% INFO    : Bus 24870	: V=0.9802373, theta=-54.653136 -> V=1.0, theta=0.0
% INFO    : Bus 24871	: V=0.9749589, theta=-54.236 -> V=1.0, theta=0.0
% INFO    : Bus 24872	: V=0.9829597, theta=-52.933709 -> V=1.0, theta=0.0
% INFO    : Bus 24873	: V=1.0004273, theta=-51.946123 -> V=1.0, theta=0.0
% INFO    : Bus 24874	: V=0.9834827, theta=-53.948101 -> V=1.0, theta=0.0
% INFO    : Bus 24875	: V=0.9953997, theta=-52.031155 -> V=1.0, theta=0.0
% INFO    : Bus 24876	: V=0.9856172, theta=-52.913212 -> V=1.0, theta=0.0
% INFO    : Bus 24877	: V=1.0002447, theta=-51.011402 -> V=1.0, theta=0.0
% INFO    : Bus 24878	: V=0.9895476, theta=-52.856853 -> V=1.0, theta=0.0
% INFO    : Bus 24879	: V=0.9807913, theta=-53.549066 -> V=1.0, theta=0.0
% INFO    : Bus 24880	: V=0.9965759, theta=-51.440024 -> V=1.0, theta=0.0
% INFO    : Bus 24881	: V=0.988279, theta=-52.881088 -> V=1.0, theta=0.0
% INFO    : Bus 24882	: V=1.0164224, theta=-47.271505 -> V=1.0, theta=0.0
% INFO    : Bus 24883	: V=1.0014015, theta=-50.817187 -> V=1.0, theta=0.0
% INFO    : Bus 24884	: V=0.9956244, theta=-52.11625 -> V=1.0, theta=0.0
% INFO    : Bus 24885	: V=0.9909528, theta=-52.962372 -> V=1.0, theta=0.0
% INFO    : Bus 24886	: V=0.9877058, theta=-52.73818 -> V=1.0, theta=0.0
% INFO    : Bus 24887	: V=0.9923076, theta=-52.418036 -> V=1.0, theta=0.0
% INFO    : Bus 24888	: V=0.9916963, theta=-52.498349 -> V=1.0, theta=0.0
% INFO    : Bus 24889	: V=1.0003827, theta=-50.994122 -> V=1.0, theta=0.0
% INFO    : Bus 24890	: V=0.9914938, theta=-52.516564 -> V=1.0, theta=0.0
% INFO    : Bus 24891	: V=0.99282, theta=-52.352187 -> V=1.0, theta=0.0
% INFO    : Bus 24892	: V=0.9939279, theta=-52.217618 -> V=1.0, theta=0.0
% INFO    : Bus 24893	: V=0.9924522, theta=-52.428259 -> V=1.0, theta=0.0
% INFO    : Bus 24894	: V=0.9930506, theta=-52.420431 -> V=1.0, theta=0.0
% INFO    : Bus 24895	: V=0.9915176, theta=-52.523074 -> V=1.0, theta=0.0
% INFO    : Bus 24896	: V=1.0010553, theta=-50.900483 -> V=1.0, theta=0.0
% INFO    : Bus 24897	: V=1.0002096, theta=-51.016733 -> V=1.0, theta=0.0
% INFO    : Bus 24898	: V=0.9932951, theta=-52.31124 -> V=1.0, theta=0.0
% INFO    : Bus 24899	: V=1.0002173, theta=-51.01159 -> V=1.0, theta=0.0
% INFO    : Bus 24900	: V=0.9751362, theta=-55.083549 -> V=1.0, theta=0.0
% INFO    : Bus 24901	: V=0.9759117, theta=-55.039067 -> V=1.0, theta=0.0
% INFO    : Bus 24902	: V=0.9920589, theta=-52.448131 -> V=1.0, theta=0.0
% INFO    : Bus 24903	: V=0.9834769, theta=-58.057138 -> V=1.0, theta=0.0
% INFO    : Bus 24904	: V=0.9867692, theta=-56.862675 -> V=1.0, theta=0.0
% INFO    : Bus 24905	: V=0.9807586, theta=-57.761785 -> V=1.0, theta=0.0
% INFO    : Bus 24906	: V=0.9912614, theta=-54.410299 -> V=1.0, theta=0.0
% INFO    : Bus 24907	: V=0.9862557, theta=-57.394996 -> V=1.0, theta=0.0
% INFO    : Bus 24908	: V=0.9818231, theta=-57.663539 -> V=1.0, theta=0.0
% INFO    : Bus 24909	: V=0.9839846, theta=-57.488793 -> V=1.0, theta=0.0
% INFO    : Bus 24910	: V=0.9875263, theta=-56.347873 -> V=1.0, theta=0.0
% INFO    : Bus 24911	: V=0.9883841, theta=-55.721756 -> V=1.0, theta=0.0
% INFO    : Bus 24912	: V=0.9867386, theta=-55.749687 -> V=1.0, theta=0.0
% INFO    : Bus 24913	: V=0.9839546, theta=-54.087265 -> V=1.0, theta=0.0
% INFO    : Bus 24914	: V=0.9882491, theta=-53.368409 -> V=1.0, theta=0.0
% INFO    : Bus 24915	: V=0.9871473, theta=-53.407002 -> V=1.0, theta=0.0
% INFO    : Bus 24916	: V=1.0011151, theta=-51.828806 -> V=1.0, theta=0.0
% INFO    : Bus 24917	: V=0.9965243, theta=-52.609196 -> V=1.0, theta=0.0
% INFO    : Bus 24918	: V=1.0175306, theta=-50.091627 -> V=1.0, theta=0.0
% INFO    : Bus 24919	: V=1.0136515, theta=-50.637038 -> V=1.0, theta=0.0
% INFO    : Bus 24920	: V=1.0071553, theta=-51.471424 -> V=1.0, theta=0.0
% INFO    : Bus 24921	: V=1.015099, theta=-50.404667 -> V=1.0, theta=0.0
% INFO    : Bus 24922	: V=1.0082342, theta=-51.341642 -> V=1.0, theta=0.0
% INFO    : Bus 24923	: V=1.0113114, theta=-50.931428 -> V=1.0, theta=0.0
% INFO    : Bus 24924	: V=1.0111603, theta=-50.93846 -> V=1.0, theta=0.0
% INFO    : Bus 24925	: V=1.0104161, theta=-51.05049 -> V=1.0, theta=0.0
% INFO    : Bus 24926	: V=1.0081899, theta=-51.388554 -> V=1.0, theta=0.0
% INFO    : Bus 24927	: V=1.0057123, theta=-51.599562 -> V=1.0, theta=0.0
% INFO    : Bus 24928	: V=1.0121787, theta=-50.830173 -> V=1.0, theta=0.0
% INFO    : Bus 24929	: V=1.0113348, theta=-50.930828 -> V=1.0, theta=0.0
% INFO    : Bus 24930	: V=1.013161, theta=-50.714428 -> V=1.0, theta=0.0
% INFO    : Bus 24931	: V=0.9766956, theta=-55.196485 -> V=1.0, theta=0.0
% INFO    : Bus 24932	: V=1.0073518, theta=-51.214112 -> V=1.0, theta=0.0
% INFO    : Bus 24933	: V=0.9864889, theta=-52.693009 -> V=1.0, theta=0.0
% INFO    : Bus 24934	: V=1.0027227, theta=-51.432383 -> V=1.0, theta=0.0
% INFO    : Bus 24935	: V=0.9849268, theta=-53.085561 -> V=1.0, theta=0.0
% INFO    : Bus 24936	: V=0.9714899, theta=-54.94725 -> V=1.0, theta=0.0
% INFO    : Bus 24937	: V=0.9775777, theta=-54.219601 -> V=1.0, theta=0.0
% INFO    : Bus 24938	: V=0.9676638, theta=-56.226755 -> V=1.0, theta=0.0
% INFO    : Bus 24939	: V=1.0118513, theta=-40.318487 -> V=1.0, theta=0.0
% INFO    : Bus 24940	: V=1.0130164, theta=-40.061788 -> V=1.0, theta=0.0
% INFO    : Bus 24941	: V=1.0037961, theta=-41.986886 -> V=1.0, theta=0.0
% INFO    : Bus 24942	: V=1.0143498, theta=-39.75951 -> V=1.0, theta=0.0
% INFO    : Bus 24943	: V=1.0009465, theta=-40.874154 -> V=1.0, theta=0.0
% INFO    : Bus 24944	: V=1.0090829, theta=-40.13694 -> V=1.0, theta=0.0
% INFO    : Bus 24945	: V=1.0077837, theta=-40.540748 -> V=1.0, theta=0.0
% INFO    : Bus 24946	: V=1.0111566, theta=-39.856363 -> V=1.0, theta=0.0
% INFO    : Bus 24947	: V=1.0009991, theta=-41.028546 -> V=1.0, theta=0.0
% INFO    : Bus 24948	: V=1.0108634, theta=-40.162934 -> V=1.0, theta=0.0
% INFO    : Bus 24949	: V=1.0185966, theta=-39.282161 -> V=1.0, theta=0.0
% INFO    : Bus 24950	: V=1.0129925, theta=-39.271651 -> V=1.0, theta=0.0
% INFO    : Bus 24951	: V=1.0076692, theta=-40.668584 -> V=1.0, theta=0.0
% INFO    : Bus 24952	: V=1.009105, theta=-40.097047 -> V=1.0, theta=0.0
% INFO    : Bus 24953	: V=1.0019662, theta=-40.865788 -> V=1.0, theta=0.0
% INFO    : Bus 24954	: V=0.9792154, theta=-53.949485 -> V=1.0, theta=0.0
% INFO    : Bus 24955	: V=0.9742135, theta=-54.23035 -> V=1.0, theta=0.0
% INFO    : Bus 24956	: V=0.9711559, theta=-54.52568 -> V=1.0, theta=0.0
% INFO    : Bus 24957	: V=0.9674204, theta=-54.769989 -> V=1.0, theta=0.0
% INFO    : Bus 24958	: V=0.9763343, theta=-55.307069 -> V=1.0, theta=0.0
% INFO    : Bus 24959	: V=0.9675102, theta=-55.944791 -> V=1.0, theta=0.0
% INFO    : Bus 24960	: V=0.968397, theta=-55.967694 -> V=1.0, theta=0.0
% INFO    : Bus 24961	: V=0.9661356, theta=-56.021446 -> V=1.0, theta=0.0
% INFO    : Bus 24962	: V=0.9670835, theta=-54.919062 -> V=1.0, theta=0.0
% INFO    : Bus 24963	: V=0.9621944, theta=-57.084976 -> V=1.0, theta=0.0
% INFO    : Bus 24964	: V=0.9671493, theta=-56.100253 -> V=1.0, theta=0.0
% INFO    : Bus 24965	: V=1.0046114, theta=-41.688039 -> V=1.0, theta=0.0
% INFO    : Bus 24966	: V=1.0189905, theta=-40.061106 -> V=1.0, theta=0.0
% INFO    : Bus 24967	: V=1.0110902, theta=-41.456669 -> V=1.0, theta=0.0
% INFO    : Bus 24968	: V=1.0062901, theta=-43.207126 -> V=1.0, theta=0.0
% INFO    : Bus 24969	: V=1.0072306, theta=-42.883763 -> V=1.0, theta=0.0
% INFO    : Bus 24970	: V=1.003527, theta=-42.615859 -> V=1.0, theta=0.0
% INFO    : Bus 24971	: V=1.0085066, theta=-42.4775 -> V=1.0, theta=0.0
% INFO    : Bus 24972	: V=0.9907866, theta=-42.94731 -> V=1.0, theta=0.0
% INFO    : Bus 24973	: V=0.98966, theta=-42.061437 -> V=1.0, theta=0.0
% INFO    : Bus 24974	: V=1.0164619, theta=-40.429003 -> V=1.0, theta=0.0
% INFO    : Bus 24975	: V=1.015498, theta=-40.637466 -> V=1.0, theta=0.0
% INFO    : Bus 24976	: V=1.0111985, theta=-41.107853 -> V=1.0, theta=0.0
% INFO    : Bus 24977	: V=1.0109901, theta=-41.122376 -> V=1.0, theta=0.0
% INFO    : Bus 24978	: V=1.010566, theta=-41.126731 -> V=1.0, theta=0.0
% INFO    : Bus 24979	: V=1.013219, theta=-40.929428 -> V=1.0, theta=0.0
% INFO    : Bus 24980	: V=1.0130105, theta=-40.926693 -> V=1.0, theta=0.0
% INFO    : Bus 24981	: V=1.0128104, theta=-40.953497 -> V=1.0, theta=0.0
% INFO    : Bus 24982	: V=1.0103813, theta=-41.940763 -> V=1.0, theta=0.0
% INFO    : Bus 24983	: V=1.005831, theta=-42.05059 -> V=1.0, theta=0.0
% INFO    : Bus 24984	: V=1.008197, theta=-41.722829 -> V=1.0, theta=0.0
% INFO    : Bus 24985	: V=0.9795477, theta=-47.221299 -> V=1.0, theta=0.0
% INFO    : Bus 24986	: V=0.9870405, theta=-45.755334 -> V=1.0, theta=0.0
% INFO    : Bus 24987	: V=0.9759627, theta=-47.271076 -> V=1.0, theta=0.0
% INFO    : Bus 24988	: V=1.001367, theta=-42.326762 -> V=1.0, theta=0.0
% INFO    : Bus 24989	: V=1.004662, theta=-41.16905 -> V=1.0, theta=0.0
% INFO    : Bus 24990	: V=1.0120812, theta=-40.254322 -> V=1.0, theta=0.0
% INFO    : Bus 24991	: V=1.0034208, theta=-41.606672 -> V=1.0, theta=0.0
% INFO    : Bus 24992	: V=1.0054949, theta=-41.372035 -> V=1.0, theta=0.0
% INFO    : Bus 24993	: V=0.9941749, theta=-42.835127 -> V=1.0, theta=0.0
% INFO    : Bus 24994	: V=0.9829346, theta=-49.108355 -> V=1.0, theta=0.0
% INFO    : Bus 24995	: V=0.9818277, theta=-49.125799 -> V=1.0, theta=0.0
% INFO    : Bus 24996	: V=0.9853009, theta=-49.097074 -> V=1.0, theta=0.0
% INFO    : Bus 24997	: V=0.9862725, theta=-49.085537 -> V=1.0, theta=0.0
% INFO    : Bus 24998	: V=0.9853604, theta=-49.098797 -> V=1.0, theta=0.0
% INFO    : Bus 24999	: V=0.9998938, theta=-48.19641 -> V=1.0, theta=0.0
% INFO    : Bus 25000	: V=0.9943259, theta=-48.775389 -> V=1.0, theta=0.0
% INFO    : Bus 25001	: V=0.9920863, theta=-48.868489 -> V=1.0, theta=0.0
% INFO    : Bus 25002	: V=0.9989048, theta=-48.126676 -> V=1.0, theta=0.0
% INFO    : Bus 25003	: V=0.9984191, theta=-48.10569 -> V=1.0, theta=0.0
% INFO    : Bus 25004	: V=0.9823686, theta=-49.314831 -> V=1.0, theta=0.0
% INFO    : Bus 25005	: V=0.9801281, theta=-49.524652 -> V=1.0, theta=0.0
% INFO    : Bus 25006	: V=0.9958762, theta=-47.63704 -> V=1.0, theta=0.0
% INFO    : Bus 25007	: V=0.9939718, theta=-47.819892 -> V=1.0, theta=0.0
% INFO    : Bus 25008	: V=0.9852142, theta=-49.257375 -> V=1.0, theta=0.0
% INFO    : Bus 25009	: V=1.0016398, theta=-47.487899 -> V=1.0, theta=0.0
% INFO    : Bus 25010	: V=1.004709, theta=-46.30088 -> V=1.0, theta=0.0
% INFO    : Bus 25011	: V=0.9915156, theta=-49.027436 -> V=1.0, theta=0.0
% INFO    : Bus 25012	: V=0.9795818, theta=-49.327449 -> V=1.0, theta=0.0
% INFO    : Bus 25013	: V=0.9946482, theta=-48.814587 -> V=1.0, theta=0.0
% INFO    : Bus 25014	: V=0.9958127, theta=-48.802065 -> V=1.0, theta=0.0
% INFO    : Bus 25015	: V=0.9975925, theta=-47.787552 -> V=1.0, theta=0.0
% INFO    : Bus 25016	: V=0.9802815, theta=-49.130922 -> V=1.0, theta=0.0
% INFO    : Bus 25017	: V=0.983897, theta=-48.500239 -> V=1.0, theta=0.0
% INFO    : Bus 25018	: V=0.9831479, theta=-48.602051 -> V=1.0, theta=0.0
% INFO    : Bus 25019	: V=0.9826985, theta=-48.636881 -> V=1.0, theta=0.0
% INFO    : Bus 25020	: V=0.9853774, theta=-48.47966 -> V=1.0, theta=0.0
% INFO    : Bus 25021	: V=0.9848518, theta=-48.64373 -> V=1.0, theta=0.0
% INFO    : Bus 25022	: V=0.9846307, theta=-48.802349 -> V=1.0, theta=0.0
% INFO    : Bus 25023	: V=0.9845194, theta=-48.405656 -> V=1.0, theta=0.0
% INFO    : Bus 25024	: V=0.9814655, theta=-48.555198 -> V=1.0, theta=0.0
% INFO    : Bus 25025	: V=1.0003223, theta=-48.311088 -> V=1.0, theta=0.0
% INFO    : Bus 25026	: V=0.9850205, theta=-49.175254 -> V=1.0, theta=0.0
% INFO    : Bus 25027	: V=0.9836505, theta=-48.971031 -> V=1.0, theta=0.0
% INFO    : Bus 25028	: V=0.9782552, theta=-49.746413 -> V=1.0, theta=0.0
% INFO    : Bus 25029	: V=0.9746768, theta=-49.931705 -> V=1.0, theta=0.0
% INFO    : Bus 25030	: V=0.9741202, theta=-49.935085 -> V=1.0, theta=0.0
% INFO    : Bus 25031	: V=0.9979402, theta=-47.386455 -> V=1.0, theta=0.0
% INFO    : Bus 25032	: V=0.9853375, theta=-49.231871 -> V=1.0, theta=0.0
% INFO    : Bus 25033	: V=0.9991125, theta=-47.731397 -> V=1.0, theta=0.0
% INFO    : Bus 25034	: V=0.9806318, theta=-49.640275 -> V=1.0, theta=0.0
% INFO    : Bus 25035	: V=0.9919187, theta=-48.788647 -> V=1.0, theta=0.0
% INFO    : Bus 25036	: V=0.999551, theta=-48.381239 -> V=1.0, theta=0.0
% INFO    : Bus 25037	: V=0.9879748, theta=-48.659845 -> V=1.0, theta=0.0
% INFO    : Bus 25038	: V=0.9980623, theta=-47.160438 -> V=1.0, theta=0.0
% INFO    : Bus 25039	: V=0.976487, theta=-49.773439 -> V=1.0, theta=0.0
% INFO    : Bus 25040	: V=0.9884851, theta=-48.840265 -> V=1.0, theta=0.0
% INFO    : Bus 25041	: V=0.984024, theta=-49.393497 -> V=1.0, theta=0.0
% INFO    : Bus 25042	: V=0.9859426, theta=-48.78318 -> V=1.0, theta=0.0
% INFO    : Bus 25043	: V=0.9874814, theta=-48.698594 -> V=1.0, theta=0.0
% INFO    : Bus 25044	: V=0.971339, theta=-49.859829 -> V=1.0, theta=0.0
% INFO    : Bus 25045	: V=0.9831716, theta=-48.957883 -> V=1.0, theta=0.0
% INFO    : Bus 25046	: V=1.0003893, theta=-48.454491 -> V=1.0, theta=0.0
% INFO    : Bus 25047	: V=1.0042985, theta=-48.377823 -> V=1.0, theta=0.0
% INFO    : Bus 25048	: V=1.0004823, theta=-49.057266 -> V=1.0, theta=0.0
% INFO    : Bus 25049	: V=0.9970835, theta=-49.490696 -> V=1.0, theta=0.0
% INFO    : Bus 25050	: V=1.002113, theta=-48.524162 -> V=1.0, theta=0.0
% INFO    : Bus 25051	: V=0.9970987, theta=-49.394926 -> V=1.0, theta=0.0
% INFO    : Bus 25052	: V=0.9952405, theta=-49.513012 -> V=1.0, theta=0.0
% INFO    : Bus 25053	: V=0.9960033, theta=-49.389814 -> V=1.0, theta=0.0
% INFO    : Bus 25054	: V=0.9973949, theta=-49.315385 -> V=1.0, theta=0.0
% INFO    : Bus 25055	: V=0.997638, theta=-49.255641 -> V=1.0, theta=0.0
% INFO    : Bus 25056	: V=1.0002321, theta=-49.031781 -> V=1.0, theta=0.0
% INFO    : Bus 25057	: V=1.0015545, theta=-48.621109 -> V=1.0, theta=0.0
% INFO    : Bus 25058	: V=0.9956109, theta=-49.616136 -> V=1.0, theta=0.0
% INFO    : Bus 25059	: V=0.9974205, theta=-49.241692 -> V=1.0, theta=0.0
% INFO    : Bus 25060	: V=0.9973885, theta=-49.230819 -> V=1.0, theta=0.0
% INFO    : Bus 25061	: V=0.9974767, theta=-49.205401 -> V=1.0, theta=0.0
% INFO    : Bus 25062	: V=0.9967584, theta=-49.273126 -> V=1.0, theta=0.0
% INFO    : Bus 25063	: V=1.0016064, theta=-48.551739 -> V=1.0, theta=0.0
% INFO    : Bus 25064	: V=1.0001847, theta=-49.056709 -> V=1.0, theta=0.0
% INFO    : Bus 25065	: V=1.0024218, theta=-48.522565 -> V=1.0, theta=0.0
% INFO    : Bus 25066	: V=0.9984115, theta=-49.348682 -> V=1.0, theta=0.0
% INFO    : Bus 25067	: V=1.001355, theta=-48.653608 -> V=1.0, theta=0.0
% INFO    : Bus 25068	: V=0.9973468, theta=-48.633133 -> V=1.0, theta=0.0
% INFO    : Bus 25069	: V=0.9993313, theta=-48.132484 -> V=1.0, theta=0.0
% INFO    : Bus 25070	: V=0.9926705, theta=-48.820826 -> V=1.0, theta=0.0
% INFO    : Bus 25071	: V=0.9980936, theta=-48.02906 -> V=1.0, theta=0.0
% INFO    : Bus 25072	: V=0.9852497, theta=-49.211686 -> V=1.0, theta=0.0
% INFO    : Bus 25073	: V=1.0070866, theta=-48.189382 -> V=1.0, theta=0.0
% INFO    : Bus 25074	: V=0.9842267, theta=-49.990682 -> V=1.0, theta=0.0
% INFO    : Bus 25075	: V=0.9842623, theta=-52.458277 -> V=1.0, theta=0.0
% INFO    : Bus 25076	: V=0.9794539, theta=-51.834492 -> V=1.0, theta=0.0
% INFO    : Bus 25077	: V=0.983072, theta=-50.681866 -> V=1.0, theta=0.0
% INFO    : Bus 25078	: V=0.987287, theta=-48.908742 -> V=1.0, theta=0.0
% INFO    : Bus 25079	: V=0.9923278, theta=-47.681109 -> V=1.0, theta=0.0
% INFO    : Bus 25080	: V=0.9822625, theta=-49.321388 -> V=1.0, theta=0.0
% INFO    : Bus 25081	: V=0.9530721, theta=-57.611923 -> V=1.0, theta=0.0
% INFO    : Bus 25082	: V=0.9411742, theta=-57.470575 -> V=1.0, theta=0.0
% INFO    : Bus 25083	: V=0.9561063, theta=-56.394421 -> V=1.0, theta=0.0
% INFO    : Bus 25084	: V=0.9515783, theta=-56.754398 -> V=1.0, theta=0.0
% INFO    : Bus 25085	: V=0.958458, theta=-56.166207 -> V=1.0, theta=0.0
% INFO    : Bus 25086	: V=0.9491429, theta=-56.646028 -> V=1.0, theta=0.0
% INFO    : Bus 25087	: V=0.9550539, theta=-56.594824 -> V=1.0, theta=0.0
% INFO    : Bus 25088	: V=0.9622782, theta=-55.658892 -> V=1.0, theta=0.0
% INFO    : Bus 25089	: V=0.9549026, theta=-55.244814 -> V=1.0, theta=0.0
% INFO    : Bus 25090	: V=0.9582523, theta=-57.12245 -> V=1.0, theta=0.0
% INFO    : Bus 25091	: V=0.9660006, theta=-54.463413 -> V=1.0, theta=0.0
% INFO    : Bus 25092	: V=0.9657041, theta=-54.528812 -> V=1.0, theta=0.0
% INFO    : Bus 25093	: V=0.9657657, theta=-54.52719 -> V=1.0, theta=0.0
% INFO    : Bus 25094	: V=0.965899, theta=-54.206384 -> V=1.0, theta=0.0
% INFO    : Bus 25095	: V=0.9661434, theta=-54.164521 -> V=1.0, theta=0.0
% INFO    : Bus 25096	: V=0.9661885, theta=-54.198947 -> V=1.0, theta=0.0
% INFO    : Bus 25097	: V=0.9664092, theta=-54.228085 -> V=1.0, theta=0.0
% INFO    : Bus 25098	: V=0.9678209, theta=-54.142354 -> V=1.0, theta=0.0
% INFO    : Bus 25099	: V=0.967172, theta=-54.154592 -> V=1.0, theta=0.0
% INFO    : Bus 25100	: V=0.966194, theta=-54.421061 -> V=1.0, theta=0.0
% INFO    : Bus 25101	: V=0.9674976, theta=-53.895751 -> V=1.0, theta=0.0
% INFO    : Bus 25102	: V=0.9647758, theta=-54.586925 -> V=1.0, theta=0.0
% INFO    : Bus 25103	: V=0.967832, theta=-53.882751 -> V=1.0, theta=0.0
% INFO    : Bus 25104	: V=0.9660725, theta=-54.503007 -> V=1.0, theta=0.0
% INFO    : Bus 25105	: V=0.9650449, theta=-54.620641 -> V=1.0, theta=0.0
% INFO    : Bus 25106	: V=0.9668219, theta=-54.457015 -> V=1.0, theta=0.0
% INFO    : Bus 25107	: V=0.9630335, theta=-55.018517 -> V=1.0, theta=0.0
% INFO    : Bus 25108	: V=0.9664627, theta=-54.270922 -> V=1.0, theta=0.0
% INFO    : Bus 25109	: V=0.9710288, theta=-54.014606 -> V=1.0, theta=0.0
% INFO    : Bus 25110	: V=0.9676493, theta=-53.853988 -> V=1.0, theta=0.0
% INFO    : Bus 25111	: V=0.9813703, theta=-51.829097 -> V=1.0, theta=0.0
% INFO    : Bus 25112	: V=0.9601752, theta=-54.60354 -> V=1.0, theta=0.0
% INFO    : Bus 25113	: V=0.9622009, theta=-55.17096 -> V=1.0, theta=0.0
% INFO    : Bus 25114	: V=0.9664525, theta=-54.423719 -> V=1.0, theta=0.0
% INFO    : Bus 25115	: V=0.9619374, theta=-55.218387 -> V=1.0, theta=0.0
% INFO    : Bus 25116	: V=0.9594927, theta=-55.558959 -> V=1.0, theta=0.0
% INFO    : Bus 25117	: V=0.9499605, theta=-55.998642 -> V=1.0, theta=0.0
% INFO    : Bus 25118	: V=0.9562765, theta=-55.976662 -> V=1.0, theta=0.0
% INFO    : Bus 25119	: V=0.9814376, theta=-52.072002 -> V=1.0, theta=0.0
% INFO    : Bus 25120	: V=0.9608764, theta=-55.389934 -> V=1.0, theta=0.0
% INFO    : Bus 25121	: V=0.9511042, theta=-55.554447 -> V=1.0, theta=0.0
% INFO    : Bus 25122	: V=0.9544139, theta=-55.298523 -> V=1.0, theta=0.0
% INFO    : Bus 25123	: V=0.9645827, theta=-54.370942 -> V=1.0, theta=0.0
% INFO    : Bus 25124	: V=0.9602305, theta=-54.514697 -> V=1.0, theta=0.0
% INFO    : Bus 25125	: V=0.9679571, theta=-53.293538 -> V=1.0, theta=0.0
% INFO    : Bus 25126	: V=0.9691529, theta=-53.370642 -> V=1.0, theta=0.0
% INFO    : Bus 25127	: V=0.9680133, theta=-53.728347 -> V=1.0, theta=0.0
% INFO    : Bus 25128	: V=0.9686877, theta=-53.512858 -> V=1.0, theta=0.0
% INFO    : Bus 25129	: V=0.968396, theta=-53.60298 -> V=1.0, theta=0.0
% INFO    : Bus 25130	: V=0.9698419, theta=-53.078485 -> V=1.0, theta=0.0
% INFO    : Bus 25131	: V=0.96016, theta=-54.441558 -> V=1.0, theta=0.0
% INFO    : Bus 25132	: V=0.9584348, theta=-54.052871 -> V=1.0, theta=0.0
% INFO    : Bus 25133	: V=0.966362, theta=-54.229868 -> V=1.0, theta=0.0
% INFO    : Bus 25134	: V=0.9663917, theta=-54.37583 -> V=1.0, theta=0.0
% INFO    : Bus 25135	: V=0.9903164, theta=-46.840788 -> V=1.0, theta=0.0
% INFO    : Bus 25136	: V=0.9893215, theta=-47.216569 -> V=1.0, theta=0.0
% INFO    : Bus 25137	: V=0.9885127, theta=-47.633368 -> V=1.0, theta=0.0
% INFO    : Bus 25138	: V=0.9902696, theta=-47.952207 -> V=1.0, theta=0.0
% INFO    : Bus 25139	: V=0.9865419, theta=-47.79009 -> V=1.0, theta=0.0
% INFO    : Bus 25140	: V=0.9839037, theta=-48.375116 -> V=1.0, theta=0.0
% INFO    : Bus 25141	: V=0.9854561, theta=-48.229858 -> V=1.0, theta=0.0
% INFO    : Bus 25142	: V=0.99053, theta=-47.831276 -> V=1.0, theta=0.0
% INFO    : Bus 25143	: V=0.9917876, theta=-47.45015 -> V=1.0, theta=0.0
% INFO    : Bus 25144	: V=0.9909874, theta=-47.686599 -> V=1.0, theta=0.0
% INFO    : Bus 25145	: V=0.9858456, theta=-48.131319 -> V=1.0, theta=0.0
% INFO    : Bus 25146	: V=0.9823084, theta=-48.502928 -> V=1.0, theta=0.0
% INFO    : Bus 25147	: V=0.9934047, theta=-47.174178 -> V=1.0, theta=0.0
% INFO    : Bus 25148	: V=0.9915004, theta=-47.579966 -> V=1.0, theta=0.0
% INFO    : Bus 25149	: V=0.9910472, theta=-47.683097 -> V=1.0, theta=0.0
% INFO    : Bus 25150	: V=0.9819593, theta=-48.152504 -> V=1.0, theta=0.0
% INFO    : Bus 25151	: V=0.9841064, theta=-47.375687 -> V=1.0, theta=0.0
% INFO    : Bus 25152	: V=0.9956095, theta=-45.544662 -> V=1.0, theta=0.0
% INFO    : Bus 25153	: V=0.9809692, theta=-47.251708 -> V=1.0, theta=0.0
% INFO    : Bus 25154	: V=0.9854948, theta=-47.159649 -> V=1.0, theta=0.0
% INFO    : Bus 25155	: V=0.9996936, theta=-45.864655 -> V=1.0, theta=0.0
% INFO    : Bus 25156	: V=1.0020066, theta=-45.42201 -> V=1.0, theta=0.0
% INFO    : Bus 25157	: V=1.0099819, theta=-44.506035 -> V=1.0, theta=0.0
% INFO    : Bus 25158	: V=0.9978776, theta=-46.295887 -> V=1.0, theta=0.0
% INFO    : Bus 25159	: V=0.993477, theta=-47.248099 -> V=1.0, theta=0.0
% INFO    : Bus 25160	: V=0.9969815, theta=-46.522663 -> V=1.0, theta=0.0
% INFO    : Bus 25161	: V=0.998855, theta=-46.266032 -> V=1.0, theta=0.0
% INFO    : Bus 25162	: V=0.9964391, theta=-46.6165 -> V=1.0, theta=0.0
% INFO    : Bus 25163	: V=0.9949611, theta=-46.610445 -> V=1.0, theta=0.0
% INFO    : Bus 25164	: V=1.0010929, theta=-46.036798 -> V=1.0, theta=0.0
% INFO    : Bus 25165	: V=0.9965543, theta=-46.642287 -> V=1.0, theta=0.0
% INFO    : Bus 25166	: V=0.9949893, theta=-46.905107 -> V=1.0, theta=0.0
% INFO    : Bus 25167	: V=1.0068119, theta=-44.491072 -> V=1.0, theta=0.0
% INFO    : Bus 25168	: V=1.0039909, theta=-45.073851 -> V=1.0, theta=0.0
% INFO    : Bus 25169	: V=1.0173489, theta=-42.802876 -> V=1.0, theta=0.0
% INFO    : Bus 25170	: V=1.0056279, theta=-44.09083 -> V=1.0, theta=0.0
% INFO    : Bus 25171	: V=1.0160262, theta=-42.466857 -> V=1.0, theta=0.0
% INFO    : Bus 25172	: V=0.9898757, theta=-45.72822 -> V=1.0, theta=0.0
% INFO    : Bus 25173	: V=0.9918217, theta=-45.400695 -> V=1.0, theta=0.0
% INFO    : Bus 25174	: V=1.0051772, theta=-42.897072 -> V=1.0, theta=0.0
% INFO    : Bus 25175	: V=0.9601676, theta=-50.145048 -> V=1.0, theta=0.0
% INFO    : Bus 25176	: V=0.9892782, theta=-47.97885 -> V=1.0, theta=0.0
% INFO    : Bus 25177	: V=0.9899562, theta=-47.609788 -> V=1.0, theta=0.0
% INFO    : Bus 25178	: V=0.9769099, theta=-49.223539 -> V=1.0, theta=0.0
% INFO    : Bus 25179	: V=0.9909379, theta=-47.244175 -> V=1.0, theta=0.0
% INFO    : Bus 25180	: V=0.9889419, theta=-47.704675 -> V=1.0, theta=0.0
% INFO    : Bus 25181	: V=0.9905529, theta=-47.053941 -> V=1.0, theta=0.0
% INFO    : Bus 25182	: V=0.9782703, theta=-48.198418 -> V=1.0, theta=0.0
% INFO    : Bus 25183	: V=0.9874557, theta=-47.206612 -> V=1.0, theta=0.0
% INFO    : Bus 25184	: V=0.9899753, theta=-49.050785 -> V=1.0, theta=0.0
% INFO    : Bus 25185	: V=0.9897446, theta=-48.748821 -> V=1.0, theta=0.0
% INFO    : Bus 25186	: V=0.9900418, theta=-48.715419 -> V=1.0, theta=0.0
% INFO    : Bus 25187	: V=0.9857037, theta=-49.238414 -> V=1.0, theta=0.0
% INFO    : Bus 25188	: V=0.9842283, theta=-50.492051 -> V=1.0, theta=0.0
% INFO    : Bus 25189	: V=0.9803769, theta=-50.934376 -> V=1.0, theta=0.0
% INFO    : Bus 25190	: V=0.9912604, theta=-48.56444 -> V=1.0, theta=0.0
% INFO    : Bus 25191	: V=0.9836778, theta=-51.15693 -> V=1.0, theta=0.0
% INFO    : Bus 25192	: V=0.9766849, theta=-52.176823 -> V=1.0, theta=0.0
% INFO    : Bus 25193	: V=0.9667294, theta=-51.6421 -> V=1.0, theta=0.0
% INFO    : Bus 25194	: V=0.9847778, theta=-49.96779 -> V=1.0, theta=0.0
% INFO    : Bus 25195	: V=0.9877964, theta=-49.212691 -> V=1.0, theta=0.0
% INFO    : Bus 25196	: V=0.9967561, theta=-46.385212 -> V=1.0, theta=0.0
% INFO    : Bus 25197	: V=0.998137, theta=-47.571216 -> V=1.0, theta=0.0
% INFO    : Bus 25198	: V=0.9955136, theta=-48.370361 -> V=1.0, theta=0.0
% INFO    : Bus 25199	: V=1.0004923, theta=-47.19839 -> V=1.0, theta=0.0
% INFO    : Bus 25200	: V=1.01528, theta=-43.898879 -> V=1.0, theta=0.0
% INFO    : Bus 25201	: V=1.0170449, theta=-43.605419 -> V=1.0, theta=0.0
% INFO    : Bus 25202	: V=1.0158653, theta=-43.801923 -> V=1.0, theta=0.0
% INFO    : Bus 25203	: V=1.0154132, theta=-43.87492 -> V=1.0, theta=0.0
% INFO    : Bus 25204	: V=1.0047174, theta=-45.848423 -> V=1.0, theta=0.0
% INFO    : Bus 25205	: V=1.0145677, theta=-44.009723 -> V=1.0, theta=0.0
% INFO    : Bus 25206	: V=1.0149002, theta=-43.956098 -> V=1.0, theta=0.0
% INFO    : Bus 25207	: V=1.0000057, theta=-46.680602 -> V=1.0, theta=0.0
% INFO    : Bus 25208	: V=1.007675, theta=-48.628167 -> V=1.0, theta=0.0
% INFO    : Bus 25209	: V=1.0037502, theta=-50.186372 -> V=1.0, theta=0.0
% INFO    : Bus 25210	: V=1.0074602, theta=-48.899767 -> V=1.0, theta=0.0
% INFO    : Bus 25211	: V=1.0189761, theta=-46.767697 -> V=1.0, theta=0.0
% INFO    : Bus 25212	: V=1.0130066, theta=-47.849792 -> V=1.0, theta=0.0
% INFO    : Bus 25213	: V=1.0147197, theta=-47.528438 -> V=1.0, theta=0.0
% INFO    : Bus 25214	: V=1.0147181, theta=-47.500931 -> V=1.0, theta=0.0
% INFO    : Bus 25215	: V=1.0160476, theta=-47.269275 -> V=1.0, theta=0.0
% INFO    : Bus 25216	: V=1.0128832, theta=-47.758525 -> V=1.0, theta=0.0
% INFO    : Bus 25217	: V=1.0094353, theta=-46.336913 -> V=1.0, theta=0.0
% INFO    : Bus 25218	: V=0.9663235, theta=-60.060812 -> V=1.0, theta=0.0
% INFO    : Bus 25219	: V=0.9593643, theta=-60.804234 -> V=1.0, theta=0.0
% INFO    : Bus 25220	: V=0.959552, theta=-61.087654 -> V=1.0, theta=0.0
% INFO    : Bus 25221	: V=0.9593265, theta=-61.168878 -> V=1.0, theta=0.0
% INFO    : Bus 25222	: V=0.9577275, theta=-61.24475 -> V=1.0, theta=0.0
% INFO    : Bus 25223	: V=0.965108, theta=-59.569021 -> V=1.0, theta=0.0
% INFO    : Bus 25224	: V=0.9682134, theta=-59.248194 -> V=1.0, theta=0.0
% INFO    : Bus 25225	: V=0.9715505, theta=-59.010954 -> V=1.0, theta=0.0
% INFO    : Bus 25226	: V=0.9725437, theta=-58.823098 -> V=1.0, theta=0.0
% INFO    : Bus 25227	: V=0.9837662, theta=-58.834477 -> V=1.0, theta=0.0
% INFO    : Bus 25228	: V=0.9829987, theta=-58.732169 -> V=1.0, theta=0.0
% INFO    : Bus 25229	: V=0.9806416, theta=-58.841937 -> V=1.0, theta=0.0
% INFO    : Bus 25230	: V=0.9738197, theta=-58.565091 -> V=1.0, theta=0.0
% INFO    : Bus 25231	: V=0.9871086, theta=-57.129304 -> V=1.0, theta=0.0
% INFO    : Bus 25232	: V=0.9892022, theta=-57.14799 -> V=1.0, theta=0.0
% INFO    : Bus 25233	: V=0.9902598, theta=-56.918708 -> V=1.0, theta=0.0
% INFO    : Bus 25234	: V=0.9889033, theta=-57.231555 -> V=1.0, theta=0.0
% INFO    : Bus 25235	: V=0.988934, theta=-57.151907 -> V=1.0, theta=0.0
% INFO    : Bus 25236	: V=0.9891735, theta=-57.066525 -> V=1.0, theta=0.0
% INFO    : Bus 25237	: V=0.9893924, theta=-57.001468 -> V=1.0, theta=0.0
% INFO    : Bus 25238	: V=0.989802, theta=-56.945601 -> V=1.0, theta=0.0
% INFO    : Bus 25239	: V=0.9878807, theta=-57.111215 -> V=1.0, theta=0.0
% INFO    : Bus 25240	: V=0.9948655, theta=-55.262153 -> V=1.0, theta=0.0
% INFO    : Bus 25241	: V=0.9887132, theta=-58.314495 -> V=1.0, theta=0.0
% INFO    : Bus 25242	: V=0.9879622, theta=-57.171667 -> V=1.0, theta=0.0
% INFO    : Bus 25243	: V=0.988325, theta=-57.111711 -> V=1.0, theta=0.0
% INFO    : Bus 25244	: V=0.9886396, theta=-57.057435 -> V=1.0, theta=0.0
% INFO    : Bus 25245	: V=0.9889429, theta=-57.007142 -> V=1.0, theta=0.0
% INFO    : Bus 25246	: V=0.989381, theta=-56.941253 -> V=1.0, theta=0.0
% INFO    : Bus 25247	: V=0.9902676, theta=-56.726958 -> V=1.0, theta=0.0
% INFO    : Bus 25248	: V=0.9909724, theta=-56.592 -> V=1.0, theta=0.0
% INFO    : Bus 25249	: V=0.994067, theta=-55.209383 -> V=1.0, theta=0.0
% INFO    : Bus 25250	: V=0.9867309, theta=-57.229359 -> V=1.0, theta=0.0
% INFO    : Bus 25251	: V=0.9857607, theta=-57.296145 -> V=1.0, theta=0.0
% INFO    : Bus 25252	: V=0.98902, theta=-57.025714 -> V=1.0, theta=0.0
% INFO    : Bus 25253	: V=0.9945368, theta=-55.246318 -> V=1.0, theta=0.0
% INFO    : Bus 25254	: V=0.9909688, theta=-56.738431 -> V=1.0, theta=0.0
% INFO    : Bus 25255	: V=0.9929297, theta=-56.362486 -> V=1.0, theta=0.0
% INFO    : Bus 25256	: V=0.9924707, theta=-56.391848 -> V=1.0, theta=0.0
% INFO    : Bus 25257	: V=0.992206, theta=-56.407997 -> V=1.0, theta=0.0
% INFO    : Bus 25258	: V=0.9935586, theta=-55.160651 -> V=1.0, theta=0.0
% INFO    : Bus 25259	: V=0.9919378, theta=-56.522494 -> V=1.0, theta=0.0
% INFO    : Bus 25260	: V=0.991742, theta=-56.499246 -> V=1.0, theta=0.0
% INFO    : Bus 25261	: V=0.9940439, theta=-55.216612 -> V=1.0, theta=0.0
% INFO    : Bus 25262	: V=0.9936982, theta=-55.103288 -> V=1.0, theta=0.0
% INFO    : Bus 25263	: V=0.9885368, theta=-57.072722 -> V=1.0, theta=0.0
% INFO    : Bus 25264	: V=0.9858129, theta=-57.387273 -> V=1.0, theta=0.0
% INFO    : Bus 25265	: V=0.9903023, theta=-56.679019 -> V=1.0, theta=0.0
% INFO    : Bus 25266	: V=0.9904152, theta=-56.637979 -> V=1.0, theta=0.0
% INFO    : Bus 25267	: V=0.9870504, theta=-57.306269 -> V=1.0, theta=0.0
% INFO    : Bus 25268	: V=0.99077, theta=-56.566609 -> V=1.0, theta=0.0
% INFO    : Bus 25269	: V=0.9863273, theta=-56.961536 -> V=1.0, theta=0.0
% INFO    : Bus 25270	: V=0.9860248, theta=-57.115648 -> V=1.0, theta=0.0
% INFO    : Bus 25271	: V=0.9843958, theta=-57.738066 -> V=1.0, theta=0.0
% INFO    : Bus 25272	: V=0.9850731, theta=-57.707097 -> V=1.0, theta=0.0
% INFO    : Bus 25273	: V=0.9868356, theta=-57.508253 -> V=1.0, theta=0.0
% INFO    : Bus 25274	: V=0.9861814, theta=-57.607745 -> V=1.0, theta=0.0
% INFO    : Bus 25275	: V=0.9856478, theta=-57.74979 -> V=1.0, theta=0.0
% INFO    : Bus 25276	: V=0.9857087, theta=-57.19097 -> V=1.0, theta=0.0
% INFO    : Bus 25277	: V=0.9861731, theta=-57.580123 -> V=1.0, theta=0.0
% INFO    : Bus 25278	: V=0.9862425, theta=-57.029983 -> V=1.0, theta=0.0
% INFO    : Bus 25279	: V=0.9865482, theta=-56.924711 -> V=1.0, theta=0.0
% INFO    : Bus 25280	: V=0.9845701, theta=-57.427414 -> V=1.0, theta=0.0
% INFO    : Bus 25281	: V=0.9860058, theta=-57.289285 -> V=1.0, theta=0.0
% INFO    : Bus 25282	: V=0.9949404, theta=-56.425009 -> V=1.0, theta=0.0
% INFO    : Bus 25283	: V=0.9983133, theta=-56.258213 -> V=1.0, theta=0.0
% INFO    : Bus 25284	: V=0.985314, theta=-57.142383 -> V=1.0, theta=0.0
% INFO    : Bus 25285	: V=0.9848626, theta=-57.17004 -> V=1.0, theta=0.0
% INFO    : Bus 25286	: V=0.9854242, theta=-57.133464 -> V=1.0, theta=0.0
% INFO    : Bus 25287	: V=0.9859007, theta=-57.097118 -> V=1.0, theta=0.0
% INFO    : Bus 25288	: V=0.9849654, theta=-57.113903 -> V=1.0, theta=0.0
% INFO    : Bus 25289	: V=0.9857925, theta=-56.80254 -> V=1.0, theta=0.0
% INFO    : Bus 25290	: V=0.9858922, theta=-56.789687 -> V=1.0, theta=0.0
% INFO    : Bus 25291	: V=0.9859652, theta=-56.770534 -> V=1.0, theta=0.0
% INFO    : Bus 25292	: V=0.9861121, theta=-56.73901 -> V=1.0, theta=0.0
% INFO    : Bus 25293	: V=1.0020829, theta=-55.977105 -> V=1.0, theta=0.0
% INFO    : Bus 25294	: V=0.9887675, theta=-56.654354 -> V=1.0, theta=0.0
% INFO    : Bus 25295	: V=0.9867106, theta=-56.930103 -> V=1.0, theta=0.0
% INFO    : Bus 25296	: V=0.9877044, theta=-56.856554 -> V=1.0, theta=0.0
% INFO    : Bus 25297	: V=1.0013714, theta=-56.013919 -> V=1.0, theta=0.0
% INFO    : Bus 25298	: V=0.9869201, theta=-56.892212 -> V=1.0, theta=0.0
% INFO    : Bus 25299	: V=0.9870421, theta=-56.855999 -> V=1.0, theta=0.0
% INFO    : Bus 25300	: V=0.986084, theta=-56.968928 -> V=1.0, theta=0.0
% INFO    : Bus 25301	: V=0.9861047, theta=-56.94593 -> V=1.0, theta=0.0
% INFO    : Bus 25302	: V=0.9854615, theta=-57.08778 -> V=1.0, theta=0.0
% INFO    : Bus 25303	: V=0.9857822, theta=-57.024431 -> V=1.0, theta=0.0
% INFO    : Bus 25304	: V=0.9850219, theta=-57.008995 -> V=1.0, theta=0.0
% INFO    : Bus 25305	: V=0.9848605, theta=-56.998375 -> V=1.0, theta=0.0
% INFO    : Bus 25306	: V=0.984459, theta=-57.068251 -> V=1.0, theta=0.0
% INFO    : Bus 25307	: V=0.9840722, theta=-57.109961 -> V=1.0, theta=0.0
% INFO    : Bus 25308	: V=0.9826987, theta=-57.14402 -> V=1.0, theta=0.0
% INFO    : Bus 25309	: V=0.98219, theta=-57.148814 -> V=1.0, theta=0.0
% INFO    : Bus 25310	: V=0.9837019, theta=-57.13004 -> V=1.0, theta=0.0
% INFO    : Bus 25311	: V=0.9834903, theta=-57.132069 -> V=1.0, theta=0.0
% INFO    : Bus 25312	: V=0.9821123, theta=-57.117436 -> V=1.0, theta=0.0
% INFO    : Bus 25313	: V=0.9844105, theta=-56.89317 -> V=1.0, theta=0.0
% INFO    : Bus 25314	: V=0.9860175, theta=-56.726081 -> V=1.0, theta=0.0
% INFO    : Bus 25315	: V=0.982088, theta=-57.117822 -> V=1.0, theta=0.0
% INFO    : Bus 25316	: V=0.9861577, theta=-56.710089 -> V=1.0, theta=0.0
% INFO    : Bus 25317	: V=0.9832587, theta=-56.994403 -> V=1.0, theta=0.0
% INFO    : Bus 25318	: V=0.9863395, theta=-56.687399 -> V=1.0, theta=0.0
% INFO    : Bus 25319	: V=0.983092, theta=-57.007667 -> V=1.0, theta=0.0
% INFO    : Bus 25320	: V=0.9865462, theta=-56.661551 -> V=1.0, theta=0.0
% INFO    : Bus 25321	: V=0.9867881, theta=-56.635692 -> V=1.0, theta=0.0
% INFO    : Bus 25322	: V=0.9860151, theta=-57.492778 -> V=1.0, theta=0.0
% INFO    : Bus 25323	: V=0.9854964, theta=-57.560826 -> V=1.0, theta=0.0
% INFO    : Bus 25324	: V=0.9877514, theta=-56.647039 -> V=1.0, theta=0.0
% INFO    : Bus 25325	: V=0.9873983, theta=-56.629799 -> V=1.0, theta=0.0
% INFO    : Bus 25326	: V=0.987127, theta=-56.607871 -> V=1.0, theta=0.0
% INFO    : Bus 25327	: V=0.9878669, theta=-56.765441 -> V=1.0, theta=0.0
% INFO    : Bus 25328	: V=0.9866772, theta=-56.688925 -> V=1.0, theta=0.0
% INFO    : Bus 25329	: V=0.9859896, theta=-56.71047 -> V=1.0, theta=0.0
% INFO    : Bus 25330	: V=0.9909314, theta=-55.519843 -> V=1.0, theta=0.0
% INFO    : Bus 25331	: V=0.9859296, theta=-56.669769 -> V=1.0, theta=0.0
% INFO    : Bus 25332	: V=0.9862931, theta=-56.43435 -> V=1.0, theta=0.0
% INFO    : Bus 25333	: V=0.99239, theta=-55.269988 -> V=1.0, theta=0.0
% INFO    : Bus 25334	: V=0.9918568, theta=-55.347042 -> V=1.0, theta=0.0
% INFO    : Bus 25335	: V=0.9903024, theta=-55.490617 -> V=1.0, theta=0.0
% INFO    : Bus 25336	: V=0.9932195, theta=-55.128884 -> V=1.0, theta=0.0
% INFO    : Bus 25337	: V=0.9913303, theta=-55.445523 -> V=1.0, theta=0.0
% INFO    : Bus 25338	: V=0.9881005, theta=-55.981561 -> V=1.0, theta=0.0
% INFO    : Bus 25339	: V=0.9856435, theta=-56.424012 -> V=1.0, theta=0.0
% INFO    : Bus 25340	: V=1.0070021, theta=-52.904966 -> V=1.0, theta=0.0
% INFO    : Bus 25341	: V=1.0071357, theta=-52.887768 -> V=1.0, theta=0.0
% INFO    : Bus 25342	: V=1.0068034, theta=-52.923173 -> V=1.0, theta=0.0
% INFO    : Bus 25343	: V=0.9925393, theta=-55.195896 -> V=1.0, theta=0.0
% INFO    : Bus 25344	: V=0.9867534, theta=-56.82832 -> V=1.0, theta=0.0
% INFO    : Bus 25345	: V=0.9858016, theta=-56.822877 -> V=1.0, theta=0.0
% INFO    : Bus 25346	: V=0.9855843, theta=-56.886046 -> V=1.0, theta=0.0
% INFO    : Bus 25347	: V=0.9853707, theta=-56.779196 -> V=1.0, theta=0.0
% INFO    : Bus 25348	: V=0.9844747, theta=-56.879779 -> V=1.0, theta=0.0
% INFO    : Bus 25349	: V=0.9854637, theta=-56.953749 -> V=1.0, theta=0.0
% INFO    : Bus 25350	: V=0.9831235, theta=-57.034812 -> V=1.0, theta=0.0
% INFO    : Bus 25351	: V=0.9823718, theta=-57.021714 -> V=1.0, theta=0.0
% INFO    : Bus 25352	: V=0.9839473, theta=-57.039389 -> V=1.0, theta=0.0
% INFO    : Bus 25353	: V=0.9817768, theta=-57.146748 -> V=1.0, theta=0.0
% INFO    : Bus 25354	: V=0.9815881, theta=-57.145243 -> V=1.0, theta=0.0
% INFO    : Bus 25355	: V=0.9840311, theta=-56.921571 -> V=1.0, theta=0.0
% INFO    : Bus 25356	: V=0.9809445, theta=-57.13317 -> V=1.0, theta=0.0
% INFO    : Bus 25357	: V=0.9807879, theta=-57.149793 -> V=1.0, theta=0.0
% INFO    : Bus 25358	: V=0.9802972, theta=-57.144164 -> V=1.0, theta=0.0
% INFO    : Bus 25359	: V=0.9806216, theta=-57.147711 -> V=1.0, theta=0.0
% INFO    : Bus 25360	: V=0.9817321, theta=-57.134464 -> V=1.0, theta=0.0
% INFO    : Bus 25361	: V=0.9808687, theta=-57.145336 -> V=1.0, theta=0.0
% INFO    : Bus 25362	: V=0.9811506, theta=-57.142416 -> V=1.0, theta=0.0
% INFO    : Bus 25363	: V=0.9783807, theta=-57.355104 -> V=1.0, theta=0.0
% INFO    : Bus 25364	: V=0.9818252, theta=-56.632039 -> V=1.0, theta=0.0
% INFO    : Bus 25365	: V=0.9824838, theta=-57.108016 -> V=1.0, theta=0.0
% INFO    : Bus 25366	: V=0.9854507, theta=-56.255019 -> V=1.0, theta=0.0
% INFO    : Bus 25367	: V=0.9813645, theta=-57.097414 -> V=1.0, theta=0.0
% INFO    : Bus 25368	: V=0.9806029, theta=-57.206149 -> V=1.0, theta=0.0
% INFO    : Bus 25369	: V=0.9912827, theta=-54.795878 -> V=1.0, theta=0.0
% INFO    : Bus 25370	: V=0.9794333, theta=-57.332853 -> V=1.0, theta=0.0
% INFO    : Bus 25371	: V=0.978283, theta=-57.374631 -> V=1.0, theta=0.0
% INFO    : Bus 25372	: V=0.9785135, theta=-57.371893 -> V=1.0, theta=0.0
% INFO    : Bus 25373	: V=0.9800825, theta=-57.289081 -> V=1.0, theta=0.0
% INFO    : Bus 25374	: V=0.980038, theta=-57.318283 -> V=1.0, theta=0.0
% INFO    : Bus 25375	: V=0.9852063, theta=-56.322082 -> V=1.0, theta=0.0
% INFO    : Bus 25376	: V=0.9836045, theta=-56.601996 -> V=1.0, theta=0.0
% INFO    : Bus 25377	: V=0.9839728, theta=-56.537964 -> V=1.0, theta=0.0
% INFO    : Bus 25378	: V=0.983152, theta=-56.687574 -> V=1.0, theta=0.0
% INFO    : Bus 25379	: V=0.9775579, theta=-57.439754 -> V=1.0, theta=0.0
% INFO    : Bus 25380	: V=0.9774076, theta=-57.46614 -> V=1.0, theta=0.0
% INFO    : Bus 25381	: V=0.9827961, theta=-56.752647 -> V=1.0, theta=0.0
% INFO    : Bus 25382	: V=0.9777888, theta=-57.534326 -> V=1.0, theta=0.0
% INFO    : Bus 25383	: V=0.9823754, theta=-56.8077 -> V=1.0, theta=0.0
% INFO    : Bus 25384	: V=0.9820989, theta=-56.846459 -> V=1.0, theta=0.0
% INFO    : Bus 25385	: V=0.9869267, theta=-58.883486 -> V=1.0, theta=0.0
% INFO    : Bus 25386	: V=0.9873024, theta=-58.866288 -> V=1.0, theta=0.0
% INFO    : Bus 25387	: V=0.9884722, theta=-57.404716 -> V=1.0, theta=0.0
% INFO    : Bus 25388	: V=0.996521, theta=-55.214754 -> V=1.0, theta=0.0
% INFO    : Bus 25389	: V=0.9888398, theta=-57.343771 -> V=1.0, theta=0.0
% INFO    : Bus 25390	: V=0.9871025, theta=-59.098632 -> V=1.0, theta=0.0
% INFO    : Bus 25391	: V=0.9875987, theta=-59.241388 -> V=1.0, theta=0.0
% INFO    : Bus 25392	: V=0.987534, theta=-59.03678 -> V=1.0, theta=0.0
% INFO    : Bus 25393	: V=0.9865406, theta=-58.400293 -> V=1.0, theta=0.0
% INFO    : Bus 25394	: V=0.9869035, theta=-59.283948 -> V=1.0, theta=0.0
% INFO    : Bus 25395	: V=0.9876366, theta=-58.837787 -> V=1.0, theta=0.0
% INFO    : Bus 25396	: V=0.9878028, theta=-58.667785 -> V=1.0, theta=0.0
% INFO    : Bus 25397	: V=0.9871459, theta=-59.017546 -> V=1.0, theta=0.0
% INFO    : Bus 25398	: V=0.9867492, theta=-59.142573 -> V=1.0, theta=0.0
% INFO    : Bus 25399	: V=0.9870349, theta=-58.816872 -> V=1.0, theta=0.0
% INFO    : Bus 25400	: V=0.9864252, theta=-58.390842 -> V=1.0, theta=0.0
% INFO    : Bus 25401	: V=0.9866615, theta=-58.350437 -> V=1.0, theta=0.0
% INFO    : Bus 25402	: V=0.9859068, theta=-56.312281 -> V=1.0, theta=0.0
% INFO    : Bus 25403	: V=0.9914689, theta=-54.767814 -> V=1.0, theta=0.0
% INFO    : Bus 25404	: V=1.0002531, theta=-57.02394 -> V=1.0, theta=0.0
% INFO    : Bus 25405	: V=0.9988811, theta=-57.265091 -> V=1.0, theta=0.0
% INFO    : Bus 25406	: V=0.9975759, theta=-57.491538 -> V=1.0, theta=0.0
% INFO    : Bus 25407	: V=0.9909768, theta=-58.818145 -> V=1.0, theta=0.0
% INFO    : Bus 25408	: V=0.9817319, theta=-56.75828 -> V=1.0, theta=0.0
% INFO    : Bus 25409	: V=0.9770468, theta=-57.180167 -> V=1.0, theta=0.0
% INFO    : Bus 25410	: V=0.9772369, theta=-57.130668 -> V=1.0, theta=0.0
% INFO    : Bus 25411	: V=0.9832769, theta=-57.265776 -> V=1.0, theta=0.0
% INFO    : Bus 25412	: V=0.9832773, theta=-57.343872 -> V=1.0, theta=0.0
% INFO    : Bus 25413	: V=0.9840295, theta=-57.226886 -> V=1.0, theta=0.0
% INFO    : Bus 25414	: V=0.9835784, theta=-57.314783 -> V=1.0, theta=0.0
% INFO    : Bus 25415	: V=0.9790125, theta=-58.066731 -> V=1.0, theta=0.0
% INFO    : Bus 25416	: V=0.9794398, theta=-57.193792 -> V=1.0, theta=0.0
% INFO    : Bus 25417	: V=0.9873066, theta=-58.505108 -> V=1.0, theta=0.0
% INFO    : Bus 25418	: V=0.9869242, theta=-59.346754 -> V=1.0, theta=0.0
% INFO    : Bus 25419	: V=0.9858476, theta=-59.46018 -> V=1.0, theta=0.0
% INFO    : Bus 25420	: V=0.9847951, theta=-59.570779 -> V=1.0, theta=0.0
% INFO    : Bus 25421	: V=0.9839421, theta=-59.655303 -> V=1.0, theta=0.0
% INFO    : Bus 25422	: V=0.9841258, theta=-59.595585 -> V=1.0, theta=0.0
% INFO    : Bus 25423	: V=0.9842832, theta=-57.922128 -> V=1.0, theta=0.0
% INFO    : Bus 25424	: V=0.9851413, theta=-57.30289 -> V=1.0, theta=0.0
% INFO    : Bus 25425	: V=0.9851851, theta=-56.421386 -> V=1.0, theta=0.0
% INFO    : Bus 25426	: V=0.9812349, theta=-58.473919 -> V=1.0, theta=0.0
% INFO    : Bus 25427	: V=0.9846669, theta=-58.759065 -> V=1.0, theta=0.0
% INFO    : Bus 25428	: V=0.9831734, theta=-58.649462 -> V=1.0, theta=0.0
% INFO    : Bus 25429	: V=0.9858746, theta=-56.382211 -> V=1.0, theta=0.0
% INFO    : Bus 25430	: V=0.984615, theta=-57.404383 -> V=1.0, theta=0.0
% INFO    : Bus 25431	: V=0.9847582, theta=-57.372876 -> V=1.0, theta=0.0
% INFO    : Bus 25432	: V=0.9849911, theta=-57.333131 -> V=1.0, theta=0.0
% INFO    : Bus 25433	: V=0.9883827, theta=-58.444858 -> V=1.0, theta=0.0
% INFO    : Bus 25434	: V=0.9827649, theta=-59.583237 -> V=1.0, theta=0.0
% INFO    : Bus 25435	: V=0.9857238, theta=-59.363517 -> V=1.0, theta=0.0
% INFO    : Bus 25436	: V=0.9843378, theta=-59.414016 -> V=1.0, theta=0.0
% INFO    : Bus 25437	: V=0.9887641, theta=-55.809079 -> V=1.0, theta=0.0
% INFO    : Bus 25438	: V=0.986959, theta=-58.279002 -> V=1.0, theta=0.0
% INFO    : Bus 25439	: V=0.9847989, theta=-56.508127 -> V=1.0, theta=0.0
% INFO    : Bus 25440	: V=0.983336, theta=-56.61864 -> V=1.0, theta=0.0
% INFO    : Bus 25441	: V=0.982247, theta=-56.658618 -> V=1.0, theta=0.0
% INFO    : Bus 25442	: V=0.9804543, theta=-56.768847 -> V=1.0, theta=0.0
% INFO    : Bus 25443	: V=0.9800235, theta=-56.770159 -> V=1.0, theta=0.0
% INFO    : Bus 25444	: V=0.9801063, theta=-57.031708 -> V=1.0, theta=0.0
% INFO    : Bus 25445	: V=0.9802475, theta=-56.937122 -> V=1.0, theta=0.0
% INFO    : Bus 25446	: V=0.9798232, theta=-57.018103 -> V=1.0, theta=0.0
% INFO    : Bus 25447	: V=0.9798011, theta=-56.895852 -> V=1.0, theta=0.0
% INFO    : Bus 25448	: V=0.9795293, theta=-56.976668 -> V=1.0, theta=0.0
% INFO    : Bus 25449	: V=0.981621, theta=-56.970468 -> V=1.0, theta=0.0
% INFO    : Bus 25450	: V=0.9809158, theta=-57.036955 -> V=1.0, theta=0.0
% INFO    : Bus 25451	: V=0.980792, theta=-57.063626 -> V=1.0, theta=0.0
% INFO    : Bus 25452	: V=0.9808411, theta=-57.108638 -> V=1.0, theta=0.0
% INFO    : Bus 25453	: V=0.9807427, theta=-57.087702 -> V=1.0, theta=0.0
% INFO    : Bus 25454	: V=0.9797007, theta=-57.087589 -> V=1.0, theta=0.0
% INFO    : Bus 25455	: V=0.9796182, theta=-57.087139 -> V=1.0, theta=0.0
% INFO    : Bus 25456	: V=0.9797111, theta=-57.060288 -> V=1.0, theta=0.0
% INFO    : Bus 25457	: V=0.9796003, theta=-57.081254 -> V=1.0, theta=0.0
% INFO    : Bus 25458	: V=0.985746, theta=-56.521858 -> V=1.0, theta=0.0
% INFO    : Bus 25459	: V=0.9855058, theta=-56.669078 -> V=1.0, theta=0.0
% INFO    : Bus 25460	: V=0.9852784, theta=-56.661891 -> V=1.0, theta=0.0
% INFO    : Bus 25461	: V=0.9851364, theta=-56.569124 -> V=1.0, theta=0.0
% INFO    : Bus 25462	: V=0.9915364, theta=-55.344927 -> V=1.0, theta=0.0
% INFO    : Bus 25463	: V=0.9847229, theta=-56.653206 -> V=1.0, theta=0.0
% INFO    : Bus 25464	: V=0.9850328, theta=-56.648957 -> V=1.0, theta=0.0
% INFO    : Bus 25465	: V=0.9849696, theta=-56.720554 -> V=1.0, theta=0.0
% INFO    : Bus 25466	: V=0.9814267, theta=-56.972776 -> V=1.0, theta=0.0
% INFO    : Bus 25467	: V=0.9844035, theta=-56.777963 -> V=1.0, theta=0.0
% INFO    : Bus 25468	: V=0.9850368, theta=-56.769654 -> V=1.0, theta=0.0
% INFO    : Bus 25469	: V=0.9981884, theta=-54.398591 -> V=1.0, theta=0.0
% INFO    : Bus 25470	: V=1.0086011, theta=-52.698561 -> V=1.0, theta=0.0
% INFO    : Bus 25471	: V=0.9986855, theta=-54.365744 -> V=1.0, theta=0.0
% INFO    : Bus 25472	: V=1.0094909, theta=-52.574001 -> V=1.0, theta=0.0
% INFO    : Bus 25473	: V=0.9965901, theta=-54.3732 -> V=1.0, theta=0.0
% INFO    : Bus 25474	: V=0.9969595, theta=-54.367848 -> V=1.0, theta=0.0
% INFO    : Bus 25475	: V=1.0102521, theta=-52.466196 -> V=1.0, theta=0.0
% INFO    : Bus 25476	: V=0.9940064, theta=-54.889129 -> V=1.0, theta=0.0
% INFO    : Bus 25477	: V=1.0081236, theta=-52.75837 -> V=1.0, theta=0.0
% INFO    : Bus 25478	: V=1.007879, theta=-52.788979 -> V=1.0, theta=0.0
% INFO    : Bus 25479	: V=1.0074904, theta=-52.831654 -> V=1.0, theta=0.0
% INFO    : Bus 25480	: V=0.9906432, theta=-55.222126 -> V=1.0, theta=0.0
% INFO    : Bus 25481	: V=0.9886709, theta=-55.895331 -> V=1.0, theta=0.0
% INFO    : Bus 25482	: V=0.9868298, theta=-56.058783 -> V=1.0, theta=0.0
% INFO    : Bus 25483	: V=0.990113, theta=-55.270118 -> V=1.0, theta=0.0
% INFO    : Bus 25484	: V=0.9880146, theta=-59.236047 -> V=1.0, theta=0.0
% INFO    : Bus 25485	: V=0.9890482, theta=-59.182401 -> V=1.0, theta=0.0
% INFO    : Bus 25486	: V=0.9867393, theta=-59.073515 -> V=1.0, theta=0.0
% INFO    : Bus 25487	: V=0.9885722, theta=-59.22996 -> V=1.0, theta=0.0
% INFO    : Bus 25488	: V=0.9882271, theta=-59.181479 -> V=1.0, theta=0.0
% INFO    : Bus 25489	: V=0.9852567, theta=-57.582926 -> V=1.0, theta=0.0
% INFO    : Bus 25490	: V=0.9852475, theta=-57.569942 -> V=1.0, theta=0.0
% INFO    : Bus 25491	: V=0.9854602, theta=-57.527999 -> V=1.0, theta=0.0
% INFO    : Bus 25492	: V=0.9848744, theta=-57.599126 -> V=1.0, theta=0.0
% INFO    : Bus 25493	: V=0.9859595, theta=-56.799197 -> V=1.0, theta=0.0
% INFO    : Bus 25494	: V=0.9841625, theta=-57.706282 -> V=1.0, theta=0.0
% INFO    : Bus 25495	: V=0.9917365, theta=-54.761444 -> V=1.0, theta=0.0
% INFO    : Bus 25496	: V=0.9845477, theta=-57.575817 -> V=1.0, theta=0.0
% INFO    : Bus 25497	: V=0.9851482, theta=-56.987323 -> V=1.0, theta=0.0
% INFO    : Bus 25498	: V=0.9825013, theta=-57.530345 -> V=1.0, theta=0.0
% INFO    : Bus 25499	: V=0.9899926, theta=-55.027075 -> V=1.0, theta=0.0
% INFO    : Bus 25500	: V=0.9797739, theta=-56.424365 -> V=1.0, theta=0.0
% INFO    : Bus 25501	: V=0.986357, theta=-56.965808 -> V=1.0, theta=0.0
% INFO    : Bus 25502	: V=0.9857764, theta=-57.183881 -> V=1.0, theta=0.0
% INFO    : Bus 25503	: V=0.9868204, theta=-58.800216 -> V=1.0, theta=0.0
% INFO    : Bus 25504	: V=0.9870092, theta=-58.792108 -> V=1.0, theta=0.0
% INFO    : Bus 25505	: V=0.9869812, theta=-58.74674 -> V=1.0, theta=0.0
% INFO    : Bus 25506	: V=0.987213, theta=-58.695887 -> V=1.0, theta=0.0
% INFO    : Bus 25507	: V=0.9879461, theta=-58.597106 -> V=1.0, theta=0.0
% INFO    : Bus 25508	: V=0.987966, theta=-58.506121 -> V=1.0, theta=0.0
% INFO    : Bus 25509	: V=0.9883701, theta=-58.490929 -> V=1.0, theta=0.0
% INFO    : Bus 25510	: V=0.9864812, theta=-58.894915 -> V=1.0, theta=0.0
% INFO    : Bus 25511	: V=0.9865399, theta=-58.85998 -> V=1.0, theta=0.0
% INFO    : Bus 25512	: V=0.9868708, theta=-58.803151 -> V=1.0, theta=0.0
% INFO    : Bus 25513	: V=0.9874915, theta=-58.762287 -> V=1.0, theta=0.0
% INFO    : Bus 25514	: V=0.9879967, theta=-57.523485 -> V=1.0, theta=0.0
% INFO    : Bus 25515	: V=0.9880788, theta=-57.511009 -> V=1.0, theta=0.0
% INFO    : Bus 25516	: V=0.9882783, theta=-57.4759 -> V=1.0, theta=0.0
% INFO    : Bus 25517	: V=0.9884802, theta=-57.428064 -> V=1.0, theta=0.0
% INFO    : Bus 25518	: V=0.9887304, theta=-57.359564 -> V=1.0, theta=0.0
% INFO    : Bus 25519	: V=0.9887121, theta=-57.328594 -> V=1.0, theta=0.0
% INFO    : Bus 25520	: V=0.988715, theta=-57.298505 -> V=1.0, theta=0.0
% INFO    : Bus 25521	: V=0.9888278, theta=-58.359818 -> V=1.0, theta=0.0
% INFO    : Bus 25522	: V=0.9786042, theta=-56.724661 -> V=1.0, theta=0.0
% INFO    : Bus 25523	: V=0.9778844, theta=-56.678489 -> V=1.0, theta=0.0
% INFO    : Bus 25524	: V=0.9810307, theta=-56.056377 -> V=1.0, theta=0.0
% INFO    : Bus 25525	: V=0.9814382, theta=-55.945041 -> V=1.0, theta=0.0
% INFO    : Bus 25526	: V=0.9837049, theta=-57.191451 -> V=1.0, theta=0.0
% INFO    : Bus 25527	: V=0.9844376, theta=-57.07114 -> V=1.0, theta=0.0
% INFO    : Bus 25528	: V=0.9790403, theta=-57.904984 -> V=1.0, theta=0.0
% INFO    : Bus 25529	: V=0.9852747, theta=-56.941906 -> V=1.0, theta=0.0
% INFO    : Bus 25530	: V=0.9837708, theta=-57.786743 -> V=1.0, theta=0.0
% INFO    : Bus 25531	: V=0.9832747, theta=-57.881334 -> V=1.0, theta=0.0
% INFO    : Bus 25532	: V=0.984478, theta=-57.138383 -> V=1.0, theta=0.0
% INFO    : Bus 25533	: V=0.978183, theta=-56.576869 -> V=1.0, theta=0.0
% INFO    : Bus 25534	: V=0.982612, theta=-55.705836 -> V=1.0, theta=0.0
% INFO    : Bus 25535	: V=0.9795069, theta=-56.417465 -> V=1.0, theta=0.0
% INFO    : Bus 25536	: V=0.981943, theta=-55.827267 -> V=1.0, theta=0.0
% INFO    : Bus 25537	: V=0.9740735, theta=-56.761007 -> V=1.0, theta=0.0
% INFO    : Bus 25538	: V=0.9849441, theta=-59.273355 -> V=1.0, theta=0.0
% INFO    : Bus 25539	: V=0.9865021, theta=-58.476541 -> V=1.0, theta=0.0
% INFO    : Bus 25540	: V=0.9827915, theta=-59.454414 -> V=1.0, theta=0.0
% INFO    : Bus 25541	: V=0.9815548, theta=-59.604828 -> V=1.0, theta=0.0
% INFO    : Bus 25542	: V=0.9822942, theta=-59.689737 -> V=1.0, theta=0.0
% INFO    : Bus 25543	: V=0.9932712, theta=-57.92826 -> V=1.0, theta=0.0
% INFO    : Bus 25544	: V=0.9926633, theta=-58.059719 -> V=1.0, theta=0.0
% INFO    : Bus 25545	: V=0.9915392, theta=-58.189689 -> V=1.0, theta=0.0
% INFO    : Bus 25546	: V=0.990858, theta=-58.824694 -> V=1.0, theta=0.0
% INFO    : Bus 25547	: V=0.9901244, theta=-59.062261 -> V=1.0, theta=0.0
% INFO    : Bus 25548	: V=0.9924628, theta=-58.536341 -> V=1.0, theta=0.0
% INFO    : Bus 25549	: V=0.9924203, theta=-58.06598 -> V=1.0, theta=0.0
% INFO    : Bus 25550	: V=0.9912914, theta=-58.773265 -> V=1.0, theta=0.0
% INFO    : Bus 25551	: V=0.9902512, theta=-58.304785 -> V=1.0, theta=0.0
% INFO    : Bus 25552	: V=0.989611, theta=-58.365531 -> V=1.0, theta=0.0
% INFO    : Bus 25553	: V=0.983319, theta=-58.113178 -> V=1.0, theta=0.0
% INFO    : Bus 25554	: V=0.9828296, theta=-59.020513 -> V=1.0, theta=0.0
% INFO    : Bus 25555	: V=0.9843937, theta=-57.738184 -> V=1.0, theta=0.0
% INFO    : Bus 25556	: V=0.9848705, theta=-57.569279 -> V=1.0, theta=0.0
% INFO    : Bus 25557	: V=0.9840573, theta=-58.179665 -> V=1.0, theta=0.0
% INFO    : Bus 25558	: V=0.9840696, theta=-57.998343 -> V=1.0, theta=0.0
% INFO    : Bus 25559	: V=0.9907196, theta=-58.216284 -> V=1.0, theta=0.0
% INFO    : Bus 25560	: V=0.986218, theta=-59.412722 -> V=1.0, theta=0.0
% INFO    : Bus 25561	: V=0.9888141, theta=-55.776186 -> V=1.0, theta=0.0
% INFO    : Bus 25562	: V=0.9845959, theta=-58.603691 -> V=1.0, theta=0.0
% INFO    : Bus 25563	: V=0.9854626, theta=-58.448668 -> V=1.0, theta=0.0
% INFO    : Bus 25564	: V=0.9860626, theta=-58.303566 -> V=1.0, theta=0.0
% INFO    : Bus 25565	: V=0.9863023, theta=-58.260552 -> V=1.0, theta=0.0
% INFO    : Bus 25566	: V=0.9861741, theta=-57.108103 -> V=1.0, theta=0.0
% INFO    : Bus 25567	: V=0.9862451, theta=-57.19166 -> V=1.0, theta=0.0
% INFO    : Bus 25568	: V=0.9863572, theta=-57.011821 -> V=1.0, theta=0.0
% INFO    : Bus 25569	: V=0.9853061, theta=-58.557265 -> V=1.0, theta=0.0
% INFO    : Bus 25570	: V=0.9857375, theta=-58.648624 -> V=1.0, theta=0.0
% INFO    : Bus 25571	: V=0.9858471, theta=-58.533304 -> V=1.0, theta=0.0
% INFO    : Bus 25572	: V=0.9861749, theta=-58.328751 -> V=1.0, theta=0.0
% INFO    : Bus 25573	: V=0.9866629, theta=-57.770669 -> V=1.0, theta=0.0
% INFO    : Bus 25574	: V=0.9856852, theta=-57.273163 -> V=1.0, theta=0.0
% INFO    : Bus 25575	: V=0.985402, theta=-58.504204 -> V=1.0, theta=0.0
% INFO    : Bus 25576	: V=0.9853938, theta=-57.375393 -> V=1.0, theta=0.0
% INFO    : Bus 25577	: V=0.9858573, theta=-58.461903 -> V=1.0, theta=0.0
% INFO    : Bus 25578	: V=0.9848203, theta=-59.251986 -> V=1.0, theta=0.0
% INFO    : Bus 25579	: V=0.9845995, theta=-57.871421 -> V=1.0, theta=0.0
% INFO    : Bus 25580	: V=0.9841574, theta=-57.961317 -> V=1.0, theta=0.0
% INFO    : Bus 25581	: V=0.9853738, theta=-57.665877 -> V=1.0, theta=0.0
% INFO    : Bus 25582	: V=0.9846136, theta=-58.671537 -> V=1.0, theta=0.0
% INFO    : Bus 25583	: V=0.9853675, theta=-59.15556 -> V=1.0, theta=0.0
% INFO    : Bus 25584	: V=0.9852503, theta=-58.714049 -> V=1.0, theta=0.0
% INFO    : Bus 25585	: V=0.9868315, theta=-58.335893 -> V=1.0, theta=0.0
% INFO    : Bus 25586	: V=0.9861418, theta=-58.851639 -> V=1.0, theta=0.0
% INFO    : Bus 25587	: V=0.9851448, theta=-59.079107 -> V=1.0, theta=0.0
% INFO    : Bus 25588	: V=0.9860969, theta=-58.429492 -> V=1.0, theta=0.0
% INFO    : Bus 25589	: V=0.9762887, theta=-57.262365 -> V=1.0, theta=0.0
% INFO    : Bus 25590	: V=0.9751398, theta=-57.279164 -> V=1.0, theta=0.0
% INFO    : Bus 25591	: V=0.9895301, theta=-55.200492 -> V=1.0, theta=0.0
% INFO    : Bus 25592	: V=0.9852048, theta=-56.033586 -> V=1.0, theta=0.0
% INFO    : Bus 25593	: V=0.9839363, theta=-56.067273 -> V=1.0, theta=0.0
% INFO    : Bus 25594	: V=0.9888792, theta=-59.018175 -> V=1.0, theta=0.0
% INFO    : Bus 25595	: V=0.9895203, theta=-58.909438 -> V=1.0, theta=0.0
% INFO    : Bus 25596	: V=0.9866301, theta=-58.953024 -> V=1.0, theta=0.0
% INFO    : Bus 25597	: V=0.9878574, theta=-59.022038 -> V=1.0, theta=0.0
% INFO    : Bus 25598	: V=0.9871675, theta=-56.183681 -> V=1.0, theta=0.0
% INFO    : Bus 25599	: V=0.9866619, theta=-56.900961 -> V=1.0, theta=0.0
% INFO    : Bus 25600	: V=0.9863331, theta=-57.033309 -> V=1.0, theta=0.0
% INFO    : Bus 25601	: V=0.985971, theta=-57.162834 -> V=1.0, theta=0.0
% INFO    : Bus 25602	: V=0.9799122, theta=-57.125439 -> V=1.0, theta=0.0
% INFO    : Bus 25603	: V=0.9784228, theta=-57.211171 -> V=1.0, theta=0.0
% INFO    : Bus 25604	: V=0.9757606, theta=-57.235834 -> V=1.0, theta=0.0
% INFO    : Bus 25605	: V=0.9816248, theta=-56.663695 -> V=1.0, theta=0.0
% INFO    : Bus 25606	: V=0.9817211, theta=-56.647246 -> V=1.0, theta=0.0
% INFO    : Bus 25607	: V=0.9769248, theta=-57.430953 -> V=1.0, theta=0.0
% INFO    : Bus 25608	: V=0.9776096, theta=-57.329097 -> V=1.0, theta=0.0
% INFO    : Bus 25609	: V=0.9778515, theta=-57.401441 -> V=1.0, theta=0.0
% INFO    : Bus 25610	: V=0.9774813, theta=-57.412524 -> V=1.0, theta=0.0
% INFO    : Bus 25611	: V=0.9770997, theta=-57.45539 -> V=1.0, theta=0.0
% INFO    : Bus 25612	: V=0.9772852, theta=-57.432731 -> V=1.0, theta=0.0
% INFO    : Bus 25613	: V=0.9774755, theta=-58.214135 -> V=1.0, theta=0.0
% INFO    : Bus 25614	: V=0.9925529, theta=-54.769564 -> V=1.0, theta=0.0
% INFO    : Bus 25615	: V=0.9775183, theta=-58.593864 -> V=1.0, theta=0.0
% INFO    : Bus 25616	: V=0.9786359, theta=-58.538529 -> V=1.0, theta=0.0
% INFO    : Bus 25617	: V=0.9808987, theta=-57.741101 -> V=1.0, theta=0.0
% INFO    : Bus 25618	: V=0.9812123, theta=-56.698962 -> V=1.0, theta=0.0
% INFO    : Bus 25619	: V=0.979613, theta=-56.766128 -> V=1.0, theta=0.0
% INFO    : Bus 25620	: V=0.9794289, theta=-56.811587 -> V=1.0, theta=0.0
% INFO    : Bus 25621	: V=0.9793781, theta=-56.748654 -> V=1.0, theta=0.0
% INFO    : Bus 25622	: V=0.9794516, theta=-56.93782 -> V=1.0, theta=0.0
% INFO    : Bus 25623	: V=0.9794082, theta=-56.875402 -> V=1.0, theta=0.0
% INFO    : Bus 25624	: V=0.980771, theta=-56.103111 -> V=1.0, theta=0.0
% INFO    : Bus 25625	: V=0.9827111, theta=-59.854051 -> V=1.0, theta=0.0
% INFO    : Bus 25626	: V=0.9806857, theta=-59.763859 -> V=1.0, theta=0.0
% INFO    : Bus 25627	: V=0.9833206, theta=-59.760727 -> V=1.0, theta=0.0
% INFO    : Bus 25628	: V=0.9804922, theta=-59.665523 -> V=1.0, theta=0.0
% INFO    : Bus 25629	: V=0.9820918, theta=-59.482314 -> V=1.0, theta=0.0
% INFO    : Bus 25630	: V=0.984945, theta=-58.314344 -> V=1.0, theta=0.0
% INFO    : Bus 25631	: V=0.9830703, theta=-59.890579 -> V=1.0, theta=0.0
% INFO    : Bus 25632	: V=0.982881, theta=-59.788362 -> V=1.0, theta=0.0
% INFO    : Bus 25633	: V=0.98432, theta=-59.593327 -> V=1.0, theta=0.0
% INFO    : Bus 25634	: V=0.9890695, theta=-55.801135 -> V=1.0, theta=0.0
% INFO    : Bus 25635	: V=0.9785705, theta=-57.085198 -> V=1.0, theta=0.0
% INFO    : Bus 25636	: V=0.9779546, theta=-57.201058 -> V=1.0, theta=0.0
% INFO    : Bus 25637	: V=0.9777576, theta=-57.186773 -> V=1.0, theta=0.0
% INFO    : Bus 25638	: V=0.9772404, theta=-57.213686 -> V=1.0, theta=0.0
% INFO    : Bus 25639	: V=0.9773749, theta=-57.485729 -> V=1.0, theta=0.0
% INFO    : Bus 25640	: V=0.9785016, theta=-57.734256 -> V=1.0, theta=0.0
% INFO    : Bus 25641	: V=0.980637, theta=-57.010112 -> V=1.0, theta=0.0
% INFO    : Bus 25642	: V=0.9804377, theta=-57.06391 -> V=1.0, theta=0.0
% INFO    : Bus 25643	: V=0.9798458, theta=-57.123656 -> V=1.0, theta=0.0
% INFO    : Bus 25644	: V=0.9963861, theta=-57.707295 -> V=1.0, theta=0.0
% INFO    : Bus 25645	: V=0.9958605, theta=-57.766364 -> V=1.0, theta=0.0
% INFO    : Bus 25646	: V=0.9944554, theta=-57.849056 -> V=1.0, theta=0.0
% INFO    : Bus 25647	: V=0.9935264, theta=-57.961032 -> V=1.0, theta=0.0
% INFO    : Bus 25648	: V=0.9981618, theta=-57.387018 -> V=1.0, theta=0.0
% INFO    : Bus 25649	: V=0.9961443, theta=-57.636512 -> V=1.0, theta=0.0
% INFO    : Bus 25650	: V=0.9919987, theta=-58.734758 -> V=1.0, theta=0.0
% INFO    : Bus 25651	: V=0.9878129, theta=-59.164209 -> V=1.0, theta=0.0
% INFO    : Bus 25652	: V=0.9903216, theta=-58.903563 -> V=1.0, theta=0.0
% INFO    : Bus 25653	: V=0.9921228, theta=-58.101886 -> V=1.0, theta=0.0
% INFO    : Bus 25654	: V=0.9871505, theta=-56.201019 -> V=1.0, theta=0.0
% INFO    : Bus 25655	: V=0.9866483, theta=-56.566993 -> V=1.0, theta=0.0
% INFO    : Bus 25656	: V=0.9841702, theta=-57.813766 -> V=1.0, theta=0.0
% INFO    : Bus 25657	: V=0.9785731, theta=-57.764003 -> V=1.0, theta=0.0
% INFO    : Bus 25658	: V=0.9766545, theta=-57.387905 -> V=1.0, theta=0.0
% INFO    : Bus 25659	: V=0.9829046, theta=-57.425546 -> V=1.0, theta=0.0
% INFO    : Bus 25660	: V=0.9854234, theta=-55.324309 -> V=1.0, theta=0.0
% INFO    : Bus 25661	: V=0.9805926, theta=-56.241417 -> V=1.0, theta=0.0
% INFO    : Bus 25662	: V=0.9766256, theta=-57.339087 -> V=1.0, theta=0.0
% INFO    : Bus 25663	: V=0.9749407, theta=-57.516888 -> V=1.0, theta=0.0
% INFO    : Bus 25664	: V=0.9829813, theta=-57.359461 -> V=1.0, theta=0.0
% INFO    : Bus 25665	: V=0.9773222, theta=-58.638843 -> V=1.0, theta=0.0
% INFO    : Bus 25666	: V=0.9757864, theta=-58.292596 -> V=1.0, theta=0.0
% INFO    : Bus 25667	: V=0.9736581, theta=-57.43674 -> V=1.0, theta=0.0
% INFO    : Bus 25668	: V=0.9810844, theta=-56.88391 -> V=1.0, theta=0.0
% INFO    : Bus 25669	: V=1.0046121, theta=-48.806665 -> V=1.0, theta=0.0
% INFO    : Bus 25670	: V=0.9969765, theta=-54.188939 -> V=1.0, theta=0.0
% INFO    : Bus 25671	: V=0.9734332, theta=-57.53174 -> V=1.0, theta=0.0
% INFO    : Bus 25672	: V=0.9871056, theta=-58.757941 -> V=1.0, theta=0.0
% INFO    : Bus 25673	: V=0.9838057, theta=-57.121659 -> V=1.0, theta=0.0
% INFO    : Bus 25674	: V=0.9924068, theta=-56.539322 -> V=1.0, theta=0.0
% INFO    : Bus 25675	: V=0.9880914, theta=-58.434539 -> V=1.0, theta=0.0
% INFO    : Bus 25676	: V=0.9880089, theta=-58.357443 -> V=1.0, theta=0.0
% INFO    : Bus 25677	: V=0.9770096, theta=-55.272619 -> V=1.0, theta=0.0
% INFO    : Bus 25678	: V=0.9670503, theta=-56.311236 -> V=1.0, theta=0.0
% INFO    : Bus 25679	: V=0.9815102, theta=-54.804422 -> V=1.0, theta=0.0
% INFO    : Bus 25680	: V=0.9729744, theta=-55.366183 -> V=1.0, theta=0.0
% INFO    : Bus 25681	: V=0.9771681, theta=-54.912646 -> V=1.0, theta=0.0
% INFO    : Bus 25682	: V=0.9767425, theta=-55.194191 -> V=1.0, theta=0.0
% INFO    : Bus 25683	: V=0.9872032, theta=-54.182268 -> V=1.0, theta=0.0
% INFO    : Bus 25684	: V=0.9898596, theta=-53.818974 -> V=1.0, theta=0.0
% INFO    : Bus 25685	: V=0.9893293, theta=-53.94129 -> V=1.0, theta=0.0
% INFO    : Bus 25686	: V=0.967286, theta=-54.222269 -> V=1.0, theta=0.0
% INFO    : Bus 25687	: V=0.9868304, theta=-53.385808 -> V=1.0, theta=0.0
% INFO    : Bus 25688	: V=0.9853716, theta=-52.868576 -> V=1.0, theta=0.0
% INFO    : Bus 25689	: V=1.0186912, theta=-52.943974 -> V=1.0, theta=0.0
% INFO    : Bus 25690	: V=0.9596173, theta=-58.428638 -> V=1.0, theta=0.0
% INFO    : Bus 25691	: V=0.9610784, theta=-59.177235 -> V=1.0, theta=0.0
% INFO    : Bus 25692	: V=0.9677247, theta=-58.089084 -> V=1.0, theta=0.0
% INFO    : Bus 25693	: V=1.0033886, theta=-54.812244 -> V=1.0, theta=0.0
% INFO    : Bus 25694	: V=1.0009264, theta=-54.983873 -> V=1.0, theta=0.0
% INFO    : Bus 25695	: V=0.9973373, theta=-55.385742 -> V=1.0, theta=0.0
% INFO    : Bus 25696	: V=1.0074031, theta=-54.191223 -> V=1.0, theta=0.0
% INFO    : Bus 25697	: V=0.9913846, theta=-55.224287 -> V=1.0, theta=0.0
% INFO    : Bus 25698	: V=0.9677587, theta=-55.720649 -> V=1.0, theta=0.0
% INFO    : Bus 25699	: V=0.9674054, theta=-55.773958 -> V=1.0, theta=0.0
% INFO    : Bus 25700	: V=0.9702717, theta=-56.191779 -> V=1.0, theta=0.0
% INFO    : Bus 25701	: V=0.9715908, theta=-56.085628 -> V=1.0, theta=0.0
% INFO    : Bus 25702	: V=0.9741556, theta=-54.881721 -> V=1.0, theta=0.0
% INFO    : Bus 25703	: V=0.9828668, theta=-53.298194 -> V=1.0, theta=0.0
% INFO    : Bus 25704	: V=0.968244, theta=-55.640282 -> V=1.0, theta=0.0
% INFO    : Bus 25705	: V=0.9648567, theta=-57.400649 -> V=1.0, theta=0.0
% INFO    : Bus 25706	: V=0.9646399, theta=-56.921537 -> V=1.0, theta=0.0
% INFO    : Bus 25707	: V=0.9677343, theta=-57.289352 -> V=1.0, theta=0.0
% INFO    : Bus 25708	: V=0.9667795, theta=-55.238488 -> V=1.0, theta=0.0
% INFO    : Bus 25709	: V=0.9617111, theta=-55.500349 -> V=1.0, theta=0.0
% INFO    : Bus 25710	: V=0.9737224, theta=-54.697789 -> V=1.0, theta=0.0
% INFO    : Bus 25711	: V=0.9644922, theta=-55.922331 -> V=1.0, theta=0.0
% INFO    : Bus 25712	: V=0.9681522, theta=-55.011974 -> V=1.0, theta=0.0
% INFO    : Bus 25713	: V=0.9696186, theta=-54.63182 -> V=1.0, theta=0.0
% INFO    : Bus 25714	: V=0.9661674, theta=-55.110297 -> V=1.0, theta=0.0
% INFO    : Bus 25715	: V=0.9642582, theta=-56.041617 -> V=1.0, theta=0.0
% INFO    : Bus 25716	: V=0.9615043, theta=-56.368493 -> V=1.0, theta=0.0
% INFO    : Bus 25717	: V=0.9717416, theta=-55.153953 -> V=1.0, theta=0.0
% INFO    : Bus 25718	: V=0.9665998, theta=-56.077717 -> V=1.0, theta=0.0
% INFO    : Bus 25719	: V=0.9654073, theta=-55.103053 -> V=1.0, theta=0.0
% INFO    : Bus 25720	: V=0.9623211, theta=-56.10714 -> V=1.0, theta=0.0
% INFO    : Bus 25721	: V=0.9608901, theta=-56.438034 -> V=1.0, theta=0.0
% INFO    : Bus 25722	: V=0.9622941, theta=-55.920957 -> V=1.0, theta=0.0
% INFO    : Bus 25723	: V=0.9609027, theta=-56.460783 -> V=1.0, theta=0.0
% INFO    : Bus 25724	: V=0.9612652, theta=-56.433193 -> V=1.0, theta=0.0
% INFO    : Bus 25725	: V=0.9577443, theta=-55.289949 -> V=1.0, theta=0.0
% INFO    : Bus 25726	: V=0.9625029, theta=-55.814268 -> V=1.0, theta=0.0
% INFO    : Bus 25727	: V=0.9802065, theta=-52.949965 -> V=1.0, theta=0.0
% INFO    : Bus 25728	: V=0.9670339, theta=-56.964692 -> V=1.0, theta=0.0
% INFO    : Bus 25729	: V=0.9814589, theta=-53.032191 -> V=1.0, theta=0.0
% INFO    : Bus 25730	: V=0.9688168, theta=-55.557146 -> V=1.0, theta=0.0
% INFO    : Bus 25731	: V=0.9628775, theta=-56.886235 -> V=1.0, theta=0.0
% INFO    : Bus 25732	: V=0.962683, theta=-55.343538 -> V=1.0, theta=0.0
% INFO    : Bus 25733	: V=1.0049182, theta=-55.338637 -> V=1.0, theta=0.0
% INFO    : Bus 25734	: V=1.0024511, theta=-55.419001 -> V=1.0, theta=0.0
% INFO    : Bus 25735	: V=0.9993224, theta=-55.505 -> V=1.0, theta=0.0
% INFO    : Bus 25736	: V=1.0120556, theta=-53.257248 -> V=1.0, theta=0.0
% INFO    : Bus 25737	: V=1.000194, theta=-54.922044 -> V=1.0, theta=0.0
% INFO    : Bus 25738	: V=0.9950226, theta=-54.152487 -> V=1.0, theta=0.0
% INFO    : Bus 25739	: V=0.9965932, theta=-54.764605 -> V=1.0, theta=0.0
% INFO    : Bus 25740	: V=0.9961776, theta=-54.715489 -> V=1.0, theta=0.0
% INFO    : Bus 25741	: V=1.010345, theta=-52.494832 -> V=1.0, theta=0.0
% INFO    : Bus 25742	: V=1.0033641, theta=-53.660941 -> V=1.0, theta=0.0
% INFO    : Bus 25743	: V=1.0028814, theta=-53.743076 -> V=1.0, theta=0.0
% INFO    : Bus 25744	: V=1.0026095, theta=-53.83804 -> V=1.0, theta=0.0
% INFO    : Bus 25745	: V=1.0103208, theta=-52.788641 -> V=1.0, theta=0.0
% INFO    : Bus 25746	: V=1.0019969, theta=-54.018656 -> V=1.0, theta=0.0
% INFO    : Bus 25747	: V=1.0108032, theta=-52.935193 -> V=1.0, theta=0.0
% INFO    : Bus 25748	: V=0.9999904, theta=-54.434065 -> V=1.0, theta=0.0
% INFO    : Bus 25749	: V=1.001073, theta=-53.731772 -> V=1.0, theta=0.0
% INFO    : Bus 25750	: V=0.9980743, theta=-54.902573 -> V=1.0, theta=0.0
% INFO    : Bus 25751	: V=0.9868039, theta=-48.766168 -> V=1.0, theta=0.0
% INFO    : Bus 25752	: V=0.9883975, theta=-48.376949 -> V=1.0, theta=0.0
% INFO    : Bus 25753	: V=0.9847825, theta=-49.19161 -> V=1.0, theta=0.0
% INFO    : Bus 25754	: V=0.9841803, theta=-49.325312 -> V=1.0, theta=0.0
% INFO    : Bus 25755	: V=0.9710032, theta=-51.328936 -> V=1.0, theta=0.0
% INFO    : Bus 25756	: V=0.97304, theta=-51.138087 -> V=1.0, theta=0.0
% INFO    : Bus 25757	: V=0.9758322, theta=-50.43353 -> V=1.0, theta=0.0
% INFO    : Bus 25758	: V=0.982059, theta=-48.961089 -> V=1.0, theta=0.0
% INFO    : Bus 25759	: V=0.9927483, theta=-47.447527 -> V=1.0, theta=0.0
% INFO    : Bus 25760	: V=0.971044, theta=-49.311485 -> V=1.0, theta=0.0
% INFO    : Bus 25761	: V=0.9937476, theta=-46.243274 -> V=1.0, theta=0.0
% INFO    : Bus 25762	: V=0.9928118, theta=-46.901076 -> V=1.0, theta=0.0
% INFO    : Bus 25763	: V=0.9782671, theta=-48.612789 -> V=1.0, theta=0.0
% INFO    : Bus 25764	: V=0.9836401, theta=-48.164183 -> V=1.0, theta=0.0
% INFO    : Bus 25765	: V=0.9762347, theta=-48.644529 -> V=1.0, theta=0.0
% INFO    : Bus 25766	: V=0.9842302, theta=-47.901835 -> V=1.0, theta=0.0
% INFO    : Bus 25767	: V=0.9783509, theta=-48.570353 -> V=1.0, theta=0.0
% INFO    : Bus 25768	: V=0.9784757, theta=-48.584246 -> V=1.0, theta=0.0
% INFO    : Bus 25769	: V=0.9790208, theta=-48.503631 -> V=1.0, theta=0.0
% INFO    : Bus 25770	: V=0.9851421, theta=-47.556818 -> V=1.0, theta=0.0
% INFO    : Bus 25771	: V=0.9923651, theta=-46.451471 -> V=1.0, theta=0.0
% INFO    : Bus 25772	: V=0.9816011, theta=-48.213988 -> V=1.0, theta=0.0
% INFO    : Bus 25773	: V=0.9612753, theta=-53.670293 -> V=1.0, theta=0.0
% INFO    : Bus 25774	: V=0.9668676, theta=-52.403884 -> V=1.0, theta=0.0
% INFO    : Bus 25775	: V=0.9614784, theta=-53.612533 -> V=1.0, theta=0.0
% INFO    : Bus 25776	: V=0.9703925, theta=-51.48143 -> V=1.0, theta=0.0
% INFO    : Bus 25777	: V=0.9723099, theta=-51.081316 -> V=1.0, theta=0.0
% INFO    : Bus 25778	: V=0.9705151, theta=-51.408388 -> V=1.0, theta=0.0
% INFO    : Bus 25779	: V=0.9825524, theta=-49.430181 -> V=1.0, theta=0.0
% INFO    : Bus 25780	: V=0.9792782, theta=-50.370426 -> V=1.0, theta=0.0
% INFO    : Bus 25781	: V=0.970004, theta=-49.702078 -> V=1.0, theta=0.0
% INFO    : Bus 25782	: V=0.971781, theta=-49.407898 -> V=1.0, theta=0.0
% INFO    : Bus 25783	: V=0.9842186, theta=-48.311013 -> V=1.0, theta=0.0
% INFO    : Bus 25784	: V=0.9864868, theta=-47.738033 -> V=1.0, theta=0.0
% INFO    : Bus 25785	: V=0.9950355, theta=-46.073744 -> V=1.0, theta=0.0
% INFO    : Bus 25786	: V=0.9618912, theta=-55.732949 -> V=1.0, theta=0.0
% INFO    : Bus 25787	: V=0.9624595, theta=-55.544366 -> V=1.0, theta=0.0
% INFO    : Bus 25788	: V=0.9619299, theta=-55.411054 -> V=1.0, theta=0.0
% INFO    : Bus 25789	: V=0.9622992, theta=-55.395402 -> V=1.0, theta=0.0
% INFO    : Bus 25790	: V=0.9642301, theta=-54.486653 -> V=1.0, theta=0.0
% INFO    : Bus 25791	: V=0.9641127, theta=-54.523522 -> V=1.0, theta=0.0
% INFO    : Bus 25792	: V=0.9642555, theta=-54.470884 -> V=1.0, theta=0.0
% INFO    : Bus 25793	: V=0.9618609, theta=-55.356985 -> V=1.0, theta=0.0
% INFO    : Bus 25794	: V=0.9644844, theta=-54.421646 -> V=1.0, theta=0.0
% INFO    : Bus 25795	: V=0.9647261, theta=-54.373811 -> V=1.0, theta=0.0
% INFO    : Bus 25796	: V=0.9649535, theta=-54.328777 -> V=1.0, theta=0.0
% INFO    : Bus 25797	: V=0.9626221, theta=-54.781505 -> V=1.0, theta=0.0
% INFO    : Bus 25798	: V=0.9632468, theta=-54.765874 -> V=1.0, theta=0.0
% INFO    : Bus 25799	: V=0.9649028, theta=-54.290659 -> V=1.0, theta=0.0
% INFO    : Bus 25800	: V=0.9643965, theta=-54.432652 -> V=1.0, theta=0.0
% INFO    : Bus 25801	: V=0.9636587, theta=-54.810849 -> V=1.0, theta=0.0
% INFO    : Bus 25802	: V=0.964652, theta=-54.365329 -> V=1.0, theta=0.0
% INFO    : Bus 25803	: V=0.9633568, theta=-54.805495 -> V=1.0, theta=0.0
% INFO    : Bus 25804	: V=0.9652535, theta=-54.272858 -> V=1.0, theta=0.0
% INFO    : Bus 25805	: V=0.962754, theta=-54.771751 -> V=1.0, theta=0.0
% INFO    : Bus 25806	: V=0.9630385, theta=-54.749952 -> V=1.0, theta=0.0
% INFO    : Bus 25807	: V=0.9668527, theta=-54.167289 -> V=1.0, theta=0.0
% INFO    : Bus 25808	: V=0.9655961, theta=-54.213077 -> V=1.0, theta=0.0
% INFO    : Bus 25809	: V=0.9659667, theta=-54.153875 -> V=1.0, theta=0.0
% INFO    : Bus 25810	: V=0.9641539, theta=-54.682067 -> V=1.0, theta=0.0
% INFO    : Bus 25811	: V=0.9652876, theta=-54.190819 -> V=1.0, theta=0.0
% INFO    : Bus 25812	: V=0.9665422, theta=-54.065631 -> V=1.0, theta=0.0
% INFO    : Bus 25813	: V=0.9637884, theta=-54.773448 -> V=1.0, theta=0.0
% INFO    : Bus 25814	: V=0.9612722, theta=-54.884278 -> V=1.0, theta=0.0
% INFO    : Bus 25815	: V=0.9616902, theta=-54.872628 -> V=1.0, theta=0.0
% INFO    : Bus 25816	: V=0.9634321, theta=-54.730541 -> V=1.0, theta=0.0
% INFO    : Bus 25817	: V=0.9681145, theta=-53.958395 -> V=1.0, theta=0.0
% INFO    : Bus 25818	: V=0.9621416, theta=-54.790399 -> V=1.0, theta=0.0
% INFO    : Bus 25819	: V=0.9630824, theta=-54.756859 -> V=1.0, theta=0.0
% INFO    : Bus 25820	: V=0.9677135, theta=-53.836424 -> V=1.0, theta=0.0
% INFO    : Bus 25821	: V=0.9656568, theta=-54.097582 -> V=1.0, theta=0.0
% INFO    : Bus 25822	: V=0.9660532, theta=-53.937922 -> V=1.0, theta=0.0
% INFO    : Bus 25823	: V=0.9663473, theta=-53.875867 -> V=1.0, theta=0.0
% INFO    : Bus 25824	: V=0.9663281, theta=-54.43285 -> V=1.0, theta=0.0
% INFO    : Bus 25825	: V=0.9622192, theta=-54.567575 -> V=1.0, theta=0.0
% INFO    : Bus 25826	: V=0.9624565, theta=-54.559802 -> V=1.0, theta=0.0
% INFO    : Bus 25827	: V=0.9626062, theta=-54.556552 -> V=1.0, theta=0.0
% INFO    : Bus 25828	: V=0.9622784, theta=-54.546925 -> V=1.0, theta=0.0
% INFO    : Bus 25829	: V=0.9673617, theta=-53.83498 -> V=1.0, theta=0.0
% INFO    : Bus 25830	: V=0.9623226, theta=-54.481911 -> V=1.0, theta=0.0
% INFO    : Bus 25831	: V=0.9650598, theta=-54.156853 -> V=1.0, theta=0.0
% INFO    : Bus 25832	: V=0.9643227, theta=-54.423673 -> V=1.0, theta=0.0
% INFO    : Bus 25833	: V=0.9659899, theta=-54.02219 -> V=1.0, theta=0.0
% INFO    : Bus 25834	: V=0.9740452, theta=-52.313987 -> V=1.0, theta=0.0
% INFO    : Bus 25835	: V=0.9678873, theta=-53.868726 -> V=1.0, theta=0.0
% INFO    : Bus 25836	: V=0.9663923, theta=-53.940812 -> V=1.0, theta=0.0
% INFO    : Bus 25837	: V=0.9666036, theta=-53.827653 -> V=1.0, theta=0.0
% INFO    : Bus 25838	: V=0.9667321, theta=-53.875335 -> V=1.0, theta=0.0
% INFO    : Bus 25839	: V=0.9680203, theta=-53.724268 -> V=1.0, theta=0.0
% INFO    : Bus 25840	: V=0.9627477, theta=-54.568024 -> V=1.0, theta=0.0
% INFO    : Bus 25841	: V=0.9750251, theta=-52.380326 -> V=1.0, theta=0.0
% INFO    : Bus 25842	: V=0.9656223, theta=-54.175665 -> V=1.0, theta=0.0
% INFO    : Bus 25843	: V=0.9701277, theta=-53.501575 -> V=1.0, theta=0.0
% INFO    : Bus 25844	: V=0.9667788, theta=-54.105388 -> V=1.0, theta=0.0
% INFO    : Bus 25845	: V=0.9661701, theta=-54.145241 -> V=1.0, theta=0.0
% INFO    : Bus 25846	: V=0.9695962, theta=-53.523785 -> V=1.0, theta=0.0
% INFO    : Bus 25847	: V=0.9692339, theta=-53.529125 -> V=1.0, theta=0.0
% INFO    : Bus 25848	: V=0.9644356, theta=-54.265245 -> V=1.0, theta=0.0
% INFO    : Bus 25849	: V=0.9627632, theta=-54.520388 -> V=1.0, theta=0.0
% INFO    : Bus 25850	: V=0.9635255, theta=-54.422053 -> V=1.0, theta=0.0
% INFO    : Bus 25851	: V=0.9680388, theta=-53.675596 -> V=1.0, theta=0.0
% INFO    : Bus 25852	: V=0.9671938, theta=-53.786201 -> V=1.0, theta=0.0
% INFO    : Bus 25853	: V=0.9669397, theta=-53.773486 -> V=1.0, theta=0.0
% INFO    : Bus 25854	: V=0.9671702, theta=-53.736928 -> V=1.0, theta=0.0
% INFO    : Bus 25855	: V=0.9675334, theta=-53.68003 -> V=1.0, theta=0.0
% INFO    : Bus 25856	: V=0.9678011, theta=-53.675609 -> V=1.0, theta=0.0
% INFO    : Bus 25857	: V=0.9682068, theta=-53.575155 -> V=1.0, theta=0.0
% INFO    : Bus 25858	: V=0.9682261, theta=-53.624393 -> V=1.0, theta=0.0
% INFO    : Bus 25859	: V=0.9649446, theta=-54.366465 -> V=1.0, theta=0.0
% INFO    : Bus 25860	: V=0.9685945, theta=-53.510817 -> V=1.0, theta=0.0
% INFO    : Bus 25861	: V=0.9683421, theta=-53.543813 -> V=1.0, theta=0.0
% INFO    : Bus 25862	: V=0.9685914, theta=-53.495175 -> V=1.0, theta=0.0
% INFO    : Bus 25863	: V=0.9688599, theta=-53.445219 -> V=1.0, theta=0.0
% INFO    : Bus 25864	: V=0.968647, theta=-54.163922 -> V=1.0, theta=0.0
% INFO    : Bus 25865	: V=0.9785456, theta=-52.66075 -> V=1.0, theta=0.0
% INFO    : Bus 25866	: V=0.969106, theta=-54.614262 -> V=1.0, theta=0.0
% INFO    : Bus 25867	: V=0.9697861, theta=-54.268638 -> V=1.0, theta=0.0
% INFO    : Bus 25868	: V=0.9625032, theta=-55.492019 -> V=1.0, theta=0.0
% INFO    : Bus 25869	: V=0.9647305, theta=-55.184624 -> V=1.0, theta=0.0
% INFO    : Bus 25870	: V=0.9744611, theta=-52.517302 -> V=1.0, theta=0.0
% INFO    : Bus 25871	: V=0.9690739, theta=-54.388655 -> V=1.0, theta=0.0
% INFO    : Bus 25872	: V=0.9618273, theta=-55.700168 -> V=1.0, theta=0.0
% INFO    : Bus 25873	: V=0.9622618, theta=-55.624743 -> V=1.0, theta=0.0
% INFO    : Bus 25874	: V=0.9615897, theta=-55.752174 -> V=1.0, theta=0.0
% INFO    : Bus 25875	: V=0.9676441, theta=-54.636976 -> V=1.0, theta=0.0
% INFO    : Bus 25876	: V=0.9680805, theta=-54.553708 -> V=1.0, theta=0.0
% INFO    : Bus 25877	: V=0.967674, theta=-54.74056 -> V=1.0, theta=0.0
% INFO    : Bus 25878	: V=0.9673924, theta=-54.743056 -> V=1.0, theta=0.0
% INFO    : Bus 25879	: V=0.967433, theta=-54.70168 -> V=1.0, theta=0.0
% INFO    : Bus 25880	: V=0.9665055, theta=-54.703448 -> V=1.0, theta=0.0
% INFO    : Bus 25881	: V=0.9664954, theta=-54.777533 -> V=1.0, theta=0.0
% INFO    : Bus 25882	: V=0.9634949, theta=-55.579075 -> V=1.0, theta=0.0
% INFO    : Bus 25883	: V=0.9671464, theta=-54.7641 -> V=1.0, theta=0.0
% INFO    : Bus 25884	: V=0.9668516, theta=-54.772515 -> V=1.0, theta=0.0
% INFO    : Bus 25885	: V=0.9684863, theta=-54.479345 -> V=1.0, theta=0.0
% INFO    : Bus 25886	: V=0.9668835, theta=-54.60128 -> V=1.0, theta=0.0
% INFO    : Bus 25887	: V=0.9630614, theta=-55.235943 -> V=1.0, theta=0.0
% INFO    : Bus 25888	: V=0.9745639, theta=-52.488888 -> V=1.0, theta=0.0
% INFO    : Bus 25889	: V=0.9683428, theta=-53.953055 -> V=1.0, theta=0.0
% INFO    : Bus 25890	: V=0.9682008, theta=-53.959189 -> V=1.0, theta=0.0
% INFO    : Bus 25891	: V=0.9615072, theta=-55.827079 -> V=1.0, theta=0.0
% INFO    : Bus 25892	: V=0.9626454, theta=-55.752222 -> V=1.0, theta=0.0
% INFO    : Bus 25893	: V=0.9639712, theta=-55.027017 -> V=1.0, theta=0.0
% INFO    : Bus 25894	: V=0.9618052, theta=-55.788424 -> V=1.0, theta=0.0
% INFO    : Bus 25895	: V=0.9620593, theta=-55.737807 -> V=1.0, theta=0.0
% INFO    : Bus 25896	: V=0.9620164, theta=-55.750659 -> V=1.0, theta=0.0
% INFO    : Bus 25897	: V=0.9611602, theta=-55.843574 -> V=1.0, theta=0.0
% INFO    : Bus 25898	: V=0.9636884, theta=-54.902922 -> V=1.0, theta=0.0
% INFO    : Bus 25899	: V=0.9636782, theta=-54.844584 -> V=1.0, theta=0.0
% INFO    : Bus 25900	: V=0.9637272, theta=-54.75717 -> V=1.0, theta=0.0
% INFO    : Bus 25901	: V=0.9643708, theta=-55.222891 -> V=1.0, theta=0.0
% INFO    : Bus 25902	: V=0.9648164, theta=-55.109625 -> V=1.0, theta=0.0
% INFO    : Bus 25903	: V=0.9652071, theta=-55.006638 -> V=1.0, theta=0.0
% INFO    : Bus 25904	: V=0.9614525, theta=-55.972834 -> V=1.0, theta=0.0
% INFO    : Bus 25905	: V=0.9608551, theta=-55.990091 -> V=1.0, theta=0.0
% INFO    : Bus 25906	: V=0.9620732, theta=-55.956294 -> V=1.0, theta=0.0
% INFO    : Bus 25907	: V=0.9638577, theta=-55.339653 -> V=1.0, theta=0.0
% INFO    : Bus 25908	: V=0.9614381, theta=-55.76731 -> V=1.0, theta=0.0
% INFO    : Bus 25909	: V=0.9616721, theta=-56.093209 -> V=1.0, theta=0.0
% INFO    : Bus 25910	: V=0.962823, theta=-55.63275 -> V=1.0, theta=0.0
% INFO    : Bus 25911	: V=0.9618814, theta=-55.683543 -> V=1.0, theta=0.0
% INFO    : Bus 25912	: V=0.9630912, theta=-56.102186 -> V=1.0, theta=0.0
% INFO    : Bus 25913	: V=0.9603434, theta=-55.937077 -> V=1.0, theta=0.0
% INFO    : Bus 25914	: V=0.9622229, theta=-56.1854 -> V=1.0, theta=0.0
% INFO    : Bus 25915	: V=0.9631989, theta=-55.232366 -> V=1.0, theta=0.0
% INFO    : Bus 25916	: V=0.9618057, theta=-56.21223 -> V=1.0, theta=0.0
% INFO    : Bus 25917	: V=0.9632684, theta=-55.244875 -> V=1.0, theta=0.0
% INFO    : Bus 25918	: V=0.9634419, theta=-55.136692 -> V=1.0, theta=0.0
% INFO    : Bus 25919	: V=0.9630588, theta=-55.476389 -> V=1.0, theta=0.0
% INFO    : Bus 25920	: V=0.96314, theta=-55.375002 -> V=1.0, theta=0.0
% INFO    : Bus 25921	: V=0.9609863, theta=-55.845825 -> V=1.0, theta=0.0
% INFO    : Bus 25922	: V=0.9608198, theta=-55.653973 -> V=1.0, theta=0.0
% INFO    : Bus 25923	: V=0.9621745, theta=-55.641335 -> V=1.0, theta=0.0
% INFO    : Bus 25924	: V=0.9625175, theta=-55.579416 -> V=1.0, theta=0.0
% INFO    : Bus 25925	: V=0.9609077, theta=-55.786627 -> V=1.0, theta=0.0
% INFO    : Bus 25926	: V=0.9619842, theta=-55.585705 -> V=1.0, theta=0.0
% INFO    : Bus 25927	: V=0.9624853, theta=-55.259241 -> V=1.0, theta=0.0
% INFO    : Bus 25928	: V=0.9616506, theta=-55.652174 -> V=1.0, theta=0.0
% INFO    : Bus 25929	: V=0.9620068, theta=-54.082138 -> V=1.0, theta=0.0
% INFO    : Bus 25930	: V=0.9626659, theta=-55.251834 -> V=1.0, theta=0.0
% INFO    : Bus 25931	: V=0.9603463, theta=-55.448897 -> V=1.0, theta=0.0
% INFO    : Bus 25932	: V=0.9593934, theta=-55.747853 -> V=1.0, theta=0.0
% INFO    : Bus 25933	: V=0.9624831, theta=-53.90356 -> V=1.0, theta=0.0
% INFO    : Bus 25934	: V=0.9637753, theta=-55.334207 -> V=1.0, theta=0.0
% INFO    : Bus 25935	: V=0.9635656, theta=-53.539376 -> V=1.0, theta=0.0
% INFO    : Bus 25936	: V=0.9649816, theta=-53.050711 -> V=1.0, theta=0.0
% INFO    : Bus 25937	: V=0.9644086, theta=-53.286726 -> V=1.0, theta=0.0
% INFO    : Bus 25938	: V=0.964409, theta=-54.67223 -> V=1.0, theta=0.0
% INFO    : Bus 25939	: V=0.9640295, theta=-55.249469 -> V=1.0, theta=0.0
% INFO    : Bus 25940	: V=0.9639813, theta=-55.266646 -> V=1.0, theta=0.0
% INFO    : Bus 25941	: V=0.9639295, theta=-55.268892 -> V=1.0, theta=0.0
% INFO    : Bus 25942	: V=0.9602064, theta=-55.575928 -> V=1.0, theta=0.0
% INFO    : Bus 25943	: V=0.9592185, theta=-55.614339 -> V=1.0, theta=0.0
% INFO    : Bus 25944	: V=0.9661919, theta=-53.935645 -> V=1.0, theta=0.0
% INFO    : Bus 25945	: V=0.965372, theta=-54.618115 -> V=1.0, theta=0.0
% INFO    : Bus 25946	: V=0.9648552, theta=-54.723251 -> V=1.0, theta=0.0
% INFO    : Bus 25947	: V=0.9637973, theta=-54.937057 -> V=1.0, theta=0.0
% INFO    : Bus 25948	: V=0.9635581, theta=-54.990773 -> V=1.0, theta=0.0
% INFO    : Bus 25949	: V=0.9640663, theta=-54.88244 -> V=1.0, theta=0.0
% INFO    : Bus 25950	: V=0.9644361, theta=-54.808697 -> V=1.0, theta=0.0
% INFO    : Bus 25951	: V=0.9637685, theta=-55.077059 -> V=1.0, theta=0.0
% INFO    : Bus 25952	: V=0.9644491, theta=-54.560284 -> V=1.0, theta=0.0
% INFO    : Bus 25953	: V=0.9670452, theta=-53.881283 -> V=1.0, theta=0.0
% INFO    : Bus 25954	: V=0.9725096, theta=-52.642499 -> V=1.0, theta=0.0
% INFO    : Bus 25955	: V=0.9726261, theta=-52.616978 -> V=1.0, theta=0.0
% INFO    : Bus 25956	: V=0.9638191, theta=-54.691665 -> V=1.0, theta=0.0
% INFO    : Bus 25957	: V=0.9639495, theta=-54.625269 -> V=1.0, theta=0.0
% INFO    : Bus 25958	: V=0.9634362, theta=-55.44833 -> V=1.0, theta=0.0
% INFO    : Bus 25959	: V=0.9653603, theta=-54.388933 -> V=1.0, theta=0.0
% INFO    : Bus 25960	: V=0.9615959, theta=-55.307834 -> V=1.0, theta=0.0
% INFO    : Bus 25961	: V=0.9613882, theta=-55.077539 -> V=1.0, theta=0.0
% INFO    : Bus 25962	: V=0.9649729, theta=-55.240671 -> V=1.0, theta=0.0
% INFO    : Bus 25963	: V=0.9696727, theta=-53.99328 -> V=1.0, theta=0.0
% INFO    : Bus 25964	: V=0.9666472, theta=-54.926302 -> V=1.0, theta=0.0
% INFO    : Bus 25965	: V=0.9713149, theta=-53.662247 -> V=1.0, theta=0.0
% INFO    : Bus 25966	: V=0.9697994, theta=-53.898323 -> V=1.0, theta=0.0
% INFO    : Bus 25967	: V=0.9663651, theta=-55.006409 -> V=1.0, theta=0.0
% INFO    : Bus 25968	: V=0.9687405, theta=-54.173067 -> V=1.0, theta=0.0
% INFO    : Bus 25969	: V=0.9680462, theta=-54.261077 -> V=1.0, theta=0.0
% INFO    : Bus 25970	: V=0.9778272, theta=-52.256398 -> V=1.0, theta=0.0
% INFO    : Bus 25971	: V=0.9637347, theta=-54.383417 -> V=1.0, theta=0.0
% INFO    : Bus 25972	: V=0.9650693, theta=-54.224614 -> V=1.0, theta=0.0
% INFO    : Bus 25973	: V=0.965983, theta=-54.199316 -> V=1.0, theta=0.0
% INFO    : Bus 25974	: V=0.9619431, theta=-54.374433 -> V=1.0, theta=0.0
% INFO    : Bus 25975	: V=0.9607766, theta=-54.451943 -> V=1.0, theta=0.0
% INFO    : Bus 25976	: V=0.971458, theta=-53.485019 -> V=1.0, theta=0.0
% INFO    : Bus 25977	: V=0.9803356, theta=-51.654053 -> V=1.0, theta=0.0
% INFO    : Bus 25978	: V=0.9632409, theta=-54.056479 -> V=1.0, theta=0.0
% INFO    : Bus 25979	: V=0.9643764, theta=-54.280237 -> V=1.0, theta=0.0
% INFO    : Bus 25980	: V=0.9649778, theta=-54.221042 -> V=1.0, theta=0.0
% INFO    : Bus 25981	: V=0.9772351, theta=-52.181723 -> V=1.0, theta=0.0
% INFO    : Bus 25982	: V=0.9666714, theta=-54.153607 -> V=1.0, theta=0.0
% INFO    : Bus 25983	: V=0.9674007, theta=-54.076525 -> V=1.0, theta=0.0
% INFO    : Bus 25984	: V=0.9683561, theta=-53.880552 -> V=1.0, theta=0.0
% INFO    : Bus 25985	: V=0.9676125, theta=-54.075811 -> V=1.0, theta=0.0
% INFO    : Bus 25986	: V=0.9669746, theta=-54.088057 -> V=1.0, theta=0.0
% INFO    : Bus 25987	: V=0.9672444, theta=-54.074484 -> V=1.0, theta=0.0
% INFO    : Bus 25988	: V=0.9689682, theta=-53.530179 -> V=1.0, theta=0.0
% INFO    : Bus 25989	: V=0.964139, theta=-54.281912 -> V=1.0, theta=0.0
% INFO    : Bus 25990	: V=0.9681364, theta=-53.547723 -> V=1.0, theta=0.0
% INFO    : Bus 25991	: V=0.9690625, theta=-53.815283 -> V=1.0, theta=0.0
% INFO    : Bus 25992	: V=0.9691806, theta=-53.502803 -> V=1.0, theta=0.0
% INFO    : Bus 25993	: V=0.9694834, theta=-53.461533 -> V=1.0, theta=0.0
% INFO    : Bus 25994	: V=0.9682982, theta=-53.505021 -> V=1.0, theta=0.0
% INFO    : Bus 25995	: V=0.9682814, theta=-53.937408 -> V=1.0, theta=0.0
% INFO    : Bus 25996	: V=0.9679671, theta=-53.913865 -> V=1.0, theta=0.0
% INFO    : Bus 25997	: V=0.9681884, theta=-53.580707 -> V=1.0, theta=0.0
% INFO    : Bus 25998	: V=0.9691343, theta=-53.393552 -> V=1.0, theta=0.0
% INFO    : Bus 25999	: V=0.9752864, theta=-51.752338 -> V=1.0, theta=0.0
% INFO    : Bus 26000	: V=0.9704938, theta=-53.167958 -> V=1.0, theta=0.0
% INFO    : Bus 26001	: V=0.9757958, theta=-51.584791 -> V=1.0, theta=0.0
% INFO    : Bus 26002	: V=0.9691396, theta=-53.482669 -> V=1.0, theta=0.0
% INFO    : Bus 26003	: V=0.9681482, theta=-53.483067 -> V=1.0, theta=0.0
% INFO    : Bus 26004	: V=0.9759285, theta=-51.786516 -> V=1.0, theta=0.0
% INFO    : Bus 26005	: V=0.9758661, theta=-51.725867 -> V=1.0, theta=0.0
% INFO    : Bus 26006	: V=0.9679109, theta=-53.701154 -> V=1.0, theta=0.0
% INFO    : Bus 26007	: V=0.9635213, theta=-54.512994 -> V=1.0, theta=0.0
% INFO    : Bus 26008	: V=0.9748665, theta=-51.840312 -> V=1.0, theta=0.0
% INFO    : Bus 26009	: V=0.9655192, theta=-54.302978 -> V=1.0, theta=0.0
% INFO    : Bus 26010	: V=0.9622426, theta=-54.541116 -> V=1.0, theta=0.0
% INFO    : Bus 26011	: V=0.9659736, theta=-54.116094 -> V=1.0, theta=0.0
% INFO    : Bus 26012	: V=0.9657749, theta=-54.200042 -> V=1.0, theta=0.0
% INFO    : Bus 26013	: V=0.9617175, theta=-54.576343 -> V=1.0, theta=0.0
% INFO    : Bus 26014	: V=0.9611859, theta=-54.626361 -> V=1.0, theta=0.0
% INFO    : Bus 26015	: V=0.9619606, theta=-54.61103 -> V=1.0, theta=0.0
% INFO    : Bus 26016	: V=0.96225, theta=-54.433577 -> V=1.0, theta=0.0
% INFO    : Bus 26017	: V=0.9615705, theta=-54.425309 -> V=1.0, theta=0.0
% INFO    : Bus 26018	: V=0.9620967, theta=-54.410424 -> V=1.0, theta=0.0
% INFO    : Bus 26019	: V=0.9674719, theta=-53.458044 -> V=1.0, theta=0.0
% INFO    : Bus 26020	: V=0.9623246, theta=-54.336886 -> V=1.0, theta=0.0
% INFO    : Bus 26021	: V=0.9626184, theta=-54.440537 -> V=1.0, theta=0.0
% INFO    : Bus 26022	: V=0.9649161, theta=-54.146444 -> V=1.0, theta=0.0
% INFO    : Bus 26023	: V=0.9630752, theta=-54.387136 -> V=1.0, theta=0.0
% INFO    : Bus 26024	: V=0.9635665, theta=-54.3116 -> V=1.0, theta=0.0
% INFO    : Bus 26025	: V=0.9654709, theta=-53.982167 -> V=1.0, theta=0.0
% INFO    : Bus 26026	: V=0.9644564, theta=-54.012353 -> V=1.0, theta=0.0
% INFO    : Bus 26027	: V=0.9610005, theta=-54.624621 -> V=1.0, theta=0.0
% INFO    : Bus 26028	: V=0.9605764, theta=-54.636157 -> V=1.0, theta=0.0
% INFO    : Bus 26029	: V=0.9594543, theta=-54.841885 -> V=1.0, theta=0.0
% INFO    : Bus 26030	: V=0.961335, theta=-54.971575 -> V=1.0, theta=0.0
% INFO    : Bus 26031	: V=0.9614252, theta=-54.76512 -> V=1.0, theta=0.0
% INFO    : Bus 26032	: V=0.9612356, theta=-54.642516 -> V=1.0, theta=0.0
% INFO    : Bus 26033	: V=0.9622245, theta=-54.614732 -> V=1.0, theta=0.0
% INFO    : Bus 26034	: V=0.9601808, theta=-54.078579 -> V=1.0, theta=0.0
% INFO    : Bus 26035	: V=0.9618639, theta=-54.855816 -> V=1.0, theta=0.0
% INFO    : Bus 26036	: V=0.9653512, theta=-52.842296 -> V=1.0, theta=0.0
% INFO    : Bus 26037	: V=0.9613573, theta=-54.84271 -> V=1.0, theta=0.0
% INFO    : Bus 26038	: V=0.9614861, theta=-54.859359 -> V=1.0, theta=0.0
% INFO    : Bus 26039	: V=0.9660302, theta=-52.629671 -> V=1.0, theta=0.0
% INFO    : Bus 26040	: V=0.9608248, theta=-54.867959 -> V=1.0, theta=0.0
% INFO    : Bus 26041	: V=0.9651325, theta=-52.920486 -> V=1.0, theta=0.0
% INFO    : Bus 26042	: V=0.9623824, theta=-54.46421 -> V=1.0, theta=0.0
% INFO    : Bus 26043	: V=0.9671338, theta=-53.386857 -> V=1.0, theta=0.0
% INFO    : Bus 26044	: V=0.9681899, theta=-53.273994 -> V=1.0, theta=0.0
% INFO    : Bus 26045	: V=0.9638231, theta=-53.792365 -> V=1.0, theta=0.0
% INFO    : Bus 26046	: V=0.9702951, theta=-51.870552 -> V=1.0, theta=0.0
% INFO    : Bus 26047	: V=0.9674678, theta=-53.022631 -> V=1.0, theta=0.0
% INFO    : Bus 26048	: V=0.9687121, theta=-52.387842 -> V=1.0, theta=0.0
% INFO    : Bus 26049	: V=0.9674431, theta=-53.545859 -> V=1.0, theta=0.0
% INFO    : Bus 26050	: V=0.978132, theta=-51.655318 -> V=1.0, theta=0.0
% INFO    : Bus 26051	: V=0.9676109, theta=-53.978091 -> V=1.0, theta=0.0
% INFO    : Bus 26052	: V=0.9762356, theta=-52.113671 -> V=1.0, theta=0.0
% INFO    : Bus 26053	: V=0.9762654, theta=-52.078135 -> V=1.0, theta=0.0
% INFO    : Bus 26054	: V=0.9696811, theta=-53.403498 -> V=1.0, theta=0.0
% INFO    : Bus 26055	: V=0.97638, theta=-51.91889 -> V=1.0, theta=0.0
% INFO    : Bus 26056	: V=0.9802352, theta=-51.346184 -> V=1.0, theta=0.0
% INFO    : Bus 26057	: V=0.966265, theta=-54.017659 -> V=1.0, theta=0.0
% INFO    : Bus 26058	: V=0.9804601, theta=-51.617405 -> V=1.0, theta=0.0
% INFO    : Bus 26059	: V=0.9610142, theta=-55.969137 -> V=1.0, theta=0.0
% INFO    : Bus 26060	: V=0.9600808, theta=-55.571125 -> V=1.0, theta=0.0
% INFO    : Bus 26061	: V=0.9637861, theta=-54.880183 -> V=1.0, theta=0.0
% INFO    : Bus 26062	: V=0.9601039, theta=-53.992965 -> V=1.0, theta=0.0
% INFO    : Bus 26063	: V=0.9670275, theta=-53.431018 -> V=1.0, theta=0.0
% INFO    : Bus 26064	: V=0.9645938, theta=-55.383426 -> V=1.0, theta=0.0
% INFO    : Bus 26065	: V=0.9694589, theta=-54.557841 -> V=1.0, theta=0.0
% INFO    : Bus 26066	: V=0.9647361, theta=-55.116465 -> V=1.0, theta=0.0
% INFO    : Bus 26067	: V=0.965602, theta=-55.097864 -> V=1.0, theta=0.0
% INFO    : Bus 26068	: V=0.9622371, theta=-55.707038 -> V=1.0, theta=0.0
% INFO    : Bus 26069	: V=0.9653614, theta=-54.423085 -> V=1.0, theta=0.0
% INFO    : Bus 26070	: V=0.9717459, theta=-56.41951 -> V=1.0, theta=0.0
% INFO    : Bus 26071	: V=0.9733646, theta=-56.146662 -> V=1.0, theta=0.0
% INFO    : Bus 26072	: V=0.9774348, theta=-55.902079 -> V=1.0, theta=0.0
% INFO    : Bus 26073	: V=0.9722728, theta=-56.403972 -> V=1.0, theta=0.0
% INFO    : Bus 26074	: V=0.9795626, theta=-55.738589 -> V=1.0, theta=0.0
% INFO    : Bus 26075	: V=0.9731255, theta=-56.78577 -> V=1.0, theta=0.0
% INFO    : Bus 26076	: V=0.9862226, theta=-55.48246 -> V=1.0, theta=0.0
% INFO    : Bus 26077	: V=0.9635271, theta=-56.430267 -> V=1.0, theta=0.0
% INFO    : Bus 26078	: V=1.0047806, theta=-53.63281 -> V=1.0, theta=0.0
% INFO    : Bus 26079	: V=1.013447, theta=-38.076577 -> V=1.0, theta=0.0
% INFO    : Bus 26080	: V=0.9912619, theta=-40.308723 -> V=1.0, theta=0.0
% INFO    : Bus 26081	: V=1.0044909, theta=-39.326522 -> V=1.0, theta=0.0
% INFO    : Bus 26082	: V=1.0113303, theta=-38.355621 -> V=1.0, theta=0.0
% INFO    : Bus 26083	: V=1.0066694, theta=-38.831072 -> V=1.0, theta=0.0
% INFO    : Bus 26084	: V=1.0137157, theta=-37.922457 -> V=1.0, theta=0.0
% INFO    : Bus 26085	: V=1.0154147, theta=-37.643818 -> V=1.0, theta=0.0
% INFO    : Bus 26086	: V=0.9966166, theta=-52.95952 -> V=1.0, theta=0.0
% INFO    : Bus 26087	: V=0.9921299, theta=-53.529594 -> V=1.0, theta=0.0
% INFO    : Bus 26088	: V=0.9866169, theta=-55.406232 -> V=1.0, theta=0.0
% INFO    : Bus 26089	: V=0.9814697, theta=-56.100181 -> V=1.0, theta=0.0
% INFO    : Bus 26090	: V=0.9843898, theta=-55.609985 -> V=1.0, theta=0.0
% INFO    : Bus 26091	: V=0.9863254, theta=-54.8111 -> V=1.0, theta=0.0
% INFO    : Bus 26092	: V=0.9881403, theta=-54.058207 -> V=1.0, theta=0.0
% INFO    : Bus 26093	: V=0.9725444, theta=-56.492879 -> V=1.0, theta=0.0
% INFO    : Bus 26094	: V=0.9853804, theta=-54.427742 -> V=1.0, theta=0.0
% INFO    : Bus 26095	: V=0.9808592, theta=-56.021833 -> V=1.0, theta=0.0
% INFO    : Bus 26096	: V=0.9783774, theta=-56.266529 -> V=1.0, theta=0.0
% INFO    : Bus 26097	: V=0.9768666, theta=-56.468664 -> V=1.0, theta=0.0
% INFO    : Bus 26098	: V=0.9694504, theta=-57.836803 -> V=1.0, theta=0.0
% INFO    : Bus 26099	: V=0.9658739, theta=-57.289121 -> V=1.0, theta=0.0
% INFO    : Bus 26100	: V=0.9679882, theta=-56.803096 -> V=1.0, theta=0.0
% INFO    : Bus 26101	: V=0.969513, theta=-56.158719 -> V=1.0, theta=0.0
% INFO    : Bus 26102	: V=1.0107657, theta=-51.181686 -> V=1.0, theta=0.0
% INFO    : Bus 26103	: V=0.9984244, theta=-53.343871 -> V=1.0, theta=0.0
% INFO    : Bus 26104	: V=0.9859722, theta=-54.592141 -> V=1.0, theta=0.0
% INFO    : Bus 26105	: V=0.9843409, theta=-54.556102 -> V=1.0, theta=0.0
% INFO    : Bus 26106	: V=0.9728539, theta=-56.070093 -> V=1.0, theta=0.0
% INFO    : Bus 26107	: V=0.9683005, theta=-53.204346 -> V=1.0, theta=0.0
% INFO    : Bus 26108	: V=0.9674534, theta=-53.213836 -> V=1.0, theta=0.0
% INFO    : Bus 26109	: V=0.9727495, theta=-52.52833 -> V=1.0, theta=0.0
% INFO    : Bus 26110	: V=0.9700402, theta=-53.103372 -> V=1.0, theta=0.0
% INFO    : Bus 26111	: V=0.9639445, theta=-53.965483 -> V=1.0, theta=0.0
% INFO    : Bus 26112	: V=0.9713685, theta=-52.709965 -> V=1.0, theta=0.0
% INFO    : Bus 26113	: V=0.9661782, theta=-53.561665 -> V=1.0, theta=0.0
% INFO    : Bus 26114	: V=0.9673595, theta=-53.342557 -> V=1.0, theta=0.0
% INFO    : Bus 26115	: V=0.9704907, theta=-52.859846 -> V=1.0, theta=0.0
% INFO    : Bus 26116	: V=0.9729041, theta=-52.277049 -> V=1.0, theta=0.0
% INFO    : Bus 26117	: V=0.9735759, theta=-52.2104 -> V=1.0, theta=0.0
% INFO    : Bus 26118	: V=0.9742372, theta=-52.084149 -> V=1.0, theta=0.0
% INFO    : Bus 26119	: V=0.9762564, theta=-51.789214 -> V=1.0, theta=0.0
% INFO    : Bus 26120	: V=0.9752783, theta=-51.918182 -> V=1.0, theta=0.0
% INFO    : Bus 26121	: V=0.9744828, theta=-51.931179 -> V=1.0, theta=0.0
% INFO    : Bus 26122	: V=0.9728971, theta=-52.352866 -> V=1.0, theta=0.0
% INFO    : Bus 26123	: V=0.9731484, theta=-52.186348 -> V=1.0, theta=0.0
% INFO    : Bus 26124	: V=0.9728158, theta=-52.155273 -> V=1.0, theta=0.0
% INFO    : Bus 26125	: V=0.9836992, theta=-50.392295 -> V=1.0, theta=0.0
% INFO    : Bus 26126	: V=0.9850477, theta=-50.31274 -> V=1.0, theta=0.0
% INFO    : Bus 26127	: V=0.9887288, theta=-48.926429 -> V=1.0, theta=0.0
% INFO    : Bus 26128	: V=0.9736616, theta=-52.051675 -> V=1.0, theta=0.0
% INFO    : Bus 26129	: V=0.9742264, theta=-51.906022 -> V=1.0, theta=0.0
% INFO    : Bus 26130	: V=0.975346, theta=-51.67707 -> V=1.0, theta=0.0
% INFO    : Bus 26131	: V=0.9769596, theta=-51.370627 -> V=1.0, theta=0.0
% INFO    : Bus 26132	: V=0.9696013, theta=-52.849779 -> V=1.0, theta=0.0
% INFO    : Bus 26133	: V=0.973348, theta=-52.125416 -> V=1.0, theta=0.0
% INFO    : Bus 26134	: V=0.9763705, theta=-51.093119 -> V=1.0, theta=0.0
% INFO    : Bus 26135	: V=0.9697313, theta=-53.026451 -> V=1.0, theta=0.0
% INFO    : Bus 26136	: V=0.9627119, theta=-52.851437 -> V=1.0, theta=0.0
% INFO    : Bus 26137	: V=0.9708842, theta=-51.538891 -> V=1.0, theta=0.0
% INFO    : Bus 26138	: V=0.9784803, theta=-50.51926 -> V=1.0, theta=0.0
% INFO    : Bus 26139	: V=0.9815413, theta=-49.760386 -> V=1.0, theta=0.0
% INFO    : Bus 26140	: V=0.9662488, theta=-53.469811 -> V=1.0, theta=0.0
% INFO    : Bus 26141	: V=0.9813734, theta=-50.71099 -> V=1.0, theta=0.0
% INFO    : Bus 26142	: V=1.0031638, theta=-44.470783 -> V=1.0, theta=0.0
% INFO    : Bus 26143	: V=1.0146083, theta=-42.336655 -> V=1.0, theta=0.0
% INFO    : Bus 26144	: V=1.0069382, theta=-44.226716 -> V=1.0, theta=0.0
% INFO    : Bus 26145	: V=1.014425, theta=-42.405574 -> V=1.0, theta=0.0
% INFO    : Bus 26146	: V=1.0088797, theta=-43.749017 -> V=1.0, theta=0.0
% INFO    : Bus 26147	: V=1.0159832, theta=-41.866744 -> V=1.0, theta=0.0
% INFO    : Bus 26148	: V=1.0091335, theta=-43.255901 -> V=1.0, theta=0.0
% INFO    : Bus 26149	: V=1.0108231, theta=-42.547554 -> V=1.0, theta=0.0
% INFO    : Bus 26150	: V=1.0170624, theta=-41.145819 -> V=1.0, theta=0.0
% INFO    : Bus 26151	: V=1.0190048, theta=-40.269062 -> V=1.0, theta=0.0
% INFO    : Bus 26152	: V=0.9797277, theta=-48.482314 -> V=1.0, theta=0.0
% INFO    : Bus 26153	: V=0.9772397, theta=-48.683805 -> V=1.0, theta=0.0
% INFO    : Bus 26154	: V=0.9788634, theta=-48.577484 -> V=1.0, theta=0.0
% INFO    : Bus 26155	: V=0.9785983, theta=-48.599773 -> V=1.0, theta=0.0
% INFO    : Bus 26156	: V=0.9784638, theta=-48.610005 -> V=1.0, theta=0.0
% INFO    : Bus 26157	: V=0.9787282, theta=-48.588414 -> V=1.0, theta=0.0
% INFO    : Bus 26158	: V=0.9784288, theta=-48.612553 -> V=1.0, theta=0.0
% INFO    : Bus 26159	: V=0.9783792, theta=-48.616884 -> V=1.0, theta=0.0
% INFO    : Bus 26160	: V=0.9767051, theta=-48.748082 -> V=1.0, theta=0.0
% INFO    : Bus 26161	: V=0.976975, theta=-48.744125 -> V=1.0, theta=0.0
% INFO    : Bus 26162	: V=0.9778883, theta=-48.660474 -> V=1.0, theta=0.0
% INFO    : Bus 26163	: V=0.9783495, theta=-48.620068 -> V=1.0, theta=0.0
% INFO    : Bus 26164	: V=0.9780854, theta=-48.623764 -> V=1.0, theta=0.0
% INFO    : Bus 26165	: V=0.977469, theta=-48.630071 -> V=1.0, theta=0.0
% INFO    : Bus 26166	: V=0.9772875, theta=-48.632854 -> V=1.0, theta=0.0
% INFO    : Bus 26167	: V=0.9862206, theta=-47.740605 -> V=1.0, theta=0.0
% INFO    : Bus 26168	: V=0.9815494, theta=-48.40088 -> V=1.0, theta=0.0
% INFO    : Bus 26169	: V=0.9799472, theta=-48.557494 -> V=1.0, theta=0.0
% INFO    : Bus 26170	: V=0.9797613, theta=-48.57998 -> V=1.0, theta=0.0
% INFO    : Bus 26171	: V=0.9803266, theta=-48.524047 -> V=1.0, theta=0.0
% INFO    : Bus 26172	: V=0.9776929, theta=-48.726529 -> V=1.0, theta=0.0
% INFO    : Bus 26173	: V=0.9771433, theta=-48.738118 -> V=1.0, theta=0.0
% INFO    : Bus 26174	: V=0.9757445, theta=-48.788375 -> V=1.0, theta=0.0
% INFO    : Bus 26175	: V=0.9769455, theta=-48.762822 -> V=1.0, theta=0.0
% INFO    : Bus 26176	: V=0.9769136, theta=-48.776676 -> V=1.0, theta=0.0
% INFO    : Bus 26177	: V=0.9766981, theta=-48.774528 -> V=1.0, theta=0.0
% INFO    : Bus 26178	: V=0.9764587, theta=-48.776907 -> V=1.0, theta=0.0
% INFO    : Bus 26179	: V=0.9901629, theta=-47.636383 -> V=1.0, theta=0.0
% INFO    : Bus 26180	: V=0.9928749, theta=-46.894809 -> V=1.0, theta=0.0
% INFO    : Bus 26181	: V=0.9937559, theta=-46.801139 -> V=1.0, theta=0.0
% INFO    : Bus 26182	: V=0.9876242, theta=-47.957532 -> V=1.0, theta=0.0
% INFO    : Bus 26183	: V=0.9908154, theta=-47.104415 -> V=1.0, theta=0.0
% INFO    : Bus 26184	: V=0.9759446, theta=-48.389801 -> V=1.0, theta=0.0
% INFO    : Bus 26185	: V=0.9882515, theta=-47.359422 -> V=1.0, theta=0.0
% INFO    : Bus 26186	: V=0.9753823, theta=-48.516217 -> V=1.0, theta=0.0
% INFO    : Bus 26187	: V=0.9836721, theta=-47.820955 -> V=1.0, theta=0.0
% INFO    : Bus 26188	: V=0.9826889, theta=-47.947249 -> V=1.0, theta=0.0
% INFO    : Bus 26189	: V=0.975853, theta=-48.591011 -> V=1.0, theta=0.0
% INFO    : Bus 26190	: V=0.9758525, theta=-48.713218 -> V=1.0, theta=0.0
% INFO    : Bus 26191	: V=0.982874, theta=-47.983716 -> V=1.0, theta=0.0
% INFO    : Bus 26192	: V=0.9841276, theta=-47.863786 -> V=1.0, theta=0.0
% INFO    : Bus 26193	: V=0.981893, theta=-48.090348 -> V=1.0, theta=0.0
% INFO    : Bus 26194	: V=0.9834645, theta=-47.961156 -> V=1.0, theta=0.0
% INFO    : Bus 26195	: V=0.9784559, theta=-48.554931 -> V=1.0, theta=0.0
% INFO    : Bus 26196	: V=0.9754565, theta=-49.068525 -> V=1.0, theta=0.0
% INFO    : Bus 26197	: V=0.9811168, theta=-48.170528 -> V=1.0, theta=0.0
% INFO    : Bus 26198	: V=0.9803223, theta=-48.230564 -> V=1.0, theta=0.0
% INFO    : Bus 26199	: V=0.9806347, theta=-48.230421 -> V=1.0, theta=0.0
% INFO    : Bus 26200	: V=0.9818205, theta=-48.346807 -> V=1.0, theta=0.0
% INFO    : Bus 26201	: V=0.9824596, theta=-48.298007 -> V=1.0, theta=0.0
% INFO    : Bus 26202	: V=0.981873, theta=-48.247021 -> V=1.0, theta=0.0
% INFO    : Bus 26203	: V=0.98235, theta=-48.269306 -> V=1.0, theta=0.0
% INFO    : Bus 26204	: V=0.9833964, theta=-48.147219 -> V=1.0, theta=0.0
% INFO    : Bus 26205	: V=0.978044, theta=-48.704965 -> V=1.0, theta=0.0
% INFO    : Bus 26206	: V=0.9785515, theta=-48.64522 -> V=1.0, theta=0.0
% INFO    : Bus 26207	: V=0.9793702, theta=-48.578358 -> V=1.0, theta=0.0
% INFO    : Bus 26208	: V=0.9800815, theta=-48.507711 -> V=1.0, theta=0.0
% INFO    : Bus 26209	: V=0.9812432, theta=-48.410111 -> V=1.0, theta=0.0
% INFO    : Bus 26210	: V=0.9820939, theta=-48.315832 -> V=1.0, theta=0.0
% INFO    : Bus 26211	: V=0.9980832, theta=-46.27317 -> V=1.0, theta=0.0
% INFO    : Bus 26212	: V=0.9866757, theta=-47.760819 -> V=1.0, theta=0.0
% INFO    : Bus 26213	: V=0.9855575, theta=-48.015031 -> V=1.0, theta=0.0
% INFO    : Bus 26214	: V=0.9862462, theta=-47.834854 -> V=1.0, theta=0.0
% INFO    : Bus 26215	: V=0.987362, theta=-47.658298 -> V=1.0, theta=0.0
% INFO    : Bus 26216	: V=0.9858494, theta=-47.940712 -> V=1.0, theta=0.0
% INFO    : Bus 26217	: V=0.9828031, theta=-48.190504 -> V=1.0, theta=0.0
% INFO    : Bus 26218	: V=0.986045, theta=-47.919535 -> V=1.0, theta=0.0
% INFO    : Bus 26219	: V=0.986081, theta=-47.932561 -> V=1.0, theta=0.0
% INFO    : Bus 26220	: V=0.9825541, theta=-48.331194 -> V=1.0, theta=0.0
% INFO    : Bus 26221	: V=0.9920179, theta=-47.231871 -> V=1.0, theta=0.0
% INFO    : Bus 26222	: V=0.9886282, theta=-47.628969 -> V=1.0, theta=0.0
% INFO    : Bus 26223	: V=0.9869812, theta=-47.769376 -> V=1.0, theta=0.0
% INFO    : Bus 26224	: V=0.9883667, theta=-47.502372 -> V=1.0, theta=0.0
% INFO    : Bus 26225	: V=0.9854127, theta=-47.753315 -> V=1.0, theta=0.0
% INFO    : Bus 26226	: V=0.9859838, theta=-47.748001 -> V=1.0, theta=0.0
% INFO    : Bus 26227	: V=0.9835091, theta=-48.037296 -> V=1.0, theta=0.0
% INFO    : Bus 26228	: V=0.9872143, theta=-47.408298 -> V=1.0, theta=0.0
% INFO    : Bus 26229	: V=0.9877412, theta=-47.362464 -> V=1.0, theta=0.0
% INFO    : Bus 26230	: V=0.9880949, theta=-47.32771 -> V=1.0, theta=0.0
% INFO    : Bus 26231	: V=0.9882897, theta=-47.316362 -> V=1.0, theta=0.0
% INFO    : Bus 26232	: V=0.9850228, theta=-47.600638 -> V=1.0, theta=0.0
% INFO    : Bus 26233	: V=0.9855042, theta=-47.748101 -> V=1.0, theta=0.0
% INFO    : Bus 26234	: V=0.9871112, theta=-47.486659 -> V=1.0, theta=0.0
% INFO    : Bus 26235	: V=0.9907241, theta=-47.086825 -> V=1.0, theta=0.0
% INFO    : Bus 26236	: V=0.9899522, theta=-47.262097 -> V=1.0, theta=0.0
% INFO    : Bus 26237	: V=0.9907739, theta=-47.13464 -> V=1.0, theta=0.0
% INFO    : Bus 26238	: V=0.9912891, theta=-47.057534 -> V=1.0, theta=0.0
% INFO    : Bus 26239	: V=0.986602, theta=-47.583883 -> V=1.0, theta=0.0
% INFO    : Bus 26240	: V=1.0034497, theta=-45.498664 -> V=1.0, theta=0.0
% INFO    : Bus 26241	: V=0.9941175, theta=-46.77085 -> V=1.0, theta=0.0
% INFO    : Bus 26242	: V=0.9890217, theta=-47.335067 -> V=1.0, theta=0.0
% INFO    : Bus 26243	: V=0.989037, theta=-47.236273 -> V=1.0, theta=0.0
% INFO    : Bus 26244	: V=1.0078234, theta=-44.861995 -> V=1.0, theta=0.0
% INFO    : Bus 26245	: V=0.9943584, theta=-46.822289 -> V=1.0, theta=0.0
% INFO    : Bus 26246	: V=0.9960548, theta=-46.672259 -> V=1.0, theta=0.0
% INFO    : Bus 26247	: V=0.9875549, theta=-47.455914 -> V=1.0, theta=0.0
% INFO    : Bus 26248	: V=0.9822887, theta=-48.06468 -> V=1.0, theta=0.0
% INFO    : Bus 26249	: V=0.9899641, theta=-47.27663 -> V=1.0, theta=0.0
% INFO    : Bus 26250	: V=0.9809813, theta=-48.456843 -> V=1.0, theta=0.0
% INFO    : Bus 26251	: V=0.9800669, theta=-48.556726 -> V=1.0, theta=0.0
% INFO    : Bus 26252	: V=1.0104889, theta=-44.553179 -> V=1.0, theta=0.0
% INFO    : Bus 26253	: V=1.0137925, theta=-44.107146 -> V=1.0, theta=0.0
% INFO    : Bus 26254	: V=1.0085241, theta=-44.817519 -> V=1.0, theta=0.0
% INFO    : Bus 26255	: V=0.9938194, theta=-47.350173 -> V=1.0, theta=0.0
% INFO    : Bus 26256	: V=0.9909581, theta=-47.794434 -> V=1.0, theta=0.0
% INFO    : Bus 26257	: V=0.9877756, theta=-48.080698 -> V=1.0, theta=0.0
% INFO    : Bus 26258	: V=0.9899639, theta=-47.610338 -> V=1.0, theta=0.0
% INFO    : Bus 26259	: V=0.99588, theta=-46.759444 -> V=1.0, theta=0.0
% INFO    : Bus 26260	: V=0.9974837, theta=-46.52859 -> V=1.0, theta=0.0
% INFO    : Bus 26261	: V=0.9923685, theta=-47.230412 -> V=1.0, theta=0.0
% INFO    : Bus 26262	: V=0.9863523, theta=-48.071015 -> V=1.0, theta=0.0
% INFO    : Bus 26263	: V=0.9939448, theta=-47.02403 -> V=1.0, theta=0.0
% INFO    : Bus 26264	: V=0.9867055, theta=-48.045715 -> V=1.0, theta=0.0
% INFO    : Bus 26265	: V=0.9910634, theta=-47.434517 -> V=1.0, theta=0.0
% INFO    : Bus 26266	: V=0.990966, theta=-47.266856 -> V=1.0, theta=0.0
% INFO    : Bus 26267	: V=0.9921531, theta=-47.262271 -> V=1.0, theta=0.0
% INFO    : Bus 26268	: V=1.0016804, theta=-45.796091 -> V=1.0, theta=0.0
% INFO    : Bus 26269	: V=1.0004552, theta=-46.000952 -> V=1.0, theta=0.0
% INFO    : Bus 26270	: V=0.9946728, theta=-46.830072 -> V=1.0, theta=0.0
% INFO    : Bus 26271	: V=1.0040017, theta=-45.438512 -> V=1.0, theta=0.0
% INFO    : Bus 26272	: V=1.0037443, theta=-45.467636 -> V=1.0, theta=0.0
% INFO    : Bus 26273	: V=1.0036729, theta=-45.489917 -> V=1.0, theta=0.0
% INFO    : Bus 26274	: V=1.0046114, theta=-45.355835 -> V=1.0, theta=0.0
% INFO    : Bus 26275	: V=1.0044616, theta=-45.371673 -> V=1.0, theta=0.0
% INFO    : Bus 26276	: V=0.9992664, theta=-46.283684 -> V=1.0, theta=0.0
% INFO    : Bus 26277	: V=0.9981816, theta=-46.315636 -> V=1.0, theta=0.0
% INFO    : Bus 26278	: V=0.9918707, theta=-47.081509 -> V=1.0, theta=0.0
% INFO    : Bus 26279	: V=0.990026, theta=-47.273807 -> V=1.0, theta=0.0
% INFO    : Bus 26280	: V=0.9913709, theta=-47.046416 -> V=1.0, theta=0.0
% INFO    : Bus 26281	: V=0.9857654, theta=-47.305187 -> V=1.0, theta=0.0
% INFO    : Bus 26282	: V=0.9877923, theta=-47.272439 -> V=1.0, theta=0.0
% INFO    : Bus 26283	: V=0.9906635, theta=-47.084794 -> V=1.0, theta=0.0
% INFO    : Bus 26284	: V=0.9882592, theta=-47.358283 -> V=1.0, theta=0.0
% INFO    : Bus 26285	: V=0.9897293, theta=-47.165229 -> V=1.0, theta=0.0
% INFO    : Bus 26286	: V=0.9781086, theta=-48.985533 -> V=1.0, theta=0.0
% INFO    : Bus 26287	: V=0.9781498, theta=-49.007974 -> V=1.0, theta=0.0
% INFO    : Bus 26288	: V=0.9788476, theta=-48.890225 -> V=1.0, theta=0.0
% INFO    : Bus 26289	: V=0.9782445, theta=-48.951567 -> V=1.0, theta=0.0
% INFO    : Bus 26290	: V=0.9858212, theta=-48.252413 -> V=1.0, theta=0.0
% INFO    : Bus 26291	: V=0.9883507, theta=-47.874338 -> V=1.0, theta=0.0
% INFO    : Bus 26292	: V=0.9860091, theta=-48.23516 -> V=1.0, theta=0.0
% INFO    : Bus 26293	: V=0.9866238, theta=-48.183047 -> V=1.0, theta=0.0
% INFO    : Bus 26294	: V=0.9840858, theta=-48.344366 -> V=1.0, theta=0.0
% INFO    : Bus 26295	: V=0.9977873, theta=-46.521991 -> V=1.0, theta=0.0
% INFO    : Bus 26296	: V=0.991754, theta=-47.350017 -> V=1.0, theta=0.0
% INFO    : Bus 26297	: V=0.9983284, theta=-46.417264 -> V=1.0, theta=0.0
% INFO    : Bus 26298	: V=0.9876506, theta=-47.864307 -> V=1.0, theta=0.0
% INFO    : Bus 26299	: V=0.9867173, theta=-47.909548 -> V=1.0, theta=0.0
% INFO    : Bus 26300	: V=0.9911551, theta=-47.301237 -> V=1.0, theta=0.0
% INFO    : Bus 26301	: V=0.9914859, theta=-47.27435 -> V=1.0, theta=0.0
% INFO    : Bus 26302	: V=0.9800527, theta=-48.777332 -> V=1.0, theta=0.0
% INFO    : Bus 26303	: V=0.9805354, theta=-48.659033 -> V=1.0, theta=0.0
% INFO    : Bus 26304	: V=0.9824381, theta=-48.232886 -> V=1.0, theta=0.0
% INFO    : Bus 26305	: V=0.9746135, theta=-49.096951 -> V=1.0, theta=0.0
% INFO    : Bus 26306	: V=0.9842257, theta=-48.784454 -> V=1.0, theta=0.0
% INFO    : Bus 26307	: V=0.9715581, theta=-49.77498 -> V=1.0, theta=0.0
% INFO    : Bus 26308	: V=0.9845328, theta=-48.676041 -> V=1.0, theta=0.0
% INFO    : Bus 26309	: V=0.9968397, theta=-46.805825 -> V=1.0, theta=0.0
% INFO    : Bus 26310	: V=0.974268, theta=-49.300339 -> V=1.0, theta=0.0
% INFO    : Bus 26311	: V=0.9728887, theta=-49.352604 -> V=1.0, theta=0.0
% INFO    : Bus 26312	: V=0.9784991, theta=-49.260232 -> V=1.0, theta=0.0
% INFO    : Bus 26313	: V=0.9806579, theta=-48.985125 -> V=1.0, theta=0.0
% INFO    : Bus 26314	: V=0.9809578, theta=-48.8204 -> V=1.0, theta=0.0
% INFO    : Bus 26315	: V=0.9932274, theta=-47.064509 -> V=1.0, theta=0.0
% INFO    : Bus 26316	: V=0.9807884, theta=-48.532063 -> V=1.0, theta=0.0
% INFO    : Bus 26317	: V=0.9808895, theta=-48.599478 -> V=1.0, theta=0.0
% INFO    : Bus 26318	: V=0.97628, theta=-49.170872 -> V=1.0, theta=0.0
% INFO    : Bus 26319	: V=0.9704027, theta=-49.249292 -> V=1.0, theta=0.0
% INFO    : Bus 26320	: V=0.9725726, theta=-49.178308 -> V=1.0, theta=0.0
% INFO    : Bus 26321	: V=0.9814552, theta=-48.667073 -> V=1.0, theta=0.0
% INFO    : Bus 26322	: V=0.9795854, theta=-49.044747 -> V=1.0, theta=0.0
% INFO    : Bus 26323	: V=0.9772159, theta=-48.502349 -> V=1.0, theta=0.0
% INFO    : Bus 26324	: V=0.9782359, theta=-48.398059 -> V=1.0, theta=0.0
% INFO    : Bus 26325	: V=0.978788, theta=-48.348527 -> V=1.0, theta=0.0
% INFO    : Bus 26326	: V=0.97916, theta=-48.311847 -> V=1.0, theta=0.0
% INFO    : Bus 26327	: V=0.9797137, theta=-48.273958 -> V=1.0, theta=0.0
% INFO    : Bus 26328	: V=0.9698087, theta=-49.860669 -> V=1.0, theta=0.0
% INFO    : Bus 26329	: V=0.970989, theta=-49.797425 -> V=1.0, theta=0.0
% INFO    : Bus 26330	: V=0.9798395, theta=-48.247408 -> V=1.0, theta=0.0
% INFO    : Bus 26331	: V=0.9723468, theta=-48.969035 -> V=1.0, theta=0.0
% INFO    : Bus 26332	: V=0.9741103, theta=-48.914955 -> V=1.0, theta=0.0
% INFO    : Bus 26333	: V=0.9759857, theta=-48.779396 -> V=1.0, theta=0.0
% INFO    : Bus 26334	: V=0.9708388, theta=-49.675689 -> V=1.0, theta=0.0
% INFO    : Bus 26335	: V=0.9822957, theta=-48.530052 -> V=1.0, theta=0.0
% INFO    : Bus 26336	: V=0.9812777, theta=-48.655179 -> V=1.0, theta=0.0
% INFO    : Bus 26337	: V=0.9831146, theta=-48.414148 -> V=1.0, theta=0.0
% INFO    : Bus 26338	: V=0.9880737, theta=-47.704679 -> V=1.0, theta=0.0
% INFO    : Bus 26339	: V=0.9858548, theta=-47.698218 -> V=1.0, theta=0.0
% INFO    : Bus 26340	: V=0.9885679, theta=-47.474139 -> V=1.0, theta=0.0
% INFO    : Bus 26341	: V=1.0048409, theta=-45.402858 -> V=1.0, theta=0.0
% INFO    : Bus 26342	: V=0.9938454, theta=-47.017079 -> V=1.0, theta=0.0
% INFO    : Bus 26343	: V=1.0063148, theta=-45.0983 -> V=1.0, theta=0.0
% INFO    : Bus 26344	: V=0.9954707, theta=-46.623984 -> V=1.0, theta=0.0
% INFO    : Bus 26345	: V=0.9960537, theta=-46.602733 -> V=1.0, theta=0.0
% INFO    : Bus 26346	: V=1.0065907, theta=-45.065977 -> V=1.0, theta=0.0
% INFO    : Bus 26347	: V=1.000001, theta=-46.04728 -> V=1.0, theta=0.0
% INFO    : Bus 26348	: V=1.0018535, theta=-45.723965 -> V=1.0, theta=0.0
% INFO    : Bus 26349	: V=0.9815733, theta=-48.223099 -> V=1.0, theta=0.0
% INFO    : Bus 26350	: V=0.9814259, theta=-48.182646 -> V=1.0, theta=0.0
% INFO    : Bus 26351	: V=0.9816579, theta=-48.119421 -> V=1.0, theta=0.0
% INFO    : Bus 26352	: V=0.9763792, theta=-48.732159 -> V=1.0, theta=0.0
% INFO    : Bus 26353	: V=0.9768182, theta=-48.797876 -> V=1.0, theta=0.0
% INFO    : Bus 26354	: V=0.9822667, theta=-48.073595 -> V=1.0, theta=0.0
% INFO    : Bus 26355	: V=0.9832194, theta=-48.212812 -> V=1.0, theta=0.0
% INFO    : Bus 26356	: V=0.9973708, theta=-46.374536 -> V=1.0, theta=0.0
% INFO    : Bus 26357	: V=1.0026175, theta=-46.072882 -> V=1.0, theta=0.0
% INFO    : Bus 26358	: V=1.0074062, theta=-45.496716 -> V=1.0, theta=0.0
% INFO    : Bus 26359	: V=1.003232, theta=-45.834586 -> V=1.0, theta=0.0
% INFO    : Bus 26360	: V=1.0048095, theta=-45.562667 -> V=1.0, theta=0.0
% INFO    : Bus 26361	: V=1.0065506, theta=-45.273981 -> V=1.0, theta=0.0
% INFO    : Bus 26362	: V=0.9808578, theta=-48.354918 -> V=1.0, theta=0.0
% INFO    : Bus 26363	: V=0.9792709, theta=-48.542308 -> V=1.0, theta=0.0
% INFO    : Bus 26364	: V=0.9767396, theta=-48.698014 -> V=1.0, theta=0.0
% INFO    : Bus 26365	: V=0.985506, theta=-47.613641 -> V=1.0, theta=0.0
% INFO    : Bus 26366	: V=0.9774125, theta=-48.703381 -> V=1.0, theta=0.0
% INFO    : Bus 26367	: V=0.9782414, theta=-48.603938 -> V=1.0, theta=0.0
% INFO    : Bus 26368	: V=0.9860586, theta=-47.514372 -> V=1.0, theta=0.0
% INFO    : Bus 26369	: V=0.978577, theta=-48.675665 -> V=1.0, theta=0.0
% INFO    : Bus 26370	: V=0.9814904, theta=-48.384546 -> V=1.0, theta=0.0
% INFO    : Bus 26371	: V=0.9827117, theta=-48.04649 -> V=1.0, theta=0.0
% INFO    : Bus 26372	: V=0.9899064, theta=-47.812254 -> V=1.0, theta=0.0
% INFO    : Bus 26373	: V=0.9810169, theta=-48.497569 -> V=1.0, theta=0.0
% INFO    : Bus 26374	: V=0.9969378, theta=-52.62967 -> V=1.0, theta=0.0
% INFO    : Bus 26375	: V=0.9638357, theta=-57.882708 -> V=1.0, theta=0.0
% INFO    : Bus 26376	: V=0.975959, theta=-55.142153 -> V=1.0, theta=0.0
% INFO    : Bus 26377	: V=0.9670716, theta=-57.684375 -> V=1.0, theta=0.0
% INFO    : Bus 26378	: V=0.9690534, theta=-57.545355 -> V=1.0, theta=0.0
% INFO    : Bus 26379	: V=0.9987172, theta=-52.391672 -> V=1.0, theta=0.0
% INFO    : Bus 26380	: V=0.9704546, theta=-57.226655 -> V=1.0, theta=0.0
% INFO    : Bus 26381	: V=0.9639642, theta=-58.037957 -> V=1.0, theta=0.0
% INFO    : Bus 26382	: V=0.9659862, theta=-57.918286 -> V=1.0, theta=0.0
% INFO    : Bus 26383	: V=0.9735845, theta=-55.53561 -> V=1.0, theta=0.0
% INFO    : Bus 26384	: V=0.9726036, theta=-56.251469 -> V=1.0, theta=0.0
% INFO    : Bus 26385	: V=0.9741674, theta=-56.041127 -> V=1.0, theta=0.0
% INFO    : Bus 26386	: V=0.9769233, theta=-55.301034 -> V=1.0, theta=0.0
% INFO    : Bus 26387	: V=0.9694057, theta=-56.916063 -> V=1.0, theta=0.0
% INFO    : Bus 26388	: V=0.9716066, theta=-56.485199 -> V=1.0, theta=0.0
% INFO    : Bus 26389	: V=0.9592236, theta=-55.530452 -> V=1.0, theta=0.0
% INFO    : Bus 26390	: V=0.9695256, theta=-55.097408 -> V=1.0, theta=0.0
% INFO    : Bus 26391	: V=0.9807056, theta=-54.456109 -> V=1.0, theta=0.0
% INFO    : Bus 26392	: V=0.9725241, theta=-56.267097 -> V=1.0, theta=0.0
% INFO    : Bus 26393	: V=0.9618879, theta=-58.453873 -> V=1.0, theta=0.0
% INFO    : Bus 26394	: V=0.999269, theta=-43.554505 -> V=1.0, theta=0.0
% INFO    : Bus 26395	: V=0.981682, theta=-49.159042 -> V=1.0, theta=0.0
% INFO    : Bus 26396	: V=0.9955893, theta=-45.956602 -> V=1.0, theta=0.0
% INFO    : Bus 26397	: V=0.999894, theta=-44.72565 -> V=1.0, theta=0.0
% INFO    : Bus 26398	: V=0.9996454, theta=-43.706098 -> V=1.0, theta=0.0
% INFO    : Bus 26399	: V=0.9957272, theta=-53.520691 -> V=1.0, theta=0.0
% INFO    : Bus 26400	: V=0.9972877, theta=-54.730465 -> V=1.0, theta=0.0
% INFO    : Bus 26401	: V=0.9955011, theta=-54.751769 -> V=1.0, theta=0.0
% INFO    : Bus 26402	: V=0.9951879, theta=-55.065278 -> V=1.0, theta=0.0
% INFO    : Bus 26403	: V=0.9832901, theta=-55.668136 -> V=1.0, theta=0.0
% INFO    : Bus 26404	: V=0.9840372, theta=-55.215969 -> V=1.0, theta=0.0
% INFO    : Bus 26405	: V=0.9940633, theta=-55.045482 -> V=1.0, theta=0.0
% INFO    : Bus 26406	: V=0.9971213, theta=-45.367714 -> V=1.0, theta=0.0
% INFO    : Bus 26407	: V=0.9956695, theta=-45.453314 -> V=1.0, theta=0.0
% INFO    : Bus 26408	: V=0.9930775, theta=-45.519222 -> V=1.0, theta=0.0
% INFO    : Bus 26409	: V=0.9942137, theta=-45.487762 -> V=1.0, theta=0.0
% INFO    : Bus 26410	: V=0.9934721, theta=-45.190799 -> V=1.0, theta=0.0
% INFO    : Bus 26411	: V=0.9888213, theta=-45.799119 -> V=1.0, theta=0.0
% INFO    : Bus 26412	: V=1.0002154, theta=-44.37295 -> V=1.0, theta=0.0
% INFO    : Bus 26413	: V=1.0042974, theta=-43.301356 -> V=1.0, theta=0.0
% INFO    : Bus 26414	: V=0.9968227, theta=-44.088182 -> V=1.0, theta=0.0
% INFO    : Bus 26415	: V=0.9932725, theta=-45.939111 -> V=1.0, theta=0.0
% INFO    : Bus 26416	: V=0.9939363, theta=-45.211567 -> V=1.0, theta=0.0
% INFO    : Bus 26417	: V=0.9995713, theta=-44.364266 -> V=1.0, theta=0.0
% INFO    : Bus 26418	: V=0.9975623, theta=-44.930289 -> V=1.0, theta=0.0
% INFO    : Bus 26419	: V=0.9986929, theta=-44.428714 -> V=1.0, theta=0.0
% INFO    : Bus 26420	: V=1.0020748, theta=-43.459805 -> V=1.0, theta=0.0
% INFO    : Bus 26421	: V=1.0011982, theta=-43.216895 -> V=1.0, theta=0.0
% INFO    : Bus 26422	: V=0.9890794, theta=-53.735401 -> V=1.0, theta=0.0
% INFO    : Bus 26423	: V=0.9783497, theta=-54.474852 -> V=1.0, theta=0.0
% INFO    : Bus 26424	: V=0.9925349, theta=-54.191526 -> V=1.0, theta=0.0
% INFO    : Bus 26425	: V=0.9936049, theta=-53.70052 -> V=1.0, theta=0.0
% INFO    : Bus 26426	: V=0.9972637, theta=-52.335062 -> V=1.0, theta=0.0
% INFO    : Bus 26427	: V=0.9939094, theta=-53.229031 -> V=1.0, theta=0.0
% INFO    : Bus 26428	: V=0.9918661, theta=-52.321594 -> V=1.0, theta=0.0
% INFO    : Bus 26429	: V=0.9896399, theta=-53.18542 -> V=1.0, theta=0.0
% INFO    : Bus 26430	: V=0.9905525, theta=-55.671492 -> V=1.0, theta=0.0
% INFO    : Bus 26431	: V=0.993766, theta=-55.700816 -> V=1.0, theta=0.0
% INFO    : Bus 26432	: V=0.9861292, theta=-56.804153 -> V=1.0, theta=0.0
% INFO    : Bus 26433	: V=0.9901206, theta=-56.061664 -> V=1.0, theta=0.0
% INFO    : Bus 26434	: V=0.9896007, theta=-56.111969 -> V=1.0, theta=0.0
% INFO    : Bus 26435	: V=0.9767722, theta=-57.789786 -> V=1.0, theta=0.0
% INFO    : Bus 26436	: V=0.9875137, theta=-56.228968 -> V=1.0, theta=0.0
% INFO    : Bus 26437	: V=0.9745739, theta=-58.995161 -> V=1.0, theta=0.0
% INFO    : Bus 26438	: V=0.9688453, theta=-59.552842 -> V=1.0, theta=0.0
% INFO    : Bus 26439	: V=0.9713759, theta=-59.391492 -> V=1.0, theta=0.0
% INFO    : Bus 26440	: V=0.9757739, theta=-58.980885 -> V=1.0, theta=0.0
% INFO    : Bus 26441	: V=0.9817129, theta=-57.375571 -> V=1.0, theta=0.0
% INFO    : Bus 26442	: V=0.986283, theta=-57.159014 -> V=1.0, theta=0.0
% INFO    : Bus 26443	: V=0.9961701, theta=-40.582743 -> V=1.0, theta=0.0
% INFO    : Bus 26444	: V=0.9652361, theta=-43.891239 -> V=1.0, theta=0.0
% INFO    : Bus 26445	: V=0.9571484, theta=-44.298157 -> V=1.0, theta=0.0
% INFO    : Bus 26446	: V=0.9617256, theta=-44.074871 -> V=1.0, theta=0.0
% INFO    : Bus 26447	: V=0.9562118, theta=-44.5308 -> V=1.0, theta=0.0
% INFO    : Bus 26448	: V=0.9815332, theta=-41.082345 -> V=1.0, theta=0.0
% INFO    : Bus 26449	: V=0.9788111, theta=-41.82155 -> V=1.0, theta=0.0
% INFO    : Bus 26450	: V=1.0191386, theta=-41.394767 -> V=1.0, theta=0.0
% INFO    : Bus 26451	: V=1.016447, theta=-41.901823 -> V=1.0, theta=0.0
% INFO    : Bus 26452	: V=1.0140406, theta=-42.20804 -> V=1.0, theta=0.0
% INFO    : Bus 26453	: V=1.0168003, theta=-41.872133 -> V=1.0, theta=0.0
% INFO    : Bus 26454	: V=1.0135767, theta=-42.250518 -> V=1.0, theta=0.0
% INFO    : Bus 26455	: V=1.0184946, theta=-41.216315 -> V=1.0, theta=0.0
% INFO    : Bus 26456	: V=1.0158103, theta=-41.977357 -> V=1.0, theta=0.0
% INFO    : Bus 26457	: V=1.0134922, theta=-42.299979 -> V=1.0, theta=0.0
% INFO    : Bus 26458	: V=1.016236, theta=-41.949587 -> V=1.0, theta=0.0
% INFO    : Bus 26459	: V=1.0045773, theta=-44.531305 -> V=1.0, theta=0.0
% INFO    : Bus 26460	: V=1.0000733, theta=-46.2028 -> V=1.0, theta=0.0
% INFO    : Bus 26461	: V=1.019576, theta=-42.480062 -> V=1.0, theta=0.0
% INFO    : Bus 26462	: V=1.019478, theta=-42.305265 -> V=1.0, theta=0.0
% INFO    : Bus 26463	: V=1.0129133, theta=-44.153105 -> V=1.0, theta=0.0
% INFO    : Bus 26464	: V=1.0135748, theta=-43.123086 -> V=1.0, theta=0.0
% INFO    : Bus 26465	: V=1.0035972, theta=-42.655892 -> V=1.0, theta=0.0
% INFO    : Bus 26466	: V=1.0183701, theta=-41.253278 -> V=1.0, theta=0.0
% INFO    : Bus 26467	: V=1.0193144, theta=-41.016906 -> V=1.0, theta=0.0
% INFO    : Bus 26468	: V=1.0198143, theta=-40.235554 -> V=1.0, theta=0.0
% INFO    : Bus 26469	: V=1.0110385, theta=-41.794515 -> V=1.0, theta=0.0
% INFO    : Bus 26470	: V=1.0103295, theta=-41.696025 -> V=1.0, theta=0.0
% INFO    : Bus 26471	: V=1.008846, theta=-41.406604 -> V=1.0, theta=0.0
% INFO    : Bus 26472	: V=1.0143875, theta=-40.764416 -> V=1.0, theta=0.0
% INFO    : Bus 26473	: V=1.0015602, theta=-49.922712 -> V=1.0, theta=0.0
% INFO    : Bus 26474	: V=0.9921205, theta=-52.520027 -> V=1.0, theta=0.0
% INFO    : Bus 26475	: V=0.9898649, theta=-53.142574 -> V=1.0, theta=0.0
% INFO    : Bus 26476	: V=0.9802644, theta=-55.222625 -> V=1.0, theta=0.0
% INFO    : Bus 26477	: V=0.9724797, theta=-55.117616 -> V=1.0, theta=0.0
% INFO    : Bus 26478	: V=0.9866821, theta=-53.221525 -> V=1.0, theta=0.0
% INFO    : Bus 26479	: V=0.9789189, theta=-54.256108 -> V=1.0, theta=0.0
% INFO    : Bus 26480	: V=0.9829446, theta=-53.394503 -> V=1.0, theta=0.0
% INFO    : Bus 26481	: V=0.9770425, theta=-52.504469 -> V=1.0, theta=0.0
% INFO    : Bus 26482	: V=0.9837835, theta=-52.919782 -> V=1.0, theta=0.0
% INFO    : Bus 26483	: V=0.9966735, theta=-50.67959 -> V=1.0, theta=0.0
% INFO    : Bus 26484	: V=0.9667538, theta=-55.787456 -> V=1.0, theta=0.0
% INFO    : Bus 26485	: V=0.9988582, theta=-54.123073 -> V=1.0, theta=0.0
% INFO    : Bus 26486	: V=1.0008615, theta=-54.009159 -> V=1.0, theta=0.0
% INFO    : Bus 26487	: V=1.0083289, theta=-52.607331 -> V=1.0, theta=0.0
% INFO    : Bus 26488	: V=0.9983127, theta=-54.143523 -> V=1.0, theta=0.0
% INFO    : Bus 26489	: V=1.0068585, theta=-52.724107 -> V=1.0, theta=0.0
% INFO    : Bus 26490	: V=1.0122653, theta=-52.188149 -> V=1.0, theta=0.0
% INFO    : Bus 26491	: V=0.9949768, theta=-54.459887 -> V=1.0, theta=0.0
% INFO    : Bus 26492	: V=0.9949858, theta=-54.465962 -> V=1.0, theta=0.0
% INFO    : Bus 26493	: V=1.0110712, theta=-52.351561 -> V=1.0, theta=0.0
% INFO    : Bus 26494	: V=0.9913574, theta=-54.728819 -> V=1.0, theta=0.0
% INFO    : Bus 26495	: V=0.9935908, theta=-54.3401 -> V=1.0, theta=0.0
% INFO    : Bus 26496	: V=1.0138473, theta=-51.980964 -> V=1.0, theta=0.0
% INFO    : Bus 26497	: V=0.9952291, theta=-54.37943 -> V=1.0, theta=0.0
% INFO    : Bus 26498	: V=0.9972043, theta=-53.740644 -> V=1.0, theta=0.0
% INFO    : Bus 26499	: V=0.9984152, theta=-53.550051 -> V=1.0, theta=0.0
% INFO    : Bus 26500	: V=1.001034, theta=-53.413692 -> V=1.0, theta=0.0
% INFO    : Bus 26501	: V=1.0091841, theta=-52.364501 -> V=1.0, theta=0.0
% INFO    : Bus 26502	: V=1.0100956, theta=-52.308503 -> V=1.0, theta=0.0
% INFO    : Bus 26503	: V=1.0111572, theta=-52.239985 -> V=1.0, theta=0.0
% INFO    : Bus 26504	: V=1.0183849, theta=-51.421658 -> V=1.0, theta=0.0
% INFO    : Bus 26505	: V=1.0155994, theta=-51.762965 -> V=1.0, theta=0.0
% INFO    : Bus 26506	: V=1.0009195, theta=-53.293457 -> V=1.0, theta=0.0
% INFO    : Bus 26507	: V=1.0002374, theta=-53.330686 -> V=1.0, theta=0.0
% INFO    : Bus 26508	: V=1.0024311, theta=-52.555625 -> V=1.0, theta=0.0
% INFO    : Bus 26509	: V=1.007199, theta=-52.238646 -> V=1.0, theta=0.0
% INFO    : Bus 26510	: V=1.0067533, theta=-52.46779 -> V=1.0, theta=0.0
% INFO    : Bus 26511	: V=1.0078314, theta=-52.445115 -> V=1.0, theta=0.0
% INFO    : Bus 26512	: V=1.0012807, theta=-53.319199 -> V=1.0, theta=0.0
% INFO    : Bus 26513	: V=0.996422, theta=-53.770013 -> V=1.0, theta=0.0
% INFO    : Bus 26514	: V=1.0039611, theta=-52.761404 -> V=1.0, theta=0.0
% INFO    : Bus 26515	: V=0.9990232, theta=-53.138132 -> V=1.0, theta=0.0
% INFO    : Bus 26516	: V=1.0016363, theta=-53.008438 -> V=1.0, theta=0.0
% INFO    : Bus 26517	: V=1.0091466, theta=-51.792747 -> V=1.0, theta=0.0
% INFO    : Bus 26518	: V=1.01081, theta=-51.549566 -> V=1.0, theta=0.0
% INFO    : Bus 26519	: V=1.0045211, theta=-52.496631 -> V=1.0, theta=0.0
% INFO    : Bus 26520	: V=1.0019644, theta=-52.538742 -> V=1.0, theta=0.0
% INFO    : Bus 26521	: V=1.0168751, theta=-50.526604 -> V=1.0, theta=0.0
% INFO    : Bus 26522	: V=1.011096, theta=-51.519316 -> V=1.0, theta=0.0
% INFO    : Bus 26523	: V=1.0071736, theta=-52.127693 -> V=1.0, theta=0.0
% INFO    : Bus 26524	: V=1.0170833, theta=-50.373303 -> V=1.0, theta=0.0
% INFO    : Bus 26525	: V=1.0171407, theta=-50.405142 -> V=1.0, theta=0.0
% INFO    : Bus 26526	: V=0.9979179, theta=-53.131741 -> V=1.0, theta=0.0
% INFO    : Bus 26527	: V=0.9991059, theta=-52.603846 -> V=1.0, theta=0.0
% INFO    : Bus 26528	: V=0.9918362, theta=-53.58789 -> V=1.0, theta=0.0
% INFO    : Bus 26529	: V=1.0010237, theta=-52.46621 -> V=1.0, theta=0.0
% INFO    : Bus 26530	: V=1.0183218, theta=-50.059452 -> V=1.0, theta=0.0
% INFO    : Bus 26531	: V=1.0074635, theta=-51.786401 -> V=1.0, theta=0.0
% INFO    : Bus 26532	: V=1.0193376, theta=-49.748951 -> V=1.0, theta=0.0
% INFO    : Bus 26533	: V=1.0123381, theta=-50.702727 -> V=1.0, theta=0.0
% INFO    : Bus 26534	: V=1.0096665, theta=-50.965568 -> V=1.0, theta=0.0
% INFO    : Bus 26535	: V=1.008204, theta=-50.996352 -> V=1.0, theta=0.0
% INFO    : Bus 26536	: V=1.0116261, theta=-50.976091 -> V=1.0, theta=0.0
% INFO    : Bus 26537	: V=1.0105808, theta=-50.953149 -> V=1.0, theta=0.0
% INFO    : Bus 26538	: V=1.0081496, theta=-51.97745 -> V=1.0, theta=0.0
% INFO    : Bus 26539	: V=1.019328, theta=-49.772248 -> V=1.0, theta=0.0
% INFO    : Bus 26540	: V=0.9915172, theta=-54.000742 -> V=1.0, theta=0.0
% INFO    : Bus 26541	: V=1.0162815, theta=-51.074767 -> V=1.0, theta=0.0
% INFO    : Bus 26542	: V=1.0110032, theta=-52.408852 -> V=1.0, theta=0.0
% INFO    : Bus 26543	: V=1.0080598, theta=-39.373131 -> V=1.0, theta=0.0
% INFO    : Bus 26544	: V=1.0064169, theta=-39.584234 -> V=1.0, theta=0.0
% INFO    : Bus 26545	: V=1.0062555, theta=-39.597038 -> V=1.0, theta=0.0
% INFO    : Bus 26546	: V=1.0073697, theta=-39.494739 -> V=1.0, theta=0.0
% INFO    : Bus 26547	: V=1.002959, theta=-39.829046 -> V=1.0, theta=0.0
% INFO    : Bus 26548	: V=1.0061492, theta=-39.469292 -> V=1.0, theta=0.0
% INFO    : Bus 26549	: V=1.0108872, theta=-39.158509 -> V=1.0, theta=0.0
% INFO    : Bus 26550	: V=1.006587, theta=-39.584165 -> V=1.0, theta=0.0
% INFO    : Bus 26551	: V=1.0061239, theta=-39.610607 -> V=1.0, theta=0.0
% INFO    : Bus 26552	: V=0.9953778, theta=-40.224405 -> V=1.0, theta=0.0
% INFO    : Bus 26553	: V=1.0054173, theta=-39.698758 -> V=1.0, theta=0.0
% INFO    : Bus 26554	: V=1.0055026, theta=-39.629552 -> V=1.0, theta=0.0
% INFO    : Bus 26555	: V=0.9993239, theta=-40.193769 -> V=1.0, theta=0.0
% INFO    : Bus 26556	: V=0.9989882, theta=-40.203015 -> V=1.0, theta=0.0
% INFO    : Bus 26557	: V=0.9991685, theta=-40.136557 -> V=1.0, theta=0.0
% INFO    : Bus 26558	: V=1.0005244, theta=-40.002475 -> V=1.0, theta=0.0
% INFO    : Bus 26559	: V=0.9587849, theta=-52.551984 -> V=1.0, theta=0.0
% INFO    : Bus 26560	: V=0.958892, theta=-52.532715 -> V=1.0, theta=0.0
% INFO    : Bus 26561	: V=0.958991, theta=-52.590358 -> V=1.0, theta=0.0
% INFO    : Bus 26562	: V=0.9599246, theta=-52.599402 -> V=1.0, theta=0.0
% INFO    : Bus 26563	: V=0.9709456, theta=-51.223691 -> V=1.0, theta=0.0
% INFO    : Bus 26564	: V=0.9736101, theta=-50.788125 -> V=1.0, theta=0.0
% INFO    : Bus 26565	: V=0.9758889, theta=-50.467186 -> V=1.0, theta=0.0
% INFO    : Bus 26566	: V=0.9709508, theta=-51.055376 -> V=1.0, theta=0.0
% INFO    : Bus 26567	: V=0.9697973, theta=-51.357436 -> V=1.0, theta=0.0
% INFO    : Bus 26568	: V=0.9692248, theta=-51.502945 -> V=1.0, theta=0.0
% INFO    : Bus 26569	: V=0.9600949, theta=-52.512333 -> V=1.0, theta=0.0
% INFO    : Bus 26570	: V=0.9624556, theta=-52.556705 -> V=1.0, theta=0.0
% INFO    : Bus 26571	: V=0.9690799, theta=-51.651068 -> V=1.0, theta=0.0
% INFO    : Bus 26572	: V=0.9694618, theta=-51.701737 -> V=1.0, theta=0.0
% INFO    : Bus 26573	: V=0.9673923, theta=-51.08356 -> V=1.0, theta=0.0
% INFO    : Bus 26574	: V=0.9703397, theta=-51.779927 -> V=1.0, theta=0.0
% INFO    : Bus 26575	: V=0.965732, theta=-55.879104 -> V=1.0, theta=0.0
% INFO    : Bus 26576	: V=0.9657253, theta=-55.750978 -> V=1.0, theta=0.0
% INFO    : Bus 26577	: V=0.9580665, theta=-53.154347 -> V=1.0, theta=0.0
% INFO    : Bus 26578	: V=0.9644812, theta=-53.011243 -> V=1.0, theta=0.0
% INFO    : Bus 26579	: V=0.9642124, theta=-53.284732 -> V=1.0, theta=0.0
% INFO    : Bus 26580	: V=0.9677998, theta=-52.56646 -> V=1.0, theta=0.0
% INFO    : Bus 26581	: V=0.9651381, theta=-52.73704 -> V=1.0, theta=0.0
% INFO    : Bus 26582	: V=0.9664656, theta=-52.345135 -> V=1.0, theta=0.0
% INFO    : Bus 26583	: V=0.9671933, theta=-52.541896 -> V=1.0, theta=0.0
% INFO    : Bus 26584	: V=0.9744227, theta=-51.453931 -> V=1.0, theta=0.0
% INFO    : Bus 26585	: V=0.9610712, theta=-52.589965 -> V=1.0, theta=0.0
% INFO    : Bus 26586	: V=0.9861504, theta=-48.861171 -> V=1.0, theta=0.0
% INFO    : Bus 26587	: V=0.974926, theta=-50.345443 -> V=1.0, theta=0.0
% INFO    : Bus 26588	: V=0.9836768, theta=-49.429164 -> V=1.0, theta=0.0
% INFO    : Bus 26589	: V=0.9583518, theta=-52.497817 -> V=1.0, theta=0.0
% INFO    : Bus 26590	: V=0.9706296, theta=-51.572827 -> V=1.0, theta=0.0
% INFO    : Bus 26591	: V=0.9419256, theta=-59.259667 -> V=1.0, theta=0.0
% INFO    : Bus 26592	: V=0.9610195, theta=-56.227635 -> V=1.0, theta=0.0
% INFO    : Bus 26593	: V=0.9651496, theta=-55.794991 -> V=1.0, theta=0.0
% INFO    : Bus 26594	: V=0.9694264, theta=-55.141579 -> V=1.0, theta=0.0
% INFO    : Bus 26595	: V=0.9662751, theta=-55.559496 -> V=1.0, theta=0.0
% INFO    : Bus 26596	: V=0.9519867, theta=-56.963752 -> V=1.0, theta=0.0
% INFO    : Bus 26597	: V=0.9556921, theta=-56.781818 -> V=1.0, theta=0.0
% INFO    : Bus 26598	: V=0.9563484, theta=-56.764516 -> V=1.0, theta=0.0
% INFO    : Bus 26599	: V=0.955867, theta=-56.844255 -> V=1.0, theta=0.0
% INFO    : Bus 26600	: V=0.9544267, theta=-57.07798 -> V=1.0, theta=0.0
% INFO    : Bus 26601	: V=0.9550892, theta=-56.761181 -> V=1.0, theta=0.0
% INFO    : Bus 26602	: V=1.0048565, theta=-56.311276 -> V=1.0, theta=0.0
% INFO    : Bus 26603	: V=1.0066673, theta=-56.047687 -> V=1.0, theta=0.0
% INFO    : Bus 26604	: V=1.0169535, theta=-54.396252 -> V=1.0, theta=0.0
% INFO    : Bus 26605	: V=0.9991876, theta=-57.168365 -> V=1.0, theta=0.0
% INFO    : Bus 26606	: V=1.0164942, theta=-54.433056 -> V=1.0, theta=0.0
% INFO    : Bus 26607	: V=1.0058182, theta=-56.215821 -> V=1.0, theta=0.0
% INFO    : Bus 26608	: V=1.0056157, theta=-55.958675 -> V=1.0, theta=0.0
% INFO    : Bus 26609	: V=1.0057756, theta=-55.934564 -> V=1.0, theta=0.0
% INFO    : Bus 26610	: V=1.0071247, theta=-55.788372 -> V=1.0, theta=0.0
% INFO    : Bus 26611	: V=1.0122617, theta=-55.602764 -> V=1.0, theta=0.0
% INFO    : Bus 26612	: V=1.011698, theta=-55.542769 -> V=1.0, theta=0.0
% INFO    : Bus 26613	: V=1.0098911, theta=-55.388167 -> V=1.0, theta=0.0
% INFO    : Bus 26614	: V=1.0084575, theta=-55.665093 -> V=1.0, theta=0.0
% INFO    : Bus 26615	: V=1.005981, theta=-55.910964 -> V=1.0, theta=0.0
% INFO    : Bus 26616	: V=1.0052302, theta=-55.99002 -> V=1.0, theta=0.0
% INFO    : Bus 26617	: V=1.0057919, theta=-55.891783 -> V=1.0, theta=0.0
% INFO    : Bus 26618	: V=1.006871, theta=-55.805537 -> V=1.0, theta=0.0
% INFO    : Bus 26619	: V=1.0068648, theta=-55.73259 -> V=1.0, theta=0.0
% INFO    : Bus 26620	: V=1.006287, theta=-55.814897 -> V=1.0, theta=0.0
% INFO    : Bus 26621	: V=1.0045864, theta=-56.051543 -> V=1.0, theta=0.0
% INFO    : Bus 26622	: V=0.9989492, theta=-56.655762 -> V=1.0, theta=0.0
% INFO    : Bus 26623	: V=1.0035074, theta=-56.152664 -> V=1.0, theta=0.0
% INFO    : Bus 26624	: V=1.0005922, theta=-56.577281 -> V=1.0, theta=0.0
% INFO    : Bus 26625	: V=1.0013715, theta=-56.459173 -> V=1.0, theta=0.0
% INFO    : Bus 26626	: V=1.0027261, theta=-56.246761 -> V=1.0, theta=0.0
% INFO    : Bus 26627	: V=1.0075193, theta=-55.649588 -> V=1.0, theta=0.0
% INFO    : Bus 26628	: V=1.0046822, theta=-56.093421 -> V=1.0, theta=0.0
% INFO    : Bus 26629	: V=0.9985219, theta=-55.892871 -> V=1.0, theta=0.0
% INFO    : Bus 26630	: V=1.0005238, theta=-56.477165 -> V=1.0, theta=0.0
% INFO    : Bus 26631	: V=1.0179135, theta=-54.135152 -> V=1.0, theta=0.0
% INFO    : Bus 26632	: V=1.0034629, theta=-56.05775 -> V=1.0, theta=0.0
% INFO    : Bus 26633	: V=1.0018742, theta=-56.308817 -> V=1.0, theta=0.0
% INFO    : Bus 26634	: V=1.0156855, theta=-54.422165 -> V=1.0, theta=0.0
% INFO    : Bus 26635	: V=0.9984825, theta=-56.570886 -> V=1.0, theta=0.0
% INFO    : Bus 26636	: V=0.9887907, theta=-57.142218 -> V=1.0, theta=0.0
% INFO    : Bus 26637	: V=0.9950977, theta=-57.487125 -> V=1.0, theta=0.0
% INFO    : Bus 26638	: V=0.9947691, theta=-57.613012 -> V=1.0, theta=0.0
% INFO    : Bus 26639	: V=1.0027808, theta=-56.221012 -> V=1.0, theta=0.0
% INFO    : Bus 26640	: V=1.002115, theta=-56.284187 -> V=1.0, theta=0.0
% INFO    : Bus 26641	: V=1.0005749, theta=-56.497948 -> V=1.0, theta=0.0
% INFO    : Bus 26642	: V=0.9988412, theta=-56.740297 -> V=1.0, theta=0.0
% INFO    : Bus 26643	: V=0.9916546, theta=-57.814208 -> V=1.0, theta=0.0
% INFO    : Bus 26644	: V=0.990571, theta=-57.965492 -> V=1.0, theta=0.0
% INFO    : Bus 26645	: V=0.9978328, theta=-56.874158 -> V=1.0, theta=0.0
% INFO    : Bus 26646	: V=1.0149393, theta=-54.570962 -> V=1.0, theta=0.0
% INFO    : Bus 26647	: V=1.0004611, theta=-56.568656 -> V=1.0, theta=0.0
% INFO    : Bus 26648	: V=1.0011276, theta=-56.585852 -> V=1.0, theta=0.0
% INFO    : Bus 26649	: V=0.9970544, theta=-56.95862 -> V=1.0, theta=0.0
% INFO    : Bus 26650	: V=0.9965931, theta=-57.013544 -> V=1.0, theta=0.0
% INFO    : Bus 26651	: V=0.991153, theta=-58.038769 -> V=1.0, theta=0.0
% INFO    : Bus 26652	: V=0.998367, theta=-56.696665 -> V=1.0, theta=0.0
% INFO    : Bus 26653	: V=1.0004315, theta=-56.604184 -> V=1.0, theta=0.0
% INFO    : Bus 26654	: V=0.9992644, theta=-56.677373 -> V=1.0, theta=0.0
% INFO    : Bus 26655	: V=0.9940949, theta=-56.747989 -> V=1.0, theta=0.0
% INFO    : Bus 26656	: V=0.9951937, theta=-57.690409 -> V=1.0, theta=0.0
% INFO    : Bus 26657	: V=0.9972939, theta=-57.395996 -> V=1.0, theta=0.0
% INFO    : Bus 26658	: V=0.9962932, theta=-57.533395 -> V=1.0, theta=0.0
% INFO    : Bus 26659	: V=0.999906, theta=-57.054966 -> V=1.0, theta=0.0
% INFO    : Bus 26660	: V=0.9944058, theta=-57.866371 -> V=1.0, theta=0.0
% INFO    : Bus 26661	: V=0.9929189, theta=-57.985853 -> V=1.0, theta=0.0
% INFO    : Bus 26662	: V=0.9855187, theta=-59.344853 -> V=1.0, theta=0.0
% INFO    : Bus 26663	: V=0.9864734, theta=-59.153897 -> V=1.0, theta=0.0
% INFO    : Bus 26664	: V=0.9922444, theta=-58.049227 -> V=1.0, theta=0.0
% INFO    : Bus 26665	: V=0.9913412, theta=-57.688735 -> V=1.0, theta=0.0
% INFO    : Bus 26666	: V=0.9915225, theta=-56.551632 -> V=1.0, theta=0.0
% INFO    : Bus 26667	: V=0.984642, theta=-57.18103 -> V=1.0, theta=0.0
% INFO    : Bus 26668	: V=0.9850716, theta=-58.093241 -> V=1.0, theta=0.0
% INFO    : Bus 26669	: V=0.9921452, theta=-57.502936 -> V=1.0, theta=0.0
% INFO    : Bus 26670	: V=0.9879686, theta=-57.218392 -> V=1.0, theta=0.0
% INFO    : Bus 26671	: V=0.9869258, theta=-57.263197 -> V=1.0, theta=0.0
% INFO    : Bus 26672	: V=1.0189534, theta=-53.977632 -> V=1.0, theta=0.0
% INFO    : Bus 26673	: V=1.0096165, theta=-55.709607 -> V=1.0, theta=0.0
% INFO    : Bus 26674	: V=1.0031391, theta=-56.567753 -> V=1.0, theta=0.0
% INFO    : Bus 26675	: V=0.9615029, theta=-55.869937 -> V=1.0, theta=0.0
% INFO    : Bus 26676	: V=0.9727776, theta=-54.649335 -> V=1.0, theta=0.0
% INFO    : Bus 26677	: V=0.9734122, theta=-54.580386 -> V=1.0, theta=0.0
% INFO    : Bus 26678	: V=0.9678936, theta=-55.244868 -> V=1.0, theta=0.0
% INFO    : Bus 26679	: V=0.9610511, theta=-55.733679 -> V=1.0, theta=0.0
% INFO    : Bus 26680	: V=0.9690567, theta=-55.227953 -> V=1.0, theta=0.0
% INFO    : Bus 26681	: V=0.9806029, theta=-54.310016 -> V=1.0, theta=0.0
% INFO    : Bus 26682	: V=0.9852443, theta=-53.48128 -> V=1.0, theta=0.0
% INFO    : Bus 26683	: V=0.9861727, theta=-53.333817 -> V=1.0, theta=0.0
% INFO    : Bus 26684	: V=0.9925956, theta=-52.85869 -> V=1.0, theta=0.0
% INFO    : Bus 26685	: V=0.988449, theta=-53.273971 -> V=1.0, theta=0.0
% INFO    : Bus 26686	: V=0.9611199, theta=-55.79488 -> V=1.0, theta=0.0
% INFO    : Bus 26687	: V=0.9614237, theta=-55.797521 -> V=1.0, theta=0.0
% INFO    : Bus 26688	: V=0.9635519, theta=-55.636856 -> V=1.0, theta=0.0
% INFO    : Bus 26689	: V=0.9639666, theta=-55.583572 -> V=1.0, theta=0.0
% INFO    : Bus 26690	: V=0.9657063, theta=-55.425511 -> V=1.0, theta=0.0
% INFO    : Bus 26691	: V=0.9750401, theta=-54.792147 -> V=1.0, theta=0.0
% INFO    : Bus 26692	: V=0.9805893, theta=-53.772275 -> V=1.0, theta=0.0
% INFO    : Bus 26693	: V=0.9813739, theta=-53.7117 -> V=1.0, theta=0.0
% INFO    : Bus 26694	: V=0.9760071, theta=-54.724598 -> V=1.0, theta=0.0
% INFO    : Bus 26695	: V=0.9791365, theta=-54.584707 -> V=1.0, theta=0.0
% INFO    : Bus 26696	: V=0.9743978, theta=-54.870837 -> V=1.0, theta=0.0
% INFO    : Bus 26697	: V=0.9794482, theta=-53.859761 -> V=1.0, theta=0.0
% INFO    : Bus 26698	: V=0.9746052, theta=-54.837457 -> V=1.0, theta=0.0
% INFO    : Bus 26699	: V=0.9645346, theta=-55.58411 -> V=1.0, theta=0.0
% INFO    : Bus 26700	: V=0.9659366, theta=-55.504408 -> V=1.0, theta=0.0
% INFO    : Bus 26701	: V=0.9768718, theta=-54.034265 -> V=1.0, theta=0.0
% INFO    : Bus 26702	: V=0.9777143, theta=-53.980228 -> V=1.0, theta=0.0
% INFO    : Bus 26703	: V=0.9737738, theta=-54.880396 -> V=1.0, theta=0.0
% INFO    : Bus 26704	: V=0.9728567, theta=-54.95755 -> V=1.0, theta=0.0
% INFO    : Bus 26705	: V=0.9746989, theta=-54.86487 -> V=1.0, theta=0.0
% INFO    : Bus 26706	: V=0.9863069, theta=-53.499534 -> V=1.0, theta=0.0
% INFO    : Bus 26707	: V=0.9764332, theta=-54.313269 -> V=1.0, theta=0.0
% INFO    : Bus 26708	: V=0.9670727, theta=-55.44561 -> V=1.0, theta=0.0
% INFO    : Bus 26709	: V=0.9722099, theta=-55.046221 -> V=1.0, theta=0.0
% INFO    : Bus 26710	: V=0.97212, theta=-55.049146 -> V=1.0, theta=0.0
% INFO    : Bus 26711	: V=0.9656217, theta=-55.53344 -> V=1.0, theta=0.0
% INFO    : Bus 26712	: V=0.9707066, theta=-55.170618 -> V=1.0, theta=0.0
% INFO    : Bus 26713	: V=0.9719321, theta=-55.097541 -> V=1.0, theta=0.0
% INFO    : Bus 26714	: V=0.9650187, theta=-55.640558 -> V=1.0, theta=0.0
% INFO    : Bus 26715	: V=0.9684608, theta=-55.363086 -> V=1.0, theta=0.0
% INFO    : Bus 26716	: V=0.9719711, theta=-55.074395 -> V=1.0, theta=0.0
% INFO    : Bus 26717	: V=0.9660442, theta=-55.537752 -> V=1.0, theta=0.0
% INFO    : Bus 26718	: V=0.9647826, theta=-55.745836 -> V=1.0, theta=0.0
% INFO    : Bus 26719	: V=0.9714982, theta=-55.475493 -> V=1.0, theta=0.0
% INFO    : Bus 26720	: V=0.979851, theta=-54.409246 -> V=1.0, theta=0.0
% INFO    : Bus 26721	: V=0.9810253, theta=-54.361432 -> V=1.0, theta=0.0
% INFO    : Bus 26722	: V=0.9860841, theta=-53.599336 -> V=1.0, theta=0.0
% INFO    : Bus 26723	: V=0.9802695, theta=-54.51472 -> V=1.0, theta=0.0
% INFO    : Bus 26724	: V=0.9739966, theta=-54.937571 -> V=1.0, theta=0.0
% INFO    : Bus 26725	: V=0.9764345, theta=-54.800346 -> V=1.0, theta=0.0
% INFO    : Bus 26726	: V=0.97814, theta=-54.683994 -> V=1.0, theta=0.0
% INFO    : Bus 26727	: V=0.9852082, theta=-53.796419 -> V=1.0, theta=0.0
% INFO    : Bus 26728	: V=0.9729782, theta=-55.038681 -> V=1.0, theta=0.0
% INFO    : Bus 26729	: V=0.973674, theta=-54.944498 -> V=1.0, theta=0.0
% INFO    : Bus 26730	: V=0.9695233, theta=-55.348257 -> V=1.0, theta=0.0
% INFO    : Bus 26731	: V=0.9979639, theta=-51.195221 -> V=1.0, theta=0.0
% INFO    : Bus 26732	: V=0.0, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 26733	: V=1.0074206, theta=-50.441892 -> V=1.0, theta=0.0
% INFO    : Bus 26734	: V=0.9934589, theta=-52.795275 -> V=1.0, theta=0.0
% INFO    : Bus 26735	: V=0.973633, theta=-54.500068 -> V=1.0, theta=0.0
% INFO    : Bus 26736	: V=0.974956, theta=-54.408197 -> V=1.0, theta=0.0
% INFO    : Bus 26737	: V=0.9741148, theta=-54.506454 -> V=1.0, theta=0.0
% INFO    : Bus 26738	: V=0.9650721, theta=-54.981762 -> V=1.0, theta=0.0
% INFO    : Bus 26739	: V=0.9718371, theta=-54.679016 -> V=1.0, theta=0.0
% INFO    : Bus 26740	: V=0.9604039, theta=-56.101458 -> V=1.0, theta=0.0
% INFO    : Bus 26741	: V=0.971518, theta=-54.751903 -> V=1.0, theta=0.0
% INFO    : Bus 26742	: V=0.9612189, theta=-55.697198 -> V=1.0, theta=0.0
% INFO    : Bus 26743	: V=0.961086, theta=-55.639563 -> V=1.0, theta=0.0
% INFO    : Bus 26744	: V=0.9635617, theta=-55.417401 -> V=1.0, theta=0.0
% INFO    : Bus 26745	: V=0.9605851, theta=-55.772461 -> V=1.0, theta=0.0
% INFO    : Bus 26746	: V=0.9602605, theta=-55.762522 -> V=1.0, theta=0.0
% INFO    : Bus 26747	: V=0.9601968, theta=-55.789948 -> V=1.0, theta=0.0
% INFO    : Bus 26748	: V=0.9639367, theta=-55.876408 -> V=1.0, theta=0.0
% INFO    : Bus 26749	: V=0.9646419, theta=-55.684609 -> V=1.0, theta=0.0
% INFO    : Bus 26750	: V=0.9667428, theta=-55.755596 -> V=1.0, theta=0.0
% INFO    : Bus 26751	: V=0.9699446, theta=-55.571431 -> V=1.0, theta=0.0
% INFO    : Bus 26752	: V=0.9724391, theta=-55.447103 -> V=1.0, theta=0.0
% INFO    : Bus 26753	: V=0.972014, theta=-55.452372 -> V=1.0, theta=0.0
% INFO    : Bus 26754	: V=0.9910769, theta=-53.376714 -> V=1.0, theta=0.0
% INFO    : Bus 26755	: V=0.9719977, theta=-55.521346 -> V=1.0, theta=0.0
% INFO    : Bus 26756	: V=0.9740254, theta=-55.307617 -> V=1.0, theta=0.0
% INFO    : Bus 26757	: V=0.9685752, theta=-55.658075 -> V=1.0, theta=0.0
% INFO    : Bus 26758	: V=0.9742954, theta=-55.375215 -> V=1.0, theta=0.0
% INFO    : Bus 26759	: V=0.9920604, theta=-53.21592 -> V=1.0, theta=0.0
% INFO    : Bus 26760	: V=0.9757687, theta=-54.767912 -> V=1.0, theta=0.0
% INFO    : Bus 26761	: V=0.9748184, theta=-54.819043 -> V=1.0, theta=0.0
% INFO    : Bus 26762	: V=0.9759715, theta=-54.753141 -> V=1.0, theta=0.0
% INFO    : Bus 26763	: V=0.973777, theta=-54.861405 -> V=1.0, theta=0.0
% INFO    : Bus 26764	: V=0.9728238, theta=-54.892687 -> V=1.0, theta=0.0
% INFO    : Bus 26765	: V=0.9723316, theta=-54.893641 -> V=1.0, theta=0.0
% INFO    : Bus 26766	: V=0.9716573, theta=-54.883524 -> V=1.0, theta=0.0
% INFO    : Bus 26767	: V=0.9610672, theta=-55.993622 -> V=1.0, theta=0.0
% INFO    : Bus 26768	: V=0.9596771, theta=-56.14018 -> V=1.0, theta=0.0
% INFO    : Bus 26769	: V=0.9596166, theta=-56.1558 -> V=1.0, theta=0.0
% INFO    : Bus 26770	: V=0.9570321, theta=-56.397837 -> V=1.0, theta=0.0
% INFO    : Bus 26771	: V=0.9561519, theta=-56.564167 -> V=1.0, theta=0.0
% INFO    : Bus 26772	: V=0.9554417, theta=-56.905691 -> V=1.0, theta=0.0
% INFO    : Bus 26773	: V=0.9552497, theta=-57.025783 -> V=1.0, theta=0.0
% INFO    : Bus 26774	: V=0.9572954, theta=-56.957584 -> V=1.0, theta=0.0
% INFO    : Bus 26775	: V=0.9578511, theta=-56.393793 -> V=1.0, theta=0.0
% INFO    : Bus 26776	: V=0.9596329, theta=-56.272603 -> V=1.0, theta=0.0
% INFO    : Bus 26777	: V=0.9600181, theta=-56.300576 -> V=1.0, theta=0.0
% INFO    : Bus 26778	: V=0.9728412, theta=-54.909527 -> V=1.0, theta=0.0
% INFO    : Bus 26779	: V=0.9740642, theta=-54.865566 -> V=1.0, theta=0.0
% INFO    : Bus 26780	: V=0.9710259, theta=-55.589547 -> V=1.0, theta=0.0
% INFO    : Bus 26781	: V=0.9902056, theta=-53.463695 -> V=1.0, theta=0.0
% INFO    : Bus 26782	: V=0.9794338, theta=-55.09004 -> V=1.0, theta=0.0
% INFO    : Bus 26783	: V=0.9776955, theta=-55.080216 -> V=1.0, theta=0.0
% INFO    : Bus 26784	: V=0.9617193, theta=-56.122678 -> V=1.0, theta=0.0
% INFO    : Bus 26785	: V=0.9685747, theta=-55.621789 -> V=1.0, theta=0.0
% INFO    : Bus 26786	: V=0.9698469, theta=-55.998366 -> V=1.0, theta=0.0
% INFO    : Bus 26787	: V=0.9598197, theta=-56.925124 -> V=1.0, theta=0.0
% INFO    : Bus 26788	: V=0.9609095, theta=-56.705917 -> V=1.0, theta=0.0
% INFO    : Bus 26789	: V=0.957066, theta=-57.006501 -> V=1.0, theta=0.0
% INFO    : Bus 26790	: V=0.9697563, theta=-56.272192 -> V=1.0, theta=0.0
% INFO    : Bus 26791	: V=0.9686593, theta=-56.239289 -> V=1.0, theta=0.0
% INFO    : Bus 26792	: V=0.9830318, theta=-54.975926 -> V=1.0, theta=0.0
% INFO    : Bus 26793	: V=0.9902176, theta=-53.429378 -> V=1.0, theta=0.0
% INFO    : Bus 26794	: V=0.9944869, theta=-52.347332 -> V=1.0, theta=0.0
% INFO    : Bus 26795	: V=0.9927689, theta=-52.362442 -> V=1.0, theta=0.0
% INFO    : Bus 26796	: V=0.9851285, theta=-54.123437 -> V=1.0, theta=0.0
% INFO    : Bus 26797	: V=0.986787, theta=-53.706807 -> V=1.0, theta=0.0
% INFO    : Bus 26798	: V=1.0066491, theta=-51.12863 -> V=1.0, theta=0.0
% INFO    : Bus 26799	: V=0.965459, theta=-55.73638 -> V=1.0, theta=0.0
% INFO    : Bus 26800	: V=0.9823466, theta=-54.04993 -> V=1.0, theta=0.0
% INFO    : Bus 26801	: V=0.9627063, theta=-55.768656 -> V=1.0, theta=0.0
% INFO    : Bus 26802	: V=0.9791356, theta=-52.700011 -> V=1.0, theta=0.0
% INFO    : Bus 26803	: V=0.9593436, theta=-55.557132 -> V=1.0, theta=0.0
% INFO    : Bus 26804	: V=0.962103, theta=-54.097055 -> V=1.0, theta=0.0
% INFO    : Bus 26805	: V=0.9797772, theta=-52.435961 -> V=1.0, theta=0.0
% INFO    : Bus 26806	: V=0.955554, theta=-54.522549 -> V=1.0, theta=0.0
% INFO    : Bus 26807	: V=0.9607725, theta=-54.043382 -> V=1.0, theta=0.0
% INFO    : Bus 26808	: V=0.9755476, theta=-51.95623 -> V=1.0, theta=0.0
% INFO    : Bus 26809	: V=0.9758747, theta=-51.877742 -> V=1.0, theta=0.0
% INFO    : Bus 26810	: V=0.9675301, theta=-53.476817 -> V=1.0, theta=0.0
% INFO    : Bus 26811	: V=0.9631201, theta=-53.505346 -> V=1.0, theta=0.0
% INFO    : Bus 26812	: V=0.9826042, theta=-50.512948 -> V=1.0, theta=0.0
% INFO    : Bus 26813	: V=0.9765497, theta=-51.297243 -> V=1.0, theta=0.0
% INFO    : Bus 26814	: V=0.97446, theta=-51.967693 -> V=1.0, theta=0.0
% INFO    : Bus 26815	: V=0.974059, theta=-52.090813 -> V=1.0, theta=0.0
% INFO    : Bus 26816	: V=0.9692447, theta=-52.999546 -> V=1.0, theta=0.0
% INFO    : Bus 26817	: V=0.9710637, theta=-52.707855 -> V=1.0, theta=0.0
% INFO    : Bus 26818	: V=0.9741486, theta=-51.814347 -> V=1.0, theta=0.0
% INFO    : Bus 26819	: V=0.9702111, theta=-51.972836 -> V=1.0, theta=0.0
% INFO    : Bus 26820	: V=0.97071, theta=-51.954308 -> V=1.0, theta=0.0
% INFO    : Bus 26821	: V=0.9716975, theta=-51.924469 -> V=1.0, theta=0.0
% INFO    : Bus 26822	: V=0.9712314, theta=-51.928923 -> V=1.0, theta=0.0
% INFO    : Bus 26823	: V=0.9696133, theta=-51.983235 -> V=1.0, theta=0.0
% INFO    : Bus 26824	: V=0.9732298, theta=-51.874989 -> V=1.0, theta=0.0
% INFO    : Bus 26825	: V=0.9710505, theta=-52.546829 -> V=1.0, theta=0.0
% INFO    : Bus 26826	: V=0.9734753, theta=-51.871574 -> V=1.0, theta=0.0
% INFO    : Bus 26827	: V=0.9714424, theta=-52.773221 -> V=1.0, theta=0.0
% INFO    : Bus 26828	: V=0.9709758, theta=-52.431077 -> V=1.0, theta=0.0
% INFO    : Bus 26829	: V=0.9713941, theta=-52.781742 -> V=1.0, theta=0.0
% INFO    : Bus 26830	: V=0.9727502, theta=-51.996851 -> V=1.0, theta=0.0
% INFO    : Bus 26831	: V=0.9714739, theta=-52.954638 -> V=1.0, theta=0.0
% INFO    : Bus 26832	: V=0.9713587, theta=-52.791581 -> V=1.0, theta=0.0
% INFO    : Bus 26833	: V=0.9726666, theta=-52.966236 -> V=1.0, theta=0.0
% INFO    : Bus 26834	: V=0.9723371, theta=-52.063221 -> V=1.0, theta=0.0
% INFO    : Bus 26835	: V=0.9721581, theta=-52.965086 -> V=1.0, theta=0.0
% INFO    : Bus 26836	: V=0.9737145, theta=-52.036374 -> V=1.0, theta=0.0
% INFO    : Bus 26837	: V=0.970012, theta=-53.174954 -> V=1.0, theta=0.0
% INFO    : Bus 26838	: V=0.9686399, theta=-53.065947 -> V=1.0, theta=0.0
% INFO    : Bus 26839	: V=0.9694414, theta=-53.04359 -> V=1.0, theta=0.0
% INFO    : Bus 26840	: V=0.9726629, theta=-52.206813 -> V=1.0, theta=0.0
% INFO    : Bus 26841	: V=0.9761221, theta=-51.507269 -> V=1.0, theta=0.0
% INFO    : Bus 26842	: V=0.9733804, theta=-52.157559 -> V=1.0, theta=0.0
% INFO    : Bus 26843	: V=0.9771942, theta=-51.247957 -> V=1.0, theta=0.0
% INFO    : Bus 26844	: V=0.9734112, theta=-51.869967 -> V=1.0, theta=0.0
% INFO    : Bus 26845	: V=0.9737612, theta=-51.973013 -> V=1.0, theta=0.0
% INFO    : Bus 26846	: V=0.9703474, theta=-52.271638 -> V=1.0, theta=0.0
% INFO    : Bus 26847	: V=0.980901, theta=-50.429756 -> V=1.0, theta=0.0
% INFO    : Bus 26848	: V=0.9896415, theta=-48.507716 -> V=1.0, theta=0.0
% INFO    : Bus 26849	: V=0.9739745, theta=-51.787111 -> V=1.0, theta=0.0
% INFO    : Bus 26850	: V=0.9712305, theta=-51.817483 -> V=1.0, theta=0.0
% INFO    : Bus 26851	: V=0.9700528, theta=-51.972989 -> V=1.0, theta=0.0
% INFO    : Bus 26852	: V=0.9705149, theta=-52.238784 -> V=1.0, theta=0.0
% INFO    : Bus 26853	: V=0.9680879, theta=-52.13747 -> V=1.0, theta=0.0
% INFO    : Bus 26854	: V=0.9684964, theta=-52.026474 -> V=1.0, theta=0.0
% INFO    : Bus 26855	: V=0.970155, theta=-51.994423 -> V=1.0, theta=0.0
% INFO    : Bus 26856	: V=0.9759648, theta=-50.937702 -> V=1.0, theta=0.0
% INFO    : Bus 26857	: V=0.9767053, theta=-50.81731 -> V=1.0, theta=0.0
% INFO    : Bus 26858	: V=0.977826, theta=-50.711375 -> V=1.0, theta=0.0
% INFO    : Bus 26859	: V=0.9785745, theta=-50.595833 -> V=1.0, theta=0.0
% INFO    : Bus 26860	: V=0.9741283, theta=-51.822991 -> V=1.0, theta=0.0
% INFO    : Bus 26861	: V=0.9732316, theta=-52.16681 -> V=1.0, theta=0.0
% INFO    : Bus 26862	: V=0.9889374, theta=-48.907752 -> V=1.0, theta=0.0
% INFO    : Bus 26863	: V=0.9772286, theta=-52.314148 -> V=1.0, theta=0.0
% INFO    : Bus 26864	: V=0.9702419, theta=-53.060656 -> V=1.0, theta=0.0
% INFO    : Bus 26865	: V=0.976933, theta=-52.360084 -> V=1.0, theta=0.0
% INFO    : Bus 26866	: V=0.9809709, theta=-53.496597 -> V=1.0, theta=0.0
% INFO    : Bus 26867	: V=0.9777632, theta=-52.241766 -> V=1.0, theta=0.0
% INFO    : Bus 26868	: V=0.9687531, theta=-53.115513 -> V=1.0, theta=0.0
% INFO    : Bus 26869	: V=0.9788914, theta=-52.078686 -> V=1.0, theta=0.0
% INFO    : Bus 26870	: V=0.9644863, theta=-54.142751 -> V=1.0, theta=0.0
% INFO    : Bus 26871	: V=0.9735482, theta=-53.49961 -> V=1.0, theta=0.0
% INFO    : Bus 26872	: V=0.9775718, theta=-52.555376 -> V=1.0, theta=0.0
% INFO    : Bus 26873	: V=0.9806254, theta=-52.077286 -> V=1.0, theta=0.0
% INFO    : Bus 26874	: V=0.981123, theta=-51.89143 -> V=1.0, theta=0.0
% INFO    : Bus 26875	: V=0.9771188, theta=-51.171628 -> V=1.0, theta=0.0
% INFO    : Bus 26876	: V=0.9755911, theta=-51.52264 -> V=1.0, theta=0.0
% INFO    : Bus 26877	: V=0.9811865, theta=-50.155443 -> V=1.0, theta=0.0
% INFO    : Bus 26878	: V=0.9840743, theta=-49.836694 -> V=1.0, theta=0.0
% INFO    : Bus 26879	: V=0.9739532, theta=-51.897543 -> V=1.0, theta=0.0
% INFO    : Bus 26880	: V=0.9750071, theta=-51.812699 -> V=1.0, theta=0.0
% INFO    : Bus 26881	: V=0.973191, theta=-51.934727 -> V=1.0, theta=0.0
% INFO    : Bus 26882	: V=0.9698966, theta=-53.299472 -> V=1.0, theta=0.0
% INFO    : Bus 26883	: V=0.9719883, theta=-53.258986 -> V=1.0, theta=0.0
% INFO    : Bus 26884	: V=0.9651513, theta=-59.619239 -> V=1.0, theta=0.0
% INFO    : Bus 26885	: V=0.9710498, theta=-58.065893 -> V=1.0, theta=0.0
% INFO    : Bus 26886	: V=0.9656133, theta=-59.350418 -> V=1.0, theta=0.0
% INFO    : Bus 26887	: V=0.9925938, theta=-53.527877 -> V=1.0, theta=0.0
% INFO    : Bus 26888	: V=0.965353, theta=-59.609644 -> V=1.0, theta=0.0
% INFO    : Bus 26889	: V=0.9650181, theta=-59.656731 -> V=1.0, theta=0.0
% INFO    : Bus 26890	: V=0.9639619, theta=-59.697845 -> V=1.0, theta=0.0
% INFO    : Bus 26891	: V=0.964953, theta=-59.691909 -> V=1.0, theta=0.0
% INFO    : Bus 26892	: V=0.9651461, theta=-59.697625 -> V=1.0, theta=0.0
% INFO    : Bus 26893	: V=0.9694187, theta=-58.259327 -> V=1.0, theta=0.0
% INFO    : Bus 26894	: V=0.9625685, theta=-59.897343 -> V=1.0, theta=0.0
% INFO    : Bus 26895	: V=0.9682191, theta=-58.38857 -> V=1.0, theta=0.0
% INFO    : Bus 26896	: V=0.958348, theta=-60.226855 -> V=1.0, theta=0.0
% INFO    : Bus 26897	: V=0.9621752, theta=-59.117971 -> V=1.0, theta=0.0
% INFO    : Bus 26898	: V=0.9668341, theta=-58.548891 -> V=1.0, theta=0.0
% INFO    : Bus 26899	: V=0.9592007, theta=-59.2248 -> V=1.0, theta=0.0
% INFO    : Bus 26900	: V=0.9637368, theta=-59.414341 -> V=1.0, theta=0.0
% INFO    : Bus 26901	: V=0.9603158, theta=-58.891916 -> V=1.0, theta=0.0
% INFO    : Bus 26902	: V=0.9834956, theta=-58.73458 -> V=1.0, theta=0.0
% INFO    : Bus 26903	: V=0.9784198, theta=-60.480304 -> V=1.0, theta=0.0
% INFO    : Bus 26904	: V=0.9894418, theta=-57.636068 -> V=1.0, theta=0.0
% INFO    : Bus 26905	: V=0.9768469, theta=-60.261538 -> V=1.0, theta=0.0
% INFO    : Bus 26906	: V=0.9816797, theta=-58.658923 -> V=1.0, theta=0.0
% INFO    : Bus 26907	: V=0.9824272, theta=-58.778476 -> V=1.0, theta=0.0
% INFO    : Bus 26908	: V=0.981552, theta=-58.727913 -> V=1.0, theta=0.0
% INFO    : Bus 26909	: V=0.9806391, theta=-58.588848 -> V=1.0, theta=0.0
% INFO    : Bus 26910	: V=0.9807943, theta=-58.687338 -> V=1.0, theta=0.0
% INFO    : Bus 26911	: V=0.9787964, theta=-59.525433 -> V=1.0, theta=0.0
% INFO    : Bus 26912	: V=0.9810317, theta=-58.677393 -> V=1.0, theta=0.0
% INFO    : Bus 26913	: V=0.98079, theta=-58.657516 -> V=1.0, theta=0.0
% INFO    : Bus 26914	: V=0.9812258, theta=-58.552142 -> V=1.0, theta=0.0
% INFO    : Bus 26915	: V=0.9798316, theta=-59.393809 -> V=1.0, theta=0.0
% INFO    : Bus 26916	: V=0.9797103, theta=-59.482789 -> V=1.0, theta=0.0
% INFO    : Bus 26917	: V=0.9805123, theta=-58.685591 -> V=1.0, theta=0.0
% INFO    : Bus 26918	: V=0.9872563, theta=-57.698068 -> V=1.0, theta=0.0
% INFO    : Bus 26919	: V=0.98257, theta=-58.27343 -> V=1.0, theta=0.0
% INFO    : Bus 26920	: V=0.9825707, theta=-58.539679 -> V=1.0, theta=0.0
% INFO    : Bus 26921	: V=0.9858263, theta=-57.455517 -> V=1.0, theta=0.0
% INFO    : Bus 26922	: V=0.9851621, theta=-57.73313 -> V=1.0, theta=0.0
% INFO    : Bus 26923	: V=0.9852368, theta=-57.688929 -> V=1.0, theta=0.0
% INFO    : Bus 26924	: V=0.9814062, theta=-58.300353 -> V=1.0, theta=0.0
% INFO    : Bus 26925	: V=0.9843775, theta=-58.62818 -> V=1.0, theta=0.0
% INFO    : Bus 26926	: V=0.982268, theta=-60.161452 -> V=1.0, theta=0.0
% INFO    : Bus 26927	: V=0.982161, theta=-60.127338 -> V=1.0, theta=0.0
% INFO    : Bus 26928	: V=0.981434, theta=-60.155815 -> V=1.0, theta=0.0
% INFO    : Bus 26929	: V=0.9849482, theta=-58.428842 -> V=1.0, theta=0.0
% INFO    : Bus 26930	: V=0.9810414, theta=-60.621018 -> V=1.0, theta=0.0
% INFO    : Bus 26931	: V=0.9797033, theta=-60.700305 -> V=1.0, theta=0.0
% INFO    : Bus 26932	: V=0.9832306, theta=-58.569488 -> V=1.0, theta=0.0
% INFO    : Bus 26933	: V=0.9826311, theta=-59.910969 -> V=1.0, theta=0.0
% INFO    : Bus 26934	: V=0.9824105, theta=-60.017779 -> V=1.0, theta=0.0
% INFO    : Bus 26935	: V=0.9781905, theta=-59.421772 -> V=1.0, theta=0.0
% INFO    : Bus 26936	: V=0.981397, theta=-58.548552 -> V=1.0, theta=0.0
% INFO    : Bus 26937	: V=0.9830003, theta=-58.279853 -> V=1.0, theta=0.0
% INFO    : Bus 26938	: V=0.9826529, theta=-57.925186 -> V=1.0, theta=0.0
% INFO    : Bus 26939	: V=1.0183511, theta=-38.400565 -> V=1.0, theta=0.0
% INFO    : Bus 26940	: V=1.0200569, theta=-37.482608 -> V=1.0, theta=0.0
% INFO    : Bus 26941	: V=1.0107042, theta=-38.498698 -> V=1.0, theta=0.0
% INFO    : Bus 26942	: V=1.0199235, theta=-37.020426 -> V=1.0, theta=0.0
% INFO    : Bus 26943	: V=1.0188743, theta=-37.781618 -> V=1.0, theta=0.0
% INFO    : Bus 26944	: V=1.0184482, theta=-37.906679 -> V=1.0, theta=0.0
% INFO    : Bus 26945	: V=0.9571094, theta=-57.67682 -> V=1.0, theta=0.0
% INFO    : Bus 26946	: V=0.9552304, theta=-57.862444 -> V=1.0, theta=0.0
% INFO    : Bus 26947	: V=0.9622861, theta=-57.22203 -> V=1.0, theta=0.0
% INFO    : Bus 26948	: V=0.9626795, theta=-56.951075 -> V=1.0, theta=0.0
% INFO    : Bus 26949	: V=0.9622047, theta=-57.002541 -> V=1.0, theta=0.0
% INFO    : Bus 26950	: V=0.962716, theta=-57.427611 -> V=1.0, theta=0.0
% INFO    : Bus 26951	: V=0.9618941, theta=-57.072665 -> V=1.0, theta=0.0
% INFO    : Bus 26952	: V=0.9718243, theta=-55.778718 -> V=1.0, theta=0.0
% INFO    : Bus 26953	: V=0.9646759, theta=-57.62584 -> V=1.0, theta=0.0
% INFO    : Bus 26954	: V=0.9558644, theta=-55.9764 -> V=1.0, theta=0.0
% INFO    : Bus 26955	: V=0.9536569, theta=-56.854249 -> V=1.0, theta=0.0
% INFO    : Bus 26956	: V=0.9639191, theta=-55.27356 -> V=1.0, theta=0.0
% INFO    : Bus 26957	: V=0.9522797, theta=-56.909696 -> V=1.0, theta=0.0
% INFO    : Bus 26958	: V=0.9592752, theta=-55.547868 -> V=1.0, theta=0.0
% INFO    : Bus 26959	: V=0.9698356, theta=-55.208622 -> V=1.0, theta=0.0
% INFO    : Bus 26960	: V=0.9666873, theta=-55.290547 -> V=1.0, theta=0.0
% INFO    : Bus 26961	: V=0.9653979, theta=-55.829698 -> V=1.0, theta=0.0
% INFO    : Bus 26962	: V=0.9597531, theta=-54.919837 -> V=1.0, theta=0.0
% INFO    : Bus 26963	: V=0.9586755, theta=-54.98345 -> V=1.0, theta=0.0
% INFO    : Bus 26964	: V=0.9542707, theta=-55.111476 -> V=1.0, theta=0.0
% INFO    : Bus 26965	: V=0.959982, theta=-54.359799 -> V=1.0, theta=0.0
% INFO    : Bus 26966	: V=0.9600369, theta=-54.278889 -> V=1.0, theta=0.0
% INFO    : Bus 26967	: V=0.9738937, theta=-52.096526 -> V=1.0, theta=0.0
% INFO    : Bus 26968	: V=0.954894, theta=-56.375883 -> V=1.0, theta=0.0
% INFO    : Bus 26969	: V=0.9464096, theta=-56.444747 -> V=1.0, theta=0.0
% INFO    : Bus 26970	: V=0.9483264, theta=-56.312476 -> V=1.0, theta=0.0
% INFO    : Bus 26971	: V=0.9581991, theta=-54.921004 -> V=1.0, theta=0.0
% INFO    : Bus 26972	: V=0.9588651, theta=-54.837581 -> V=1.0, theta=0.0
% INFO    : Bus 26973	: V=0.9617608, theta=-53.955021 -> V=1.0, theta=0.0
% INFO    : Bus 26974	: V=0.9364754, theta=-55.9409 -> V=1.0, theta=0.0
% INFO    : Bus 26975	: V=0.976077, theta=-43.040953 -> V=1.0, theta=0.0
% INFO    : Bus 26976	: V=0.9632346, theta=-43.727064 -> V=1.0, theta=0.0
% INFO    : Bus 26977	: V=0.9647387, theta=-43.881748 -> V=1.0, theta=0.0
% INFO    : Bus 26978	: V=0.9701313, theta=-43.83619 -> V=1.0, theta=0.0
% INFO    : Bus 26979	: V=0.9866504, theta=-50.605798 -> V=1.0, theta=0.0
% INFO    : Bus 26980	: V=0.975416, theta=-52.175012 -> V=1.0, theta=0.0
% INFO    : Bus 26981	: V=0.9755814, theta=-52.163665 -> V=1.0, theta=0.0
% INFO    : Bus 26982	: V=0.9782904, theta=-51.855952 -> V=1.0, theta=0.0
% INFO    : Bus 26983	: V=0.9774637, theta=-51.960863 -> V=1.0, theta=0.0
% INFO    : Bus 26984	: V=0.9767217, theta=-52.18482 -> V=1.0, theta=0.0
% INFO    : Bus 26985	: V=0.9770405, theta=-52.181046 -> V=1.0, theta=0.0
% INFO    : Bus 26986	: V=0.9739557, theta=-52.228657 -> V=1.0, theta=0.0
% INFO    : Bus 26987	: V=0.9737134, theta=-52.57423 -> V=1.0, theta=0.0
% INFO    : Bus 26988	: V=0.9881313, theta=-50.427529 -> V=1.0, theta=0.0
% INFO    : Bus 26989	: V=0.9886499, theta=-50.365809 -> V=1.0, theta=0.0
% INFO    : Bus 26990	: V=0.97099, theta=-52.97171 -> V=1.0, theta=0.0
% INFO    : Bus 26991	: V=0.9776345, theta=-51.934572 -> V=1.0, theta=0.0
% INFO    : Bus 26992	: V=0.978554, theta=-51.808214 -> V=1.0, theta=0.0
% INFO    : Bus 26993	: V=0.9688772, theta=-53.220322 -> V=1.0, theta=0.0
% INFO    : Bus 26994	: V=0.9760833, theta=-52.125669 -> V=1.0, theta=0.0
% INFO    : Bus 26995	: V=0.9732361, theta=-52.493866 -> V=1.0, theta=0.0
% INFO    : Bus 26996	: V=0.9873869, theta=-50.377655 -> V=1.0, theta=0.0
% INFO    : Bus 26997	: V=0.9765232, theta=-52.061463 -> V=1.0, theta=0.0
% INFO    : Bus 26998	: V=0.973648, theta=-52.386521 -> V=1.0, theta=0.0
% INFO    : Bus 26999	: V=0.9722084, theta=-52.510637 -> V=1.0, theta=0.0
% INFO    : Bus 27000	: V=0.9716916, theta=-52.534649 -> V=1.0, theta=0.0
% INFO    : Bus 27001	: V=0.971291, theta=-52.541238 -> V=1.0, theta=0.0
% INFO    : Bus 27002	: V=0.971368, theta=-52.498259 -> V=1.0, theta=0.0
% INFO    : Bus 27003	: V=0.9707954, theta=-52.482357 -> V=1.0, theta=0.0
% INFO    : Bus 27004	: V=0.9725666, theta=-52.286808 -> V=1.0, theta=0.0
% INFO    : Bus 27005	: V=0.9750505, theta=-52.124466 -> V=1.0, theta=0.0
% INFO    : Bus 27006	: V=0.9744699, theta=-52.239294 -> V=1.0, theta=0.0
% INFO    : Bus 27007	: V=0.9786136, theta=-51.591457 -> V=1.0, theta=0.0
% INFO    : Bus 27008	: V=0.9785162, theta=-51.59971 -> V=1.0, theta=0.0
% INFO    : Bus 27009	: V=0.9736564, theta=-52.34191 -> V=1.0, theta=0.0
% INFO    : Bus 27010	: V=0.9727429, theta=-52.409255 -> V=1.0, theta=0.0
% INFO    : Bus 27011	: V=0.9798861, theta=-51.590839 -> V=1.0, theta=0.0
% INFO    : Bus 27012	: V=0.9808003, theta=-51.505431 -> V=1.0, theta=0.0
% INFO    : Bus 27013	: V=0.9904845, theta=-50.146187 -> V=1.0, theta=0.0
% INFO    : Bus 27014	: V=0.9793579, theta=-51.72752 -> V=1.0, theta=0.0
% INFO    : Bus 27015	: V=0.9801918, theta=-51.632353 -> V=1.0, theta=0.0
% INFO    : Bus 27016	: V=0.9802535, theta=-51.710431 -> V=1.0, theta=0.0
% INFO    : Bus 27017	: V=0.9812789, theta=-51.477625 -> V=1.0, theta=0.0
% INFO    : Bus 27018	: V=0.9829823, theta=-51.269393 -> V=1.0, theta=0.0
% INFO    : Bus 27019	: V=0.976867, theta=-52.020942 -> V=1.0, theta=0.0
% INFO    : Bus 27020	: V=0.9769716, theta=-52.000955 -> V=1.0, theta=0.0
% INFO    : Bus 27021	: V=0.9810027, theta=-51.468965 -> V=1.0, theta=0.0
% INFO    : Bus 27022	: V=0.9805782, theta=-51.512982 -> V=1.0, theta=0.0
% INFO    : Bus 27023	: V=0.9815521, theta=-51.413339 -> V=1.0, theta=0.0
% INFO    : Bus 27024	: V=0.9820967, theta=-51.276545 -> V=1.0, theta=0.0
% INFO    : Bus 27025	: V=0.981944, theta=-51.25986 -> V=1.0, theta=0.0
% INFO    : Bus 27026	: V=0.9836503, theta=-51.045849 -> V=1.0, theta=0.0
% INFO    : Bus 27027	: V=0.982033, theta=-51.089887 -> V=1.0, theta=0.0
% INFO    : Bus 27028	: V=0.9812682, theta=-51.204655 -> V=1.0, theta=0.0
% INFO    : Bus 27029	: V=0.9829898, theta=-50.94981 -> V=1.0, theta=0.0
% INFO    : Bus 27030	: V=0.9742382, theta=-52.125431 -> V=1.0, theta=0.0
% INFO    : Bus 27031	: V=0.9746449, theta=-52.117997 -> V=1.0, theta=0.0
% INFO    : Bus 27032	: V=0.9798905, theta=-51.472832 -> V=1.0, theta=0.0
% INFO    : Bus 27033	: V=0.9792826, theta=-51.531451 -> V=1.0, theta=0.0
% INFO    : Bus 27034	: V=0.9776477, theta=-51.69905 -> V=1.0, theta=0.0
% INFO    : Bus 27035	: V=0.97865, theta=-51.569185 -> V=1.0, theta=0.0
% INFO    : Bus 27036	: V=0.9766659, theta=-51.828744 -> V=1.0, theta=0.0
% INFO    : Bus 27037	: V=0.9759437, theta=-51.917678 -> V=1.0, theta=0.0
% INFO    : Bus 27038	: V=0.9764829, theta=-51.839901 -> V=1.0, theta=0.0
% INFO    : Bus 27039	: V=0.9795688, theta=-51.458995 -> V=1.0, theta=0.0
% INFO    : Bus 27040	: V=0.9801138, theta=-51.377533 -> V=1.0, theta=0.0
% INFO    : Bus 27041	: V=0.9778019, theta=-51.638124 -> V=1.0, theta=0.0
% INFO    : Bus 27042	: V=0.9782145, theta=-51.520034 -> V=1.0, theta=0.0
% INFO    : Bus 27043	: V=0.9795668, theta=-51.323674 -> V=1.0, theta=0.0
% INFO    : Bus 27044	: V=0.9807371, theta=-51.144854 -> V=1.0, theta=0.0
% INFO    : Bus 27045	: V=0.9776264, theta=-51.535494 -> V=1.0, theta=0.0
% INFO    : Bus 27046	: V=0.9825968, theta=-51.268419 -> V=1.0, theta=0.0
% INFO    : Bus 27047	: V=0.9857978, theta=-50.914018 -> V=1.0, theta=0.0
% INFO    : Bus 27048	: V=0.9800928, theta=-51.373033 -> V=1.0, theta=0.0
% INFO    : Bus 27049	: V=0.9815859, theta=-51.247349 -> V=1.0, theta=0.0
% INFO    : Bus 27050	: V=0.9859471, theta=-50.578793 -> V=1.0, theta=0.0
% INFO    : Bus 27051	: V=0.9840604, theta=-50.794275 -> V=1.0, theta=0.0
% INFO    : Bus 27052	: V=0.9766559, theta=-51.59246 -> V=1.0, theta=0.0
% INFO    : Bus 27053	: V=0.9902132, theta=-49.6377 -> V=1.0, theta=0.0
% INFO    : Bus 27054	: V=0.9901473, theta=-49.655826 -> V=1.0, theta=0.0
% INFO    : Bus 27055	: V=0.9902668, theta=-49.428025 -> V=1.0, theta=0.0
% INFO    : Bus 27056	: V=0.9894581, theta=-49.756307 -> V=1.0, theta=0.0
% INFO    : Bus 27057	: V=0.9907495, theta=-49.336161 -> V=1.0, theta=0.0
% INFO    : Bus 27058	: V=0.9876416, theta=-50.360029 -> V=1.0, theta=0.0
% INFO    : Bus 27059	: V=0.9900776, theta=-50.054313 -> V=1.0, theta=0.0
% INFO    : Bus 27060	: V=0.9919839, theta=-50.02685 -> V=1.0, theta=0.0
% INFO    : Bus 27061	: V=0.9939995, theta=-49.864078 -> V=1.0, theta=0.0
% INFO    : Bus 27062	: V=0.9877866, theta=-50.585621 -> V=1.0, theta=0.0
% INFO    : Bus 27063	: V=0.9903776, theta=-50.16346 -> V=1.0, theta=0.0
% INFO    : Bus 27064	: V=0.9847924, theta=-50.961278 -> V=1.0, theta=0.0
% INFO    : Bus 27065	: V=0.9861646, theta=-50.773778 -> V=1.0, theta=0.0
% INFO    : Bus 27066	: V=0.986666, theta=-50.812265 -> V=1.0, theta=0.0
% INFO    : Bus 27067	: V=0.9940352, theta=-49.820477 -> V=1.0, theta=0.0
% INFO    : Bus 27068	: V=0.9943133, theta=-49.792431 -> V=1.0, theta=0.0
% INFO    : Bus 27069	: V=0.9940629, theta=-49.819813 -> V=1.0, theta=0.0
% INFO    : Bus 27070	: V=0.9911667, theta=-50.234092 -> V=1.0, theta=0.0
% INFO    : Bus 27071	: V=0.9976802, theta=-49.433335 -> V=1.0, theta=0.0
% INFO    : Bus 27072	: V=0.9953685, theta=-49.672507 -> V=1.0, theta=0.0
% INFO    : Bus 27073	: V=0.9914822, theta=-50.104656 -> V=1.0, theta=0.0
% INFO    : Bus 27074	: V=0.9917635, theta=-50.150932 -> V=1.0, theta=0.0
% INFO    : Bus 27075	: V=0.9846751, theta=-50.981251 -> V=1.0, theta=0.0
% INFO    : Bus 27076	: V=0.9824786, theta=-51.299125 -> V=1.0, theta=0.0
% INFO    : Bus 27077	: V=0.9761739, theta=-52.188084 -> V=1.0, theta=0.0
% INFO    : Bus 27078	: V=0.96546, theta=-52.669997 -> V=1.0, theta=0.0
% INFO    : Bus 27079	: V=0.9673722, theta=-53.663999 -> V=1.0, theta=0.0
% INFO    : Bus 27080	: V=0.981412, theta=-51.433121 -> V=1.0, theta=0.0
% INFO    : Bus 27081	: V=0.9805402, theta=-51.548299 -> V=1.0, theta=0.0
% INFO    : Bus 27082	: V=0.9796896, theta=-51.665326 -> V=1.0, theta=0.0
% INFO    : Bus 27083	: V=0.9724735, theta=-52.284585 -> V=1.0, theta=0.0
% INFO    : Bus 27084	: V=0.9683436, theta=-52.629378 -> V=1.0, theta=0.0
% INFO    : Bus 27085	: V=0.9763916, theta=-52.101961 -> V=1.0, theta=0.0
% INFO    : Bus 27086	: V=0.9864261, theta=-50.63197 -> V=1.0, theta=0.0
% INFO    : Bus 27087	: V=0.9756166, theta=-52.18936 -> V=1.0, theta=0.0
% INFO    : Bus 27088	: V=0.968192, theta=-53.458629 -> V=1.0, theta=0.0
% INFO    : Bus 27089	: V=0.9758997, theta=-52.160492 -> V=1.0, theta=0.0
% INFO    : Bus 27090	: V=0.9762197, theta=-52.129284 -> V=1.0, theta=0.0
% INFO    : Bus 27091	: V=0.971935, theta=-52.663531 -> V=1.0, theta=0.0
% INFO    : Bus 27092	: V=0.9677459, theta=-53.291968 -> V=1.0, theta=0.0
% INFO    : Bus 27093	: V=0.9689931, theta=-52.934476 -> V=1.0, theta=0.0
% INFO    : Bus 27094	: V=0.9716498, theta=-52.631535 -> V=1.0, theta=0.0
% INFO    : Bus 27095	: V=0.9664708, theta=-53.22032 -> V=1.0, theta=0.0
% INFO    : Bus 27096	: V=0.9711674, theta=-52.654631 -> V=1.0, theta=0.0
% INFO    : Bus 27097	: V=0.9748859, theta=-52.305425 -> V=1.0, theta=0.0
% INFO    : Bus 27098	: V=0.9739202, theta=-52.20674 -> V=1.0, theta=0.0
% INFO    : Bus 27099	: V=0.9715465, theta=-52.527501 -> V=1.0, theta=0.0
% INFO    : Bus 27100	: V=0.9745929, theta=-52.106123 -> V=1.0, theta=0.0
% INFO    : Bus 27101	: V=0.971565, theta=-52.397874 -> V=1.0, theta=0.0
% INFO    : Bus 27102	: V=0.973627, theta=-52.249723 -> V=1.0, theta=0.0
% INFO    : Bus 27103	: V=0.9620159, theta=-53.70563 -> V=1.0, theta=0.0
% INFO    : Bus 27104	: V=0.9647527, theta=-53.452521 -> V=1.0, theta=0.0
% INFO    : Bus 27105	: V=0.9620868, theta=-53.722026 -> V=1.0, theta=0.0
% INFO    : Bus 27106	: V=0.9632051, theta=-53.603229 -> V=1.0, theta=0.0
% INFO    : Bus 27107	: V=0.9686936, theta=-52.847228 -> V=1.0, theta=0.0
% INFO    : Bus 27108	: V=0.9692698, theta=-52.800285 -> V=1.0, theta=0.0
% INFO    : Bus 27109	: V=0.9699823, theta=-52.746186 -> V=1.0, theta=0.0
% INFO    : Bus 27110	: V=0.9676837, theta=-53.108463 -> V=1.0, theta=0.0
% INFO    : Bus 27111	: V=0.9626322, theta=-53.801736 -> V=1.0, theta=0.0
% INFO    : Bus 27112	: V=0.959405, theta=-54.544049 -> V=1.0, theta=0.0
% INFO    : Bus 27113	: V=0.9655181, theta=-53.369369 -> V=1.0, theta=0.0
% INFO    : Bus 27114	: V=0.9624029, theta=-53.764344 -> V=1.0, theta=0.0
% INFO    : Bus 27115	: V=0.9628934, theta=-53.698886 -> V=1.0, theta=0.0
% INFO    : Bus 27116	: V=0.9561612, theta=-54.800092 -> V=1.0, theta=0.0
% INFO    : Bus 27117	: V=0.9656207, theta=-53.539686 -> V=1.0, theta=0.0
% INFO    : Bus 27118	: V=0.9650583, theta=-53.948782 -> V=1.0, theta=0.0
% INFO    : Bus 27119	: V=0.9659493, theta=-53.521679 -> V=1.0, theta=0.0
% INFO    : Bus 27120	: V=0.9597987, theta=-54.342375 -> V=1.0, theta=0.0
% INFO    : Bus 27121	: V=0.9646319, theta=-53.667096 -> V=1.0, theta=0.0
% INFO    : Bus 27122	: V=0.9639271, theta=-53.743246 -> V=1.0, theta=0.0
% INFO    : Bus 27123	: V=0.9616933, theta=-54.5218 -> V=1.0, theta=0.0
% INFO    : Bus 27124	: V=0.9637083, theta=-54.248605 -> V=1.0, theta=0.0
% INFO    : Bus 27125	: V=0.9734913, theta=-52.456716 -> V=1.0, theta=0.0
% INFO    : Bus 27126	: V=0.9792385, theta=-50.965005 -> V=1.0, theta=0.0
% INFO    : Bus 27127	: V=0.9915168, theta=-50.133033 -> V=1.0, theta=0.0
% INFO    : Bus 27128	: V=0.9987822, theta=-49.279986 -> V=1.0, theta=0.0
% INFO    : Bus 27129	: V=0.9893269, theta=-50.283963 -> V=1.0, theta=0.0
% INFO    : Bus 27130	: V=0.9748418, theta=-52.424446 -> V=1.0, theta=0.0
% INFO    : Bus 27131	: V=0.9715644, theta=-52.525603 -> V=1.0, theta=0.0
% INFO    : Bus 27132	: V=1.0156041, theta=-40.118268 -> V=1.0, theta=0.0
% INFO    : Bus 27133	: V=1.0017323, theta=-43.876831 -> V=1.0, theta=0.0
% INFO    : Bus 27134	: V=0.9993652, theta=-44.203474 -> V=1.0, theta=0.0
% INFO    : Bus 27135	: V=1.0067357, theta=-40.982481 -> V=1.0, theta=0.0
% INFO    : Bus 27136	: V=0.9731287, theta=-58.220928 -> V=1.0, theta=0.0
% INFO    : Bus 27137	: V=0.9749544, theta=-57.473478 -> V=1.0, theta=0.0
% INFO    : Bus 27138	: V=0.9614278, theta=-59.468551 -> V=1.0, theta=0.0
% INFO    : Bus 27139	: V=0.9619582, theta=-59.039822 -> V=1.0, theta=0.0
% INFO    : Bus 27140	: V=0.9722572, theta=-57.421564 -> V=1.0, theta=0.0
% INFO    : Bus 27141	: V=0.9698125, theta=-57.268504 -> V=1.0, theta=0.0
% INFO    : Bus 27142	: V=1.0152466, theta=-45.385357 -> V=1.0, theta=0.0
% INFO    : Bus 27143	: V=0.9961943, theta=-48.592302 -> V=1.0, theta=0.0
% INFO    : Bus 27144	: V=0.9719931, theta=-50.644112 -> V=1.0, theta=0.0
% INFO    : Bus 27145	: V=0.9895005, theta=-48.070974 -> V=1.0, theta=0.0
% INFO    : Bus 27146	: V=0.9989005, theta=-46.917966 -> V=1.0, theta=0.0
% INFO    : Bus 27147	: V=0.9942755, theta=-47.418135 -> V=1.0, theta=0.0
% INFO    : Bus 27148	: V=1.0070414, theta=-46.185138 -> V=1.0, theta=0.0
% INFO    : Bus 27149	: V=0.9969327, theta=-47.330558 -> V=1.0, theta=0.0
% INFO    : Bus 27150	: V=1.0047886, theta=-46.386785 -> V=1.0, theta=0.0
% INFO    : Bus 27151	: V=0.999291, theta=-46.409076 -> V=1.0, theta=0.0
% INFO    : Bus 27152	: V=0.9985911, theta=-46.413356 -> V=1.0, theta=0.0
% INFO    : Bus 27153	: V=0.9987748, theta=-46.478467 -> V=1.0, theta=0.0
% INFO    : Bus 27154	: V=0.9964082, theta=-46.938198 -> V=1.0, theta=0.0
% INFO    : Bus 27155	: V=0.9964562, theta=-46.930402 -> V=1.0, theta=0.0
% INFO    : Bus 27156	: V=0.9952735, theta=-46.899765 -> V=1.0, theta=0.0
% INFO    : Bus 27157	: V=0.9955562, theta=-46.639047 -> V=1.0, theta=0.0
% INFO    : Bus 27158	: V=1.0029909, theta=-44.57897 -> V=1.0, theta=0.0
% INFO    : Bus 27159	: V=1.0003, theta=-46.113861 -> V=1.0, theta=0.0
% INFO    : Bus 27160	: V=1.0161287, theta=-44.400452 -> V=1.0, theta=0.0
% INFO    : Bus 27161	: V=1.0138808, theta=-41.547382 -> V=1.0, theta=0.0
% INFO    : Bus 27162	: V=1.0198362, theta=-39.790329 -> V=1.0, theta=0.0
% INFO    : Bus 27163	: V=0.9909366, theta=-41.889664 -> V=1.0, theta=0.0
% INFO    : Bus 27164	: V=1.0084883, theta=-51.656193 -> V=1.0, theta=0.0
% INFO    : Bus 27165	: V=1.0058574, theta=-52.349131 -> V=1.0, theta=0.0
% INFO    : Bus 27166	: V=1.0064613, theta=-52.19587 -> V=1.0, theta=0.0
% INFO    : Bus 27167	: V=1.0117165, theta=-51.760008 -> V=1.0, theta=0.0
% INFO    : Bus 27168	: V=1.0033143, theta=-52.414729 -> V=1.0, theta=0.0
% INFO    : Bus 27169	: V=1.0067389, theta=-52.282532 -> V=1.0, theta=0.0
% INFO    : Bus 27170	: V=1.0068942, theta=-52.242956 -> V=1.0, theta=0.0
% INFO    : Bus 27171	: V=1.0092933, theta=-50.239785 -> V=1.0, theta=0.0
% INFO    : Bus 27172	: V=1.0113005, theta=-50.214356 -> V=1.0, theta=0.0
% INFO    : Bus 27173	: V=1.0163646, theta=-50.06773 -> V=1.0, theta=0.0
% INFO    : Bus 27174	: V=1.0143998, theta=-50.535318 -> V=1.0, theta=0.0
% INFO    : Bus 27175	: V=1.0001239, theta=-52.172128 -> V=1.0, theta=0.0
% INFO    : Bus 27176	: V=1.0153466, theta=-50.563799 -> V=1.0, theta=0.0
% INFO    : Bus 27177	: V=0.9905831, theta=-56.190529 -> V=1.0, theta=0.0
% INFO    : Bus 27178	: V=0.9713734, theta=-57.991604 -> V=1.0, theta=0.0
% INFO    : Bus 27179	: V=0.9994468, theta=-54.615775 -> V=1.0, theta=0.0
% INFO    : Bus 27180	: V=0.9900878, theta=-56.287498 -> V=1.0, theta=0.0
% INFO    : Bus 27181	: V=0.9726361, theta=-57.139943 -> V=1.0, theta=0.0
% INFO    : Bus 27182	: V=0.9804278, theta=-49.404059 -> V=1.0, theta=0.0
% INFO    : Bus 27183	: V=0.9936765, theta=-47.534179 -> V=1.0, theta=0.0
% INFO    : Bus 27184	: V=0.9943992, theta=-46.401927 -> V=1.0, theta=0.0
% INFO    : Bus 27185	: V=0.9978893, theta=-44.450299 -> V=1.0, theta=0.0
% INFO    : Bus 27186	: V=0.9941548, theta=-47.238349 -> V=1.0, theta=0.0
% INFO    : Bus 27187	: V=0.9958403, theta=-45.331323 -> V=1.0, theta=0.0
% INFO    : Bus 27188	: V=0.9900657, theta=-47.842672 -> V=1.0, theta=0.0
% INFO    : Bus 27189	: V=0.9803199, theta=-49.050567 -> V=1.0, theta=0.0
% INFO    : Bus 27190	: V=0.9791874, theta=-49.013348 -> V=1.0, theta=0.0
% INFO    : Bus 27191	: V=0.9901904, theta=-47.813641 -> V=1.0, theta=0.0
% INFO    : Bus 27192	: V=0.9902828, theta=-47.430348 -> V=1.0, theta=0.0
% INFO    : Bus 27193	: V=0.9812036, theta=-49.550121 -> V=1.0, theta=0.0
% INFO    : Bus 27194	: V=0.983291, theta=-50.17907 -> V=1.0, theta=0.0
% INFO    : Bus 27195	: V=0.9853134, theta=-50.599533 -> V=1.0, theta=0.0
% INFO    : Bus 27196	: V=0.9880322, theta=-50.082211 -> V=1.0, theta=0.0
% INFO    : Bus 27197	: V=0.9842312, theta=-50.309809 -> V=1.0, theta=0.0
% INFO    : Bus 27198	: V=0.9921591, theta=-48.295679 -> V=1.0, theta=0.0
% INFO    : Bus 27199	: V=0.993824, theta=-47.111922 -> V=1.0, theta=0.0
% INFO    : Bus 27200	: V=0.991337, theta=-46.573927 -> V=1.0, theta=0.0
% INFO    : Bus 27201	: V=1.002033, theta=-42.771974 -> V=1.0, theta=0.0
% INFO    : Bus 27202	: V=0.9903506, theta=-44.454086 -> V=1.0, theta=0.0
% INFO    : Bus 27203	: V=0.9857596, theta=-44.537391 -> V=1.0, theta=0.0
% INFO    : Bus 27204	: V=0.9894982, theta=-44.826012 -> V=1.0, theta=0.0
% INFO    : Bus 27205	: V=0.9999396, theta=-43.922356 -> V=1.0, theta=0.0
% INFO    : Bus 27206	: V=1.0008032, theta=-43.01798 -> V=1.0, theta=0.0
% INFO    : Bus 27207	: V=0.9670865, theta=-56.857706 -> V=1.0, theta=0.0
% INFO    : Bus 27208	: V=0.9704921, theta=-56.505547 -> V=1.0, theta=0.0
% INFO    : Bus 27209	: V=0.9637903, theta=-57.423526 -> V=1.0, theta=0.0
% INFO    : Bus 27210	: V=0.9792761, theta=-57.955642 -> V=1.0, theta=0.0
% INFO    : Bus 27211	: V=0.9786062, theta=-58.017701 -> V=1.0, theta=0.0
% INFO    : Bus 27212	: V=0.9780365, theta=-58.025447 -> V=1.0, theta=0.0
% INFO    : Bus 27213	: V=0.9774643, theta=-57.688732 -> V=1.0, theta=0.0
% INFO    : Bus 27214	: V=0.978111, theta=-57.942211 -> V=1.0, theta=0.0
% INFO    : Bus 27215	: V=0.967553, theta=-57.255259 -> V=1.0, theta=0.0
% INFO    : Bus 27216	: V=0.969166, theta=-56.630268 -> V=1.0, theta=0.0
% INFO    : Bus 27217	: V=0.9668536, theta=-55.293671 -> V=1.0, theta=0.0
% INFO    : Bus 27218	: V=0.9712628, theta=-56.296552 -> V=1.0, theta=0.0
% INFO    : Bus 27219	: V=0.9677844, theta=-55.046499 -> V=1.0, theta=0.0
% INFO    : Bus 27220	: V=0.9705223, theta=-55.568829 -> V=1.0, theta=0.0
% INFO    : Bus 27221	: V=0.9702678, theta=-54.824027 -> V=1.0, theta=0.0
% INFO    : Bus 27222	: V=0.9726811, theta=-56.844313 -> V=1.0, theta=0.0
% INFO    : Bus 27223	: V=0.9730643, theta=-56.892874 -> V=1.0, theta=0.0
% INFO    : Bus 27224	: V=0.9727186, theta=-56.711413 -> V=1.0, theta=0.0
% INFO    : Bus 27225	: V=0.9739757, theta=-58.53274 -> V=1.0, theta=0.0
% INFO    : Bus 27226	: V=0.9743548, theta=-57.0502 -> V=1.0, theta=0.0
% INFO    : Bus 27227	: V=0.9769343, theta=-57.268467 -> V=1.0, theta=0.0
% INFO    : Bus 27228	: V=0.9799725, theta=-57.926953 -> V=1.0, theta=0.0
% INFO    : Bus 27229	: V=0.9834895, theta=-55.549451 -> V=1.0, theta=0.0
% INFO    : Bus 27230	: V=0.9781987, theta=-58.157001 -> V=1.0, theta=0.0
% INFO    : Bus 27231	: V=0.9777776, theta=-58.211234 -> V=1.0, theta=0.0
% INFO    : Bus 27232	: V=0.9769667, theta=-58.259012 -> V=1.0, theta=0.0
% INFO    : Bus 27233	: V=0.9758444, theta=-57.193196 -> V=1.0, theta=0.0
% INFO    : Bus 27234	: V=0.9832956, theta=-55.446121 -> V=1.0, theta=0.0
% INFO    : Bus 27235	: V=0.9830367, theta=-55.485017 -> V=1.0, theta=0.0
% INFO    : Bus 27236	: V=0.9742397, theta=-58.67849 -> V=1.0, theta=0.0
% INFO    : Bus 27237	: V=0.9722004, theta=-56.047244 -> V=1.0, theta=0.0
% INFO    : Bus 27238	: V=0.9757093, theta=-54.258298 -> V=1.0, theta=0.0
% INFO    : Bus 27239	: V=0.9724334, theta=-53.95867 -> V=1.0, theta=0.0
% INFO    : Bus 27240	: V=0.9729975, theta=-55.297967 -> V=1.0, theta=0.0
% INFO    : Bus 27241	: V=0.983737, theta=-54.883871 -> V=1.0, theta=0.0
% INFO    : Bus 27242	: V=0.969703, theta=-53.728197 -> V=1.0, theta=0.0
% INFO    : Bus 27243	: V=0.9671019, theta=-53.321299 -> V=1.0, theta=0.0
% INFO    : Bus 27244	: V=0.9851109, theta=-52.177929 -> V=1.0, theta=0.0
% INFO    : Bus 27245	: V=0.9984798, theta=-49.406498 -> V=1.0, theta=0.0
% INFO    : Bus 27246	: V=0.9985328, theta=-49.401049 -> V=1.0, theta=0.0
% INFO    : Bus 27247	: V=0.9839783, theta=-51.458524 -> V=1.0, theta=0.0
% INFO    : Bus 27248	: V=0.9877438, theta=-51.119604 -> V=1.0, theta=0.0
% INFO    : Bus 27249	: V=0.9929285, theta=-50.518302 -> V=1.0, theta=0.0
% INFO    : Bus 27250	: V=0.9847058, theta=-50.791839 -> V=1.0, theta=0.0
% INFO    : Bus 27251	: V=0.9894491, theta=-50.718596 -> V=1.0, theta=0.0
% INFO    : Bus 27252	: V=0.9998801, theta=-49.009425 -> V=1.0, theta=0.0
% INFO    : Bus 27253	: V=0.9974542, theta=-49.555377 -> V=1.0, theta=0.0
% INFO    : Bus 27254	: V=0.9799995, theta=-55.214685 -> V=1.0, theta=0.0
% INFO    : Bus 27255	: V=0.9600218, theta=-57.487266 -> V=1.0, theta=0.0
% INFO    : Bus 27256	: V=0.9801627, theta=-54.81248 -> V=1.0, theta=0.0
% INFO    : Bus 27257	: V=0.9774036, theta=-54.944946 -> V=1.0, theta=0.0
% INFO    : Bus 27258	: V=0.9668869, theta=-56.072586 -> V=1.0, theta=0.0
% INFO    : Bus 27259	: V=0.9687875, theta=-55.724905 -> V=1.0, theta=0.0
% INFO    : Bus 27260	: V=0.968074, theta=-56.255022 -> V=1.0, theta=0.0
% INFO    : Bus 27261	: V=0.9803954, theta=-57.010664 -> V=1.0, theta=0.0
% INFO    : Bus 27262	: V=0.9796757, theta=-57.147947 -> V=1.0, theta=0.0
% INFO    : Bus 27263	: V=0.9777137, theta=-58.175361 -> V=1.0, theta=0.0
% INFO    : Bus 27264	: V=0.9774902, theta=-58.273857 -> V=1.0, theta=0.0
% INFO    : Bus 27265	: V=0.9806165, theta=-56.830324 -> V=1.0, theta=0.0
% INFO    : Bus 27266	: V=0.9776754, theta=-58.134978 -> V=1.0, theta=0.0
% INFO    : Bus 27267	: V=0.9819947, theta=-56.713555 -> V=1.0, theta=0.0
% INFO    : Bus 27268	: V=0.9792539, theta=-57.597843 -> V=1.0, theta=0.0
% INFO    : Bus 27269	: V=0.9789016, theta=-57.847985 -> V=1.0, theta=0.0
% INFO    : Bus 27270	: V=0.9790927, theta=-57.279903 -> V=1.0, theta=0.0
% INFO    : Bus 27271	: V=0.9785428, theta=-57.404307 -> V=1.0, theta=0.0
% INFO    : Bus 27272	: V=0.9767813, theta=-58.559011 -> V=1.0, theta=0.0
% INFO    : Bus 27273	: V=0.977695, theta=-58.480417 -> V=1.0, theta=0.0
% INFO    : Bus 27274	: V=0.9807091, theta=-57.463177 -> V=1.0, theta=0.0
% INFO    : Bus 27275	: V=0.9821411, theta=-56.678807 -> V=1.0, theta=0.0
% INFO    : Bus 27276	: V=0.982948, theta=-56.49872 -> V=1.0, theta=0.0
% INFO    : Bus 27277	: V=0.9908323, theta=-54.653669 -> V=1.0, theta=0.0
% INFO    : Bus 27278	: V=0.9789181, theta=-57.62636 -> V=1.0, theta=0.0
% INFO    : Bus 27279	: V=0.9799734, theta=-57.268194 -> V=1.0, theta=0.0
% INFO    : Bus 27280	: V=0.9764568, theta=-57.447531 -> V=1.0, theta=0.0
% INFO    : Bus 27281	: V=0.9774385, theta=-57.767192 -> V=1.0, theta=0.0
% INFO    : Bus 27282	: V=0.9776391, theta=-57.641728 -> V=1.0, theta=0.0
% INFO    : Bus 27283	: V=0.9855594, theta=-59.218573 -> V=1.0, theta=0.0
% INFO    : Bus 27284	: V=0.9916301, theta=-59.01153 -> V=1.0, theta=0.0
% INFO    : Bus 27285	: V=0.9843236, theta=-58.952549 -> V=1.0, theta=0.0
% INFO    : Bus 27286	: V=0.9821959, theta=-59.311387 -> V=1.0, theta=0.0
% INFO    : Bus 27287	: V=0.9816586, theta=-57.24971 -> V=1.0, theta=0.0
% INFO    : Bus 27288	: V=0.979664, theta=-56.363856 -> V=1.0, theta=0.0
% INFO    : Bus 27289	: V=0.9908857, theta=-54.624377 -> V=1.0, theta=0.0
% INFO    : Bus 27290	: V=0.9798397, theta=-56.904511 -> V=1.0, theta=0.0
% INFO    : Bus 27291	: V=0.9927972, theta=-46.151244 -> V=1.0, theta=0.0
% INFO    : Bus 27292	: V=0.9960868, theta=-45.874701 -> V=1.0, theta=0.0
% INFO    : Bus 27293	: V=0.9943998, theta=-45.649904 -> V=1.0, theta=0.0
% INFO    : Bus 27294	: V=0.9946277, theta=-46.125732 -> V=1.0, theta=0.0
% INFO    : Bus 27295	: V=0.9954424, theta=-45.244624 -> V=1.0, theta=0.0
% INFO    : Bus 27296	: V=0.9981105, theta=-45.281053 -> V=1.0, theta=0.0
% INFO    : Bus 27297	: V=0.9931091, theta=-45.527447 -> V=1.0, theta=0.0
% INFO    : Bus 27298	: V=0.9940436, theta=-45.599267 -> V=1.0, theta=0.0
% INFO    : Bus 27299	: V=0.9923059, theta=-46.042059 -> V=1.0, theta=0.0
% INFO    : Bus 27300	: V=0.9922236, theta=-46.013885 -> V=1.0, theta=0.0
% INFO    : Bus 27301	: V=0.9961421, theta=-45.548498 -> V=1.0, theta=0.0
% INFO    : Bus 27302	: V=0.9928343, theta=-46.060567 -> V=1.0, theta=0.0
% INFO    : Bus 27303	: V=0.9962513, theta=-45.25168 -> V=1.0, theta=0.0
% INFO    : Bus 27304	: V=0.9946284, theta=-45.681587 -> V=1.0, theta=0.0
% INFO    : Bus 27305	: V=0.969211, theta=-45.642312 -> V=1.0, theta=0.0
% INFO    : Bus 27306	: V=0.9911205, theta=-45.24546 -> V=1.0, theta=0.0
% INFO    : Bus 27307	: V=0.9981832, theta=-44.622406 -> V=1.0, theta=0.0
% INFO    : Bus 27308	: V=1.0083485, theta=-51.274127 -> V=1.0, theta=0.0
% INFO    : Bus 27309	: V=0.9887215, theta=-54.443763 -> V=1.0, theta=0.0
% INFO    : Bus 27310	: V=0.9961564, theta=-53.549241 -> V=1.0, theta=0.0
% INFO    : Bus 27311	: V=0.974231, theta=-56.337148 -> V=1.0, theta=0.0
% INFO    : Bus 27312	: V=0.9710551, theta=-56.926843 -> V=1.0, theta=0.0
% INFO    : Bus 27313	: V=0.9746812, theta=-56.324679 -> V=1.0, theta=0.0
% INFO    : Bus 27314	: V=0.9767512, theta=-56.259617 -> V=1.0, theta=0.0
% INFO    : Bus 27315	: V=0.977606, theta=-56.244057 -> V=1.0, theta=0.0
% INFO    : Bus 27316	: V=0.9858815, theta=-54.755442 -> V=1.0, theta=0.0
% INFO    : Bus 27317	: V=0.9858181, theta=-55.05266 -> V=1.0, theta=0.0
% INFO    : Bus 27318	: V=0.9776535, theta=-56.244098 -> V=1.0, theta=0.0
% INFO    : Bus 27319	: V=0.9722956, theta=-57.209846 -> V=1.0, theta=0.0
% INFO    : Bus 27320	: V=0.9918743, theta=-54.556712 -> V=1.0, theta=0.0
% INFO    : Bus 27321	: V=0.9782902, theta=-57.255555 -> V=1.0, theta=0.0
% INFO    : Bus 27322	: V=0.9778515, theta=-57.513288 -> V=1.0, theta=0.0
% INFO    : Bus 27323	: V=1.0037418, theta=-41.284028 -> V=1.0, theta=0.0
% INFO    : Bus 27324	: V=1.0066575, theta=-41.428165 -> V=1.0, theta=0.0
% INFO    : Bus 27325	: V=1.002734, theta=-41.987412 -> V=1.0, theta=0.0
% INFO    : Bus 27326	: V=1.0057745, theta=-41.249173 -> V=1.0, theta=0.0
% INFO    : Bus 27327	: V=1.0070907, theta=-40.546222 -> V=1.0, theta=0.0
% INFO    : Bus 27328	: V=0.9940986, theta=-40.667676 -> V=1.0, theta=0.0
% INFO    : Bus 27329	: V=1.0093841, theta=-39.472327 -> V=1.0, theta=0.0
% INFO    : Bus 27330	: V=1.0162051, theta=-38.497896 -> V=1.0, theta=0.0
% INFO    : Bus 27331	: V=1.0218204, theta=-36.893569 -> V=1.0, theta=0.0
% INFO    : Bus 27332	: V=1.0123663, theta=-39.463627 -> V=1.0, theta=0.0
% INFO    : Bus 27333	: V=1.0126393, theta=-39.602297 -> V=1.0, theta=0.0
% INFO    : Bus 27334	: V=1.0081406, theta=-40.256522 -> V=1.0, theta=0.0
% INFO    : Bus 27335	: V=1.0063943, theta=-40.394099 -> V=1.0, theta=0.0
% INFO    : Bus 27336	: V=1.006509, theta=-40.398978 -> V=1.0, theta=0.0
% INFO    : Bus 27337	: V=1.0138808, theta=-39.336951 -> V=1.0, theta=0.0
% INFO    : Bus 27338	: V=1.0060894, theta=-40.494719 -> V=1.0, theta=0.0
% INFO    : Bus 27339	: V=1.009236, theta=-40.221163 -> V=1.0, theta=0.0
% INFO    : Bus 27340	: V=1.0022028, theta=-40.482296 -> V=1.0, theta=0.0
% INFO    : Bus 27341	: V=1.0081947, theta=-40.533381 -> V=1.0, theta=0.0
% INFO    : Bus 27342	: V=1.0040786, theta=-40.955141 -> V=1.0, theta=0.0
% INFO    : Bus 27343	: V=0.9655668, theta=-59.06007 -> V=1.0, theta=0.0
% INFO    : Bus 27344	: V=0.9656389, theta=-58.260876 -> V=1.0, theta=0.0
% INFO    : Bus 27345	: V=0.9747556, theta=-56.162106 -> V=1.0, theta=0.0
% INFO    : Bus 27346	: V=0.97466, theta=-56.146387 -> V=1.0, theta=0.0
% INFO    : Bus 27347	: V=0.9617412, theta=-58.231968 -> V=1.0, theta=0.0
% INFO    : Bus 27348	: V=0.9602754, theta=-58.423321 -> V=1.0, theta=0.0
% INFO    : Bus 27349	: V=0.9676678, theta=-57.478477 -> V=1.0, theta=0.0
% INFO    : Bus 27350	: V=0.9572321, theta=-59.111911 -> V=1.0, theta=0.0
% INFO    : Bus 27351	: V=0.9537256, theta=-58.971938 -> V=1.0, theta=0.0
% INFO    : Bus 27352	: V=0.9555251, theta=-59.115792 -> V=1.0, theta=0.0
% INFO    : Bus 27353	: V=0.9502969, theta=-59.186595 -> V=1.0, theta=0.0
% INFO    : Bus 27354	: V=0.9510018, theta=-59.287642 -> V=1.0, theta=0.0
% INFO    : Bus 27355	: V=0.9546571, theta=-59.286047 -> V=1.0, theta=0.0
% INFO    : Bus 27356	: V=0.9637043, theta=-59.578393 -> V=1.0, theta=0.0
% INFO    : Bus 27357	: V=0.9543619, theta=-56.579836 -> V=1.0, theta=0.0
% INFO    : Bus 27358	: V=0.9588204, theta=-55.722346 -> V=1.0, theta=0.0
% INFO    : Bus 27359	: V=0.9666535, theta=-55.921217 -> V=1.0, theta=0.0
% INFO    : Bus 27360	: V=0.9511851, theta=-56.332481 -> V=1.0, theta=0.0
% INFO    : Bus 27361	: V=0.9518431, theta=-56.294736 -> V=1.0, theta=0.0
% INFO    : Bus 27362	: V=0.9497635, theta=-56.427207 -> V=1.0, theta=0.0
% INFO    : Bus 27363	: V=0.9465983, theta=-57.212898 -> V=1.0, theta=0.0
% INFO    : Bus 27364	: V=0.9446532, theta=-57.337898 -> V=1.0, theta=0.0
% INFO    : Bus 27365	: V=0.9428426, theta=-57.50466 -> V=1.0, theta=0.0
% INFO    : Bus 27366	: V=0.9487888, theta=-57.372665 -> V=1.0, theta=0.0
% INFO    : Bus 27367	: V=0.9732589, theta=-55.368544 -> V=1.0, theta=0.0
% INFO    : Bus 27368	: V=0.97215, theta=-55.626487 -> V=1.0, theta=0.0
% INFO    : Bus 27369	: V=0.9713905, theta=-55.515857 -> V=1.0, theta=0.0
% INFO    : Bus 27370	: V=0.9711497, theta=-55.517894 -> V=1.0, theta=0.0
% INFO    : Bus 27371	: V=0.9714671, theta=-55.515016 -> V=1.0, theta=0.0
% INFO    : Bus 27372	: V=0.971595, theta=-55.50436 -> V=1.0, theta=0.0
% INFO    : Bus 27373	: V=0.9759737, theta=-54.621853 -> V=1.0, theta=0.0
% INFO    : Bus 27374	: V=0.9723379, theta=-55.468355 -> V=1.0, theta=0.0
% INFO    : Bus 27375	: V=0.9739745, theta=-55.378548 -> V=1.0, theta=0.0
% INFO    : Bus 27376	: V=0.9786559, theta=-54.568785 -> V=1.0, theta=0.0
% INFO    : Bus 27377	: V=0.97536, theta=-55.234837 -> V=1.0, theta=0.0
% INFO    : Bus 27378	: V=0.9838144, theta=-53.323334 -> V=1.0, theta=0.0
% INFO    : Bus 27379	: V=0.977006, theta=-54.527384 -> V=1.0, theta=0.0
% INFO    : Bus 27380	: V=0.9737372, theta=-55.35724 -> V=1.0, theta=0.0
% INFO    : Bus 27381	: V=0.9764122, theta=-54.352838 -> V=1.0, theta=0.0
% INFO    : Bus 27382	: V=0.9770072, theta=-54.255497 -> V=1.0, theta=0.0
% INFO    : Bus 27383	: V=0.9769704, theta=-54.515996 -> V=1.0, theta=0.0
% INFO    : Bus 27384	: V=0.984232, theta=-53.173429 -> V=1.0, theta=0.0
% INFO    : Bus 27385	: V=0.9909456, theta=-48.81843 -> V=1.0, theta=0.0
% INFO    : Bus 27386	: V=0.9787148, theta=-52.68489 -> V=1.0, theta=0.0
% INFO    : Bus 27387	: V=0.979371, theta=-52.635257 -> V=1.0, theta=0.0
% INFO    : Bus 27388	: V=0.9807552, theta=-52.498947 -> V=1.0, theta=0.0
% INFO    : Bus 27389	: V=0.9797633, theta=-52.726766 -> V=1.0, theta=0.0
% INFO    : Bus 27390	: V=0.9778213, theta=-52.699671 -> V=1.0, theta=0.0
% INFO    : Bus 27391	: V=0.9803193, theta=-53.155876 -> V=1.0, theta=0.0
% INFO    : Bus 27392	: V=0.9801121, theta=-54.658252 -> V=1.0, theta=0.0
% INFO    : Bus 27393	: V=0.9804627, theta=-55.880787 -> V=1.0, theta=0.0
% INFO    : Bus 27394	: V=0.9792069, theta=-56.275774 -> V=1.0, theta=0.0
% INFO    : Bus 27395	: V=0.9791813, theta=-56.203397 -> V=1.0, theta=0.0
% INFO    : Bus 27396	: V=0.9793115, theta=-56.072793 -> V=1.0, theta=0.0
% INFO    : Bus 27397	: V=0.9787399, theta=-55.938737 -> V=1.0, theta=0.0
% INFO    : Bus 27398	: V=0.9806283, theta=-56.422992 -> V=1.0, theta=0.0
% INFO    : Bus 27399	: V=0.9779411, theta=-57.285029 -> V=1.0, theta=0.0
% INFO    : Bus 27400	: V=0.9787208, theta=-56.564427 -> V=1.0, theta=0.0
% INFO    : Bus 27401	: V=0.9760116, theta=-57.515603 -> V=1.0, theta=0.0
% INFO    : Bus 27402	: V=0.9729573, theta=-55.838132 -> V=1.0, theta=0.0
% INFO    : Bus 27403	: V=0.9733271, theta=-55.798229 -> V=1.0, theta=0.0
% INFO    : Bus 27404	: V=0.9735371, theta=-55.766025 -> V=1.0, theta=0.0
% INFO    : Bus 27405	: V=0.9748455, theta=-55.668798 -> V=1.0, theta=0.0
% INFO    : Bus 27406	: V=0.9799954, theta=-55.744828 -> V=1.0, theta=0.0
% INFO    : Bus 27407	: V=0.9829955, theta=-54.048093 -> V=1.0, theta=0.0
% INFO    : Bus 27408	: V=0.9742364, theta=-55.667183 -> V=1.0, theta=0.0
% INFO    : Bus 27409	: V=0.9743072, theta=-55.552543 -> V=1.0, theta=0.0
% INFO    : Bus 27410	: V=0.9783684, theta=-54.612527 -> V=1.0, theta=0.0
% INFO    : Bus 27411	: V=0.9752498, theta=-54.735185 -> V=1.0, theta=0.0
% INFO    : Bus 27412	: V=0.9747274, theta=-54.825224 -> V=1.0, theta=0.0
% INFO    : Bus 27413	: V=0.9746459, theta=-55.871183 -> V=1.0, theta=0.0
% INFO    : Bus 27414	: V=0.9778569, theta=-55.609319 -> V=1.0, theta=0.0
% INFO    : Bus 27415	: V=0.9690445, theta=-56.027709 -> V=1.0, theta=0.0
% INFO    : Bus 27416	: V=0.9783059, theta=-55.804927 -> V=1.0, theta=0.0
% INFO    : Bus 27417	: V=0.9737587, theta=-55.964228 -> V=1.0, theta=0.0
% INFO    : Bus 27418	: V=0.9735173, theta=-55.831389 -> V=1.0, theta=0.0
% INFO    : Bus 27419	: V=0.9716773, theta=-55.910808 -> V=1.0, theta=0.0
% INFO    : Bus 27420	: V=0.970516, theta=-55.875162 -> V=1.0, theta=0.0
% INFO    : Bus 27421	: V=0.9760609, theta=-54.272641 -> V=1.0, theta=0.0
% INFO    : Bus 27422	: V=0.9723389, theta=-55.458215 -> V=1.0, theta=0.0
% INFO    : Bus 27423	: V=0.9761537, theta=-54.06918 -> V=1.0, theta=0.0
% INFO    : Bus 27424	: V=0.9767545, theta=-53.914079 -> V=1.0, theta=0.0
% INFO    : Bus 27425	: V=0.9766272, theta=-53.785457 -> V=1.0, theta=0.0
% INFO    : Bus 27426	: V=0.9781546, theta=-53.168896 -> V=1.0, theta=0.0
% INFO    : Bus 27427	: V=0.9842921, theta=-52.591357 -> V=1.0, theta=0.0
% INFO    : Bus 27428	: V=0.9780088, theta=-53.602284 -> V=1.0, theta=0.0
% INFO    : Bus 27429	: V=0.969822, theta=-56.07133 -> V=1.0, theta=0.0
% INFO    : Bus 27430	: V=0.9852609, theta=-52.825226 -> V=1.0, theta=0.0
% INFO    : Bus 27431	: V=0.9752242, theta=-55.983279 -> V=1.0, theta=0.0
% INFO    : Bus 27432	: V=0.9784178, theta=-54.625061 -> V=1.0, theta=0.0
% INFO    : Bus 27433	: V=0.9834557, theta=-53.52647 -> V=1.0, theta=0.0
% INFO    : Bus 27434	: V=0.9790856, theta=-54.694021 -> V=1.0, theta=0.0
% INFO    : Bus 27435	: V=0.9760047, theta=-55.663803 -> V=1.0, theta=0.0
% INFO    : Bus 27436	: V=0.9762076, theta=-56.141358 -> V=1.0, theta=0.0
% INFO    : Bus 27437	: V=0.9770823, theta=-55.406279 -> V=1.0, theta=0.0
% INFO    : Bus 27438	: V=0.9773303, theta=-55.372617 -> V=1.0, theta=0.0
% INFO    : Bus 27439	: V=0.9828578, theta=-54.081212 -> V=1.0, theta=0.0
% INFO    : Bus 27440	: V=0.9795068, theta=-55.348328 -> V=1.0, theta=0.0
% INFO    : Bus 27441	: V=0.9769523, theta=-55.362627 -> V=1.0, theta=0.0
% INFO    : Bus 27442	: V=0.9765532, theta=-55.354543 -> V=1.0, theta=0.0
% INFO    : Bus 27443	: V=0.9765822, theta=-55.533811 -> V=1.0, theta=0.0
% INFO    : Bus 27444	: V=0.9797491, theta=-54.51921 -> V=1.0, theta=0.0
% INFO    : Bus 27445	: V=0.9810456, theta=-54.132855 -> V=1.0, theta=0.0
% INFO    : Bus 27446	: V=0.9809622, theta=-54.735118 -> V=1.0, theta=0.0
% INFO    : Bus 27447	: V=0.9814811, theta=-54.517959 -> V=1.0, theta=0.0
% INFO    : Bus 27448	: V=0.9825297, theta=-53.820804 -> V=1.0, theta=0.0
% INFO    : Bus 27449	: V=0.9840545, theta=-53.288161 -> V=1.0, theta=0.0
% INFO    : Bus 27450	: V=0.9876393, theta=-52.301757 -> V=1.0, theta=0.0
% INFO    : Bus 27451	: V=0.9775361, theta=-52.564533 -> V=1.0, theta=0.0
% INFO    : Bus 27452	: V=0.979939, theta=-54.737243 -> V=1.0, theta=0.0
% INFO    : Bus 27453	: V=0.9754034, theta=-59.38826 -> V=1.0, theta=0.0
% INFO    : Bus 27454	: V=0.9766695, theta=-59.101676 -> V=1.0, theta=0.0
% INFO    : Bus 27455	: V=0.9767734, theta=-58.539666 -> V=1.0, theta=0.0
% INFO    : Bus 27456	: V=0.9771258, theta=-59.247754 -> V=1.0, theta=0.0
% INFO    : Bus 27457	: V=0.9743739, theta=-59.545333 -> V=1.0, theta=0.0
% INFO    : Bus 27458	: V=0.9774019, theta=-57.932234 -> V=1.0, theta=0.0
% INFO    : Bus 27459	: V=0.9780148, theta=-57.862892 -> V=1.0, theta=0.0
% INFO    : Bus 27460	: V=0.9789337, theta=-57.684113 -> V=1.0, theta=0.0
% INFO    : Bus 27461	: V=0.9816753, theta=-56.174377 -> V=1.0, theta=0.0
% INFO    : Bus 27462	: V=0.9817491, theta=-56.134363 -> V=1.0, theta=0.0
% INFO    : Bus 27463	: V=0.9794867, theta=-58.152536 -> V=1.0, theta=0.0
% INFO    : Bus 27464	: V=0.9818565, theta=-56.073491 -> V=1.0, theta=0.0
% INFO    : Bus 27465	: V=0.9762706, theta=-59.082286 -> V=1.0, theta=0.0
% INFO    : Bus 27466	: V=0.9773136, theta=-58.765758 -> V=1.0, theta=0.0
% INFO    : Bus 27467	: V=0.9773579, theta=-58.636763 -> V=1.0, theta=0.0
% INFO    : Bus 27468	: V=0.978068, theta=-58.601372 -> V=1.0, theta=0.0
% INFO    : Bus 27469	: V=0.9766793, theta=-58.657866 -> V=1.0, theta=0.0
% INFO    : Bus 27470	: V=0.9785207, theta=-57.689319 -> V=1.0, theta=0.0
% INFO    : Bus 27471	: V=0.9792975, theta=-57.584121 -> V=1.0, theta=0.0
% INFO    : Bus 27472	: V=0.9816797, theta=-56.151124 -> V=1.0, theta=0.0
% INFO    : Bus 27473	: V=0.9774397, theta=-57.81319 -> V=1.0, theta=0.0
% INFO    : Bus 27474	: V=0.9765014, theta=-59.072625 -> V=1.0, theta=0.0
% INFO    : Bus 27475	: V=0.9762291, theta=-59.084754 -> V=1.0, theta=0.0
% INFO    : Bus 27476	: V=0.9752473, theta=-59.081119 -> V=1.0, theta=0.0
% INFO    : Bus 27477	: V=0.9758522, theta=-59.052962 -> V=1.0, theta=0.0
% INFO    : Bus 27478	: V=0.9766616, theta=-58.971578 -> V=1.0, theta=0.0
% INFO    : Bus 27479	: V=0.9762822, theta=-59.022464 -> V=1.0, theta=0.0
% INFO    : Bus 27480	: V=0.9773088, theta=-58.949872 -> V=1.0, theta=0.0
% INFO    : Bus 27481	: V=0.9770245, theta=-58.473981 -> V=1.0, theta=0.0
% INFO    : Bus 27482	: V=0.977022, theta=-59.348014 -> V=1.0, theta=0.0
% INFO    : Bus 27483	: V=0.9763615, theta=-58.496985 -> V=1.0, theta=0.0
% INFO    : Bus 27484	: V=0.9761139, theta=-59.45523 -> V=1.0, theta=0.0
% INFO    : Bus 27485	: V=0.977378, theta=-58.387969 -> V=1.0, theta=0.0
% INFO    : Bus 27486	: V=0.9727155, theta=-59.760705 -> V=1.0, theta=0.0
% INFO    : Bus 27487	: V=0.9769368, theta=-58.364711 -> V=1.0, theta=0.0
% INFO    : Bus 27488	: V=0.9815326, theta=-55.987983 -> V=1.0, theta=0.0
% INFO    : Bus 27489	: V=0.9756156, theta=-58.765752 -> V=1.0, theta=0.0
% INFO    : Bus 27490	: V=0.9749898, theta=-59.518262 -> V=1.0, theta=0.0
% INFO    : Bus 27491	: V=0.9761868, theta=-58.71344 -> V=1.0, theta=0.0
% INFO    : Bus 27492	: V=0.9762682, theta=-58.682939 -> V=1.0, theta=0.0
% INFO    : Bus 27493	: V=0.9773676, theta=-59.169744 -> V=1.0, theta=0.0
% INFO    : Bus 27494	: V=0.9765972, theta=-58.586911 -> V=1.0, theta=0.0
% INFO    : Bus 27495	: V=0.981673, theta=-56.221876 -> V=1.0, theta=0.0
% INFO    : Bus 27496	: V=0.9761936, theta=-58.797104 -> V=1.0, theta=0.0
% INFO    : Bus 27497	: V=0.97575, theta=-58.808795 -> V=1.0, theta=0.0
% INFO    : Bus 27498	: V=0.9752721, theta=-59.426768 -> V=1.0, theta=0.0
% INFO    : Bus 27499	: V=0.9760915, theta=-58.765321 -> V=1.0, theta=0.0
% INFO    : Bus 27500	: V=0.9756207, theta=-59.364695 -> V=1.0, theta=0.0
% INFO    : Bus 27501	: V=0.9765536, theta=-59.245929 -> V=1.0, theta=0.0
% INFO    : Bus 27502	: V=0.9769869, theta=-59.215023 -> V=1.0, theta=0.0
% INFO    : Bus 27503	: V=0.9769534, theta=-58.396813 -> V=1.0, theta=0.0
% INFO    : Bus 27504	: V=0.9736806, theta=-59.612102 -> V=1.0, theta=0.0
% INFO    : Bus 27505	: V=0.9765471, theta=-58.79804 -> V=1.0, theta=0.0
% INFO    : Bus 27506	: V=0.9817297, theta=-56.201103 -> V=1.0, theta=0.0
% INFO    : Bus 27507	: V=0.9760876, theta=-58.560434 -> V=1.0, theta=0.0
% INFO    : Bus 27508	: V=0.9763962, theta=-58.642398 -> V=1.0, theta=0.0
% INFO    : Bus 27509	: V=0.975795, theta=-58.665053 -> V=1.0, theta=0.0
% INFO    : Bus 27510	: V=0.9763391, theta=-59.344608 -> V=1.0, theta=0.0
% INFO    : Bus 27511	: V=0.9754232, theta=-59.387237 -> V=1.0, theta=0.0
% INFO    : Bus 27512	: V=0.9736591, theta=-59.780216 -> V=1.0, theta=0.0
% INFO    : Bus 27513	: V=0.9733404, theta=-59.75291 -> V=1.0, theta=0.0
% INFO    : Bus 27514	: V=0.9765396, theta=-58.412851 -> V=1.0, theta=0.0
% INFO    : Bus 27515	: V=0.9720252, theta=-59.833639 -> V=1.0, theta=0.0
% INFO    : Bus 27516	: V=0.9753632, theta=-59.544582 -> V=1.0, theta=0.0
% INFO    : Bus 27517	: V=0.9746625, theta=-59.652587 -> V=1.0, theta=0.0
% INFO    : Bus 27518	: V=0.9724416, theta=-59.850234 -> V=1.0, theta=0.0
% INFO    : Bus 27519	: V=0.973489, theta=-58.979052 -> V=1.0, theta=0.0
% INFO    : Bus 27520	: V=0.9709593, theta=-59.934474 -> V=1.0, theta=0.0
% INFO    : Bus 27521	: V=0.9718302, theta=-59.878999 -> V=1.0, theta=0.0
% INFO    : Bus 27522	: V=0.9763598, theta=-58.481686 -> V=1.0, theta=0.0
% INFO    : Bus 27523	: V=0.9737846, theta=-59.642767 -> V=1.0, theta=0.0
% INFO    : Bus 27524	: V=0.9762358, theta=-58.509727 -> V=1.0, theta=0.0
% INFO    : Bus 27525	: V=0.9747353, theta=-59.565625 -> V=1.0, theta=0.0
% INFO    : Bus 27526	: V=0.9733224, theta=-59.029053 -> V=1.0, theta=0.0
% INFO    : Bus 27527	: V=0.9739599, theta=-59.54472 -> V=1.0, theta=0.0
% INFO    : Bus 27528	: V=0.9748926, theta=-59.426418 -> V=1.0, theta=0.0
% INFO    : Bus 27529	: V=0.9765484, theta=-59.328522 -> V=1.0, theta=0.0
% INFO    : Bus 27530	: V=0.9783325, theta=-58.514791 -> V=1.0, theta=0.0
% INFO    : Bus 27531	: V=0.9770682, theta=-58.597159 -> V=1.0, theta=0.0
% INFO    : Bus 27532	: V=0.9790289, theta=-58.003887 -> V=1.0, theta=0.0
% INFO    : Bus 27533	: V=0.9773718, theta=-59.073003 -> V=1.0, theta=0.0
% INFO    : Bus 27534	: V=0.9766842, theta=-58.954083 -> V=1.0, theta=0.0
% INFO    : Bus 27535	: V=0.9784831, theta=-58.166135 -> V=1.0, theta=0.0
% INFO    : Bus 27536	: V=0.978608, theta=-58.143911 -> V=1.0, theta=0.0
% INFO    : Bus 27537	: V=0.976211, theta=-58.85193 -> V=1.0, theta=0.0
% INFO    : Bus 27538	: V=0.9775116, theta=-58.353425 -> V=1.0, theta=0.0
% INFO    : Bus 27539	: V=0.9774895, theta=-58.326073 -> V=1.0, theta=0.0
% INFO    : Bus 27540	: V=0.9787384, theta=-58.13832 -> V=1.0, theta=0.0
% INFO    : Bus 27541	: V=0.9790673, theta=-58.075513 -> V=1.0, theta=0.0
% INFO    : Bus 27542	: V=0.9752499, theta=-59.322081 -> V=1.0, theta=0.0
% INFO    : Bus 27543	: V=0.9756831, theta=-59.027652 -> V=1.0, theta=0.0
% INFO    : Bus 27544	: V=0.9743222, theta=-58.845159 -> V=1.0, theta=0.0
% INFO    : Bus 27545	: V=0.9745356, theta=-59.251548 -> V=1.0, theta=0.0
% INFO    : Bus 27546	: V=0.9771851, theta=-58.796046 -> V=1.0, theta=0.0
% INFO    : Bus 27547	: V=0.9817309, theta=-56.130162 -> V=1.0, theta=0.0
% INFO    : Bus 27548	: V=0.9791333, theta=-56.949387 -> V=1.0, theta=0.0
% INFO    : Bus 27549	: V=0.9782599, theta=-57.30938 -> V=1.0, theta=0.0
% INFO    : Bus 27550	: V=0.9791015, theta=-56.656315 -> V=1.0, theta=0.0
% INFO    : Bus 27551	: V=0.9762549, theta=-58.622543 -> V=1.0, theta=0.0
% INFO    : Bus 27552	: V=0.9757937, theta=-57.798305 -> V=1.0, theta=0.0
% INFO    : Bus 27553	: V=0.9755947, theta=-58.605042 -> V=1.0, theta=0.0
% INFO    : Bus 27554	: V=0.9749947, theta=-58.057639 -> V=1.0, theta=0.0
% INFO    : Bus 27555	: V=0.9771125, theta=-57.970705 -> V=1.0, theta=0.0
% INFO    : Bus 27556	: V=0.9777479, theta=-57.646864 -> V=1.0, theta=0.0
% INFO    : Bus 27557	: V=0.9758391, theta=-58.216584 -> V=1.0, theta=0.0
% INFO    : Bus 27558	: V=0.9764531, theta=-57.879945 -> V=1.0, theta=0.0
% INFO    : Bus 27559	: V=0.97681, theta=-58.254204 -> V=1.0, theta=0.0
% INFO    : Bus 27560	: V=0.9759357, theta=-59.047879 -> V=1.0, theta=0.0
% INFO    : Bus 27561	: V=0.9742261, theta=-58.756243 -> V=1.0, theta=0.0
% INFO    : Bus 27562	: V=0.9755209, theta=-59.738394 -> V=1.0, theta=0.0
% INFO    : Bus 27563	: V=0.9756892, theta=-58.698413 -> V=1.0, theta=0.0
% INFO    : Bus 27564	: V=0.9759198, theta=-58.830943 -> V=1.0, theta=0.0
% INFO    : Bus 27565	: V=0.9758571, theta=-59.750819 -> V=1.0, theta=0.0
% INFO    : Bus 27566	: V=0.9777224, theta=-58.688345 -> V=1.0, theta=0.0
% INFO    : Bus 27567	: V=0.982019, theta=-57.840505 -> V=1.0, theta=0.0
% INFO    : Bus 27568	: V=0.9801942, theta=-58.234514 -> V=1.0, theta=0.0
% INFO    : Bus 27569	: V=0.9786846, theta=-58.747962 -> V=1.0, theta=0.0
% INFO    : Bus 27570	: V=0.9886346, theta=-55.251595 -> V=1.0, theta=0.0
% INFO    : Bus 27571	: V=0.9795871, theta=-58.561833 -> V=1.0, theta=0.0
% INFO    : Bus 27572	: V=0.9811313, theta=-58.376064 -> V=1.0, theta=0.0
% INFO    : Bus 27573	: V=0.9786671, theta=-58.705638 -> V=1.0, theta=0.0
% INFO    : Bus 27574	: V=0.981739, theta=-58.368508 -> V=1.0, theta=0.0
% INFO    : Bus 27575	: V=0.9796557, theta=-57.846151 -> V=1.0, theta=0.0
% INFO    : Bus 27576	: V=0.9764836, theta=-59.753327 -> V=1.0, theta=0.0
% INFO    : Bus 27577	: V=0.9767895, theta=-58.429963 -> V=1.0, theta=0.0
% INFO    : Bus 27578	: V=0.9779236, theta=-56.273997 -> V=1.0, theta=0.0
% INFO    : Bus 27579	: V=0.9722698, theta=-59.795059 -> V=1.0, theta=0.0
% INFO    : Bus 27580	: V=0.9788218, theta=-58.095679 -> V=1.0, theta=0.0
% INFO    : Bus 27581	: V=0.9787162, theta=-58.136256 -> V=1.0, theta=0.0
% INFO    : Bus 27582	: V=0.9785787, theta=-58.18062 -> V=1.0, theta=0.0
% INFO    : Bus 27583	: V=0.9754019, theta=-58.814481 -> V=1.0, theta=0.0
% INFO    : Bus 27584	: V=0.9726934, theta=-60.129889 -> V=1.0, theta=0.0
% INFO    : Bus 27585	: V=0.9731738, theta=-59.924339 -> V=1.0, theta=0.0
% INFO    : Bus 27586	: V=0.9783285, theta=-58.20327 -> V=1.0, theta=0.0
% INFO    : Bus 27587	: V=0.9792067, theta=-58.005729 -> V=1.0, theta=0.0
% INFO    : Bus 27588	: V=0.9862546, theta=-54.277681 -> V=1.0, theta=0.0
% INFO    : Bus 27589	: V=0.9876583, theta=-54.20709 -> V=1.0, theta=0.0
% INFO    : Bus 27590	: V=0.9835732, theta=-54.817133 -> V=1.0, theta=0.0
% INFO    : Bus 27591	: V=0.9821331, theta=-54.170192 -> V=1.0, theta=0.0
% INFO    : Bus 27592	: V=0.9772783, theta=-55.197455 -> V=1.0, theta=0.0
% INFO    : Bus 27593	: V=0.9828366, theta=-54.393525 -> V=1.0, theta=0.0
% INFO    : Bus 27594	: V=0.9775468, theta=-55.194972 -> V=1.0, theta=0.0
% INFO    : Bus 27595	: V=0.9819718, theta=-54.542653 -> V=1.0, theta=0.0
% INFO    : Bus 27596	: V=0.9842803, theta=-54.351929 -> V=1.0, theta=0.0
% INFO    : Bus 27597	: V=0.9816879, theta=-54.602773 -> V=1.0, theta=0.0
% INFO    : Bus 27598	: V=0.9852858, theta=-54.269762 -> V=1.0, theta=0.0
% INFO    : Bus 27599	: V=0.9860933, theta=-54.687398 -> V=1.0, theta=0.0
% INFO    : Bus 27600	: V=0.9912644, theta=-54.003201 -> V=1.0, theta=0.0
% INFO    : Bus 27601	: V=0.9939952, theta=-53.844527 -> V=1.0, theta=0.0
% INFO    : Bus 27602	: V=0.9643065, theta=-55.229195 -> V=1.0, theta=0.0
% INFO    : Bus 27603	: V=0.9612095, theta=-55.005785 -> V=1.0, theta=0.0
% INFO    : Bus 27604	: V=0.9686976, theta=-55.155828 -> V=1.0, theta=0.0
% INFO    : Bus 27605	: V=0.9641131, theta=-56.466213 -> V=1.0, theta=0.0
% INFO    : Bus 27606	: V=0.9694717, theta=-56.312055 -> V=1.0, theta=0.0
% INFO    : Bus 27607	: V=0.9708562, theta=-56.336136 -> V=1.0, theta=0.0
% INFO    : Bus 27608	: V=0.9746609, theta=-55.95615 -> V=1.0, theta=0.0
% INFO    : Bus 27609	: V=0.9814043, theta=-54.731399 -> V=1.0, theta=0.0
% INFO    : Bus 27610	: V=0.9759642, theta=-55.526955 -> V=1.0, theta=0.0
% INFO    : Bus 27611	: V=0.9812456, theta=-54.418285 -> V=1.0, theta=0.0
% INFO    : Bus 27612	: V=0.9737355, theta=-55.447227 -> V=1.0, theta=0.0
% INFO    : Bus 27613	: V=0.9697701, theta=-54.978327 -> V=1.0, theta=0.0
% INFO    : Bus 27614	: V=0.9855898, theta=-55.518037 -> V=1.0, theta=0.0
% INFO    : Bus 27615	: V=0.9628886, theta=-54.518605 -> V=1.0, theta=0.0
% INFO    : Bus 27616	: V=0.9648101, theta=-53.947783 -> V=1.0, theta=0.0
% INFO    : Bus 27617	: V=0.9721781, theta=-52.497599 -> V=1.0, theta=0.0
% INFO    : Bus 27618	: V=0.9725033, theta=-52.428622 -> V=1.0, theta=0.0
% INFO    : Bus 27619	: V=0.9729169, theta=-52.343856 -> V=1.0, theta=0.0
% INFO    : Bus 27620	: V=0.9693715, theta=-53.506997 -> V=1.0, theta=0.0
% INFO    : Bus 27621	: V=0.9752446, theta=-52.167678 -> V=1.0, theta=0.0
% INFO    : Bus 27622	: V=0.9722029, theta=-53.73576 -> V=1.0, theta=0.0
% INFO    : Bus 27623	: V=0.9745637, theta=-52.353688 -> V=1.0, theta=0.0
% INFO    : Bus 27624	: V=0.9763459, theta=-53.596868 -> V=1.0, theta=0.0
% INFO    : Bus 27625	: V=0.986859, theta=-53.804165 -> V=1.0, theta=0.0
% INFO    : Bus 27626	: V=1.0008576, theta=-53.428032 -> V=1.0, theta=0.0
% INFO    : Bus 27627	: V=0.9897625, theta=-54.244987 -> V=1.0, theta=0.0
% INFO    : Bus 27628	: V=0.9900695, theta=-54.097056 -> V=1.0, theta=0.0
% INFO    : Bus 27629	: V=0.9980835, theta=-53.599582 -> V=1.0, theta=0.0
% INFO    : Bus 27630	: V=1.0005591, theta=-53.41658 -> V=1.0, theta=0.0
% INFO    : Bus 27631	: V=0.9981155, theta=-53.694408 -> V=1.0, theta=0.0
% INFO    : Bus 27632	: V=0.9857483, theta=-54.689384 -> V=1.0, theta=0.0
% INFO    : Bus 27633	: V=0.9954494, theta=-53.878036 -> V=1.0, theta=0.0
% INFO    : Bus 27634	: V=0.976112, theta=-55.286786 -> V=1.0, theta=0.0
% INFO    : Bus 27635	: V=0.9853608, theta=-53.963029 -> V=1.0, theta=0.0
% INFO    : Bus 27636	: V=0.9848838, theta=-53.696423 -> V=1.0, theta=0.0
% INFO    : Bus 27637	: V=0.9729591, theta=-55.486922 -> V=1.0, theta=0.0
% INFO    : Bus 27638	: V=0.9708941, theta=-54.32249 -> V=1.0, theta=0.0
% INFO    : Bus 27639	: V=0.969767, theta=-54.599275 -> V=1.0, theta=0.0
% INFO    : Bus 27640	: V=0.9718546, theta=-55.689001 -> V=1.0, theta=0.0
% INFO    : Bus 27641	: V=0.9850721, theta=-54.341947 -> V=1.0, theta=0.0
% INFO    : Bus 27642	: V=0.9743262, theta=-52.434977 -> V=1.0, theta=0.0
% INFO    : Bus 27643	: V=0.9846072, theta=-52.912409 -> V=1.0, theta=0.0
% INFO    : Bus 27644	: V=0.9931075, theta=-51.169137 -> V=1.0, theta=0.0
% INFO    : Bus 27645	: V=0.9907002, theta=-51.658457 -> V=1.0, theta=0.0
% INFO    : Bus 27646	: V=0.9841325, theta=-51.507352 -> V=1.0, theta=0.0
% INFO    : Bus 27647	: V=0.9877347, theta=-52.135569 -> V=1.0, theta=0.0
% INFO    : Bus 27648	: V=0.996647, theta=-50.475797 -> V=1.0, theta=0.0
% INFO    : Bus 27649	: V=0.9883563, theta=-51.291664 -> V=1.0, theta=0.0
% INFO    : Bus 27650	: V=0.9874785, theta=-50.931651 -> V=1.0, theta=0.0
% INFO    : Bus 27651	: V=0.9880043, theta=-50.826816 -> V=1.0, theta=0.0
% INFO    : Bus 27652	: V=0.9887681, theta=-50.443303 -> V=1.0, theta=0.0
% INFO    : Bus 27653	: V=0.9876461, theta=-51.048784 -> V=1.0, theta=0.0
% INFO    : Bus 27654	: V=0.988919, theta=-49.617631 -> V=1.0, theta=0.0
% INFO    : Bus 27655	: V=0.9925703, theta=-51.91461 -> V=1.0, theta=0.0
% INFO    : Bus 27656	: V=0.9947022, theta=-51.381358 -> V=1.0, theta=0.0
% INFO    : Bus 27657	: V=0.9849319, theta=-49.875471 -> V=1.0, theta=0.0
% INFO    : Bus 27658	: V=0.9871678, theta=-48.639709 -> V=1.0, theta=0.0
% INFO    : Bus 27659	: V=0.9898243, theta=-48.996911 -> V=1.0, theta=0.0
% INFO    : Bus 27660	: V=0.9878595, theta=-48.717418 -> V=1.0, theta=0.0
% INFO    : Bus 27661	: V=0.994233, theta=-46.580089 -> V=1.0, theta=0.0
% INFO    : Bus 27662	: V=0.9897907, theta=-48.499127 -> V=1.0, theta=0.0
% INFO    : Bus 27663	: V=0.9920668, theta=-47.082524 -> V=1.0, theta=0.0
% INFO    : Bus 27664	: V=0.9461777, theta=-57.712277 -> V=1.0, theta=0.0
% INFO    : Bus 27665	: V=0.9471223, theta=-57.435449 -> V=1.0, theta=0.0
% INFO    : Bus 27666	: V=0.9555995, theta=-57.210367 -> V=1.0, theta=0.0
% INFO    : Bus 27667	: V=0.9621545, theta=-56.484082 -> V=1.0, theta=0.0
% INFO    : Bus 27668	: V=0.9552884, theta=-56.843178 -> V=1.0, theta=0.0
% INFO    : Bus 27669	: V=0.9598478, theta=-56.539283 -> V=1.0, theta=0.0
% INFO    : Bus 27670	: V=0.961939, theta=-56.258249 -> V=1.0, theta=0.0
% INFO    : Bus 27671	: V=0.9648781, theta=-55.51634 -> V=1.0, theta=0.0
% INFO    : Bus 27672	: V=0.9788262, theta=-53.042361 -> V=1.0, theta=0.0
% INFO    : Bus 27673	: V=0.9783423, theta=-52.9776 -> V=1.0, theta=0.0
% INFO    : Bus 27674	: V=0.9821161, theta=-55.560596 -> V=1.0, theta=0.0
% INFO    : Bus 27675	: V=0.9904236, theta=-55.763801 -> V=1.0, theta=0.0
% INFO    : Bus 27676	: V=0.9879327, theta=-55.638947 -> V=1.0, theta=0.0
% INFO    : Bus 27677	: V=0.9629387, theta=-57.23662 -> V=1.0, theta=0.0
% INFO    : Bus 27678	: V=0.981356, theta=-55.05226 -> V=1.0, theta=0.0
% INFO    : Bus 27679	: V=0.9692605, theta=-57.455197 -> V=1.0, theta=0.0
% INFO    : Bus 27680	: V=0.9839002, theta=-55.897359 -> V=1.0, theta=0.0
% INFO    : Bus 27681	: V=0.9817424, theta=-56.03079 -> V=1.0, theta=0.0
% INFO    : Bus 27682	: V=0.9683406, theta=-57.425479 -> V=1.0, theta=0.0
% INFO    : Bus 27683	: V=1.0013264, theta=-43.565694 -> V=1.0, theta=0.0
% INFO    : Bus 27684	: V=1.0066161, theta=-42.637931 -> V=1.0, theta=0.0
% INFO    : Bus 27685	: V=1.0154397, theta=-39.491899 -> V=1.0, theta=0.0
% INFO    : Bus 27686	: V=0.9977873, theta=-49.404522 -> V=1.0, theta=0.0
% INFO    : Bus 27687	: V=0.9978555, theta=-49.397791 -> V=1.0, theta=0.0
% INFO    : Bus 27688	: V=0.9941451, theta=-49.726998 -> V=1.0, theta=0.0
% INFO    : Bus 27689	: V=0.9972028, theta=-49.464799 -> V=1.0, theta=0.0
% INFO    : Bus 27690	: V=0.9797725, theta=-50.732669 -> V=1.0, theta=0.0
% INFO    : Bus 27691	: V=0.9793592, theta=-50.573722 -> V=1.0, theta=0.0
% INFO    : Bus 27692	: V=0.9969223, theta=-49.4766 -> V=1.0, theta=0.0
% INFO    : Bus 27693	: V=0.9903742, theta=-49.646241 -> V=1.0, theta=0.0
% INFO    : Bus 27694	: V=0.992876, theta=-48.807134 -> V=1.0, theta=0.0
% INFO    : Bus 27695	: V=0.9887885, theta=-49.608476 -> V=1.0, theta=0.0
% INFO    : Bus 27696	: V=0.9726495, theta=-50.209357 -> V=1.0, theta=0.0
% INFO    : Bus 27697	: V=0.9882726, theta=-48.361352 -> V=1.0, theta=0.0
% INFO    : Bus 27698	: V=0.9884062, theta=-48.800161 -> V=1.0, theta=0.0
% INFO    : Bus 27699	: V=0.9901359, theta=-48.7735 -> V=1.0, theta=0.0
% INFO    : Bus 27700	: V=0.9946908, theta=-48.447515 -> V=1.0, theta=0.0
% INFO    : Bus 27701	: V=0.9897825, theta=-48.89214 -> V=1.0, theta=0.0
% INFO    : Bus 27702	: V=0.9851515, theta=-49.584623 -> V=1.0, theta=0.0
% INFO    : Bus 27703	: V=0.9839344, theta=-49.546539 -> V=1.0, theta=0.0
% INFO    : Bus 27704	: V=0.9779367, theta=-49.416252 -> V=1.0, theta=0.0
% INFO    : Bus 27705	: V=0.9798594, theta=-49.358335 -> V=1.0, theta=0.0
% INFO    : Bus 27706	: V=0.9789138, theta=-49.280261 -> V=1.0, theta=0.0
% INFO    : Bus 27707	: V=0.9778381, theta=-49.340392 -> V=1.0, theta=0.0
% INFO    : Bus 27708	: V=0.9686276, theta=-49.917333 -> V=1.0, theta=0.0
% INFO    : Bus 27709	: V=0.9788273, theta=-49.171654 -> V=1.0, theta=0.0
% INFO    : Bus 27710	: V=0.9796688, theta=-48.954333 -> V=1.0, theta=0.0
% INFO    : Bus 27711	: V=0.967971, theta=-49.892269 -> V=1.0, theta=0.0
% INFO    : Bus 27712	: V=0.9971415, theta=-48.034797 -> V=1.0, theta=0.0
% INFO    : Bus 27713	: V=0.9880972, theta=-48.586484 -> V=1.0, theta=0.0
% INFO    : Bus 27714	: V=0.9900662, theta=-48.099594 -> V=1.0, theta=0.0
% INFO    : Bus 27715	: V=0.974251, theta=-48.241331 -> V=1.0, theta=0.0
% INFO    : Bus 27716	: V=0.9811678, theta=-48.193165 -> V=1.0, theta=0.0
% INFO    : Bus 27717	: V=0.9934302, theta=-49.783685 -> V=1.0, theta=0.0
% INFO    : Bus 27718	: V=0.9940445, theta=-49.697879 -> V=1.0, theta=0.0
% INFO    : Bus 27719	: V=0.9948568, theta=-43.325239 -> V=1.0, theta=0.0
% INFO    : Bus 27720	: V=0.9944146, theta=-43.363099 -> V=1.0, theta=0.0
% INFO    : Bus 27721	: V=1.0184225, theta=-39.375022 -> V=1.0, theta=0.0
% INFO    : Bus 27722	: V=0.9973784, theta=-42.369569 -> V=1.0, theta=0.0
% INFO    : Bus 27723	: V=0.986903, theta=-43.175501 -> V=1.0, theta=0.0
% INFO    : Bus 27724	: V=0.9901689, theta=-43.096117 -> V=1.0, theta=0.0
% INFO    : Bus 27725	: V=0.9895899, theta=-43.152884 -> V=1.0, theta=0.0
% INFO    : Bus 27726	: V=0.9895062, theta=-43.171976 -> V=1.0, theta=0.0
% INFO    : Bus 27727	: V=0.9957681, theta=-42.40271 -> V=1.0, theta=0.0
% INFO    : Bus 27728	: V=0.9885055, theta=-43.212986 -> V=1.0, theta=0.0
% INFO    : Bus 27729	: V=0.9902823, theta=-42.710364 -> V=1.0, theta=0.0
% INFO    : Bus 27730	: V=1.0045916, theta=-41.268304 -> V=1.0, theta=0.0
% INFO    : Bus 27731	: V=0.9985379, theta=-42.026014 -> V=1.0, theta=0.0
% INFO    : Bus 27732	: V=0.9959125, theta=-42.455314 -> V=1.0, theta=0.0
% INFO    : Bus 27733	: V=1.0117417, theta=-40.654379 -> V=1.0, theta=0.0
% INFO    : Bus 27734	: V=1.0108093, theta=-40.493282 -> V=1.0, theta=0.0
% INFO    : Bus 27735	: V=0.9921972, theta=-53.461542 -> V=1.0, theta=0.0
% INFO    : Bus 27736	: V=0.987607, theta=-55.836714 -> V=1.0, theta=0.0
% INFO    : Bus 27737	: V=0.9875998, theta=-55.876737 -> V=1.0, theta=0.0
% INFO    : Bus 27738	: V=0.9904607, theta=-55.518214 -> V=1.0, theta=0.0
% INFO    : Bus 27739	: V=0.9934129, theta=-53.29604 -> V=1.0, theta=0.0
% INFO    : Bus 27740	: V=0.9928091, theta=-53.55633 -> V=1.0, theta=0.0
% INFO    : Bus 27741	: V=0.9885415, theta=-56.212701 -> V=1.0, theta=0.0
% INFO    : Bus 27742	: V=0.9872604, theta=-56.733952 -> V=1.0, theta=0.0
% INFO    : Bus 27743	: V=0.9896449, theta=-56.744273 -> V=1.0, theta=0.0
% INFO    : Bus 27744	: V=0.989864, theta=-56.432498 -> V=1.0, theta=0.0
% INFO    : Bus 27745	: V=0.9907991, theta=-56.480938 -> V=1.0, theta=0.0
% INFO    : Bus 27746	: V=0.9905395, theta=-56.363785 -> V=1.0, theta=0.0
% INFO    : Bus 27747	: V=0.9902054, theta=-56.037299 -> V=1.0, theta=0.0
% INFO    : Bus 27748	: V=0.9887644, theta=-54.912496 -> V=1.0, theta=0.0
% INFO    : Bus 27749	: V=0.9914414, theta=-55.012022 -> V=1.0, theta=0.0
% INFO    : Bus 27750	: V=0.9907794, theta=-54.85575 -> V=1.0, theta=0.0
% INFO    : Bus 27751	: V=0.9891745, theta=-55.422989 -> V=1.0, theta=0.0
% INFO    : Bus 27752	: V=0.9881166, theta=-56.033484 -> V=1.0, theta=0.0
% INFO    : Bus 27753	: V=0.987023, theta=-56.584012 -> V=1.0, theta=0.0
% INFO    : Bus 27754	: V=0.9885573, theta=-56.741898 -> V=1.0, theta=0.0
% INFO    : Bus 27755	: V=0.9857606, theta=-57.073025 -> V=1.0, theta=0.0
% INFO    : Bus 27756	: V=0.9848451, theta=-57.447787 -> V=1.0, theta=0.0
% INFO    : Bus 27757	: V=0.9816778, theta=-58.547445 -> V=1.0, theta=0.0
% INFO    : Bus 27758	: V=0.9849196, theta=-57.801776 -> V=1.0, theta=0.0
% INFO    : Bus 27759	: V=0.9862454, theta=-57.44564 -> V=1.0, theta=0.0
% INFO    : Bus 27760	: V=0.982416, theta=-57.03984 -> V=1.0, theta=0.0
% INFO    : Bus 27761	: V=0.9895058, theta=-55.974768 -> V=1.0, theta=0.0
% INFO    : Bus 27762	: V=0.9891171, theta=-55.55364 -> V=1.0, theta=0.0
% INFO    : Bus 27763	: V=0.9834806, theta=-57.80379 -> V=1.0, theta=0.0
% INFO    : Bus 27764	: V=0.9837312, theta=-57.740342 -> V=1.0, theta=0.0
% INFO    : Bus 27765	: V=0.9852186, theta=-56.212629 -> V=1.0, theta=0.0
% INFO    : Bus 27766	: V=0.9881091, theta=-55.779927 -> V=1.0, theta=0.0
% INFO    : Bus 27767	: V=0.9647563, theta=-57.560845 -> V=1.0, theta=0.0
% INFO    : Bus 27768	: V=0.9585724, theta=-58.541281 -> V=1.0, theta=0.0
% INFO    : Bus 27769	: V=0.9665493, theta=-57.611346 -> V=1.0, theta=0.0
% INFO    : Bus 27770	: V=0.9572643, theta=-57.869756 -> V=1.0, theta=0.0
% INFO    : Bus 27771	: V=0.98976, theta=-55.919008 -> V=1.0, theta=0.0
% INFO    : Bus 27772	: V=1.0115213, theta=-53.634315 -> V=1.0, theta=0.0
% INFO    : Bus 27773	: V=0.9862772, theta=-56.474131 -> V=1.0, theta=0.0
% INFO    : Bus 27774	: V=0.9820319, theta=-56.954635 -> V=1.0, theta=0.0
% INFO    : Bus 27775	: V=0.9702047, theta=-58.378706 -> V=1.0, theta=0.0
% INFO    : Bus 27776	: V=0.9866112, theta=-53.736109 -> V=1.0, theta=0.0
% INFO    : Bus 27777	: V=0.9732469, theta=-55.235786 -> V=1.0, theta=0.0
% INFO    : Bus 27778	: V=0.9817563, theta=-54.194673 -> V=1.0, theta=0.0
% INFO    : Bus 27779	: V=0.9717137, theta=-55.3654 -> V=1.0, theta=0.0
% INFO    : Bus 27780	: V=0.9837861, theta=-54.061092 -> V=1.0, theta=0.0
% INFO    : Bus 27781	: V=0.9710632, theta=-55.462761 -> V=1.0, theta=0.0
% INFO    : Bus 27782	: V=0.9694874, theta=-55.530188 -> V=1.0, theta=0.0
% INFO    : Bus 27783	: V=0.9681603, theta=-55.612393 -> V=1.0, theta=0.0
% INFO    : Bus 27784	: V=0.9860686, theta=-53.919507 -> V=1.0, theta=0.0
% INFO    : Bus 27785	: V=1.001997, theta=-51.984474 -> V=1.0, theta=0.0
% INFO    : Bus 27786	: V=1.0060765, theta=-51.515405 -> V=1.0, theta=0.0
% INFO    : Bus 27787	: V=1.0027294, theta=-52.655519 -> V=1.0, theta=0.0
% INFO    : Bus 27788	: V=0.9877807, theta=-53.943938 -> V=1.0, theta=0.0
% INFO    : Bus 27789	: V=0.9702219, theta=-55.563926 -> V=1.0, theta=0.0
% INFO    : Bus 27790	: V=0.9774994, theta=-55.42326 -> V=1.0, theta=0.0
% INFO    : Bus 27791	: V=0.9815649, theta=-55.176293 -> V=1.0, theta=0.0
% INFO    : Bus 27792	: V=0.9814932, theta=-54.911541 -> V=1.0, theta=0.0
% INFO    : Bus 27793	: V=0.9825803, theta=-54.636753 -> V=1.0, theta=0.0
% INFO    : Bus 27794	: V=0.9891584, theta=-54.636795 -> V=1.0, theta=0.0
% INFO    : Bus 27795	: V=0.982396, theta=-54.635962 -> V=1.0, theta=0.0
% INFO    : Bus 27796	: V=0.9901491, theta=-54.61098 -> V=1.0, theta=0.0
% INFO    : Bus 27797	: V=0.9819163, theta=-54.69994 -> V=1.0, theta=0.0
% INFO    : Bus 27798	: V=0.9819762, theta=-54.633406 -> V=1.0, theta=0.0
% INFO    : Bus 27799	: V=0.9812923, theta=-54.542326 -> V=1.0, theta=0.0
% INFO    : Bus 27800	: V=0.9637661, theta=-58.006054 -> V=1.0, theta=0.0
% INFO    : Bus 27801	: V=0.9566623, theta=-57.528153 -> V=1.0, theta=0.0
% INFO    : Bus 27802	: V=0.9550427, theta=-57.731559 -> V=1.0, theta=0.0
% INFO    : Bus 27803	: V=0.9639648, theta=-55.669014 -> V=1.0, theta=0.0
% INFO    : Bus 27804	: V=0.962253, theta=-58.39644 -> V=1.0, theta=0.0
% INFO    : Bus 27805	: V=0.9715671, theta=-57.026055 -> V=1.0, theta=0.0
% INFO    : Bus 27806	: V=0.9667282, theta=-57.55026 -> V=1.0, theta=0.0
% INFO    : Bus 27807	: V=0.9630275, theta=-58.450404 -> V=1.0, theta=0.0
% INFO    : Bus 27808	: V=0.9621414, theta=-58.656971 -> V=1.0, theta=0.0
% INFO    : Bus 27809	: V=0.96167, theta=-58.917841 -> V=1.0, theta=0.0
% INFO    : Bus 81859	: V=1.0185787, theta=-40.540711 -> V=1.0, theta=0.0
% INFO    : Bus 81860	: V=1.0182477, theta=-40.694498 -> V=1.0, theta=0.0
% INFO    : Bus 81861	: V=1.0203154, theta=-39.029598 -> V=1.0, theta=0.0
% INFO    : Bus 81862	: V=1.0190975, theta=-39.344086 -> V=1.0, theta=0.0
% INFO    : Bus 81863	: V=1.0189644, theta=-39.419514 -> V=1.0, theta=0.0
% INFO    : Bus 81864	: V=1.0103301, theta=-54.63234 -> V=1.0, theta=0.0
% INFO    : Bus 81865	: V=1.0078177, theta=-55.012426 -> V=1.0, theta=0.0
% INFO    : Bus 81866	: V=1.0196141, theta=-40.83739 -> V=1.0, theta=0.0
% INFO    : Bus 81867	: V=1.0185158, theta=-41.303796 -> V=1.0, theta=0.0
% INFO    : Bus 81868	: V=1.0185734, theta=-41.506179 -> V=1.0, theta=0.0
% INFO    : Bus 81869	: V=1.01785, theta=-42.580568 -> V=1.0, theta=0.0
% INFO    : Bus 81870	: V=1.016952, theta=-42.892437 -> V=1.0, theta=0.0
% INFO    : Bus 81871	: V=1.0190835, theta=-39.857397 -> V=1.0, theta=0.0
% INFO    : Bus 81872	: V=1.0193026, theta=-39.885583 -> V=1.0, theta=0.0
% INFO    : Bus 81873	: V=1.0104058, theta=-41.036664 -> V=1.0, theta=0.0
% INFO    : Bus 81874	: V=1.008413, theta=-41.410949 -> V=1.0, theta=0.0
% INFO    : Bus 81875	: V=1.0101914, theta=-42.63448 -> V=1.0, theta=0.0
% INFO    : Bus 81876	: V=1.0092194, theta=-42.905961 -> V=1.0, theta=0.0
% INFO    : Bus 81877	: V=1.016808, theta=-42.712481 -> V=1.0, theta=0.0
% INFO    : Bus 81878	: V=1.0091959, theta=-50.756021 -> V=1.0, theta=0.0
% INFO    : Bus 81879	: V=1.0054895, theta=-51.053258 -> V=1.0, theta=0.0
% INFO    : Bus 81880	: V=1.0117979, theta=-55.488735 -> V=1.0, theta=0.0
% INFO    : Bus 81881	: V=1.0049051, theta=-57.25181 -> V=1.0, theta=0.0
% INFO    : Bus 81882	: V=1.0018016, theta=-57.660467 -> V=1.0, theta=0.0
% INFO    : Bus 81883	: V=1.0191634, theta=-43.031093 -> V=1.0, theta=0.0
% INFO    : Bus 81884	: V=1.0168319, theta=-43.687241 -> V=1.0, theta=0.0
% INFO    : Bus 81885	: V=1.0162616, theta=-43.853416 -> V=1.0, theta=0.0
% INFO    : Bus 81886	: V=0.9914333, theta=-50.135967 -> V=1.0, theta=0.0
% INFO    : Bus 81887	: V=0.98928, theta=-50.576239 -> V=1.0, theta=0.0
% INFO    : Bus 81888	: V=1.0152438, theta=-40.026266 -> V=1.0, theta=0.0
% INFO    : Bus 81889	: V=1.0009185, theta=-57.249449 -> V=1.0, theta=0.0
% INFO    : Bus 81890	: V=1.0191662, theta=-43.090278 -> V=1.0, theta=0.0
% INFO    : Bus 81891	: V=1.0178222, theta=-43.382618 -> V=1.0, theta=0.0
% INFO    : Bus 81892	: V=1.0175489, theta=-43.536976 -> V=1.0, theta=0.0
% INFO    : Bus 81893	: V=1.0199587, theta=-54.780928 -> V=1.0, theta=0.0
% INFO    : Bus 81894	: V=1.0193005, theta=-43.336586 -> V=1.0, theta=0.0
% INFO    : Bus 81895	: V=1.02, theta=-48.634195 -> V=1.0, theta=0.0
% INFO    : Bus 81896	: V=1.013515, theta=-53.244481 -> V=1.0, theta=0.0
% INFO    : Bus 81897	: V=1.0061588, theta=-56.775868 -> V=1.0, theta=0.0
% INFO    : Bus 81898	: V=1.0185486, theta=-40.601191 -> V=1.0, theta=0.0
% INFO    : Bus 81899	: V=1.0172388, theta=-40.9162 -> V=1.0, theta=0.0
% INFO    : Bus 81900	: V=1.02, theta=-40.472828 -> V=1.0, theta=0.0
% INFO    : Bus 81901	: V=1.0192104, theta=-40.869053 -> V=1.0, theta=0.0
% INFO    : Bus 81902	: V=1.0182743, theta=-42.733936 -> V=1.0, theta=0.0
% INFO    : Bus 81903	: V=1.0161051, theta=-43.290364 -> V=1.0, theta=0.0
% INFO    : Bus 81904	: V=1.02, theta=-48.781987 -> V=1.0, theta=0.0
% INFO    : Bus 81905	: V=0.9876889, theta=-54.698785 -> V=1.0, theta=0.0
% INFO    : Bus 81906	: V=1.0157166, theta=-39.987001 -> V=1.0, theta=0.0
% INFO    : Bus 81907	: V=1.0121834, theta=-49.956718 -> V=1.0, theta=0.0
% INFO    : Bus 81908	: V=1.0179824, theta=-47.981974 -> V=1.0, theta=0.0
% INFO    : Bus 81909	: V=1.0177751, theta=-48.115909 -> V=1.0, theta=0.0
% INFO    : Bus 81910	: V=1.0005947, theta=-57.745297 -> V=1.0, theta=0.0
% INFO    : Bus 81911	: V=1.0177722, theta=-42.585675 -> V=1.0, theta=0.0
% INFO    : Bus 81912	: V=1.017597, theta=-42.816812 -> V=1.0, theta=0.0
% INFO    : Bus 81913	: V=1.0072478, theta=-45.162467 -> V=1.0, theta=0.0
% INFO    : Bus 81914	: V=1.0020221, theta=-46.297431 -> V=1.0, theta=0.0
% INFO    : Bus 81915	: V=0.9984605, theta=-57.412636 -> V=1.0, theta=0.0
% INFO    : Bus 81916	: V=0.9869579, theta=-52.391169 -> V=1.0, theta=0.0
% INFO    : Bus 81917	: V=1.02, theta=-42.605275 -> V=1.0, theta=0.0
% INFO    : Bus 81918	: V=1.0175388, theta=-42.924477 -> V=1.0, theta=0.0
% INFO    : Bus 81919	: V=0.9783506, theta=-57.660234 -> V=1.0, theta=0.0
% INFO    : Bus 81920	: V=0.9761997, theta=-57.885944 -> V=1.0, theta=0.0
% INFO    : Bus 81921	: V=1.0104898, theta=-41.547467 -> V=1.0, theta=0.0
% INFO    : Bus 81922	: V=1.0114868, theta=-56.530447 -> V=1.0, theta=0.0
% INFO    : Bus 81923	: V=1.0041262, theta=-49.330285 -> V=1.0, theta=0.0
% INFO    : Bus 81924	: V=0.9732613, theta=-52.541526 -> V=1.0, theta=0.0
% INFO    : Bus 81925	: V=0.9909061, theta=-52.374708 -> V=1.0, theta=0.0
% INFO    : Bus 81926	: V=0.9798401, theta=-54.671191 -> V=1.0, theta=0.0
% INFO    : Bus 81927	: V=0.9951607, theta=-54.200805 -> V=1.0, theta=0.0
% INFO    : Bus 81928	: V=1.0156761, theta=-42.740988 -> V=1.0, theta=0.0
% INFO    : Bus 81929	: V=1.0129171, theta=-32.573573 -> V=1.0, theta=0.0
% INFO    : Bus 81930	: V=1.0100659, theta=-33.032313 -> V=1.0, theta=0.0
% INFO    : Bus 81931	: V=1.0099733, theta=-33.07727 -> V=1.0, theta=0.0
% INFO    : Bus 81932	: V=1.0088369, theta=-49.424984 -> V=1.0, theta=0.0
% INFO    : Bus 81933	: V=1.0063467, theta=-50.724824 -> V=1.0, theta=0.0
% INFO    : Bus 81934	: V=1.0147518, theta=-49.164712 -> V=1.0, theta=0.0
% INFO    : Bus 81935	: V=1.0199757, theta=-39.092903 -> V=1.0, theta=0.0
% INFO    : Bus 81936	: V=1.0173677, theta=-39.156746 -> V=1.0, theta=0.0
% INFO    : Bus 81937	: V=1.0137864, theta=-26.994471 -> V=1.0, theta=0.0
% INFO    : Bus 81938	: V=1.0136482, theta=-27.028694 -> V=1.0, theta=0.0
% INFO    : Bus 81939	: V=1.0138401, theta=-40.886247 -> V=1.0, theta=0.0
% INFO    : Bus 81940	: V=1.0134051, theta=-41.134466 -> V=1.0, theta=0.0
% INFO    : Bus 81941	: V=1.0104532, theta=-48.349902 -> V=1.0, theta=0.0
% INFO    : Bus 81942	: V=1.0076917, theta=-36.386529 -> V=1.0, theta=0.0
% INFO    : Bus 81943	: V=1.0051052, theta=-42.32542 -> V=1.0, theta=0.0
% INFO    : Bus 81944	: V=1.0074475, theta=-44.059308 -> V=1.0, theta=0.0
% INFO    : Bus 81945	: V=1.0040269, theta=-44.536559 -> V=1.0, theta=0.0
% INFO    : Bus 81946	: V=1.0068216, theta=-36.127979 -> V=1.0, theta=0.0
% INFO    : Bus 81947	: V=1.0058373, theta=-36.334492 -> V=1.0, theta=0.0
% INFO    : Bus 81948	: V=0.9822412, theta=-43.930382 -> V=1.0, theta=0.0
% INFO    : Bus 81949	: V=1.0152831, theta=-30.810658 -> V=1.0, theta=0.0
% INFO    : Bus 81950	: V=0.9786277, theta=-43.100428 -> V=1.0, theta=0.0
% INFO    : Bus 81951	: V=1.0156193, theta=-30.722723 -> V=1.0, theta=0.0
% INFO    : Bus 81952	: V=1.02, theta=-41.67915 -> V=1.0, theta=0.0
% INFO    : Bus 81953	: V=1.0053848, theta=-43.223014 -> V=1.0, theta=0.0
% INFO    : Bus 81954	: V=1.0154408, theta=-33.092447 -> V=1.0, theta=0.0
% INFO    : Bus 81955	: V=1.0073652, theta=-45.023129 -> V=1.0, theta=0.0
% INFO    : Bus 81956	: V=1.0065499, theta=-45.311169 -> V=1.0, theta=0.0
% INFO    : Bus 81957	: V=1.0039258, theta=-50.245343 -> V=1.0, theta=0.0
% INFO    : Bus 81958	: V=1.0012432, theta=-50.800367 -> V=1.0, theta=0.0
% INFO    : Bus 81959	: V=1.0500021, theta=-29.881416 -> V=1.0, theta=0.0
% INFO    : Bus 81960	: V=1.0414869, theta=-30.495508 -> V=1.0, theta=0.0
% INFO    : Bus 81961	: V=1.0390191, theta=-30.63264 -> V=1.0, theta=0.0
% INFO    : Bus 81962	: V=1.017199, theta=-39.183917 -> V=1.0, theta=0.0
% INFO    : Bus 81963	: V=1.0166618, theta=-39.304515 -> V=1.0, theta=0.0
% INFO    : Bus 81964	: V=1.0124273, theta=-35.73081 -> V=1.0, theta=0.0
% INFO    : Bus 81965	: V=1.0107436, theta=-36.233886 -> V=1.0, theta=0.0
% INFO    : Bus 81966	: V=0.9984513, theta=-48.135456 -> V=1.0, theta=0.0
% INFO    : Bus 81967	: V=1.02, theta=-25.934528 -> V=1.0, theta=0.0
% INFO    : Bus 81968	: V=1.017137, theta=-28.607226 -> V=1.0, theta=0.0
% INFO    : Bus 81969	: V=1.001014, theta=-38.737786 -> V=1.0, theta=0.0
% INFO    : Bus 81970	: V=1.0058019, theta=-38.060952 -> V=1.0, theta=0.0
% INFO    : Bus 81971	: V=1.0124099, theta=-38.912714 -> V=1.0, theta=0.0
% INFO    : Bus 81972	: V=0.9825089, theta=-51.546624 -> V=1.0, theta=0.0
% INFO    : Bus 81973	: V=0.9776142, theta=-51.916721 -> V=1.0, theta=0.0
% INFO    : Bus 81974	: V=1.0047021, theta=-34.78401 -> V=1.0, theta=0.0
% INFO    : Bus 81975	: V=0.9968064, theta=-43.733461 -> V=1.0, theta=0.0
% INFO    : Bus 81976	: V=1.0049087, theta=-47.632512 -> V=1.0, theta=0.0
% INFO    : Bus 81977	: V=0.9836734, theta=-44.584919 -> V=1.0, theta=0.0
% INFO    : Bus 81978	: V=0.9781816, theta=-49.918665 -> V=1.0, theta=0.0
% INFO    : Bus 81979	: V=0.992145, theta=-41.443234 -> V=1.0, theta=0.0
% INFO    : Bus 81980	: V=1.010941, theta=-48.415572 -> V=1.0, theta=0.0
% INFO    : Bus 81981	: V=0.999774, theta=-32.26875 -> V=1.0, theta=0.0
% INFO    : Bus 81982	: V=0.9717452, theta=-50.813308 -> V=1.0, theta=0.0
% INFO    : Bus 81983	: V=0.9973015, theta=-39.939461 -> V=1.0, theta=0.0
% INFO    : Bus 81984	: V=0.9879394, theta=-41.266418 -> V=1.0, theta=0.0
% INFO    : Bus 81985	: V=1.0007377, theta=-31.417407 -> V=1.0, theta=0.0
% INFO    : Bus 81986	: V=1.0164692, theta=-28.772283 -> V=1.0, theta=0.0
% INFO    : Bus 81987	: V=1.0190824, theta=-28.778624 -> V=1.0, theta=0.0
% INFO    : Bus 81988	: V=0.9816555, theta=-43.883437 -> V=1.0, theta=0.0
% INFO    : Bus 81989	: V=1.0276016, theta=-30.257696 -> V=1.0, theta=0.0
% INFO    : Bus 81990	: V=1.0202084, theta=-29.523435 -> V=1.0, theta=0.0
% INFO    : Bus 81991	: V=1.02, theta=-28.241895 -> V=1.0, theta=0.0
% INFO    : Bus 81992	: V=1.0085079, theta=-44.547048 -> V=1.0, theta=0.0
% INFO    : Bus 81993	: V=0.9762454, theta=-49.693418 -> V=1.0, theta=0.0
% INFO    : Bus 81994	: V=1.0286083, theta=-30.599738 -> V=1.0, theta=0.0
% INFO    : Bus 81995	: V=0.9962136, theta=-30.15899 -> V=1.0, theta=0.0
% INFO    : Bus 81996	: V=1.0146277, theta=-42.105242 -> V=1.0, theta=0.0
% INFO    : Bus 81997	: V=1.0131095, theta=-42.498607 -> V=1.0, theta=0.0
% INFO    : Bus 81998	: V=1.0126779, theta=-42.641392 -> V=1.0, theta=0.0
% INFO    : Bus 81999	: V=1.0174372, theta=-50.159297 -> V=1.0, theta=0.0
% INFO    : Bus 82000	: V=1.0198858, theta=-36.836367 -> V=1.0, theta=0.0
% INFO    : Bus 82001	: V=1.0192578, theta=-37.021592 -> V=1.0, theta=0.0
% INFO    : Bus 82002	: V=1.0170904, theta=-49.967324 -> V=1.0, theta=0.0
% INFO    : Bus 82003	: V=1.016788, theta=-39.75606 -> V=1.0, theta=0.0
% INFO    : Bus 82004	: V=1.0154705, theta=-39.982377 -> V=1.0, theta=0.0
% INFO    : Bus 82005	: V=1.019175, theta=-40.320029 -> V=1.0, theta=0.0
% INFO    : Bus 82006	: V=1.0194706, theta=-38.07416 -> V=1.0, theta=0.0
% INFO    : Bus 82007	: V=1.0187291, theta=-38.462706 -> V=1.0, theta=0.0
% INFO    : Bus 82008	: V=1.009285, theta=-54.096212 -> V=1.0, theta=0.0
% INFO    : Bus 82009	: V=1.0078285, theta=-54.488271 -> V=1.0, theta=0.0
% INFO    : Bus 82010	: V=1.02, theta=-49.654815 -> V=1.0, theta=0.0
% INFO    : Bus 82011	: V=0.9910752, theta=-56.584876 -> V=1.0, theta=0.0
% INFO    : Bus 82012	: V=1.0196307, theta=-39.178396 -> V=1.0, theta=0.0
% INFO    : Bus 82013	: V=1.0170758, theta=-37.544958 -> V=1.0, theta=0.0
% INFO    : Bus 82014	: V=1.0145122, theta=-39.957919 -> V=1.0, theta=0.0
% INFO    : Bus 82015	: V=0.9960819, theta=-55.300078 -> V=1.0, theta=0.0
% INFO    : Bus 82016	: V=0.9959532, theta=-55.495767 -> V=1.0, theta=0.0
% INFO    : Bus 82017	: V=1.009424, theta=-39.672332 -> V=1.0, theta=0.0
% INFO    : Bus 82018	: V=1.0088641, theta=-39.694719 -> V=1.0, theta=0.0
% INFO    : Bus 82019	: V=1.0167524, theta=-43.631824 -> V=1.0, theta=0.0
% INFO    : Bus 82020	: V=1.0162298, theta=-43.640042 -> V=1.0, theta=0.0
% INFO    : Bus 82021	: V=1.0128377, theta=-40.647406 -> V=1.0, theta=0.0
% INFO    : Bus 82022	: V=1.0118713, theta=-40.765202 -> V=1.0, theta=0.0
% INFO    : Bus 82023	: V=1.0034824, theta=-52.600232 -> V=1.0, theta=0.0
% INFO    : Bus 82024	: V=1.0040165, theta=-52.756362 -> V=1.0, theta=0.0
% INFO    : Bus 82025	: V=1.0166851, theta=-38.175627 -> V=1.0, theta=0.0
% INFO    : Bus 82026	: V=1.0127905, theta=-38.84077 -> V=1.0, theta=0.0
% INFO    : Bus 82027	: V=1.0119213, theta=-39.023209 -> V=1.0, theta=0.0
% INFO    : Bus 82028	: V=1.0136928, theta=-47.500108 -> V=1.0, theta=0.0
% INFO    : Bus 82029	: V=0.9946946, theta=-52.640966 -> V=1.0, theta=0.0
% INFO    : Bus 82030	: V=0.9886119, theta=-53.735283 -> V=1.0, theta=0.0
% INFO    : Bus 82031	: V=1.0129524, theta=-52.141696 -> V=1.0, theta=0.0
% INFO    : Bus 82032	: V=1.0105245, theta=-44.220213 -> V=1.0, theta=0.0
% INFO    : Bus 82033	: V=1.0099442, theta=-44.3812 -> V=1.0, theta=0.0
% INFO    : Bus 82034	: V=0.9784412, theta=-51.811519 -> V=1.0, theta=0.0
% INFO    : Bus 82035	: V=1.0184699, theta=-39.997219 -> V=1.0, theta=0.0
% INFO    : Bus 82036	: V=1.0173388, theta=-40.16861 -> V=1.0, theta=0.0
% INFO    : Bus 82037	: V=1.0044726, theta=-48.30723 -> V=1.0, theta=0.0
% INFO    : Bus 82038	: V=0.9878897, theta=-50.05906 -> V=1.0, theta=0.0
% INFO    : Bus 82039	: V=0.9833474, theta=-51.379491 -> V=1.0, theta=0.0
% INFO    : Bus 82040	: V=1.0024952, theta=-48.426724 -> V=1.0, theta=0.0
% INFO    : Bus 82041	: V=1.0013832, theta=-48.604805 -> V=1.0, theta=0.0
% INFO    : Bus 82042	: V=1.0086816, theta=-55.759263 -> V=1.0, theta=0.0
% INFO    : Bus 82043	: V=1.0065103, theta=-56.180365 -> V=1.0, theta=0.0
% INFO    : Bus 82044	: V=1.0112439, theta=-55.063571 -> V=1.0, theta=0.0
% INFO    : Bus 82045	: V=1.0085571, theta=-55.544882 -> V=1.0, theta=0.0
% INFO    : Bus 82046	: V=0.9828206, theta=-51.279697 -> V=1.0, theta=0.0
% INFO    : Bus 82047	: V=0.9832025, theta=-51.399693 -> V=1.0, theta=0.0
% INFO    : Bus 82048	: V=0.9929041, theta=-50.009091 -> V=1.0, theta=0.0
% INFO    : Bus 82049	: V=0.988901, theta=-56.900192 -> V=1.0, theta=0.0
% INFO    : Bus 82050	: V=0.9852524, theta=-54.401289 -> V=1.0, theta=0.0
% INFO    : Bus 82051	: V=1.0069519, theta=-52.173509 -> V=1.0, theta=0.0
% INFO    : Bus 82052	: V=0.9932402, theta=-54.432121 -> V=1.0, theta=0.0
% INFO    : Bus 82053	: V=0.9977732, theta=-54.898724 -> V=1.0, theta=0.0
% INFO    : Bus 82054	: V=0.9901457, theta=-56.985783 -> V=1.0, theta=0.0
% INFO    : Bus 82055	: V=0.9792511, theta=-49.243478 -> V=1.0, theta=0.0
% INFO    : Bus 82056	: V=1.0134096, theta=-55.510226 -> V=1.0, theta=0.0
% INFO    : Bus 82057	: V=0.9894819, theta=-51.071821 -> V=1.0, theta=0.0
% INFO    : Bus 82058	: V=0.9984135, theta=-48.560382 -> V=1.0, theta=0.0
% INFO    : Bus 82059	: V=0.9944185, theta=-46.035723 -> V=1.0, theta=0.0
% INFO    : Bus 82060	: V=0.9738758, theta=-53.846283 -> V=1.0, theta=0.0
% INFO    : Bus 82061	: V=1.0084205, theta=-51.377951 -> V=1.0, theta=0.0
% INFO    : Bus 82062	: V=0.9601534, theta=-59.742211 -> V=1.0, theta=0.0
% INFO    : Bus 82063	: V=0.9628953, theta=-59.512899 -> V=1.0, theta=0.0
% INFO    : Bus 82064	: V=0.9499796, theta=-61.678521 -> V=1.0, theta=0.0
% INFO    : Bus 82065	: V=0.9470554, theta=-62.1623 -> V=1.0, theta=0.0
% INFO    : Bus 82066	: V=0.9615692, theta=-59.733276 -> V=1.0, theta=0.0
% INFO    : Bus 82067	: V=0.9622742, theta=-60.043777 -> V=1.0, theta=0.0
% INFO    : Bus 82068	: V=0.956458, theta=-60.273455 -> V=1.0, theta=0.0
% INFO    : Bus 82069	: V=0.9540092, theta=-60.96808 -> V=1.0, theta=0.0
% INFO    : Bus 82070	: V=0.9450487, theta=-61.998432 -> V=1.0, theta=0.0
% INFO    : Bus 82071	: V=0.9422082, theta=-62.62411 -> V=1.0, theta=0.0
% INFO    : Bus 82072	: V=0.9506382, theta=-61.427163 -> V=1.0, theta=0.0
% INFO    : Bus 82073	: V=0.9543641, theta=-61.146718 -> V=1.0, theta=0.0
% INFO    : Bus 82074	: V=0.9467148, theta=-61.912639 -> V=1.0, theta=0.0
% INFO    : Bus 82075	: V=0.9476869, theta=-61.922749 -> V=1.0, theta=0.0
% INFO    : Bus 82076	: V=0.9563923, theta=-60.306082 -> V=1.0, theta=0.0
% INFO    : Bus 82077	: V=0.9503774, theta=-61.741578 -> V=1.0, theta=0.0
% INFO    : Bus 82078	: V=0.9477282, theta=-61.576665 -> V=1.0, theta=0.0
% INFO    : Bus 82079	: V=0.9451009, theta=-62.043184 -> V=1.0, theta=0.0
% INFO    : Bus 82080	: V=0.9426252, theta=-62.41276 -> V=1.0, theta=0.0
% INFO    : Bus 82081	: V=0.9413316, theta=-62.589305 -> V=1.0, theta=0.0
% INFO    : Bus 82082	: V=0.940366, theta=-62.733244 -> V=1.0, theta=0.0
% INFO    : Bus 82083	: V=0.9454903, theta=-62.300292 -> V=1.0, theta=0.0
% INFO    : Bus 82084	: V=0.9532498, theta=-60.604289 -> V=1.0, theta=0.0
% INFO    : Bus 82085	: V=0.9492682, theta=-61.694574 -> V=1.0, theta=0.0
% INFO    : Bus 82086	: V=0.9430001, theta=-62.469903 -> V=1.0, theta=0.0
% INFO    : Bus 82087	: V=0.9397776, theta=-62.830807 -> V=1.0, theta=0.0
% INFO    : Bus 82088	: V=0.9428837, theta=-62.387655 -> V=1.0, theta=0.0
% INFO    : Bus 82089	: V=0.948538, theta=-61.578218 -> V=1.0, theta=0.0
% INFO    : Bus 82090	: V=0.9526467, theta=-61.43025 -> V=1.0, theta=0.0
% INFO    : Bus 82091	: V=0.9767214, theta=-57.522186 -> V=1.0, theta=0.0
% INFO    : Bus 82092	: V=0.9504454, theta=-61.204937 -> V=1.0, theta=0.0
% INFO    : Bus 82093	: V=0.9616148, theta=-59.749653 -> V=1.0, theta=0.0
% INFO    : Bus 82094	: V=0.9620788, theta=-60.220746 -> V=1.0, theta=0.0
% INFO    : Bus 82095	: V=0.9570984, theta=-60.700401 -> V=1.0, theta=0.0
% INFO    : Bus 82096	: V=0.9444543, theta=-63.098582 -> V=1.0, theta=0.0
% INFO    : Bus 82097	: V=0.9449155, theta=-62.215947 -> V=1.0, theta=0.0
% INFO    : Bus 82098	: V=0.9400607, theta=-63.100644 -> V=1.0, theta=0.0
% INFO    : Bus 82099	: V=0.9533371, theta=-61.474171 -> V=1.0, theta=0.0
% INFO    : Bus 82100	: V=0.9825497, theta=-57.352918 -> V=1.0, theta=0.0
% INFO    : Bus 82101	: V=0.9476915, theta=-61.500742 -> V=1.0, theta=0.0
% INFO    : Bus 82102	: V=0.9471216, theta=-61.864703 -> V=1.0, theta=0.0
% INFO    : Bus 82103	: V=0.9812, theta=-49.425899 -> V=1.0, theta=0.0
% INFO    : Bus 82104	: V=0.9726353, theta=-50.755574 -> V=1.0, theta=0.0
% INFO    : Bus 82105	: V=0.9820731, theta=-49.354603 -> V=1.0, theta=0.0
% INFO    : Bus 82106	: V=0.9818412, theta=-49.407284 -> V=1.0, theta=0.0
% INFO    : Bus 82107	: V=0.9718692, theta=-50.894064 -> V=1.0, theta=0.0
% INFO    : Bus 82108	: V=0.9669454, theta=-50.863676 -> V=1.0, theta=0.0
% INFO    : Bus 82109	: V=0.9764144, theta=-49.948784 -> V=1.0, theta=0.0
% INFO    : Bus 82110	: V=0.968396, theta=-50.939384 -> V=1.0, theta=0.0
% INFO    : Bus 82111	: V=0.980326, theta=-49.644074 -> V=1.0, theta=0.0
% INFO    : Bus 82112	: V=0.9757704, theta=-50.469908 -> V=1.0, theta=0.0
% INFO    : Bus 82113	: V=0.9539105, theta=-52.365754 -> V=1.0, theta=0.0
% INFO    : Bus 82114	: V=0.9805445, theta=-48.959798 -> V=1.0, theta=0.0
% INFO    : Bus 82115	: V=0.9796425, theta=-49.295321 -> V=1.0, theta=0.0
% INFO    : Bus 82116	: V=1.016013, theta=-48.561819 -> V=1.0, theta=0.0
% INFO    : Bus 82117	: V=0.9612477, theta=-58.438312 -> V=1.0, theta=0.0
% INFO    : Bus 82118	: V=0.977961, theta=-51.080023 -> V=1.0, theta=0.0
% INFO    : Bus 82119	: V=0.963152, theta=-53.256471 -> V=1.0, theta=0.0
% INFO    : Bus 82120	: V=0.9933153, theta=-49.870919 -> V=1.0, theta=0.0
% INFO    : Bus 82121	: V=0.9891216, theta=-50.51985 -> V=1.0, theta=0.0
% INFO    : Bus 82122	: V=0.9775462, theta=-50.711589 -> V=1.0, theta=0.0
% INFO    : Bus 82123	: V=0.9940835, theta=-51.741945 -> V=1.0, theta=0.0
% INFO    : Bus 82124	: V=0.9899826, theta=-51.479336 -> V=1.0, theta=0.0
% INFO    : Bus 82125	: V=0.9848511, theta=-52.49933 -> V=1.0, theta=0.0
% INFO    : Bus 82126	: V=0.9884696, theta=-51.870307 -> V=1.0, theta=0.0
% INFO    : Bus 82127	: V=0.9856149, theta=-52.509128 -> V=1.0, theta=0.0
% INFO    : Bus 82128	: V=0.9901667, theta=-53.749999 -> V=1.0, theta=0.0
% INFO    : Bus 82129	: V=0.9825326, theta=-54.841878 -> V=1.0, theta=0.0
% INFO    : Bus 82130	: V=0.9908875, theta=-52.673375 -> V=1.0, theta=0.0
% INFO    : Bus 82131	: V=0.9980815, theta=-50.880119 -> V=1.0, theta=0.0
% INFO    : Bus 82132	: V=0.9950207, theta=-51.994259 -> V=1.0, theta=0.0
% INFO    : Bus 82133	: V=0.9885132, theta=-53.040493 -> V=1.0, theta=0.0
% INFO    : Bus 82134	: V=1.0065175, theta=-45.035376 -> V=1.0, theta=0.0
% INFO    : Bus 82135	: V=0.9923887, theta=-46.855881 -> V=1.0, theta=0.0
% INFO    : Bus 82136	: V=1.0067287, theta=-45.029033 -> V=1.0, theta=0.0
% INFO    : Bus 82137	: V=0.9972352, theta=-46.53807 -> V=1.0, theta=0.0
% INFO    : Bus 82138	: V=0.996161, theta=-46.5835 -> V=1.0, theta=0.0
% INFO    : Bus 82139	: V=1.0018978, theta=-46.05243 -> V=1.0, theta=0.0
% INFO    : Bus 82140	: V=0.9989986, theta=-46.21031 -> V=1.0, theta=0.0
% INFO    : Bus 82141	: V=0.9986982, theta=-46.29277 -> V=1.0, theta=0.0
% INFO    : Bus 82142	: V=0.9979769, theta=-46.378767 -> V=1.0, theta=0.0
% INFO    : Bus 82143	: V=0.993401, theta=-46.22696 -> V=1.0, theta=0.0
% INFO    : Bus 82144	: V=1.0074365, theta=-44.911681 -> V=1.0, theta=0.0
% INFO    : Bus 82145	: V=1.0037636, theta=-45.563745 -> V=1.0, theta=0.0
% INFO    : Bus 82146	: V=0.9664823, theta=-53.077609 -> V=1.0, theta=0.0
% INFO    : Bus 82147	: V=0.9596376, theta=-53.642732 -> V=1.0, theta=0.0
% INFO    : Bus 82148	: V=0.9616618, theta=-53.602368 -> V=1.0, theta=0.0
% INFO    : Bus 82149	: V=0.9613307, theta=-53.552635 -> V=1.0, theta=0.0
% INFO    : Bus 82150	: V=1.0021251, theta=-44.908671 -> V=1.0, theta=0.0
% INFO    : Bus 82151	: V=1.0105261, theta=-43.637241 -> V=1.0, theta=0.0
% INFO    : Bus 82152	: V=1.0091762, theta=-43.987976 -> V=1.0, theta=0.0
% INFO    : Bus 82153	: V=1.0007289, theta=-43.363444 -> V=1.0, theta=0.0
% INFO    : Bus 82154	: V=1.0121244, theta=-41.314369 -> V=1.0, theta=0.0
% INFO    : Bus 82155	: V=1.0067687, theta=-42.351982 -> V=1.0, theta=0.0
% INFO    : Bus 82156	: V=1.0157977, theta=-43.819216 -> V=1.0, theta=0.0
% INFO    : Bus 82157	: V=1.0150363, theta=-43.925124 -> V=1.0, theta=0.0
% INFO    : Bus 82158	: V=0.9948591, theta=-46.998807 -> V=1.0, theta=0.0
% INFO    : Bus 82159	: V=0.9993917, theta=-45.132238 -> V=1.0, theta=0.0
% INFO    : Bus 82160	: V=0.9468941, theta=-52.755562 -> V=1.0, theta=0.0
% INFO    : Bus 82161	: V=0.9519042, theta=-51.858237 -> V=1.0, theta=0.0
% INFO    : Bus 82162	: V=0.9584412, theta=-50.882639 -> V=1.0, theta=0.0
% INFO    : Bus 82163	: V=0.9409825, theta=-62.168558 -> V=1.0, theta=0.0
% INFO    : Bus 82164	: V=0.9518442, theta=-60.928532 -> V=1.0, theta=0.0
% INFO    : Bus 82165	: V=0.9462753, theta=-61.393926 -> V=1.0, theta=0.0
% INFO    : Bus 82166	: V=0.9447098, theta=-61.626811 -> V=1.0, theta=0.0
% INFO    : Bus 82167	: V=0.9410674, theta=-61.982149 -> V=1.0, theta=0.0
% INFO    : Bus 82168	: V=0.9478566, theta=-61.577662 -> V=1.0, theta=0.0
% INFO    : Bus 82169	: V=0.970815, theta=-56.23898 -> V=1.0, theta=0.0
% INFO    : Bus 82170	: V=0.9679106, theta=-56.846454 -> V=1.0, theta=0.0
% INFO    : Bus 82171	: V=0.971076, theta=-56.134428 -> V=1.0, theta=0.0
% INFO    : Bus 82172	: V=0.9675878, theta=-56.78621 -> V=1.0, theta=0.0
% INFO    : Bus 82173	: V=0.9717114, theta=-56.195871 -> V=1.0, theta=0.0
% INFO    : Bus 82174	: V=0.9694481, theta=-56.610444 -> V=1.0, theta=0.0
% INFO    : Bus 82175	: V=0.9681099, theta=-56.680148 -> V=1.0, theta=0.0
% INFO    : Bus 82176	: V=0.9684107, theta=-56.717335 -> V=1.0, theta=0.0
% INFO    : Bus 82177	: V=0.9701526, theta=-56.338915 -> V=1.0, theta=0.0
% INFO    : Bus 82178	: V=0.9641857, theta=-57.237724 -> V=1.0, theta=0.0
% INFO    : Bus 82179	: V=0.9710425, theta=-56.135028 -> V=1.0, theta=0.0
% INFO    : Bus 82180	: V=0.9663494, theta=-57.106176 -> V=1.0, theta=0.0
% INFO    : Bus 82181	: V=0.9717399, theta=-56.209252 -> V=1.0, theta=0.0
% INFO    : Bus 82182	: V=0.9765536, theta=-55.244376 -> V=1.0, theta=0.0
% INFO    : Bus 82183	: V=0.9746014, theta=-55.564747 -> V=1.0, theta=0.0
% INFO    : Bus 82184	: V=0.9721068, theta=-56.066062 -> V=1.0, theta=0.0
% INFO    : Bus 82185	: V=0.966273, theta=-57.094613 -> V=1.0, theta=0.0
% INFO    : Bus 82186	: V=0.9663597, theta=-57.428438 -> V=1.0, theta=0.0
% INFO    : Bus 82187	: V=0.9751743, theta=-56.432779 -> V=1.0, theta=0.0
% INFO    : Bus 82188	: V=0.9663711, theta=-56.84489 -> V=1.0, theta=0.0
% INFO    : Bus 82189	: V=1.0064613, theta=-43.035497 -> V=1.0, theta=0.0
% INFO    : Bus 82190	: V=0.9916067, theta=-45.112387 -> V=1.0, theta=0.0
% INFO    : Bus 82191	: V=1.0089359, theta=-42.602123 -> V=1.0, theta=0.0
% INFO    : Bus 82192	: V=1.0066715, theta=-42.887706 -> V=1.0, theta=0.0
% INFO    : Bus 82193	: V=0.9420391, theta=-59.586034 -> V=1.0, theta=0.0
% INFO    : Bus 82194	: V=0.93337, theta=-61.225277 -> V=1.0, theta=0.0
% INFO    : Bus 82195	: V=0.9400887, theta=-59.741158 -> V=1.0, theta=0.0
% INFO    : Bus 82196	: V=0.9596829, theta=-57.468667 -> V=1.0, theta=0.0
% INFO    : Bus 82197	: V=0.9575743, theta=-57.35025 -> V=1.0, theta=0.0
% INFO    : Bus 82198	: V=0.9762369, theta=-52.98329 -> V=1.0, theta=0.0
% INFO    : Bus 82199	: V=0.9676766, theta=-55.063622 -> V=1.0, theta=0.0
% INFO    : Bus 82200	: V=0.9559889, theta=-57.361515 -> V=1.0, theta=0.0
% INFO    : Bus 82201	: V=0.9540164, theta=-56.866569 -> V=1.0, theta=0.0
% INFO    : Bus 82202	: V=0.9597768, theta=-55.817004 -> V=1.0, theta=0.0
% INFO    : Bus 82203	: V=0.9587003, theta=-56.387198 -> V=1.0, theta=0.0
% INFO    : Bus 82204	: V=0.9527183, theta=-57.180602 -> V=1.0, theta=0.0
% INFO    : Bus 82205	: V=0.9545098, theta=-57.313497 -> V=1.0, theta=0.0
% INFO    : Bus 82206	: V=0.9557992, theta=-56.495554 -> V=1.0, theta=0.0
% INFO    : Bus 82207	: V=0.9521995, theta=-57.501937 -> V=1.0, theta=0.0
% INFO    : Bus 82208	: V=0.9467616, theta=-57.916922 -> V=1.0, theta=0.0
% INFO    : Bus 82209	: V=0.960853, theta=-55.859105 -> V=1.0, theta=0.0
% INFO    : Bus 82210	: V=0.9502401, theta=-57.583527 -> V=1.0, theta=0.0
% INFO    : Bus 82211	: V=0.9714995, theta=-52.548939 -> V=1.0, theta=0.0
% INFO    : Bus 82212	: V=0.9648549, theta=-53.733067 -> V=1.0, theta=0.0
% INFO    : Bus 82213	: V=0.9693322, theta=-52.703431 -> V=1.0, theta=0.0
% INFO    : Bus 82214	: V=0.9723795, theta=-52.635582 -> V=1.0, theta=0.0
% INFO    : Bus 82215	: V=0.9651634, theta=-52.545861 -> V=1.0, theta=0.0
% INFO    : Bus 82216	: V=0.9967248, theta=-46.245756 -> V=1.0, theta=0.0
% INFO    : Bus 82217	: V=0.997418, theta=-46.159894 -> V=1.0, theta=0.0
% INFO    : Bus 82218	: V=1.0073126, theta=-45.135186 -> V=1.0, theta=0.0
% INFO    : Bus 82219	: V=1.0051607, theta=-45.389107 -> V=1.0, theta=0.0
% INFO    : Bus 82220	: V=1.0012386, theta=-45.858949 -> V=1.0, theta=0.0
% INFO    : Bus 82221	: V=1.0056405, theta=-45.364613 -> V=1.0, theta=0.0
% INFO    : Bus 82222	: V=1.0024935, theta=-45.935742 -> V=1.0, theta=0.0
% INFO    : Bus 82223	: V=1.0010361, theta=-45.793686 -> V=1.0, theta=0.0
% INFO    : Bus 82224	: V=1.0019544, theta=-45.860411 -> V=1.0, theta=0.0
% INFO    : Bus 82225	: V=1.0016112, theta=-45.889066 -> V=1.0, theta=0.0
% INFO    : Bus 82226	: V=1.0008834, theta=-45.95285 -> V=1.0, theta=0.0
% INFO    : Bus 82227	: V=1.0056543, theta=-45.052127 -> V=1.0, theta=0.0
% INFO    : Bus 82228	: V=1.0120907, theta=-44.583204 -> V=1.0, theta=0.0
% INFO    : Bus 82229	: V=1.0034343, theta=-46.399686 -> V=1.0, theta=0.0
% INFO    : Bus 82230	: V=0.9944235, theta=-47.976593 -> V=1.0, theta=0.0
% INFO    : Bus 82231	: V=1.0032317, theta=-45.749333 -> V=1.0, theta=0.0
% INFO    : Bus 82232	: V=1.0148502, theta=-43.005562 -> V=1.0, theta=0.0
% INFO    : Bus 82233	: V=0.9782123, theta=-48.909091 -> V=1.0, theta=0.0
% INFO    : Bus 82234	: V=0.966831, theta=-56.87631 -> V=1.0, theta=0.0
% INFO    : Bus 82235	: V=0.9757277, theta=-55.876971 -> V=1.0, theta=0.0
% INFO    : Bus 82236	: V=0.989609, theta=-43.402962 -> V=1.0, theta=0.0
% INFO    : Bus 82237	: V=0.9940569, theta=-43.333302 -> V=1.0, theta=0.0
% INFO    : Bus 82238	: V=0.9620741, theta=-57.924936 -> V=1.0, theta=0.0
% INFO    : Bus 82239	: V=0.9567282, theta=-58.469257 -> V=1.0, theta=0.0
% INFO    : Bus 82240	: V=0.9710127, theta=-56.380889 -> V=1.0, theta=0.0
% INFO    : Bus 82241	: V=0.9660293, theta=-57.337883 -> V=1.0, theta=0.0
% INFO    : Bus 82242	: V=0.965449, theta=-57.537014 -> V=1.0, theta=0.0
% INFO    : Bus 82243	: V=0.9730118, theta=-56.143404 -> V=1.0, theta=0.0
% INFO    : Bus 82244	: V=0.9719993, theta=-56.308859 -> V=1.0, theta=0.0
% INFO    : Bus 82245	: V=0.9697879, theta=-56.848942 -> V=1.0, theta=0.0
% INFO    : Bus 82246	: V=1.016862, theta=-42.992206 -> V=1.0, theta=0.0
% INFO    : Bus 82247	: V=1.0134894, theta=-42.972862 -> V=1.0, theta=0.0
% INFO    : Bus 82248	: V=1.0109756, theta=-43.540821 -> V=1.0, theta=0.0
% INFO    : Bus 82249	: V=0.9848546, theta=-53.300328 -> V=1.0, theta=0.0
% INFO    : Bus 82250	: V=0.9856656, theta=-52.046247 -> V=1.0, theta=0.0
% INFO    : Bus 82251	: V=0.9840177, theta=-52.359478 -> V=1.0, theta=0.0
% INFO    : Bus 82252	: V=0.9802071, theta=-52.090523 -> V=1.0, theta=0.0
% INFO    : Bus 82253	: V=0.9885812, theta=-51.580646 -> V=1.0, theta=0.0
% INFO    : Bus 82254	: V=0.9874753, theta=-51.931808 -> V=1.0, theta=0.0
% INFO    : Bus 82255	: V=0.9817052, theta=-51.726923 -> V=1.0, theta=0.0
% INFO    : Bus 82256	: V=0.9768623, theta=-52.529691 -> V=1.0, theta=0.0
% INFO    : Bus 82257	: V=0.9793615, theta=-52.470412 -> V=1.0, theta=0.0
% INFO    : Bus 82258	: V=0.97387, theta=-53.051633 -> V=1.0, theta=0.0
% INFO    : Bus 82259	: V=0.9915617, theta=-50.126062 -> V=1.0, theta=0.0
% INFO    : Bus 82260	: V=0.9886186, theta=-51.001603 -> V=1.0, theta=0.0
% INFO    : Bus 82261	: V=0.9866165, theta=-51.27222 -> V=1.0, theta=0.0
% INFO    : Bus 82262	: V=0.9833613, theta=-51.754594 -> V=1.0, theta=0.0
% INFO    : Bus 82263	: V=0.9830887, theta=-52.005726 -> V=1.0, theta=0.0
% INFO    : Bus 82264	: V=0.9819549, theta=-52.06217 -> V=1.0, theta=0.0
% INFO    : Bus 82265	: V=0.9888544, theta=-50.796105 -> V=1.0, theta=0.0
% INFO    : Bus 82266	: V=0.984314, theta=-51.487891 -> V=1.0, theta=0.0
% INFO    : Bus 82267	: V=0.980612, theta=-51.566673 -> V=1.0, theta=0.0
% INFO    : Bus 82268	: V=0.9878856, theta=-50.844403 -> V=1.0, theta=0.0
% INFO    : Bus 82269	: V=0.9855704, theta=-51.336076 -> V=1.0, theta=0.0
% INFO    : Bus 82270	: V=0.9860556, theta=-51.078858 -> V=1.0, theta=0.0
% INFO    : Bus 82271	: V=0.9551827, theta=-55.868663 -> V=1.0, theta=0.0
% INFO    : Bus 82272	: V=0.9484804, theta=-56.505735 -> V=1.0, theta=0.0
% INFO    : Bus 82273	: V=0.942248, theta=-57.038704 -> V=1.0, theta=0.0
% INFO    : Bus 82274	: V=1.0110916, theta=-44.18916 -> V=1.0, theta=0.0
% INFO    : Bus 82275	: V=1.0081778, theta=-44.671091 -> V=1.0, theta=0.0
% INFO    : Bus 82276	: V=1.0113672, theta=-43.963921 -> V=1.0, theta=0.0
% INFO    : Bus 82277	: V=1.008633, theta=-44.424207 -> V=1.0, theta=0.0
% INFO    : Bus 82278	: V=0.9894124, theta=-49.856439 -> V=1.0, theta=0.0
% INFO    : Bus 82279	: V=0.9893374, theta=-49.991743 -> V=1.0, theta=0.0
% INFO    : Bus 82280	: V=1.0019862, theta=-47.680305 -> V=1.0, theta=0.0
% INFO    : Bus 82281	: V=0.998899, theta=-48.281872 -> V=1.0, theta=0.0
% INFO    : Bus 82282	: V=0.9667327, theta=-50.961236 -> V=1.0, theta=0.0
% INFO    : Bus 82283	: V=0.9584196, theta=-51.814414 -> V=1.0, theta=0.0
% INFO    : Bus 82284	: V=0.9640446, theta=-52.013465 -> V=1.0, theta=0.0
% INFO    : Bus 82285	: V=0.9590952, theta=-52.441986 -> V=1.0, theta=0.0
% INFO    : Bus 82286	: V=0.9695454, theta=-51.879235 -> V=1.0, theta=0.0
% INFO    : Bus 82287	: V=0.96573, theta=-51.838514 -> V=1.0, theta=0.0
% INFO    : Bus 82288	: V=0.967885, theta=-50.548073 -> V=1.0, theta=0.0
% INFO    : Bus 82289	: V=0.9628201, theta=-55.366546 -> V=1.0, theta=0.0
% INFO    : Bus 82290	: V=0.9559438, theta=-56.596598 -> V=1.0, theta=0.0
% INFO    : Bus 82291	: V=0.9563411, theta=-56.595594 -> V=1.0, theta=0.0
% INFO    : Bus 82292	: V=0.9818589, theta=-53.775851 -> V=1.0, theta=0.0
% INFO    : Bus 82293	: V=0.9696159, theta=-55.248227 -> V=1.0, theta=0.0
% INFO    : Bus 82294	: V=0.9660504, theta=-55.504679 -> V=1.0, theta=0.0
% INFO    : Bus 82295	: V=0.9788145, theta=-54.22669 -> V=1.0, theta=0.0
% INFO    : Bus 82296	: V=0.9750038, theta=-55.02126 -> V=1.0, theta=0.0
% INFO    : Bus 82297	: V=0.9705367, theta=-55.477047 -> V=1.0, theta=0.0
% INFO    : Bus 82298	: V=0.9551376, theta=-60.158502 -> V=1.0, theta=0.0
% INFO    : Bus 82299	: V=0.9591173, theta=-59.720573 -> V=1.0, theta=0.0
% INFO    : Bus 82300	: V=0.9637612, theta=-58.411748 -> V=1.0, theta=0.0
% INFO    : Bus 82301	: V=0.9606654, theta=-59.314877 -> V=1.0, theta=0.0
% INFO    : Bus 82302	: V=0.96711, theta=-57.588952 -> V=1.0, theta=0.0
% INFO    : Bus 82303	: V=0.9612787, theta=-50.331292 -> V=1.0, theta=0.0
% INFO    : Bus 82304	: V=0.9604315, theta=-50.424295 -> V=1.0, theta=0.0
% INFO    : Bus 82305	: V=0.9621956, theta=-50.211614 -> V=1.0, theta=0.0
% INFO    : Bus 82306	: V=0.9747094, theta=-49.175162 -> V=1.0, theta=0.0
% INFO    : Bus 82307	: V=0.9700647, theta=-49.215268 -> V=1.0, theta=0.0
% INFO    : Bus 82308	: V=0.9945135, theta=-55.539913 -> V=1.0, theta=0.0
% INFO    : Bus 82309	: V=0.9965668, theta=-53.749573 -> V=1.0, theta=0.0
% INFO    : Bus 82310	: V=0.9911654, theta=-54.691839 -> V=1.0, theta=0.0
% INFO    : Bus 82311	: V=1.0103921, theta=-50.767457 -> V=1.0, theta=0.0
% INFO    : Bus 82312	: V=1.0046483, theta=-52.417023 -> V=1.0, theta=0.0
% INFO    : Bus 82313	: V=1.0024121, theta=-52.825775 -> V=1.0, theta=0.0
% INFO    : Bus 82314	: V=1.0157706, theta=-49.536463 -> V=1.0, theta=0.0
% INFO    : Bus 82315	: V=1.0121523, theta=-50.172208 -> V=1.0, theta=0.0
% INFO    : Bus 82316	: V=0.9769192, theta=-56.819919 -> V=1.0, theta=0.0
% INFO    : Bus 82317	: V=0.9766475, theta=-57.330578 -> V=1.0, theta=0.0
% INFO    : Bus 82318	: V=0.9743407, theta=-57.906072 -> V=1.0, theta=0.0
% INFO    : Bus 82319	: V=0.9681153, theta=-58.10218 -> V=1.0, theta=0.0
% INFO    : Bus 82320	: V=0.9715954, theta=-57.32429 -> V=1.0, theta=0.0
% INFO    : Bus 82321	: V=0.967581, theta=-58.206068 -> V=1.0, theta=0.0
% INFO    : Bus 82322	: V=0.9747979, theta=-56.769856 -> V=1.0, theta=0.0
% INFO    : Bus 82323	: V=0.9998065, theta=-44.173664 -> V=1.0, theta=0.0
% INFO    : Bus 82324	: V=0.9957415, theta=-45.419224 -> V=1.0, theta=0.0
% INFO    : Bus 82325	: V=1.0094102, theta=-42.073516 -> V=1.0, theta=0.0
% INFO    : Bus 82326	: V=0.9519447, theta=-51.58227 -> V=1.0, theta=0.0
% INFO    : Bus 82327	: V=0.9625549, theta=-50.23931 -> V=1.0, theta=0.0
% INFO    : Bus 82328	: V=0.9582504, theta=-53.72935 -> V=1.0, theta=0.0
% INFO    : Bus 82329	: V=0.9790305, theta=-51.227433 -> V=1.0, theta=0.0
% INFO    : Bus 82330	: V=0.9732944, theta=-52.029125 -> V=1.0, theta=0.0
% INFO    : Bus 82331	: V=0.9634142, theta=-52.572787 -> V=1.0, theta=0.0
% INFO    : Bus 82332	: V=0.9712689, theta=-51.913054 -> V=1.0, theta=0.0
% INFO    : Bus 82333	: V=1.0117261, theta=-42.568585 -> V=1.0, theta=0.0
% INFO    : Bus 82334	: V=0.9825342, theta=-43.412341 -> V=1.0, theta=0.0
% INFO    : Bus 82335	: V=0.9480861, theta=-60.746358 -> V=1.0, theta=0.0
% INFO    : Bus 82336	: V=0.9401832, theta=-60.878959 -> V=1.0, theta=0.0
% INFO    : Bus 82337	: V=0.9481574, theta=-61.890072 -> V=1.0, theta=0.0
% INFO    : Bus 82338	: V=0.955694, theta=-60.612473 -> V=1.0, theta=0.0
% INFO    : Bus 82339	: V=0.9540102, theta=-60.898843 -> V=1.0, theta=0.0
% INFO    : Bus 82340	: V=0.9495949, theta=-61.374611 -> V=1.0, theta=0.0
% INFO    : Bus 82341	: V=0.9671922, theta=-57.238756 -> V=1.0, theta=0.0
% INFO    : Bus 82342	: V=0.95634, theta=-59.787488 -> V=1.0, theta=0.0
% INFO    : Bus 82343	: V=0.9385229, theta=-60.62729 -> V=1.0, theta=0.0
% INFO    : Bus 82344	: V=0.9416472, theta=-60.267224 -> V=1.0, theta=0.0
% INFO    : Bus 82345	: V=0.939628, theta=-60.616648 -> V=1.0, theta=0.0
% INFO    : Bus 82346	: V=1.002362, theta=-56.956142 -> V=1.0, theta=0.0
% INFO    : Bus 82347	: V=1.0005924, theta=-57.253676 -> V=1.0, theta=0.0
% INFO    : Bus 82348	: V=1.0046671, theta=-56.840984 -> V=1.0, theta=0.0
% INFO    : Bus 82349	: V=0.9993806, theta=-57.430018 -> V=1.0, theta=0.0
% INFO    : Bus 82350	: V=0.9985677, theta=-57.4099 -> V=1.0, theta=0.0
% INFO    : Bus 82351	: V=0.9894566, theta=-58.506956 -> V=1.0, theta=0.0
% INFO    : Bus 82352	: V=0.9959529, theta=-57.744951 -> V=1.0, theta=0.0
% INFO    : Bus 82353	: V=0.9963719, theta=-57.632148 -> V=1.0, theta=0.0
% INFO    : Bus 82354	: V=0.9930638, theta=-57.876855 -> V=1.0, theta=0.0
% INFO    : Bus 82355	: V=0.9924198, theta=-57.853884 -> V=1.0, theta=0.0
% INFO    : Bus 82356	: V=0.99462, theta=-57.740968 -> V=1.0, theta=0.0
% INFO    : Bus 82357	: V=0.9960873, theta=-57.631197 -> V=1.0, theta=0.0
% INFO    : Bus 82358	: V=0.9995039, theta=-57.880847 -> V=1.0, theta=0.0
% INFO    : Bus 82359	: V=0.9858296, theta=-59.000813 -> V=1.0, theta=0.0
% INFO    : Bus 82360	: V=0.9848078, theta=-58.820394 -> V=1.0, theta=0.0
% INFO    : Bus 82361	: V=0.9849006, theta=-58.723415 -> V=1.0, theta=0.0
% INFO    : Bus 82362	: V=0.9849539, theta=-58.776372 -> V=1.0, theta=0.0
% INFO    : Bus 82363	: V=0.9946244, theta=-57.847923 -> V=1.0, theta=0.0
% INFO    : Bus 82364	: V=0.9969971, theta=-57.771588 -> V=1.0, theta=0.0
% INFO    : Bus 82365	: V=0.9985368, theta=-57.853746 -> V=1.0, theta=0.0
% INFO    : Bus 82366	: V=0.9962835, theta=-58.117392 -> V=1.0, theta=0.0
% INFO    : Bus 82367	: V=0.9895157, theta=-58.791409 -> V=1.0, theta=0.0
% INFO    : Bus 82368	: V=0.9921015, theta=-58.139234 -> V=1.0, theta=0.0
% INFO    : Bus 82369	: V=0.9753334, theta=-59.07703 -> V=1.0, theta=0.0
% INFO    : Bus 82370	: V=0.9817713, theta=-58.760262 -> V=1.0, theta=0.0
% INFO    : Bus 82371	: V=0.9907883, theta=-57.304124 -> V=1.0, theta=0.0
% INFO    : Bus 82372	: V=0.9864583, theta=-58.031531 -> V=1.0, theta=0.0
% INFO    : Bus 82373	: V=0.9865054, theta=-58.190767 -> V=1.0, theta=0.0
% INFO    : Bus 82374	: V=0.9828484, theta=-58.165088 -> V=1.0, theta=0.0
% INFO    : Bus 82375	: V=0.9799835, theta=-58.243387 -> V=1.0, theta=0.0
% INFO    : Bus 82376	: V=0.9781369, theta=-58.743051 -> V=1.0, theta=0.0
% INFO    : Bus 82377	: V=0.9775662, theta=-58.268398 -> V=1.0, theta=0.0
% INFO    : Bus 82378	: V=0.9792313, theta=-58.327119 -> V=1.0, theta=0.0
% INFO    : Bus 82379	: V=0.9882001, theta=-57.385229 -> V=1.0, theta=0.0
% INFO    : Bus 82380	: V=0.9848353, theta=-57.939356 -> V=1.0, theta=0.0
% INFO    : Bus 82381	: V=0.9715564, theta=-58.877462 -> V=1.0, theta=0.0
% INFO    : Bus 82382	: V=0.9750635, theta=-58.484285 -> V=1.0, theta=0.0
% INFO    : Bus 82383	: V=0.9735371, theta=-58.222677 -> V=1.0, theta=0.0
% INFO    : Bus 82384	: V=0.9686953, theta=-58.489728 -> V=1.0, theta=0.0
% INFO    : Bus 82385	: V=0.9757444, theta=-57.151971 -> V=1.0, theta=0.0
% INFO    : Bus 82386	: V=1.0101144, theta=-54.773264 -> V=1.0, theta=0.0
% INFO    : Bus 82387	: V=1.0066522, theta=-55.131428 -> V=1.0, theta=0.0
% INFO    : Bus 82388	: V=1.0107298, theta=-54.40006 -> V=1.0, theta=0.0
% INFO    : Bus 82389	: V=1.0107739, theta=-54.2153 -> V=1.0, theta=0.0
% INFO    : Bus 82390	: V=1.0008838, theta=-55.594989 -> V=1.0, theta=0.0
% INFO    : Bus 82391	: V=0.9931268, theta=-55.59012 -> V=1.0, theta=0.0
% INFO    : Bus 82392	: V=0.99152, theta=-55.753362 -> V=1.0, theta=0.0
% INFO    : Bus 82393	: V=1.0042715, theta=-54.713298 -> V=1.0, theta=0.0
% INFO    : Bus 82394	: V=0.9961308, theta=-55.795499 -> V=1.0, theta=0.0
% INFO    : Bus 82395	: V=0.9983445, theta=-55.504814 -> V=1.0, theta=0.0
% INFO    : Bus 82396	: V=0.9894275, theta=-56.940642 -> V=1.0, theta=0.0
% INFO    : Bus 82397	: V=0.9812513, theta=-56.452411 -> V=1.0, theta=0.0
% INFO    : Bus 82398	: V=0.9872178, theta=-47.77449 -> V=1.0, theta=0.0
% INFO    : Bus 82399	: V=0.9807744, theta=-47.488854 -> V=1.0, theta=0.0
% INFO    : Bus 82400	: V=0.9964993, theta=-46.458714 -> V=1.0, theta=0.0
% INFO    : Bus 82401	: V=0.9873613, theta=-47.465503 -> V=1.0, theta=0.0
% INFO    : Bus 82402	: V=0.9745861, theta=-55.103516 -> V=1.0, theta=0.0
% INFO    : Bus 82403	: V=0.97527, theta=-55.038245 -> V=1.0, theta=0.0
% INFO    : Bus 82404	: V=0.9759516, theta=-55.2131 -> V=1.0, theta=0.0
% INFO    : Bus 82405	: V=0.9754974, theta=-55.054425 -> V=1.0, theta=0.0
% INFO    : Bus 82406	: V=0.9736448, theta=-55.898385 -> V=1.0, theta=0.0
% INFO    : Bus 82407	: V=0.9732823, theta=-55.431965 -> V=1.0, theta=0.0
% INFO    : Bus 82408	: V=0.9681094, theta=-56.341268 -> V=1.0, theta=0.0
% INFO    : Bus 82409	: V=0.9740559, theta=-55.178028 -> V=1.0, theta=0.0
% INFO    : Bus 82410	: V=0.9781295, theta=-54.254013 -> V=1.0, theta=0.0
% INFO    : Bus 82411	: V=0.9622369, theta=-55.928193 -> V=1.0, theta=0.0
% INFO    : Bus 82412	: V=0.997893, theta=-49.073139 -> V=1.0, theta=0.0
% INFO    : Bus 82413	: V=0.9927333, theta=-50.017845 -> V=1.0, theta=0.0
% INFO    : Bus 82414	: V=0.985627, theta=-50.994365 -> V=1.0, theta=0.0
% INFO    : Bus 82415	: V=0.9861921, theta=-50.487648 -> V=1.0, theta=0.0
% INFO    : Bus 82416	: V=0.9816246, theta=-51.024713 -> V=1.0, theta=0.0
% INFO    : Bus 82417	: V=0.9770336, theta=-51.518285 -> V=1.0, theta=0.0
% INFO    : Bus 82418	: V=0.9876532, theta=-50.238245 -> V=1.0, theta=0.0
% INFO    : Bus 82419	: V=0.9813997, theta=-51.025036 -> V=1.0, theta=0.0
% INFO    : Bus 82420	: V=0.9795937, theta=-51.086205 -> V=1.0, theta=0.0
% INFO    : Bus 82421	: V=0.9859292, theta=-51.167155 -> V=1.0, theta=0.0
% INFO    : Bus 82422	: V=0.9890198, theta=-50.504725 -> V=1.0, theta=0.0
% INFO    : Bus 82423	: V=0.9787574, theta=-51.929557 -> V=1.0, theta=0.0
% INFO    : Bus 82424	: V=0.9781342, theta=-52.211286 -> V=1.0, theta=0.0
% INFO    : Bus 82425	: V=0.9826207, theta=-51.235629 -> V=1.0, theta=0.0
% INFO    : Bus 82426	: V=0.978377, theta=-51.672494 -> V=1.0, theta=0.0
% INFO    : Bus 82427	: V=0.9764888, theta=-51.968429 -> V=1.0, theta=0.0
% INFO    : Bus 82428	: V=0.9751364, theta=-51.986633 -> V=1.0, theta=0.0
% INFO    : Bus 82429	: V=0.9780772, theta=-51.772293 -> V=1.0, theta=0.0
% INFO    : Bus 82430	: V=0.9771689, theta=-51.744862 -> V=1.0, theta=0.0
% INFO    : Bus 82431	: V=0.9768728, theta=-51.87131 -> V=1.0, theta=0.0
% INFO    : Bus 82432	: V=0.9768128, theta=-51.860099 -> V=1.0, theta=0.0
% INFO    : Bus 82433	: V=0.9767278, theta=-51.81335 -> V=1.0, theta=0.0
% INFO    : Bus 82434	: V=0.9758059, theta=-51.915102 -> V=1.0, theta=0.0
% INFO    : Bus 82435	: V=0.9742965, theta=-52.095572 -> V=1.0, theta=0.0
% INFO    : Bus 82436	: V=0.9821589, theta=-51.678303 -> V=1.0, theta=0.0
% INFO    : Bus 82437	: V=0.9778233, theta=-52.331588 -> V=1.0, theta=0.0
% INFO    : Bus 82438	: V=0.9812465, theta=-51.634425 -> V=1.0, theta=0.0
% INFO    : Bus 82439	: V=0.9756886, theta=-52.439614 -> V=1.0, theta=0.0
% INFO    : Bus 82440	: V=0.9590057, theta=-53.80347 -> V=1.0, theta=0.0
% INFO    : Bus 82441	: V=0.9900489, theta=-49.759055 -> V=1.0, theta=0.0
% INFO    : Bus 82442	: V=0.9850679, theta=-50.476664 -> V=1.0, theta=0.0
% INFO    : Bus 82443	: V=0.9899421, theta=-49.934132 -> V=1.0, theta=0.0
% INFO    : Bus 82444	: V=0.9883622, theta=-50.201007 -> V=1.0, theta=0.0
% INFO    : Bus 82445	: V=0.9838084, theta=-50.444663 -> V=1.0, theta=0.0
% INFO    : Bus 82446	: V=0.9913718, theta=-49.617053 -> V=1.0, theta=0.0
% INFO    : Bus 82447	: V=0.9792146, theta=-51.386354 -> V=1.0, theta=0.0
% INFO    : Bus 82448	: V=0.9776483, theta=-51.485173 -> V=1.0, theta=0.0
% INFO    : Bus 82449	: V=0.9744715, theta=-51.561558 -> V=1.0, theta=0.0
% INFO    : Bus 82450	: V=0.9826764, theta=-51.216195 -> V=1.0, theta=0.0
% INFO    : Bus 82451	: V=0.9930534, theta=-49.550792 -> V=1.0, theta=0.0
% INFO    : Bus 82452	: V=0.9838879, theta=-50.538219 -> V=1.0, theta=0.0
% INFO    : Bus 82453	: V=0.9979801, theta=-48.267931 -> V=1.0, theta=0.0
% INFO    : Bus 82454	: V=0.9884966, theta=-49.876678 -> V=1.0, theta=0.0
% INFO    : Bus 82455	: V=0.9888351, theta=-49.912529 -> V=1.0, theta=0.0
% INFO    : Bus 82456	: V=0.9848357, theta=-50.584745 -> V=1.0, theta=0.0
% INFO    : Bus 82457	: V=0.9972716, theta=-48.713837 -> V=1.0, theta=0.0
% INFO    : Bus 82458	: V=0.9925858, theta=-49.692488 -> V=1.0, theta=0.0
% INFO    : Bus 82459	: V=0.9919393, theta=-49.697328 -> V=1.0, theta=0.0
% INFO    : Bus 82460	: V=0.9767081, theta=-51.864199 -> V=1.0, theta=0.0
% INFO    : Bus 82461	: V=0.9751613, theta=-51.951154 -> V=1.0, theta=0.0
% INFO    : Bus 82462	: V=0.976202, theta=-51.953189 -> V=1.0, theta=0.0
% INFO    : Bus 82463	: V=0.9771205, theta=-51.861338 -> V=1.0, theta=0.0
% INFO    : Bus 82464	: V=0.9824395, theta=-51.190033 -> V=1.0, theta=0.0
% INFO    : Bus 82465	: V=0.9801661, theta=-51.800249 -> V=1.0, theta=0.0
% INFO    : Bus 82466	: V=0.9747311, theta=-52.189001 -> V=1.0, theta=0.0
% INFO    : Bus 82467	: V=0.9669038, theta=-52.644214 -> V=1.0, theta=0.0
% INFO    : Bus 82468	: V=0.982898, theta=-51.139305 -> V=1.0, theta=0.0
% INFO    : Bus 82469	: V=0.9783386, theta=-51.525659 -> V=1.0, theta=0.0
% INFO    : Bus 82470	: V=0.9755951, theta=-52.079607 -> V=1.0, theta=0.0
% INFO    : Bus 82471	: V=0.9755411, theta=-52.360752 -> V=1.0, theta=0.0
% INFO    : Bus 82472	: V=0.9731262, theta=-52.438164 -> V=1.0, theta=0.0
% INFO    : Bus 82473	: V=0.9820135, theta=-51.287345 -> V=1.0, theta=0.0
% INFO    : Bus 82474	: V=0.9786485, theta=-52.220885 -> V=1.0, theta=0.0
% INFO    : Bus 82475	: V=0.9841983, theta=-51.019205 -> V=1.0, theta=0.0
% INFO    : Bus 82476	: V=0.9854797, theta=-50.889838 -> V=1.0, theta=0.0
% INFO    : Bus 82477	: V=0.9795965, theta=-52.1782 -> V=1.0, theta=0.0
% INFO    : Bus 82478	: V=0.9781103, theta=-51.886771 -> V=1.0, theta=0.0
% INFO    : Bus 82479	: V=0.9808967, theta=-51.577743 -> V=1.0, theta=0.0
% INFO    : Bus 82480	: V=0.9816182, theta=-51.357142 -> V=1.0, theta=0.0
% INFO    : Bus 82481	: V=0.9798037, theta=-51.627291 -> V=1.0, theta=0.0
% INFO    : Bus 82482	: V=0.9864552, theta=-50.713771 -> V=1.0, theta=0.0
% INFO    : Bus 82483	: V=0.9755798, theta=-52.5388 -> V=1.0, theta=0.0
% INFO    : Bus 82484	: V=0.9882908, theta=-50.580451 -> V=1.0, theta=0.0
% INFO    : Bus 82485	: V=0.9855894, theta=-51.282878 -> V=1.0, theta=0.0
% INFO    : Bus 82486	: V=0.9889044, theta=-50.509414 -> V=1.0, theta=0.0
% INFO    : Bus 82487	: V=0.9918072, theta=-49.780599 -> V=1.0, theta=0.0
% INFO    : Bus 82488	: V=0.957907, theta=-53.899101 -> V=1.0, theta=0.0
% INFO    : Bus 82489	: V=0.9765332, theta=-51.738644 -> V=1.0, theta=0.0
% INFO    : Bus 82490	: V=0.9566312, theta=-53.938686 -> V=1.0, theta=0.0
% INFO    : Bus 82491	: V=0.9634941, theta=-53.477819 -> V=1.0, theta=0.0
% INFO    : Bus 82492	: V=0.9788966, theta=-51.586343 -> V=1.0, theta=0.0
% INFO    : Bus 82493	: V=0.9805485, theta=-51.33453 -> V=1.0, theta=0.0
% INFO    : Bus 82494	: V=0.9736151, theta=-52.646609 -> V=1.0, theta=0.0
% INFO    : Bus 82495	: V=0.9655149, theta=-53.059708 -> V=1.0, theta=0.0
% INFO    : Bus 82496	: V=0.983601, theta=-50.928178 -> V=1.0, theta=0.0
% INFO    : Bus 82497	: V=0.9817245, theta=-51.44391 -> V=1.0, theta=0.0
% INFO    : Bus 82498	: V=0.9879851, theta=-50.628032 -> V=1.0, theta=0.0
% INFO    : Bus 82499	: V=0.9777484, theta=-51.64147 -> V=1.0, theta=0.0
% INFO    : Bus 82500	: V=0.9736901, theta=-52.570593 -> V=1.0, theta=0.0
% INFO    : Bus 82501	: V=0.9753694, theta=-51.907419 -> V=1.0, theta=0.0
% INFO    : Bus 82502	: V=0.974873, theta=-51.883545 -> V=1.0, theta=0.0
% INFO    : Bus 82503	: V=0.9730748, theta=-52.042644 -> V=1.0, theta=0.0
% INFO    : Bus 82504	: V=0.9760567, theta=-51.790389 -> V=1.0, theta=0.0
% INFO    : Bus 82505	: V=0.981594, theta=-51.211292 -> V=1.0, theta=0.0
% INFO    : Bus 82506	: V=0.976569, theta=-51.858223 -> V=1.0, theta=0.0
% INFO    : Bus 82507	: V=0.9650684, theta=-52.750451 -> V=1.0, theta=0.0
% INFO    : Bus 82508	: V=0.9672815, theta=-53.168732 -> V=1.0, theta=0.0
% INFO    : Bus 82509	: V=0.9928439, theta=-49.573591 -> V=1.0, theta=0.0
% INFO    : Bus 82510	: V=0.9836684, theta=-51.094535 -> V=1.0, theta=0.0
% INFO    : Bus 82511	: V=0.982918, theta=-51.251904 -> V=1.0, theta=0.0
% INFO    : Bus 82512	: V=0.9658914, theta=-56.645684 -> V=1.0, theta=0.0
% INFO    : Bus 82513	: V=0.9673115, theta=-56.788612 -> V=1.0, theta=0.0
% INFO    : Bus 82514	: V=0.9440569, theta=-60.624221 -> V=1.0, theta=0.0
% INFO    : Bus 82515	: V=0.98473, theta=-55.918325 -> V=1.0, theta=0.0
% INFO    : Bus 82516	: V=0.9816685, theta=-56.373432 -> V=1.0, theta=0.0
% INFO    : Bus 82517	: V=0.9945267, theta=-54.46456 -> V=1.0, theta=0.0
% INFO    : Bus 82518	: V=0.990059, theta=-55.219508 -> V=1.0, theta=0.0
% INFO    : Bus 82519	: V=0.9741619, theta=-57.063926 -> V=1.0, theta=0.0
% INFO    : Bus 82520	: V=0.9733084, theta=-57.295688 -> V=1.0, theta=0.0
% INFO    : Bus 82521	: V=0.983379, theta=-54.615111 -> V=1.0, theta=0.0
% INFO    : Bus 82522	: V=0.9852546, theta=-54.148535 -> V=1.0, theta=0.0
% INFO    : Bus 82523	: V=0.9839103, theta=-54.694884 -> V=1.0, theta=0.0
% INFO    : Bus 82524	: V=0.9860065, theta=-53.96978 -> V=1.0, theta=0.0
% INFO    : Bus 82525	: V=0.9851385, theta=-54.572663 -> V=1.0, theta=0.0
% INFO    : Bus 82526	: V=0.9872025, theta=-54.380858 -> V=1.0, theta=0.0
% INFO    : Bus 82527	: V=0.9828329, theta=-54.014274 -> V=1.0, theta=0.0
% INFO    : Bus 82528	: V=0.9653231, theta=-49.221352 -> V=1.0, theta=0.0
% INFO    : Bus 82529	: V=0.9673811, theta=-48.898089 -> V=1.0, theta=0.0
% INFO    : Bus 82530	: V=0.97273, theta=-48.664986 -> V=1.0, theta=0.0
% INFO    : Bus 82531	: V=0.9706908, theta=-49.284932 -> V=1.0, theta=0.0
% INFO    : Bus 82532	: V=0.97114, theta=-49.056942 -> V=1.0, theta=0.0
% INFO    : Bus 82533	: V=0.9683743, theta=-49.217816 -> V=1.0, theta=0.0
% INFO    : Bus 82534	: V=0.9705865, theta=-48.921505 -> V=1.0, theta=0.0
% INFO    : Bus 82535	: V=0.9680496, theta=-48.915401 -> V=1.0, theta=0.0
% INFO    : Bus 82536	: V=0.9768911, theta=-48.016602 -> V=1.0, theta=0.0
% INFO    : Bus 82537	: V=0.9962852, theta=-46.957163 -> V=1.0, theta=0.0
% INFO    : Bus 82538	: V=0.9955233, theta=-47.249809 -> V=1.0, theta=0.0
% INFO    : Bus 82539	: V=0.9867465, theta=-48.178436 -> V=1.0, theta=0.0
% INFO    : Bus 82540	: V=0.9783328, theta=-48.724382 -> V=1.0, theta=0.0
% INFO    : Bus 82541	: V=0.9820284, theta=-47.887902 -> V=1.0, theta=0.0
% INFO    : Bus 82542	: V=0.9715823, theta=-50.625526 -> V=1.0, theta=0.0
% INFO    : Bus 82543	: V=0.9859071, theta=-48.466173 -> V=1.0, theta=0.0
% INFO    : Bus 82544	: V=0.9809472, theta=-49.840085 -> V=1.0, theta=0.0
% INFO    : Bus 82545	: V=0.9883303, theta=-47.570804 -> V=1.0, theta=0.0
% INFO    : Bus 82546	: V=0.9807031, theta=-49.232719 -> V=1.0, theta=0.0
% INFO    : Bus 82547	: V=0.9921495, theta=-50.653627 -> V=1.0, theta=0.0
% INFO    : Bus 82548	: V=0.9779157, theta=-51.386822 -> V=1.0, theta=0.0
% INFO    : Bus 82549	: V=0.9836105, theta=-50.571303 -> V=1.0, theta=0.0
% INFO    : Bus 82550	: V=0.9966136, theta=-49.141653 -> V=1.0, theta=0.0
% INFO    : Bus 82551	: V=0.9965091, theta=-54.312733 -> V=1.0, theta=0.0
% INFO    : Bus 82552	: V=1.0149176, theta=-49.492048 -> V=1.0, theta=0.0
% INFO    : Bus 82553	: V=1.0107891, theta=-50.205439 -> V=1.0, theta=0.0
% INFO    : Bus 82554	: V=0.9413133, theta=-61.626102 -> V=1.0, theta=0.0
% INFO    : Bus 82555	: V=0.9501495, theta=-60.177164 -> V=1.0, theta=0.0
% INFO    : Bus 82556	: V=0.9448421, theta=-61.351657 -> V=1.0, theta=0.0
% INFO    : Bus 82557	: V=0.9567218, theta=-58.045945 -> V=1.0, theta=0.0
% INFO    : Bus 82558	: V=0.956356, theta=-58.515379 -> V=1.0, theta=0.0
% INFO    : Bus 82559	: V=0.9562634, theta=-57.906398 -> V=1.0, theta=0.0
% INFO    : Bus 82560	: V=0.9865364, theta=-45.886279 -> V=1.0, theta=0.0
% INFO    : Bus 82561	: V=0.9881391, theta=-45.678471 -> V=1.0, theta=0.0
% INFO    : Bus 82562	: V=0.9836071, theta=-46.250326 -> V=1.0, theta=0.0
% INFO    : Bus 82563	: V=0.9930011, theta=-47.664021 -> V=1.0, theta=0.0
% INFO    : Bus 82564	: V=0.9918004, theta=-46.459101 -> V=1.0, theta=0.0
% INFO    : Bus 82565	: V=1.0023526, theta=-45.793697 -> V=1.0, theta=0.0
% INFO    : Bus 82566	: V=1.0013992, theta=-45.740532 -> V=1.0, theta=0.0
% INFO    : Bus 82567	: V=0.9971335, theta=-45.509741 -> V=1.0, theta=0.0
% INFO    : Bus 82568	: V=1.0115864, theta=-42.448242 -> V=1.0, theta=0.0
% INFO    : Bus 82569	: V=1.0059521, theta=-43.420439 -> V=1.0, theta=0.0
% INFO    : Bus 82570	: V=0.9969188, theta=-43.91886 -> V=1.0, theta=0.0
% INFO    : Bus 82571	: V=0.9986329, theta=-42.731645 -> V=1.0, theta=0.0
% INFO    : Bus 82572	: V=0.9970464, theta=-42.46959 -> V=1.0, theta=0.0
% INFO    : Bus 82573	: V=1.0104717, theta=-54.610297 -> V=1.0, theta=0.0
% INFO    : Bus 82574	: V=1.0118888, theta=-54.818953 -> V=1.0, theta=0.0
% INFO    : Bus 82575	: V=1.0111543, theta=-55.007234 -> V=1.0, theta=0.0
% INFO    : Bus 82576	: V=0.988588, theta=-58.073675 -> V=1.0, theta=0.0
% INFO    : Bus 82577	: V=0.9822418, theta=-57.905404 -> V=1.0, theta=0.0
% INFO    : Bus 82578	: V=0.9887528, theta=-57.828575 -> V=1.0, theta=0.0
% INFO    : Bus 82579	: V=0.9785053, theta=-57.621816 -> V=1.0, theta=0.0
% INFO    : Bus 82580	: V=0.9988466, theta=-55.75274 -> V=1.0, theta=0.0
% INFO    : Bus 82581	: V=1.0101262, theta=-53.713435 -> V=1.0, theta=0.0
% INFO    : Bus 82582	: V=0.9888662, theta=-43.446142 -> V=1.0, theta=0.0
% INFO    : Bus 82583	: V=0.9901293, theta=-43.870039 -> V=1.0, theta=0.0
% INFO    : Bus 82584	: V=0.9732951, theta=-45.373358 -> V=1.0, theta=0.0
% INFO    : Bus 82585	: V=1.0002806, theta=-53.221026 -> V=1.0, theta=0.0
% INFO    : Bus 82586	: V=0.9977082, theta=-53.673343 -> V=1.0, theta=0.0
% INFO    : Bus 82587	: V=1.0028858, theta=-53.025721 -> V=1.0, theta=0.0
% INFO    : Bus 82588	: V=1.002008, theta=-53.247784 -> V=1.0, theta=0.0
% INFO    : Bus 82589	: V=0.9583995, theta=-50.079702 -> V=1.0, theta=0.0
% INFO    : Bus 82590	: V=0.9688277, theta=-50.225832 -> V=1.0, theta=0.0
% INFO    : Bus 82591	: V=0.9682782, theta=-50.063572 -> V=1.0, theta=0.0
% INFO    : Bus 82592	: V=0.9553297, theta=-58.688138 -> V=1.0, theta=0.0
% INFO    : Bus 82593	: V=0.9620928, theta=-57.08923 -> V=1.0, theta=0.0
% INFO    : Bus 82594	: V=0.9562826, theta=-57.974367 -> V=1.0, theta=0.0
% INFO    : Bus 82595	: V=0.9571293, theta=-57.961534 -> V=1.0, theta=0.0
% INFO    : Bus 82596	: V=0.9772891, theta=-55.275784 -> V=1.0, theta=0.0
% INFO    : Bus 82597	: V=0.9526317, theta=-57.890601 -> V=1.0, theta=0.0
% INFO    : Bus 82598	: V=0.9614667, theta=-49.020784 -> V=1.0, theta=0.0
% INFO    : Bus 82599	: V=0.941966, theta=-51.626828 -> V=1.0, theta=0.0
% INFO    : Bus 82600	: V=0.9637733, theta=-49.673701 -> V=1.0, theta=0.0
% INFO    : Bus 82601	: V=0.9612691, theta=-53.749968 -> V=1.0, theta=0.0
% INFO    : Bus 82602	: V=0.9611072, theta=-57.008319 -> V=1.0, theta=0.0
% INFO    : Bus 82603	: V=0.9593647, theta=-57.155802 -> V=1.0, theta=0.0
% INFO    : Bus 82604	: V=0.9620008, theta=-56.986842 -> V=1.0, theta=0.0
% INFO    : Bus 82605	: V=0.9563514, theta=-57.542925 -> V=1.0, theta=0.0
% INFO    : Bus 82606	: V=0.9612034, theta=-57.08708 -> V=1.0, theta=0.0
% INFO    : Bus 82607	: V=0.9677175, theta=-56.569455 -> V=1.0, theta=0.0
% INFO    : Bus 82608	: V=0.9686217, theta=-56.458059 -> V=1.0, theta=0.0
% INFO    : Bus 82609	: V=0.968336, theta=-56.503758 -> V=1.0, theta=0.0
% INFO    : Bus 82610	: V=0.9684954, theta=-56.151589 -> V=1.0, theta=0.0
% INFO    : Bus 82611	: V=0.96631, theta=-56.634508 -> V=1.0, theta=0.0
% INFO    : Bus 82612	: V=0.9580768, theta=-57.560891 -> V=1.0, theta=0.0
% INFO    : Bus 82613	: V=0.9640513, theta=-56.894873 -> V=1.0, theta=0.0
% INFO    : Bus 82614	: V=0.958229, theta=-57.603624 -> V=1.0, theta=0.0
% INFO    : Bus 82615	: V=0.9676418, theta=-55.509997 -> V=1.0, theta=0.0
% INFO    : Bus 82616	: V=0.9520492, theta=-58.076804 -> V=1.0, theta=0.0
% INFO    : Bus 82617	: V=0.985205, theta=-54.598945 -> V=1.0, theta=0.0
% INFO    : Bus 82618	: V=0.9793743, theta=-55.047598 -> V=1.0, theta=0.0
% INFO    : Bus 82619	: V=0.9614935, theta=-56.58155 -> V=1.0, theta=0.0
% INFO    : Bus 82620	: V=0.9565311, theta=-57.08454 -> V=1.0, theta=0.0
% INFO    : Bus 82621	: V=0.9569937, theta=-57.010106 -> V=1.0, theta=0.0
% INFO    : Bus 82622	: V=0.9550596, theta=-57.284102 -> V=1.0, theta=0.0
% INFO    : Bus 82623	: V=0.9665371, theta=-55.594909 -> V=1.0, theta=0.0
% INFO    : Bus 82624	: V=0.965894, theta=-56.608756 -> V=1.0, theta=0.0
% INFO    : Bus 82625	: V=0.9675352, theta=-56.637037 -> V=1.0, theta=0.0
% INFO    : Bus 82626	: V=0.9625192, theta=-57.455984 -> V=1.0, theta=0.0
% INFO    : Bus 82627	: V=0.9611604, theta=-57.261088 -> V=1.0, theta=0.0
% INFO    : Bus 82628	: V=0.9924284, theta=-55.12194 -> V=1.0, theta=0.0
% INFO    : Bus 82629	: V=0.9946285, theta=-54.798494 -> V=1.0, theta=0.0
% INFO    : Bus 82630	: V=0.9902842, theta=-55.779773 -> V=1.0, theta=0.0
% INFO    : Bus 82631	: V=0.9730308, theta=-56.560139 -> V=1.0, theta=0.0
% INFO    : Bus 82632	: V=0.9713303, theta=-48.302311 -> V=1.0, theta=0.0
% INFO    : Bus 82633	: V=0.9821514, theta=-46.992928 -> V=1.0, theta=0.0
% INFO    : Bus 82634	: V=0.9629596, theta=-54.358034 -> V=1.0, theta=0.0
% INFO    : Bus 82635	: V=0.974535, theta=-52.204847 -> V=1.0, theta=0.0
% INFO    : Bus 82636	: V=0.9681641, theta=-52.957692 -> V=1.0, theta=0.0
% INFO    : Bus 82637	: V=0.9751853, theta=-51.908279 -> V=1.0, theta=0.0
% INFO    : Bus 82638	: V=0.9714884, theta=-52.615006 -> V=1.0, theta=0.0
% INFO    : Bus 82639	: V=0.9754752, theta=-51.902724 -> V=1.0, theta=0.0
% INFO    : Bus 82640	: V=0.9710891, theta=-52.651482 -> V=1.0, theta=0.0
% INFO    : Bus 82641	: V=0.9703757, theta=-52.55237 -> V=1.0, theta=0.0
% INFO    : Bus 82642	: V=0.9797543, theta=-49.945827 -> V=1.0, theta=0.0
% INFO    : Bus 82643	: V=1.0053667, theta=-42.208784 -> V=1.0, theta=0.0
% INFO    : Bus 82644	: V=0.9992101, theta=-53.851252 -> V=1.0, theta=0.0
% INFO    : Bus 82645	: V=1.0007123, theta=-54.096872 -> V=1.0, theta=0.0
% INFO    : Bus 82646	: V=0.9395052, theta=-61.80858 -> V=1.0, theta=0.0
% INFO    : Bus 82647	: V=0.9427199, theta=-60.558868 -> V=1.0, theta=0.0
% INFO    : Bus 82648	: V=0.9393411, theta=-61.646654 -> V=1.0, theta=0.0
% INFO    : Bus 82649	: V=1.0090928, theta=-42.635648 -> V=1.0, theta=0.0
% INFO    : Bus 82650	: V=1.0099642, theta=-42.826204 -> V=1.0, theta=0.0
% INFO    : Bus 82651	: V=1.0101302, theta=-43.184605 -> V=1.0, theta=0.0
% INFO    : Bus 82652	: V=0.9873497, theta=-51.213119 -> V=1.0, theta=0.0
% INFO    : Bus 82653	: V=0.9829441, theta=-51.4846 -> V=1.0, theta=0.0
% INFO    : Bus 82654	: V=0.9887254, theta=-50.971803 -> V=1.0, theta=0.0
% INFO    : Bus 82655	: V=0.989105, theta=-50.639034 -> V=1.0, theta=0.0
% INFO    : Bus 82656	: V=0.9857808, theta=-51.267516 -> V=1.0, theta=0.0
% INFO    : Bus 82657	: V=0.9907167, theta=-50.61232 -> V=1.0, theta=0.0
% INFO    : Bus 82658	: V=0.9876694, theta=-51.323059 -> V=1.0, theta=0.0
% INFO    : Bus 82659	: V=0.9897295, theta=-51.103515 -> V=1.0, theta=0.0
% INFO    : Bus 82660	: V=0.9971784, theta=-50.063413 -> V=1.0, theta=0.0
% INFO    : Bus 82661	: V=0.9976074, theta=-50.353977 -> V=1.0, theta=0.0
% INFO    : Bus 82662	: V=0.9929786, theta=-49.662951 -> V=1.0, theta=0.0
% INFO    : Bus 82663	: V=0.9964187, theta=-50.051817 -> V=1.0, theta=0.0
% INFO    : Bus 82664	: V=0.990847, theta=-50.925216 -> V=1.0, theta=0.0
% INFO    : Bus 82665	: V=0.9875812, theta=-51.189416 -> V=1.0, theta=0.0
% INFO    : Bus 82666	: V=0.9830027, theta=-53.670225 -> V=1.0, theta=0.0
% INFO    : Bus 82667	: V=0.9783448, theta=-54.648592 -> V=1.0, theta=0.0
% INFO    : Bus 82668	: V=0.9895781, theta=-43.487399 -> V=1.0, theta=0.0
% INFO    : Bus 82669	: V=0.9895419, theta=-43.397193 -> V=1.0, theta=0.0
% INFO    : Bus 82670	: V=0.9897645, theta=-43.348254 -> V=1.0, theta=0.0
% INFO    : Bus 82671	: V=1.0054621, theta=-41.880897 -> V=1.0, theta=0.0
% INFO    : Bus 82672	: V=0.9957488, theta=-43.456341 -> V=1.0, theta=0.0
% INFO    : Bus 82673	: V=0.990162, theta=-43.714346 -> V=1.0, theta=0.0
% INFO    : Bus 82674	: V=0.9902361, theta=-43.787914 -> V=1.0, theta=0.0
% INFO    : Bus 82675	: V=0.9936548, theta=-43.593679 -> V=1.0, theta=0.0
% INFO    : Bus 82676	: V=0.9873468, theta=-43.386407 -> V=1.0, theta=0.0
% INFO    : Bus 82677	: V=1.003294, theta=-42.02875 -> V=1.0, theta=0.0
% INFO    : Bus 82678	: V=0.9972575, theta=-42.885856 -> V=1.0, theta=0.0
% INFO    : Bus 82679	: V=0.9902562, theta=-43.698807 -> V=1.0, theta=0.0
% INFO    : Bus 82680	: V=0.9898407, theta=-43.366224 -> V=1.0, theta=0.0
% INFO    : Bus 82681	: V=0.9869299, theta=-43.852341 -> V=1.0, theta=0.0
% INFO    : Bus 82682	: V=1.0105451, theta=-41.469684 -> V=1.0, theta=0.0
% INFO    : Bus 82683	: V=1.0029958, theta=-42.830787 -> V=1.0, theta=0.0
% INFO    : Bus 82684	: V=0.9793831, theta=-44.432519 -> V=1.0, theta=0.0
% INFO    : Bus 82685	: V=1.0088318, theta=-43.957111 -> V=1.0, theta=0.0
% INFO    : Bus 82686	: V=1.0051715, theta=-44.769344 -> V=1.0, theta=0.0
% INFO    : Bus 82687	: V=1.0092167, theta=-44.491882 -> V=1.0, theta=0.0
% INFO    : Bus 82688	: V=1.0035167, theta=-44.735524 -> V=1.0, theta=0.0
% INFO    : Bus 82689	: V=1.0053298, theta=-44.515986 -> V=1.0, theta=0.0
% INFO    : Bus 82690	: V=1.0047316, theta=-44.626264 -> V=1.0, theta=0.0
% INFO    : Bus 82691	: V=1.0106596, theta=-43.757187 -> V=1.0, theta=0.0
% INFO    : Bus 82692	: V=1.0080378, theta=-44.305008 -> V=1.0, theta=0.0
% INFO    : Bus 82693	: V=1.0062917, theta=-44.42557 -> V=1.0, theta=0.0
% INFO    : Bus 82694	: V=1.0138646, theta=-43.262234 -> V=1.0, theta=0.0
% INFO    : Bus 82695	: V=1.0038596, theta=-44.611561 -> V=1.0, theta=0.0
% INFO    : Bus 82696	: V=1.0138542, theta=-43.244304 -> V=1.0, theta=0.0
% INFO    : Bus 82697	: V=0.9694283, theta=-56.777369 -> V=1.0, theta=0.0
% INFO    : Bus 82698	: V=0.9758233, theta=-55.820351 -> V=1.0, theta=0.0
% INFO    : Bus 82699	: V=0.979464, theta=-55.36145 -> V=1.0, theta=0.0
% INFO    : Bus 82700	: V=0.9719676, theta=-56.521776 -> V=1.0, theta=0.0
% INFO    : Bus 82701	: V=0.9778027, theta=-55.599582 -> V=1.0, theta=0.0
% INFO    : Bus 82702	: V=0.9851251, theta=-54.861613 -> V=1.0, theta=0.0
% INFO    : Bus 82703	: V=0.9792806, theta=-54.954095 -> V=1.0, theta=0.0
% INFO    : Bus 82704	: V=0.9926189, theta=-42.949619 -> V=1.0, theta=0.0
% INFO    : Bus 82705	: V=0.9950237, theta=-42.70884 -> V=1.0, theta=0.0
% INFO    : Bus 82706	: V=0.9816856, theta=-47.630752 -> V=1.0, theta=0.0
% INFO    : Bus 82707	: V=0.9752499, theta=-54.068833 -> V=1.0, theta=0.0
% INFO    : Bus 82708	: V=0.9870415, theta=-52.802792 -> V=1.0, theta=0.0
% INFO    : Bus 82709	: V=0.9753037, theta=-53.972304 -> V=1.0, theta=0.0
% INFO    : Bus 82710	: V=0.9762622, theta=-53.932244 -> V=1.0, theta=0.0
% INFO    : Bus 82711	: V=0.9752583, theta=-54.198768 -> V=1.0, theta=0.0
% INFO    : Bus 82712	: V=0.9863479, theta=-52.139477 -> V=1.0, theta=0.0
% INFO    : Bus 82713	: V=0.9881253, theta=-52.370868 -> V=1.0, theta=0.0
% INFO    : Bus 82714	: V=0.985919, theta=-52.757215 -> V=1.0, theta=0.0
% INFO    : Bus 82715	: V=0.9736807, theta=-58.316221 -> V=1.0, theta=0.0
% INFO    : Bus 82716	: V=0.9974891, theta=-53.015067 -> V=1.0, theta=0.0
% INFO    : Bus 82717	: V=1.0052497, theta=-51.928778 -> V=1.0, theta=0.0
% INFO    : Bus 82718	: V=1.00165, theta=-52.370733 -> V=1.0, theta=0.0
% INFO    : Bus 82719	: V=0.9986924, theta=-52.802449 -> V=1.0, theta=0.0
% INFO    : Bus 82720	: V=0.9451344, theta=-61.292098 -> V=1.0, theta=0.0
% INFO    : Bus 82721	: V=0.9458388, theta=-61.61465 -> V=1.0, theta=0.0
% INFO    : Bus 82722	: V=0.9429995, theta=-62.241335 -> V=1.0, theta=0.0
% INFO    : Bus 82723	: V=0.9391415, theta=-62.949694 -> V=1.0, theta=0.0
% INFO    : Bus 82724	: V=1.0310574, theta=-31.74716 -> V=1.0, theta=0.0
% INFO    : Bus 82725	: V=1.0225294, theta=-32.311386 -> V=1.0, theta=0.0
% INFO    : Bus 82726	: V=1.0018862, theta=-43.365109 -> V=1.0, theta=0.0
% INFO    : Bus 82727	: V=1.0047767, theta=-44.410552 -> V=1.0, theta=0.0
% INFO    : Bus 82728	: V=0.9749891, theta=-46.955361 -> V=1.0, theta=0.0
% INFO    : Bus 82729	: V=1.0023211, theta=-45.375401 -> V=1.0, theta=0.0
% INFO    : Bus 82730	: V=0.9974472, theta=-45.256001 -> V=1.0, theta=0.0
% INFO    : Bus 82731	: V=0.9984573, theta=-45.0171 -> V=1.0, theta=0.0
% INFO    : Bus 82732	: V=0.9936139, theta=-47.586945 -> V=1.0, theta=0.0
% INFO    : Bus 82733	: V=0.9825875, theta=-47.834789 -> V=1.0, theta=0.0
% INFO    : Bus 82734	: V=0.9868317, theta=-48.29677 -> V=1.0, theta=0.0
% INFO    : Bus 82735	: V=0.9807967, theta=-48.782415 -> V=1.0, theta=0.0
% INFO    : Bus 82736	: V=0.9750354, theta=-49.790668 -> V=1.0, theta=0.0
% INFO    : Bus 82737	: V=0.972455, theta=-49.910395 -> V=1.0, theta=0.0
% INFO    : Bus 82738	: V=0.9733723, theta=-49.779697 -> V=1.0, theta=0.0
% INFO    : Bus 82739	: V=0.9689345, theta=-50.045029 -> V=1.0, theta=0.0
% INFO    : Bus 82740	: V=1.0069914, theta=-43.286567 -> V=1.0, theta=0.0
% INFO    : Bus 82741	: V=1.007069, theta=-43.367988 -> V=1.0, theta=0.0
% INFO    : Bus 82742	: V=1.0068024, theta=-31.78887 -> V=1.0, theta=0.0
% INFO    : Bus 82743	: V=0.9839338, theta=-33.445355 -> V=1.0, theta=0.0
% INFO    : Bus 82744	: V=0.9972002, theta=-33.380746 -> V=1.0, theta=0.0
% INFO    : Bus 82745	: V=0.9658651, theta=-47.849999 -> V=1.0, theta=0.0
% INFO    : Bus 82746	: V=1.0044546, theta=-32.704976 -> V=1.0, theta=0.0
% INFO    : Bus 82747	: V=1.0035014, theta=-32.76135 -> V=1.0, theta=0.0
% INFO    : Bus 82748	: V=1.0030769, theta=-32.741012 -> V=1.0, theta=0.0
% INFO    : Bus 82749	: V=1.0109145, theta=-31.231032 -> V=1.0, theta=0.0
% INFO    : Bus 82750	: V=0.9986366, theta=-33.179868 -> V=1.0, theta=0.0
% INFO    : Bus 82751	: V=1.0006349, theta=-32.843874 -> V=1.0, theta=0.0
% INFO    : Bus 82752	: V=1.0081843, theta=-31.804302 -> V=1.0, theta=0.0
% INFO    : Bus 82753	: V=1.0035397, theta=-32.501296 -> V=1.0, theta=0.0
% INFO    : Bus 82754	: V=0.9945715, theta=-33.489547 -> V=1.0, theta=0.0
% INFO    : Bus 82755	: V=0.9887965, theta=-33.181917 -> V=1.0, theta=0.0
% INFO    : Bus 82756	: V=1.0005373, theta=-33.001361 -> V=1.0, theta=0.0
% INFO    : Bus 82757	: V=0.9691885, theta=-32.402169 -> V=1.0, theta=0.0
% INFO    : Bus 82758	: V=0.976893, theta=-31.791445 -> V=1.0, theta=0.0
% INFO    : Bus 82759	: V=0.9982225, theta=-50.947966 -> V=1.0, theta=0.0
% INFO    : Bus 82760	: V=0.9916184, theta=-51.537582 -> V=1.0, theta=0.0
% INFO    : Bus 82761	: V=1.0022781, theta=-50.519747 -> V=1.0, theta=0.0
% INFO    : Bus 82762	: V=0.994223, theta=-51.603157 -> V=1.0, theta=0.0
% INFO    : Bus 82763	: V=0.9930346, theta=-51.591621 -> V=1.0, theta=0.0
% INFO    : Bus 82764	: V=1.0026989, theta=-50.541367 -> V=1.0, theta=0.0
% INFO    : Bus 82765	: V=0.9980312, theta=-51.721995 -> V=1.0, theta=0.0
% INFO    : Bus 82766	: V=0.9876532, theta=-52.038896 -> V=1.0, theta=0.0
% INFO    : Bus 82767	: V=0.985138, theta=-51.841537 -> V=1.0, theta=0.0
% INFO    : Bus 82768	: V=0.9969448, theta=-50.213332 -> V=1.0, theta=0.0
% INFO    : Bus 82769	: V=0.9954057, theta=-50.577605 -> V=1.0, theta=0.0
% INFO    : Bus 82770	: V=1.0046981, theta=-51.406617 -> V=1.0, theta=0.0
% INFO    : Bus 82771	: V=1.0029734, theta=-51.885584 -> V=1.0, theta=0.0
% INFO    : Bus 82772	: V=1.0084313, theta=-53.903632 -> V=1.0, theta=0.0
% INFO    : Bus 82773	: V=1.0068727, theta=-54.278817 -> V=1.0, theta=0.0
% INFO    : Bus 82774	: V=1.0061804, theta=-53.30421 -> V=1.0, theta=0.0
% INFO    : Bus 82775	: V=1.0032415, theta=-53.560621 -> V=1.0, theta=0.0
% INFO    : Bus 82776	: V=0.9740446, theta=-54.532605 -> V=1.0, theta=0.0
% INFO    : Bus 82777	: V=0.9792571, theta=-53.531018 -> V=1.0, theta=0.0
% INFO    : Bus 82778	: V=0.9829101, theta=-53.366417 -> V=1.0, theta=0.0
% INFO    : Bus 82779	: V=0.9730423, theta=-54.375136 -> V=1.0, theta=0.0
% INFO    : Bus 82780	: V=0.9646977, theta=-55.655409 -> V=1.0, theta=0.0
% INFO    : Bus 82781	: V=0.9593679, theta=-56.468226 -> V=1.0, theta=0.0
% INFO    : Bus 82782	: V=0.9941423, theta=-52.672293 -> V=1.0, theta=0.0
% INFO    : Bus 82783	: V=0.9603049, theta=-56.031749 -> V=1.0, theta=0.0
% INFO    : Bus 82784	: V=0.9628922, theta=-55.678355 -> V=1.0, theta=0.0
% INFO    : Bus 82785	: V=0.9669349, theta=-54.761928 -> V=1.0, theta=0.0
% INFO    : Bus 82786	: V=0.9638957, theta=-55.732835 -> V=1.0, theta=0.0
% INFO    : Bus 82787	: V=0.9612171, theta=-53.112214 -> V=1.0, theta=0.0
% INFO    : Bus 82788	: V=0.9624307, theta=-52.96996 -> V=1.0, theta=0.0
% INFO    : Bus 82789	: V=0.9629303, theta=-52.988066 -> V=1.0, theta=0.0
% INFO    : Bus 82790	: V=0.9629499, theta=-53.216161 -> V=1.0, theta=0.0
% INFO    : Bus 82791	: V=0.9720287, theta=-52.286193 -> V=1.0, theta=0.0
% INFO    : Bus 82792	: V=0.9579927, theta=-52.259084 -> V=1.0, theta=0.0
% INFO    : Bus 82793	: V=0.9633429, theta=-52.78979 -> V=1.0, theta=0.0
% INFO    : Bus 82794	: V=0.9615595, theta=-53.168525 -> V=1.0, theta=0.0
% INFO    : Bus 82795	: V=0.9831797, theta=-52.481791 -> V=1.0, theta=0.0
% INFO    : Bus 82796	: V=0.992047, theta=-31.552907 -> V=1.0, theta=0.0
% INFO    : Bus 82797	: V=0.962028, theta=-33.339506 -> V=1.0, theta=0.0
% INFO    : Bus 82798	: V=0.9879187, theta=-32.027611 -> V=1.0, theta=0.0
% INFO    : Bus 82799	: V=0.987591, theta=-33.721484 -> V=1.0, theta=0.0
% INFO    : Bus 82800	: V=0.9755974, theta=-34.466876 -> V=1.0, theta=0.0
% INFO    : Bus 82801	: V=0.9878696, theta=-40.89634 -> V=1.0, theta=0.0
% INFO    : Bus 82802	: V=0.9883168, theta=-40.988008 -> V=1.0, theta=0.0
% INFO    : Bus 82803	: V=0.979856, theta=-41.735705 -> V=1.0, theta=0.0
% INFO    : Bus 82804	: V=1.0008526, theta=-37.719665 -> V=1.0, theta=0.0
% INFO    : Bus 82805	: V=1.0030009, theta=-37.97003 -> V=1.0, theta=0.0
% INFO    : Bus 82806	: V=0.9998148, theta=-38.588025 -> V=1.0, theta=0.0
% INFO    : Bus 82807	: V=0.9820999, theta=-40.601347 -> V=1.0, theta=0.0
% INFO    : Bus 82808	: V=0.9836624, theta=-41.133788 -> V=1.0, theta=0.0
% INFO    : Bus 82809	: V=0.9877084, theta=-33.229475 -> V=1.0, theta=0.0
% INFO    : Bus 82810	: V=1.0274141, theta=-31.532505 -> V=1.0, theta=0.0
% INFO    : Bus 82811	: V=1.0186441, theta=-30.260407 -> V=1.0, theta=0.0
% INFO    : Bus 82812	: V=1.0150893, theta=-31.151712 -> V=1.0, theta=0.0
% INFO    : Bus 82813	: V=1.0019538, theta=-34.231538 -> V=1.0, theta=0.0
% INFO    : Bus 82814	: V=0.9820151, theta=-41.96039 -> V=1.0, theta=0.0
% INFO    : Bus 82815	: V=0.9669291, theta=-43.683272 -> V=1.0, theta=0.0
% INFO    : Bus 82816	: V=0.9666451, theta=-45.754153 -> V=1.0, theta=0.0
% INFO    : Bus 82817	: V=0.9649681, theta=-46.14186 -> V=1.0, theta=0.0
% INFO    : Bus 82818	: V=0.9780986, theta=-43.816942 -> V=1.0, theta=0.0
% INFO    : Bus 82819	: V=0.970717, theta=-32.617042 -> V=1.0, theta=0.0
% INFO    : Bus 82820	: V=0.9889808, theta=-37.71524 -> V=1.0, theta=0.0
% INFO    : Bus 82821	: V=0.9893047, theta=-37.754995 -> V=1.0, theta=0.0
% INFO    : Bus 82822	: V=0.9852845, theta=-38.033098 -> V=1.0, theta=0.0
% INFO    : Bus 82823	: V=0.9866095, theta=-37.95241 -> V=1.0, theta=0.0
% INFO    : Bus 82824	: V=0.9824398, theta=-38.246577 -> V=1.0, theta=0.0
% INFO    : Bus 82825	: V=0.9822548, theta=-38.258151 -> V=1.0, theta=0.0
% INFO    : Bus 82826	: V=0.9820131, theta=-38.325109 -> V=1.0, theta=0.0
% INFO    : Bus 82827	: V=0.9951067, theta=-37.633144 -> V=1.0, theta=0.0
% INFO    : Bus 82828	: V=0.9849134, theta=-38.181446 -> V=1.0, theta=0.0
% INFO    : Bus 82829	: V=0.9903796, theta=-37.999158 -> V=1.0, theta=0.0
% INFO    : Bus 82830	: V=0.9861017, theta=-38.438597 -> V=1.0, theta=0.0
% INFO    : Bus 82831	: V=0.982752, theta=-38.332098 -> V=1.0, theta=0.0
% INFO    : Bus 82832	: V=0.9800464, theta=-38.832603 -> V=1.0, theta=0.0
% INFO    : Bus 82833	: V=0.9798997, theta=-38.787041 -> V=1.0, theta=0.0
% INFO    : Bus 82834	: V=0.9811936, theta=-38.462331 -> V=1.0, theta=0.0
% INFO    : Bus 82835	: V=0.9943274, theta=-36.468832 -> V=1.0, theta=0.0
% INFO    : Bus 82836	: V=0.995603, theta=-36.252486 -> V=1.0, theta=0.0
% INFO    : Bus 82837	: V=0.9964124, theta=-36.572389 -> V=1.0, theta=0.0
% INFO    : Bus 82838	: V=0.9893999, theta=-37.676355 -> V=1.0, theta=0.0
% INFO    : Bus 82839	: V=0.9913212, theta=-37.235872 -> V=1.0, theta=0.0
% INFO    : Bus 82840	: V=0.9835701, theta=-38.01317 -> V=1.0, theta=0.0
% INFO    : Bus 82841	: V=0.988334, theta=-37.188545 -> V=1.0, theta=0.0
% INFO    : Bus 82842	: V=0.9844849, theta=-38.033246 -> V=1.0, theta=0.0
% INFO    : Bus 82843	: V=0.9788353, theta=-38.664377 -> V=1.0, theta=0.0
% INFO    : Bus 82844	: V=0.9727826, theta=-39.209648 -> V=1.0, theta=0.0
% INFO    : Bus 82845	: V=0.9762293, theta=-40.135814 -> V=1.0, theta=0.0
% INFO    : Bus 82846	: V=0.9742936, theta=-40.223715 -> V=1.0, theta=0.0
% INFO    : Bus 82847	: V=0.9771916, theta=-39.797571 -> V=1.0, theta=0.0
% INFO    : Bus 82848	: V=0.9770494, theta=-39.331382 -> V=1.0, theta=0.0
% INFO    : Bus 82849	: V=0.9780345, theta=-38.961302 -> V=1.0, theta=0.0
% INFO    : Bus 82850	: V=0.9833327, theta=-38.663797 -> V=1.0, theta=0.0
% INFO    : Bus 82851	: V=1.0044432, theta=-37.026694 -> V=1.0, theta=0.0
% INFO    : Bus 82852	: V=0.9952931, theta=-37.605943 -> V=1.0, theta=0.0
% INFO    : Bus 82853	: V=0.9971221, theta=-37.46072 -> V=1.0, theta=0.0
% INFO    : Bus 82854	: V=0.9973604, theta=-35.565892 -> V=1.0, theta=0.0
% INFO    : Bus 82855	: V=0.9936554, theta=-36.388853 -> V=1.0, theta=0.0
% INFO    : Bus 82856	: V=0.9742173, theta=-39.233634 -> V=1.0, theta=0.0
% INFO    : Bus 82857	: V=0.9755198, theta=-39.411849 -> V=1.0, theta=0.0
% INFO    : Bus 82858	: V=0.9733306, theta=-39.902492 -> V=1.0, theta=0.0
% INFO    : Bus 82859	: V=0.9725829, theta=-39.911401 -> V=1.0, theta=0.0
% INFO    : Bus 82860	: V=0.9708531, theta=-41.038482 -> V=1.0, theta=0.0
% INFO    : Bus 82861	: V=0.9676507, theta=-40.813313 -> V=1.0, theta=0.0
% INFO    : Bus 82862	: V=0.9666208, theta=-41.178934 -> V=1.0, theta=0.0
% INFO    : Bus 82863	: V=0.9864466, theta=-37.969029 -> V=1.0, theta=0.0
% INFO    : Bus 82864	: V=0.9770357, theta=-38.99518 -> V=1.0, theta=0.0
% INFO    : Bus 82865	: V=0.9878703, theta=-37.970334 -> V=1.0, theta=0.0
% INFO    : Bus 82866	: V=0.9777607, theta=-34.587739 -> V=1.0, theta=0.0
% INFO    : Bus 82867	: V=1.0041369, theta=-33.513441 -> V=1.0, theta=0.0
% INFO    : Bus 82868	: V=0.9614203, theta=-33.593713 -> V=1.0, theta=0.0
% INFO    : Bus 82869	: V=0.9794329, theta=-31.879661 -> V=1.0, theta=0.0
% INFO    : Bus 82870	: V=0.9713189, theta=-32.916374 -> V=1.0, theta=0.0
% INFO    : Bus 82871	: V=0.9666694, theta=-33.315375 -> V=1.0, theta=0.0
% INFO    : Bus 82872	: V=0.9656796, theta=-33.336018 -> V=1.0, theta=0.0
% INFO    : Bus 82873	: V=0.9633849, theta=-33.434218 -> V=1.0, theta=0.0
% INFO    : Bus 82874	: V=0.9928643, theta=-35.479567 -> V=1.0, theta=0.0
% INFO    : Bus 82875	: V=0.9876025, theta=-35.774077 -> V=1.0, theta=0.0
% INFO    : Bus 82876	: V=0.9960118, theta=-34.536497 -> V=1.0, theta=0.0
% INFO    : Bus 82877	: V=0.9896975, theta=-37.528985 -> V=1.0, theta=0.0
% INFO    : Bus 82878	: V=0.9802132, theta=-52.960787 -> V=1.0, theta=0.0
% INFO    : Bus 82879	: V=0.9749707, theta=-55.05504 -> V=1.0, theta=0.0
% INFO    : Bus 82880	: V=0.9746712, theta=-35.475862 -> V=1.0, theta=0.0
% INFO    : Bus 82881	: V=0.9779191, theta=-35.086122 -> V=1.0, theta=0.0
% INFO    : Bus 82882	: V=0.9812334, theta=-34.43454 -> V=1.0, theta=0.0
% INFO    : Bus 82883	: V=1.0121758, theta=-33.565453 -> V=1.0, theta=0.0
% INFO    : Bus 82884	: V=0.9887714, theta=-41.269229 -> V=1.0, theta=0.0
% INFO    : Bus 82885	: V=0.9891898, theta=-41.261377 -> V=1.0, theta=0.0
% INFO    : Bus 82886	: V=0.983541, theta=-41.506748 -> V=1.0, theta=0.0
% INFO    : Bus 82887	: V=0.9822133, theta=-41.738223 -> V=1.0, theta=0.0
% INFO    : Bus 82888	: V=0.9807695, theta=-41.714762 -> V=1.0, theta=0.0
% INFO    : Bus 82889	: V=0.9788411, theta=-42.077642 -> V=1.0, theta=0.0
% INFO    : Bus 82890	: V=0.97833, theta=-42.17511 -> V=1.0, theta=0.0
% INFO    : Bus 82891	: V=0.9980776, theta=-39.885558 -> V=1.0, theta=0.0
% INFO    : Bus 82892	: V=0.9912331, theta=-40.870589 -> V=1.0, theta=0.0
% INFO    : Bus 82893	: V=0.9900281, theta=-40.906497 -> V=1.0, theta=0.0
% INFO    : Bus 82894	: V=0.9735322, theta=-42.67874 -> V=1.0, theta=0.0
% INFO    : Bus 82895	: V=0.9721278, theta=-43.015168 -> V=1.0, theta=0.0
% INFO    : Bus 82896	: V=0.981879, theta=-42.547996 -> V=1.0, theta=0.0
% INFO    : Bus 82897	: V=0.9826955, theta=-43.335169 -> V=1.0, theta=0.0
% INFO    : Bus 82898	: V=0.9834213, theta=-41.475097 -> V=1.0, theta=0.0
% INFO    : Bus 82899	: V=0.9832694, theta=-39.319076 -> V=1.0, theta=0.0
% INFO    : Bus 82900	: V=0.9719645, theta=-42.016168 -> V=1.0, theta=0.0
% INFO    : Bus 82901	: V=0.966454, theta=-43.011227 -> V=1.0, theta=0.0
% INFO    : Bus 82902	: V=0.9722195, theta=-41.678648 -> V=1.0, theta=0.0
% INFO    : Bus 82903	: V=0.9708768, theta=-42.439449 -> V=1.0, theta=0.0
% INFO    : Bus 82904	: V=0.9659003, theta=-34.436834 -> V=1.0, theta=0.0
% INFO    : Bus 82905	: V=1.0017903, theta=-34.006697 -> V=1.0, theta=0.0
% INFO    : Bus 82906	: V=0.9873232, theta=-34.574783 -> V=1.0, theta=0.0
% INFO    : Bus 82907	: V=0.9920154, theta=-34.66387 -> V=1.0, theta=0.0
% INFO    : Bus 82908	: V=0.9987242, theta=-33.313776 -> V=1.0, theta=0.0
% INFO    : Bus 82909	: V=0.9928364, theta=-33.957607 -> V=1.0, theta=0.0
% INFO    : Bus 82910	: V=1.0031013, theta=-48.614287 -> V=1.0, theta=0.0
% INFO    : Bus 82911	: V=1.0049393, theta=-48.703733 -> V=1.0, theta=0.0
% INFO    : Bus 82912	: V=1.0034416, theta=-48.804919 -> V=1.0, theta=0.0
% INFO    : Bus 82913	: V=1.001002, theta=-49.124493 -> V=1.0, theta=0.0
% INFO    : Bus 82914	: V=1.0060353, theta=-48.962288 -> V=1.0, theta=0.0
% INFO    : Bus 82915	: V=0.990044, theta=-50.421358 -> V=1.0, theta=0.0
% INFO    : Bus 82916	: V=1.0024538, theta=-48.784432 -> V=1.0, theta=0.0
% INFO    : Bus 82917	: V=1.0018858, theta=-48.200975 -> V=1.0, theta=0.0
% INFO    : Bus 82918	: V=1.0055504, theta=-48.342881 -> V=1.0, theta=0.0
% INFO    : Bus 82919	: V=0.9965004, theta=-51.290444 -> V=1.0, theta=0.0
% INFO    : Bus 82920	: V=0.9908564, theta=-51.872242 -> V=1.0, theta=0.0
% INFO    : Bus 82921	: V=1.0060917, theta=-48.622286 -> V=1.0, theta=0.0
% INFO    : Bus 82922	: V=0.966591, theta=-52.14237 -> V=1.0, theta=0.0
% INFO    : Bus 82923	: V=0.967822, theta=-52.294585 -> V=1.0, theta=0.0
% INFO    : Bus 82924	: V=0.9646282, theta=-52.424562 -> V=1.0, theta=0.0
% INFO    : Bus 82925	: V=0.9685135, theta=-52.003214 -> V=1.0, theta=0.0
% INFO    : Bus 82926	: V=0.9771419, theta=-51.752479 -> V=1.0, theta=0.0
% INFO    : Bus 82927	: V=0.9707469, theta=-52.305133 -> V=1.0, theta=0.0
% INFO    : Bus 82928	: V=0.9644784, theta=-52.400695 -> V=1.0, theta=0.0
% INFO    : Bus 82929	: V=0.979711, theta=-51.989266 -> V=1.0, theta=0.0
% INFO    : Bus 82930	: V=0.9780138, theta=-52.286397 -> V=1.0, theta=0.0
% INFO    : Bus 82931	: V=0.9663799, theta=-52.471811 -> V=1.0, theta=0.0
% INFO    : Bus 82932	: V=0.9782893, theta=-52.285749 -> V=1.0, theta=0.0
% INFO    : Bus 82933	: V=0.9692926, theta=-51.108226 -> V=1.0, theta=0.0
% INFO    : Bus 82934	: V=0.9681185, theta=-51.539067 -> V=1.0, theta=0.0
% INFO    : Bus 82935	: V=0.9737883, theta=-50.881084 -> V=1.0, theta=0.0
% INFO    : Bus 82936	: V=0.9843618, theta=-50.801821 -> V=1.0, theta=0.0
% INFO    : Bus 82937	: V=0.9796531, theta=-52.21473 -> V=1.0, theta=0.0
% INFO    : Bus 82938	: V=0.9770339, theta=-52.815316 -> V=1.0, theta=0.0
% INFO    : Bus 82939	: V=0.9686805, theta=-52.460858 -> V=1.0, theta=0.0
% INFO    : Bus 82940	: V=0.9663771, theta=-53.659164 -> V=1.0, theta=0.0
% INFO    : Bus 82941	: V=0.9668858, theta=-44.480733 -> V=1.0, theta=0.0
% INFO    : Bus 82942	: V=0.9650213, theta=-44.420276 -> V=1.0, theta=0.0
% INFO    : Bus 82943	: V=0.9683578, theta=-44.467607 -> V=1.0, theta=0.0
% INFO    : Bus 82944	: V=0.9764396, theta=-43.937607 -> V=1.0, theta=0.0
% INFO    : Bus 82945	: V=0.9694475, theta=-44.456943 -> V=1.0, theta=0.0
% INFO    : Bus 82946	: V=0.9774174, theta=-43.682626 -> V=1.0, theta=0.0
% INFO    : Bus 82947	: V=0.9698826, theta=-44.446787 -> V=1.0, theta=0.0
% INFO    : Bus 82948	: V=0.9728822, theta=-43.941676 -> V=1.0, theta=0.0
% INFO    : Bus 82949	: V=0.9690574, theta=-44.557388 -> V=1.0, theta=0.0
% INFO    : Bus 82950	: V=0.9639596, theta=-44.609378 -> V=1.0, theta=0.0
% INFO    : Bus 82951	: V=0.9786646, theta=-43.790683 -> V=1.0, theta=0.0
% INFO    : Bus 82952	: V=0.9717988, theta=-44.549927 -> V=1.0, theta=0.0
% INFO    : Bus 82953	: V=0.9752477, theta=-44.096344 -> V=1.0, theta=0.0
% INFO    : Bus 82954	: V=0.9698214, theta=-44.646394 -> V=1.0, theta=0.0
% INFO    : Bus 82955	: V=0.9660016, theta=-44.843908 -> V=1.0, theta=0.0
% INFO    : Bus 82956	: V=0.9687347, theta=-44.707689 -> V=1.0, theta=0.0
% INFO    : Bus 82957	: V=0.965077, theta=-40.849237 -> V=1.0, theta=0.0
% INFO    : Bus 82958	: V=0.9695883, theta=-39.686812 -> V=1.0, theta=0.0
% INFO    : Bus 82959	: V=0.9640614, theta=-40.306424 -> V=1.0, theta=0.0
% INFO    : Bus 82960	: V=0.9666235, theta=-41.613192 -> V=1.0, theta=0.0
% INFO    : Bus 82961	: V=0.9628792, theta=-41.856441 -> V=1.0, theta=0.0
% INFO    : Bus 82962	: V=0.9771017, theta=-43.628746 -> V=1.0, theta=0.0
% INFO    : Bus 82963	: V=0.9671279, theta=-44.134827 -> V=1.0, theta=0.0
% INFO    : Bus 82964	: V=0.981712, theta=-43.421414 -> V=1.0, theta=0.0
% INFO    : Bus 82965	: V=0.9749809, theta=-43.818961 -> V=1.0, theta=0.0
% INFO    : Bus 82966	: V=0.9627897, theta=-44.170781 -> V=1.0, theta=0.0
% INFO    : Bus 82967	: V=0.9734116, theta=-44.18042 -> V=1.0, theta=0.0
% INFO    : Bus 82968	: V=0.9729676, theta=-43.875425 -> V=1.0, theta=0.0
% INFO    : Bus 82969	: V=0.9821153, theta=-43.690419 -> V=1.0, theta=0.0
% INFO    : Bus 82970	: V=0.9808339, theta=-43.831846 -> V=1.0, theta=0.0
% INFO    : Bus 82971	: V=0.9668959, theta=-44.700157 -> V=1.0, theta=0.0
% INFO    : Bus 82972	: V=0.9563726, theta=-46.040828 -> V=1.0, theta=0.0
% INFO    : Bus 82973	: V=0.9785668, theta=-43.988311 -> V=1.0, theta=0.0
% INFO    : Bus 82974	: V=0.9718191, theta=-44.812691 -> V=1.0, theta=0.0
% INFO    : Bus 82975	: V=0.9747444, theta=-44.169058 -> V=1.0, theta=0.0
% INFO    : Bus 82976	: V=0.9749744, theta=-44.367538 -> V=1.0, theta=0.0
% INFO    : Bus 82977	: V=0.9687748, theta=-44.692904 -> V=1.0, theta=0.0
% INFO    : Bus 82978	: V=0.9672236, theta=-44.634993 -> V=1.0, theta=0.0
% INFO    : Bus 82979	: V=0.9686299, theta=-44.835872 -> V=1.0, theta=0.0
% INFO    : Bus 82980	: V=0.9726694, theta=-44.367242 -> V=1.0, theta=0.0
% INFO    : Bus 82981	: V=0.9639529, theta=-45.121953 -> V=1.0, theta=0.0
% INFO    : Bus 82982	: V=0.9639445, theta=-45.109335 -> V=1.0, theta=0.0
% INFO    : Bus 82983	: V=0.9774639, theta=-44.642994 -> V=1.0, theta=0.0
% INFO    : Bus 82984	: V=0.9746604, theta=-45.369742 -> V=1.0, theta=0.0
% INFO    : Bus 82985	: V=0.987124, theta=-37.746715 -> V=1.0, theta=0.0
% INFO    : Bus 82986	: V=0.9771374, theta=-38.536092 -> V=1.0, theta=0.0
% INFO    : Bus 82987	: V=0.9841272, theta=-38.372273 -> V=1.0, theta=0.0
% INFO    : Bus 82988	: V=0.98475, theta=-38.386173 -> V=1.0, theta=0.0
% INFO    : Bus 82989	: V=0.9829248, theta=-38.963117 -> V=1.0, theta=0.0
% INFO    : Bus 82990	: V=0.9868039, theta=-38.75116 -> V=1.0, theta=0.0
% INFO    : Bus 82991	: V=0.9830591, theta=-38.988542 -> V=1.0, theta=0.0
% INFO    : Bus 82992	: V=0.9831733, theta=-39.854059 -> V=1.0, theta=0.0
% INFO    : Bus 82993	: V=0.9834326, theta=-40.540902 -> V=1.0, theta=0.0
% INFO    : Bus 82994	: V=0.9669411, theta=-55.484292 -> V=1.0, theta=0.0
% INFO    : Bus 82995	: V=0.965317, theta=-54.472763 -> V=1.0, theta=0.0
% INFO    : Bus 82996	: V=0.9730445, theta=-54.77591 -> V=1.0, theta=0.0
% INFO    : Bus 82997	: V=0.9668431, theta=-55.649975 -> V=1.0, theta=0.0
% INFO    : Bus 82998	: V=0.9689129, theta=-55.443103 -> V=1.0, theta=0.0
% INFO    : Bus 82999	: V=0.9600663, theta=-56.048414 -> V=1.0, theta=0.0
% INFO    : Bus 83000	: V=0.9692607, theta=-55.58264 -> V=1.0, theta=0.0
% INFO    : Bus 83001	: V=0.9641148, theta=-55.427455 -> V=1.0, theta=0.0
% INFO    : Bus 83002	: V=0.9645161, theta=-43.344878 -> V=1.0, theta=0.0
% INFO    : Bus 83003	: V=0.9685001, theta=-42.554997 -> V=1.0, theta=0.0
% INFO    : Bus 83004	: V=0.9671024, theta=-43.758308 -> V=1.0, theta=0.0
% INFO    : Bus 83005	: V=0.9700106, theta=-42.842214 -> V=1.0, theta=0.0
% INFO    : Bus 83006	: V=0.9676711, theta=-43.979097 -> V=1.0, theta=0.0
% INFO    : Bus 83007	: V=0.9664493, theta=-43.985454 -> V=1.0, theta=0.0
% INFO    : Bus 83008	: V=0.9658187, theta=-43.782163 -> V=1.0, theta=0.0
% INFO    : Bus 83009	: V=0.9644324, theta=-44.136501 -> V=1.0, theta=0.0
% INFO    : Bus 83010	: V=0.9673242, theta=-44.192625 -> V=1.0, theta=0.0
% INFO    : Bus 83011	: V=0.9633304, theta=-44.818956 -> V=1.0, theta=0.0
% INFO    : Bus 83012	: V=0.9657393, theta=-44.206813 -> V=1.0, theta=0.0
% INFO    : Bus 83013	: V=0.9684674, theta=-44.864529 -> V=1.0, theta=0.0
% INFO    : Bus 83014	: V=0.9676555, theta=-45.325358 -> V=1.0, theta=0.0
% INFO    : Bus 83015	: V=0.9679723, theta=-45.883952 -> V=1.0, theta=0.0
% INFO    : Bus 83016	: V=0.9695005, theta=-45.661716 -> V=1.0, theta=0.0
% INFO    : Bus 83017	: V=1.0052986, theta=-32.312357 -> V=1.0, theta=0.0
% INFO    : Bus 83018	: V=1.003332, theta=-40.162591 -> V=1.0, theta=0.0
% INFO    : Bus 83019	: V=0.9993417, theta=-40.212918 -> V=1.0, theta=0.0
% INFO    : Bus 83020	: V=0.9846453, theta=-41.463741 -> V=1.0, theta=0.0
% INFO    : Bus 83021	: V=0.9782593, theta=-41.469784 -> V=1.0, theta=0.0
% INFO    : Bus 83022	: V=0.975147, theta=-42.467109 -> V=1.0, theta=0.0
% INFO    : Bus 83023	: V=0.9986324, theta=-41.07836 -> V=1.0, theta=0.0
% INFO    : Bus 83024	: V=0.9964333, theta=-41.342087 -> V=1.0, theta=0.0
% INFO    : Bus 83025	: V=0.9995198, theta=-41.439651 -> V=1.0, theta=0.0
% INFO    : Bus 83026	: V=0.9988772, theta=-41.51278 -> V=1.0, theta=0.0
% INFO    : Bus 83027	: V=0.9924724, theta=-42.310192 -> V=1.0, theta=0.0
% INFO    : Bus 83028	: V=0.9779294, theta=-43.415654 -> V=1.0, theta=0.0
% INFO    : Bus 83029	: V=0.9942765, theta=-41.819846 -> V=1.0, theta=0.0
% INFO    : Bus 83030	: V=0.9712559, theta=-43.300355 -> V=1.0, theta=0.0
% INFO    : Bus 83031	: V=0.9746142, theta=-43.122482 -> V=1.0, theta=0.0
% INFO    : Bus 83032	: V=0.9686161, theta=-43.990005 -> V=1.0, theta=0.0
% INFO    : Bus 83033	: V=0.9719525, theta=-44.008413 -> V=1.0, theta=0.0
% INFO    : Bus 83034	: V=0.9816416, theta=-43.682676 -> V=1.0, theta=0.0
% INFO    : Bus 83035	: V=0.9921683, theta=-43.021167 -> V=1.0, theta=0.0
% INFO    : Bus 83036	: V=0.9827664, theta=-43.788009 -> V=1.0, theta=0.0
% INFO    : Bus 83037	: V=0.9929554, theta=-43.01033 -> V=1.0, theta=0.0
% INFO    : Bus 83038	: V=0.99207, theta=-43.075973 -> V=1.0, theta=0.0
% INFO    : Bus 83039	: V=0.9834377, theta=-43.677679 -> V=1.0, theta=0.0
% INFO    : Bus 83040	: V=0.9887824, theta=-43.28847 -> V=1.0, theta=0.0
% INFO    : Bus 83041	: V=0.9862764, theta=-43.635267 -> V=1.0, theta=0.0
% INFO    : Bus 83042	: V=0.9829581, theta=-43.812285 -> V=1.0, theta=0.0
% INFO    : Bus 83043	: V=0.9891138, theta=-43.281403 -> V=1.0, theta=0.0
% INFO    : Bus 83044	: V=0.9859085, theta=-43.647091 -> V=1.0, theta=0.0
% INFO    : Bus 83045	: V=0.9872216, theta=-43.761819 -> V=1.0, theta=0.0
% INFO    : Bus 83046	: V=0.9862759, theta=-43.832169 -> V=1.0, theta=0.0
% INFO    : Bus 83047	: V=0.9767612, theta=-43.922745 -> V=1.0, theta=0.0
% INFO    : Bus 83048	: V=0.9766208, theta=-43.92137 -> V=1.0, theta=0.0
% INFO    : Bus 83049	: V=0.9792176, theta=-43.784904 -> V=1.0, theta=0.0
% INFO    : Bus 83050	: V=0.9764447, theta=-43.875195 -> V=1.0, theta=0.0
% INFO    : Bus 83051	: V=0.9789446, theta=-43.669305 -> V=1.0, theta=0.0
% INFO    : Bus 83052	: V=0.9736345, theta=-43.925354 -> V=1.0, theta=0.0
% INFO    : Bus 83053	: V=0.9877092, theta=-42.979359 -> V=1.0, theta=0.0
% INFO    : Bus 83054	: V=0.9806778, theta=-43.561278 -> V=1.0, theta=0.0
% INFO    : Bus 83055	: V=0.9771949, theta=-43.707514 -> V=1.0, theta=0.0
% INFO    : Bus 83056	: V=0.985706, theta=-43.348115 -> V=1.0, theta=0.0
% INFO    : Bus 83057	: V=0.9784245, theta=-44.007706 -> V=1.0, theta=0.0
% INFO    : Bus 83058	: V=0.9808051, theta=-43.857587 -> V=1.0, theta=0.0
% INFO    : Bus 83059	: V=0.9763066, theta=-44.214991 -> V=1.0, theta=0.0
% INFO    : Bus 83060	: V=0.975248, theta=-44.415538 -> V=1.0, theta=0.0
% INFO    : Bus 83061	: V=0.9840999, theta=-43.903205 -> V=1.0, theta=0.0
% INFO    : Bus 83062	: V=0.9878239, theta=-43.868345 -> V=1.0, theta=0.0
% INFO    : Bus 83063	: V=0.984595, theta=-44.111382 -> V=1.0, theta=0.0
% INFO    : Bus 83064	: V=0.9847109, theta=-44.212531 -> V=1.0, theta=0.0
% INFO    : Bus 83065	: V=0.9855264, theta=-44.131319 -> V=1.0, theta=0.0
% INFO    : Bus 83066	: V=0.9850403, theta=-44.12633 -> V=1.0, theta=0.0
% INFO    : Bus 83067	: V=0.9809316, theta=-44.56578 -> V=1.0, theta=0.0
% INFO    : Bus 83068	: V=0.9824215, theta=-44.118749 -> V=1.0, theta=0.0
% INFO    : Bus 83069	: V=0.977709, theta=-44.444808 -> V=1.0, theta=0.0
% INFO    : Bus 83070	: V=0.9841369, theta=-44.476848 -> V=1.0, theta=0.0
% INFO    : Bus 83071	: V=0.9807439, theta=-44.444302 -> V=1.0, theta=0.0
% INFO    : Bus 83072	: V=0.9925844, theta=-43.681184 -> V=1.0, theta=0.0
% INFO    : Bus 83073	: V=0.9890247, theta=-44.100821 -> V=1.0, theta=0.0
% INFO    : Bus 83074	: V=1.0004902, theta=-42.341936 -> V=1.0, theta=0.0
% INFO    : Bus 83075	: V=0.9921453, theta=-43.089829 -> V=1.0, theta=0.0
% INFO    : Bus 83076	: V=0.9914752, theta=-43.18287 -> V=1.0, theta=0.0
% INFO    : Bus 83077	: V=0.9814773, theta=-43.0596 -> V=1.0, theta=0.0
% INFO    : Bus 83078	: V=0.9921395, theta=-43.386968 -> V=1.0, theta=0.0
% INFO    : Bus 83079	: V=0.9886343, theta=-43.76703 -> V=1.0, theta=0.0
% INFO    : Bus 83080	: V=0.9888597, theta=-30.468542 -> V=1.0, theta=0.0
% INFO    : Bus 83081	: V=1.0003551, theta=-28.955858 -> V=1.0, theta=0.0
% INFO    : Bus 83082	: V=0.9940552, theta=-29.532208 -> V=1.0, theta=0.0
% INFO    : Bus 83083	: V=1.029343, theta=-30.695017 -> V=1.0, theta=0.0
% INFO    : Bus 83084	: V=1.0312592, theta=-30.655501 -> V=1.0, theta=0.0
% INFO    : Bus 83085	: V=1.0322704, theta=-30.383633 -> V=1.0, theta=0.0
% INFO    : Bus 83086	: V=1.0127728, theta=-27.182674 -> V=1.0, theta=0.0
% INFO    : Bus 83087	: V=1.0186819, theta=-26.14481 -> V=1.0, theta=0.0
% INFO    : Bus 83088	: V=1.011976, theta=-27.216737 -> V=1.0, theta=0.0
% INFO    : Bus 83089	: V=0.9833509, theta=-34.73098 -> V=1.0, theta=0.0
% INFO    : Bus 83090	: V=0.9805664, theta=-35.249175 -> V=1.0, theta=0.0
% INFO    : Bus 83091	: V=1.0126712, theta=-32.323833 -> V=1.0, theta=0.0
% INFO    : Bus 83092	: V=1.0236146, theta=-32.539673 -> V=1.0, theta=0.0
% INFO    : Bus 83093	: V=1.0009563, theta=-33.653758 -> V=1.0, theta=0.0
% INFO    : Bus 83094	: V=1.0000386, theta=-33.829742 -> V=1.0, theta=0.0
% INFO    : Bus 83095	: V=1.0119529, theta=-32.919301 -> V=1.0, theta=0.0
% INFO    : Bus 83096	: V=1.0049225, theta=-33.449778 -> V=1.0, theta=0.0
% INFO    : Bus 83097	: V=1.0017021, theta=-33.500599 -> V=1.0, theta=0.0
% INFO    : Bus 83098	: V=0.998484, theta=-33.783339 -> V=1.0, theta=0.0
% INFO    : Bus 83099	: V=0.9957632, theta=-33.869627 -> V=1.0, theta=0.0
% INFO    : Bus 83100	: V=0.9854696, theta=-34.37765 -> V=1.0, theta=0.0
% INFO    : Bus 83101	: V=1.0026418, theta=-47.524758 -> V=1.0, theta=0.0
% INFO    : Bus 83102	: V=0.9911365, theta=-48.596074 -> V=1.0, theta=0.0
% INFO    : Bus 83103	: V=0.9579614, theta=-53.798981 -> V=1.0, theta=0.0
% INFO    : Bus 83104	: V=1.0022896, theta=-48.172139 -> V=1.0, theta=0.0
% INFO    : Bus 83105	: V=1.0030135, theta=-48.700832 -> V=1.0, theta=0.0
% INFO    : Bus 83106	: V=0.9946454, theta=-49.536047 -> V=1.0, theta=0.0
% INFO    : Bus 83107	: V=0.9883749, theta=-50.275835 -> V=1.0, theta=0.0
% INFO    : Bus 83108	: V=0.9709943, theta=-54.477839 -> V=1.0, theta=0.0
% INFO    : Bus 83109	: V=1.0031675, theta=-50.254409 -> V=1.0, theta=0.0
% INFO    : Bus 83110	: V=0.9964282, theta=-51.389158 -> V=1.0, theta=0.0
% INFO    : Bus 83111	: V=0.990501, theta=-38.227636 -> V=1.0, theta=0.0
% INFO    : Bus 83112	: V=0.9796103, theta=-39.304428 -> V=1.0, theta=0.0
% INFO    : Bus 83113	: V=0.9676651, theta=-40.089256 -> V=1.0, theta=0.0
% INFO    : Bus 83114	: V=0.9689829, theta=-40.286857 -> V=1.0, theta=0.0
% INFO    : Bus 83115	: V=1.0049341, theta=-30.665787 -> V=1.0, theta=0.0
% INFO    : Bus 83116	: V=0.9851352, theta=-37.444163 -> V=1.0, theta=0.0
% INFO    : Bus 83117	: V=0.9797949, theta=-38.252373 -> V=1.0, theta=0.0
% INFO    : Bus 83118	: V=0.9791524, theta=-38.174345 -> V=1.0, theta=0.0
% INFO    : Bus 83119	: V=0.975418, theta=-38.363436 -> V=1.0, theta=0.0
% INFO    : Bus 83120	: V=0.9767759, theta=-38.315943 -> V=1.0, theta=0.0
% INFO    : Bus 83121	: V=0.9725118, theta=-38.224942 -> V=1.0, theta=0.0
% INFO    : Bus 83122	: V=0.9792782, theta=-37.377132 -> V=1.0, theta=0.0
% INFO    : Bus 83123	: V=0.9715732, theta=-38.35662 -> V=1.0, theta=0.0
% INFO    : Bus 83124	: V=0.9781808, theta=-38.531567 -> V=1.0, theta=0.0
% INFO    : Bus 83125	: V=0.9804198, theta=-38.458375 -> V=1.0, theta=0.0
% INFO    : Bus 83126	: V=0.9920757, theta=-37.923689 -> V=1.0, theta=0.0
% INFO    : Bus 83127	: V=0.973904, theta=-38.508447 -> V=1.0, theta=0.0
% INFO    : Bus 83128	: V=0.9755704, theta=-35.762814 -> V=1.0, theta=0.0
% INFO    : Bus 83129	: V=0.98564, theta=-35.160595 -> V=1.0, theta=0.0
% INFO    : Bus 83130	: V=0.9750083, theta=-38.392298 -> V=1.0, theta=0.0
% INFO    : Bus 83131	: V=0.9920108, theta=-33.202656 -> V=1.0, theta=0.0
% INFO    : Bus 83132	: V=0.9744494, theta=-37.559335 -> V=1.0, theta=0.0
% INFO    : Bus 83133	: V=0.9717482, theta=-38.962426 -> V=1.0, theta=0.0
% INFO    : Bus 83134	: V=0.9822078, theta=-41.399994 -> V=1.0, theta=0.0
% INFO    : Bus 83135	: V=0.9781531, theta=-41.480092 -> V=1.0, theta=0.0
% INFO    : Bus 83136	: V=0.9761903, theta=-41.703031 -> V=1.0, theta=0.0
% INFO    : Bus 83137	: V=0.9757712, theta=-42.051993 -> V=1.0, theta=0.0
% INFO    : Bus 83138	: V=0.9771427, theta=-41.095434 -> V=1.0, theta=0.0
% INFO    : Bus 83139	: V=0.9737683, theta=-41.655175 -> V=1.0, theta=0.0
% INFO    : Bus 83140	: V=0.9721832, theta=-41.337327 -> V=1.0, theta=0.0
% INFO    : Bus 83141	: V=0.9722411, theta=-41.965823 -> V=1.0, theta=0.0
% INFO    : Bus 83142	: V=0.9714226, theta=-42.115427 -> V=1.0, theta=0.0
% INFO    : Bus 83143	: V=0.9689734, theta=-42.786398 -> V=1.0, theta=0.0
% INFO    : Bus 83144	: V=0.9690269, theta=-43.017205 -> V=1.0, theta=0.0
% INFO    : Bus 83145	: V=0.9699233, theta=-43.056306 -> V=1.0, theta=0.0
% INFO    : Bus 83146	: V=0.9751411, theta=-42.386472 -> V=1.0, theta=0.0
% INFO    : Bus 83147	: V=0.9714885, theta=-42.539457 -> V=1.0, theta=0.0
% INFO    : Bus 83148	: V=0.9759121, theta=-42.300189 -> V=1.0, theta=0.0
% INFO    : Bus 83149	: V=0.9741496, theta=-42.950692 -> V=1.0, theta=0.0
% INFO    : Bus 83150	: V=0.9737803, theta=-42.664248 -> V=1.0, theta=0.0
% INFO    : Bus 83151	: V=0.9759883, theta=-43.334724 -> V=1.0, theta=0.0
% INFO    : Bus 83152	: V=0.9713309, theta=-42.60217 -> V=1.0, theta=0.0
% INFO    : Bus 83153	: V=0.9692005, theta=-44.288153 -> V=1.0, theta=0.0
% INFO    : Bus 83154	: V=0.9726885, theta=-43.570504 -> V=1.0, theta=0.0
% INFO    : Bus 83155	: V=0.9734246, theta=-44.086514 -> V=1.0, theta=0.0
% INFO    : Bus 83156	: V=0.9797221, theta=-43.574325 -> V=1.0, theta=0.0
% INFO    : Bus 83157	: V=0.9777918, theta=-44.065298 -> V=1.0, theta=0.0
% INFO    : Bus 83158	: V=0.9779967, theta=-43.572063 -> V=1.0, theta=0.0
% INFO    : Bus 83159	: V=0.9792631, theta=-44.021991 -> V=1.0, theta=0.0
% INFO    : Bus 83160	: V=0.9744933, theta=-43.734016 -> V=1.0, theta=0.0
% INFO    : Bus 83161	: V=0.9748455, theta=-44.350273 -> V=1.0, theta=0.0
% INFO    : Bus 83162	: V=0.9728832, theta=-45.3201 -> V=1.0, theta=0.0
% INFO    : Bus 83163	: V=0.9720899, theta=-45.390706 -> V=1.0, theta=0.0
% INFO    : Bus 83164	: V=0.9748414, theta=-45.325134 -> V=1.0, theta=0.0
% INFO    : Bus 83165	: V=0.9720329, theta=-45.403015 -> V=1.0, theta=0.0
% INFO    : Bus 83166	: V=0.9818805, theta=-43.010629 -> V=1.0, theta=0.0
% INFO    : Bus 83167	: V=0.9742617, theta=-43.462266 -> V=1.0, theta=0.0
% INFO    : Bus 83168	: V=0.9789107, theta=-42.484858 -> V=1.0, theta=0.0
% INFO    : Bus 83169	: V=0.9748702, theta=-43.050664 -> V=1.0, theta=0.0
% INFO    : Bus 83170	: V=0.9695612, theta=-43.336919 -> V=1.0, theta=0.0
% INFO    : Bus 83171	: V=0.9735133, theta=-43.848786 -> V=1.0, theta=0.0
% INFO    : Bus 83172	: V=0.9706743, theta=-43.70159 -> V=1.0, theta=0.0
% INFO    : Bus 83173	: V=0.9710555, theta=-43.406457 -> V=1.0, theta=0.0
% INFO    : Bus 83174	: V=0.9709962, theta=-43.792085 -> V=1.0, theta=0.0
% INFO    : Bus 83175	: V=0.9715795, theta=-43.921353 -> V=1.0, theta=0.0
% INFO    : Bus 83176	: V=0.9705043, theta=-43.914314 -> V=1.0, theta=0.0
% INFO    : Bus 83177	: V=0.9692191, theta=-43.410435 -> V=1.0, theta=0.0
% INFO    : Bus 83178	: V=0.973671, theta=-42.888421 -> V=1.0, theta=0.0
% INFO    : Bus 83179	: V=0.9725739, theta=-43.514184 -> V=1.0, theta=0.0
% INFO    : Bus 83180	: V=0.971224, theta=-43.6279 -> V=1.0, theta=0.0
% INFO    : Bus 83181	: V=0.9722075, theta=-43.709659 -> V=1.0, theta=0.0
% INFO    : Bus 83182	: V=0.9710702, theta=-43.795758 -> V=1.0, theta=0.0
% INFO    : Bus 83183	: V=0.9710858, theta=-43.578519 -> V=1.0, theta=0.0
% INFO    : Bus 83184	: V=0.9689366, theta=-44.556461 -> V=1.0, theta=0.0
% INFO    : Bus 83185	: V=0.9740241, theta=-44.333561 -> V=1.0, theta=0.0
% INFO    : Bus 83186	: V=0.9733994, theta=-44.653677 -> V=1.0, theta=0.0
% INFO    : Bus 83187	: V=0.9730771, theta=-44.216921 -> V=1.0, theta=0.0
% INFO    : Bus 83188	: V=0.9817393, theta=-43.527943 -> V=1.0, theta=0.0
% INFO    : Bus 83189	: V=0.981189, theta=-44.431636 -> V=1.0, theta=0.0
% INFO    : Bus 83190	: V=0.9781933, theta=-44.502337 -> V=1.0, theta=0.0
% INFO    : Bus 83191	: V=0.9713926, theta=-44.94846 -> V=1.0, theta=0.0
% INFO    : Bus 83192	: V=0.9729621, theta=-45.298072 -> V=1.0, theta=0.0
% INFO    : Bus 83193	: V=0.9730625, theta=-45.356907 -> V=1.0, theta=0.0
% INFO    : Bus 83194	: V=0.975481, theta=-45.38643 -> V=1.0, theta=0.0
% INFO    : Bus 83195	: V=0.9774031, theta=-45.353948 -> V=1.0, theta=0.0
% INFO    : Bus 83196	: V=0.9763724, theta=-45.317891 -> V=1.0, theta=0.0
% INFO    : Bus 83197	: V=0.9766718, theta=-45.301148 -> V=1.0, theta=0.0
% INFO    : Bus 83198	: V=0.9726878, theta=-45.31569 -> V=1.0, theta=0.0
% INFO    : Bus 83199	: V=0.9903615, theta=-43.7906 -> V=1.0, theta=0.0
% INFO    : Bus 83200	: V=0.9804539, theta=-44.579531 -> V=1.0, theta=0.0
% INFO    : Bus 83201	: V=0.9904096, theta=-43.831881 -> V=1.0, theta=0.0
% INFO    : Bus 83202	: V=0.9818394, theta=-44.643585 -> V=1.0, theta=0.0
% INFO    : Bus 83203	: V=0.9799209, theta=-44.858741 -> V=1.0, theta=0.0
% INFO    : Bus 83204	: V=0.9723003, theta=-44.460369 -> V=1.0, theta=0.0
% INFO    : Bus 83205	: V=0.9764218, theta=-44.775787 -> V=1.0, theta=0.0
% INFO    : Bus 83206	: V=0.984326, theta=-44.174567 -> V=1.0, theta=0.0
% INFO    : Bus 83207	: V=0.9825316, theta=-44.345414 -> V=1.0, theta=0.0
% INFO    : Bus 83208	: V=0.9745192, theta=-42.428513 -> V=1.0, theta=0.0
% INFO    : Bus 83209	: V=0.9729475, theta=-43.000935 -> V=1.0, theta=0.0
% INFO    : Bus 83210	: V=0.9732759, theta=-43.151639 -> V=1.0, theta=0.0
% INFO    : Bus 83211	: V=0.9711818, theta=-43.306584 -> V=1.0, theta=0.0
% INFO    : Bus 83212	: V=0.9689455, theta=-43.457879 -> V=1.0, theta=0.0
% INFO    : Bus 83213	: V=0.970422, theta=-43.896884 -> V=1.0, theta=0.0
% INFO    : Bus 83214	: V=0.9743544, theta=-43.437842 -> V=1.0, theta=0.0
% INFO    : Bus 83215	: V=0.9723801, theta=-43.602741 -> V=1.0, theta=0.0
% INFO    : Bus 83216	: V=0.9742083, theta=-43.826481 -> V=1.0, theta=0.0
% INFO    : Bus 83217	: V=0.9758244, theta=-44.0607 -> V=1.0, theta=0.0
% INFO    : Bus 83218	: V=0.9757735, theta=-44.082606 -> V=1.0, theta=0.0
% INFO    : Bus 83219	: V=0.9801823, theta=-43.924783 -> V=1.0, theta=0.0
% INFO    : Bus 83220	: V=0.9795811, theta=-44.049236 -> V=1.0, theta=0.0
% INFO    : Bus 83221	: V=0.9784865, theta=-44.269728 -> V=1.0, theta=0.0
% INFO    : Bus 83222	: V=0.9744922, theta=-44.454763 -> V=1.0, theta=0.0
% INFO    : Bus 83223	: V=0.9741926, theta=-44.52799 -> V=1.0, theta=0.0
% INFO    : Bus 83224	: V=0.9721583, theta=-44.732331 -> V=1.0, theta=0.0
% INFO    : Bus 83225	: V=0.9879671, theta=-33.157218 -> V=1.0, theta=0.0
% INFO    : Bus 83226	: V=1.0049791, theta=-29.91559 -> V=1.0, theta=0.0
% INFO    : Bus 83227	: V=1.0023449, theta=-29.723262 -> V=1.0, theta=0.0
% INFO    : Bus 83228	: V=0.9735316, theta=-33.802984 -> V=1.0, theta=0.0
% INFO    : Bus 83229	: V=1.0315307, theta=-31.865753 -> V=1.0, theta=0.0
% INFO    : Bus 83230	: V=1.0185235, theta=-32.334191 -> V=1.0, theta=0.0
% INFO    : Bus 83231	: V=0.99393, theta=-31.947929 -> V=1.0, theta=0.0
% INFO    : Bus 83232	: V=1.0122501, theta=-29.708762 -> V=1.0, theta=0.0
% INFO    : Bus 83233	: V=1.015108, theta=-28.500541 -> V=1.0, theta=0.0
% INFO    : Bus 83234	: V=1.0041954, theta=-30.37029 -> V=1.0, theta=0.0
% INFO    : Bus 83235	: V=0.9820515, theta=-41.084368 -> V=1.0, theta=0.0
% INFO    : Bus 83236	: V=0.992914, theta=-40.30027 -> V=1.0, theta=0.0
% INFO    : Bus 83237	: V=0.9892048, theta=-39.128362 -> V=1.0, theta=0.0
% INFO    : Bus 83238	: V=1.0022783, theta=-38.278949 -> V=1.0, theta=0.0
% INFO    : Bus 83239	: V=0.9967784, theta=-38.652088 -> V=1.0, theta=0.0
% INFO    : Bus 83240	: V=1.0014071, theta=-39.045575 -> V=1.0, theta=0.0
% INFO    : Bus 83241	: V=1.0043299, theta=-39.574755 -> V=1.0, theta=0.0
% INFO    : Bus 83242	: V=1.0022975, theta=-39.992425 -> V=1.0, theta=0.0
% INFO    : Bus 83243	: V=0.9820032, theta=-43.442826 -> V=1.0, theta=0.0
% INFO    : Bus 83244	: V=0.9851519, theta=-43.33299 -> V=1.0, theta=0.0
% INFO    : Bus 83245	: V=0.9840788, theta=-43.267652 -> V=1.0, theta=0.0
% INFO    : Bus 83246	: V=0.9924433, theta=-42.73471 -> V=1.0, theta=0.0
% INFO    : Bus 83247	: V=0.9988505, theta=-43.64673 -> V=1.0, theta=0.0
% INFO    : Bus 83248	: V=1.0081801, theta=-42.269805 -> V=1.0, theta=0.0
% INFO    : Bus 83249	: V=0.985012, theta=-42.366601 -> V=1.0, theta=0.0
% INFO    : Bus 83250	: V=0.9800244, theta=-43.033475 -> V=1.0, theta=0.0
% INFO    : Bus 83251	: V=1.0103262, theta=-42.349622 -> V=1.0, theta=0.0
% INFO    : Bus 83252	: V=1.0094702, theta=-42.731881 -> V=1.0, theta=0.0
% INFO    : Bus 83253	: V=1.0064656, theta=-43.043348 -> V=1.0, theta=0.0
% INFO    : Bus 83254	: V=1.0071414, theta=-43.030154 -> V=1.0, theta=0.0
% INFO    : Bus 83255	: V=0.9947377, theta=-30.765756 -> V=1.0, theta=0.0
% INFO    : Bus 83256	: V=1.0021689, theta=-34.023125 -> V=1.0, theta=0.0
% INFO    : Bus 83257	: V=0.9976104, theta=-34.26288 -> V=1.0, theta=0.0
% INFO    : Bus 83258	: V=0.9988142, theta=-34.288862 -> V=1.0, theta=0.0
% INFO    : Bus 83259	: V=0.9989216, theta=-34.368503 -> V=1.0, theta=0.0
% INFO    : Bus 83260	: V=0.9991731, theta=-34.490224 -> V=1.0, theta=0.0
% INFO    : Bus 83261	: V=0.9988187, theta=-34.39994 -> V=1.0, theta=0.0
% INFO    : Bus 83262	: V=0.9992258, theta=-34.252066 -> V=1.0, theta=0.0
% INFO    : Bus 83263	: V=0.999394, theta=-34.218645 -> V=1.0, theta=0.0
% INFO    : Bus 83264	: V=1.0034158, theta=-33.858755 -> V=1.0, theta=0.0
% INFO    : Bus 83265	: V=1.0068868, theta=-33.418206 -> V=1.0, theta=0.0
% INFO    : Bus 83266	: V=0.9985459, theta=-34.180938 -> V=1.0, theta=0.0
% INFO    : Bus 83267	: V=1.0030221, theta=-33.777823 -> V=1.0, theta=0.0
% INFO    : Bus 83268	: V=0.9999047, theta=-34.144049 -> V=1.0, theta=0.0
% INFO    : Bus 83269	: V=1.0033003, theta=-33.851864 -> V=1.0, theta=0.0
% INFO    : Bus 83270	: V=0.9998435, theta=-34.242372 -> V=1.0, theta=0.0
% INFO    : Bus 83271	: V=1.0029308, theta=-33.651188 -> V=1.0, theta=0.0
% INFO    : Bus 83272	: V=0.9977005, theta=-34.07431 -> V=1.0, theta=0.0
% INFO    : Bus 83273	: V=1.0004683, theta=-34.327161 -> V=1.0, theta=0.0
% INFO    : Bus 83274	: V=0.9977493, theta=-34.539797 -> V=1.0, theta=0.0
% INFO    : Bus 83275	: V=1.0049954, theta=-32.690421 -> V=1.0, theta=0.0
% INFO    : Bus 83276	: V=1.002058, theta=-33.53003 -> V=1.0, theta=0.0
% INFO    : Bus 83277	: V=1.002949, theta=-34.581014 -> V=1.0, theta=0.0
% INFO    : Bus 83278	: V=1.0013196, theta=-34.661743 -> V=1.0, theta=0.0
% INFO    : Bus 83279	: V=0.998813, theta=-34.500721 -> V=1.0, theta=0.0
% INFO    : Bus 83280	: V=1.0015816, theta=-34.460182 -> V=1.0, theta=0.0
% INFO    : Bus 83281	: V=1.0003722, theta=-34.590466 -> V=1.0, theta=0.0
% INFO    : Bus 83282	: V=0.9980711, theta=-35.11151 -> V=1.0, theta=0.0
% INFO    : Bus 83283	: V=0.9992043, theta=-34.43582 -> V=1.0, theta=0.0
% INFO    : Bus 83284	: V=0.9991398, theta=-34.432297 -> V=1.0, theta=0.0
% INFO    : Bus 83285	: V=0.996133, theta=-34.651435 -> V=1.0, theta=0.0
% INFO    : Bus 83286	: V=0.9837676, theta=-37.582876 -> V=1.0, theta=0.0
% INFO    : Bus 83287	: V=0.9823367, theta=-37.493502 -> V=1.0, theta=0.0
% INFO    : Bus 83288	: V=1.0002969, theta=-34.820185 -> V=1.0, theta=0.0
% INFO    : Bus 83289	: V=0.9983848, theta=-35.096221 -> V=1.0, theta=0.0
% INFO    : Bus 83290	: V=0.9969422, theta=-35.881647 -> V=1.0, theta=0.0
% INFO    : Bus 83291	: V=1.0028938, theta=-39.272119 -> V=1.0, theta=0.0
% INFO    : Bus 83292	: V=0.997872, theta=-39.2 -> V=1.0, theta=0.0
% INFO    : Bus 83293	: V=1.0119275, theta=-39.184662 -> V=1.0, theta=0.0
% INFO    : Bus 83294	: V=1.0119798, theta=-39.495397 -> V=1.0, theta=0.0
% INFO    : Bus 83295	: V=1.0121285, theta=-39.37179 -> V=1.0, theta=0.0
% INFO    : Bus 83296	: V=1.0114129, theta=-39.642827 -> V=1.0, theta=0.0
% INFO    : Bus 83297	: V=1.002284, theta=-40.421889 -> V=1.0, theta=0.0
% INFO    : Bus 83298	: V=1.0024037, theta=-41.0432 -> V=1.0, theta=0.0
% INFO    : Bus 83299	: V=1.0007399, theta=-37.943864 -> V=1.0, theta=0.0
% INFO    : Bus 83300	: V=0.9450983, theta=-56.641028 -> V=1.0, theta=0.0
% INFO    : Bus 83301	: V=0.9465674, theta=-58.940076 -> V=1.0, theta=0.0
% INFO    : Bus 83302	: V=0.9476656, theta=-58.228591 -> V=1.0, theta=0.0
% INFO    : Bus 83303	: V=0.9504397, theta=-56.539161 -> V=1.0, theta=0.0
% INFO    : Bus 83304	: V=0.942349, theta=-58.514445 -> V=1.0, theta=0.0
% INFO    : Bus 83305	: V=0.9570931, theta=-57.161556 -> V=1.0, theta=0.0
% INFO    : Bus 83306	: V=0.9986403, theta=-35.60867 -> V=1.0, theta=0.0
% INFO    : Bus 83307	: V=0.9848631, theta=-36.471609 -> V=1.0, theta=0.0
% INFO    : Bus 83308	: V=1.0025521, theta=-32.799933 -> V=1.0, theta=0.0
% INFO    : Bus 83309	: V=0.9711851, theta=-40.027072 -> V=1.0, theta=0.0
% INFO    : Bus 83310	: V=0.9660543, theta=-41.510394 -> V=1.0, theta=0.0
% INFO    : Bus 83311	: V=0.9694112, theta=-40.391993 -> V=1.0, theta=0.0
% INFO    : Bus 83312	: V=0.9661525, theta=-40.698843 -> V=1.0, theta=0.0
% INFO    : Bus 83313	: V=0.9995093, theta=-34.004332 -> V=1.0, theta=0.0
% INFO    : Bus 83314	: V=0.9910085, theta=-34.721698 -> V=1.0, theta=0.0
% INFO    : Bus 83315	: V=0.9889827, theta=-36.654486 -> V=1.0, theta=0.0
% INFO    : Bus 83316	: V=0.9950518, theta=-48.622841 -> V=1.0, theta=0.0
% INFO    : Bus 83317	: V=0.9893959, theta=-48.458089 -> V=1.0, theta=0.0
% INFO    : Bus 83318	: V=0.9868103, theta=-50.586745 -> V=1.0, theta=0.0
% INFO    : Bus 83319	: V=0.988133, theta=-50.476554 -> V=1.0, theta=0.0
% INFO    : Bus 83320	: V=0.9915822, theta=-50.077344 -> V=1.0, theta=0.0
% INFO    : Bus 83321	: V=0.9872098, theta=-50.599899 -> V=1.0, theta=0.0
% INFO    : Bus 83322	: V=0.9812896, theta=-51.035137 -> V=1.0, theta=0.0
% INFO    : Bus 83323	: V=0.9919779, theta=-49.721492 -> V=1.0, theta=0.0
% INFO    : Bus 83324	: V=0.970129, theta=-50.848094 -> V=1.0, theta=0.0
% INFO    : Bus 83325	: V=0.9692331, theta=-50.812814 -> V=1.0, theta=0.0
% INFO    : Bus 83326	: V=0.9684149, theta=-50.793875 -> V=1.0, theta=0.0
% INFO    : Bus 83327	: V=0.9697392, theta=-50.872914 -> V=1.0, theta=0.0
% INFO    : Bus 83328	: V=0.9714328, theta=-50.763014 -> V=1.0, theta=0.0
% INFO    : Bus 83329	: V=0.9654012, theta=-49.175225 -> V=1.0, theta=0.0
% INFO    : Bus 83330	: V=0.9726111, theta=-50.045602 -> V=1.0, theta=0.0
% INFO    : Bus 83331	: V=0.9902462, theta=-48.88264 -> V=1.0, theta=0.0
% INFO    : Bus 83332	: V=0.9900425, theta=-49.441787 -> V=1.0, theta=0.0
% INFO    : Bus 83333	: V=0.9760853, theta=-50.290218 -> V=1.0, theta=0.0
% INFO    : Bus 83334	: V=0.9738567, theta=-50.16343 -> V=1.0, theta=0.0
% INFO    : Bus 83335	: V=0.9692719, theta=-50.995557 -> V=1.0, theta=0.0
% INFO    : Bus 83336	: V=0.9777258, theta=-50.287644 -> V=1.0, theta=0.0
% INFO    : Bus 83337	: V=0.95468, theta=-51.746003 -> V=1.0, theta=0.0
% INFO    : Bus 83338	: V=0.9646592, theta=-52.318279 -> V=1.0, theta=0.0
% INFO    : Bus 83339	: V=0.975523, theta=-49.466405 -> V=1.0, theta=0.0
% INFO    : Bus 83340	: V=0.9678321, theta=-50.504304 -> V=1.0, theta=0.0
% INFO    : Bus 83341	: V=0.9685023, theta=-50.929202 -> V=1.0, theta=0.0
% INFO    : Bus 83342	: V=0.9868956, theta=-44.065768 -> V=1.0, theta=0.0
% INFO    : Bus 83343	: V=0.9888153, theta=-43.824239 -> V=1.0, theta=0.0
% INFO    : Bus 83344	: V=0.99488, theta=-43.639662 -> V=1.0, theta=0.0
% INFO    : Bus 83345	: V=0.9834689, theta=-44.483795 -> V=1.0, theta=0.0
% INFO    : Bus 83346	: V=0.9836037, theta=-44.49185 -> V=1.0, theta=0.0
% INFO    : Bus 83347	: V=0.9878427, theta=-44.540697 -> V=1.0, theta=0.0
% INFO    : Bus 83348	: V=0.988606, theta=-44.145702 -> V=1.0, theta=0.0
% INFO    : Bus 83349	: V=0.9883264, theta=-44.129147 -> V=1.0, theta=0.0
% INFO    : Bus 83350	: V=0.9843245, theta=-44.623008 -> V=1.0, theta=0.0
% INFO    : Bus 83351	: V=0.9834543, theta=-44.747838 -> V=1.0, theta=0.0
% INFO    : Bus 83352	: V=0.9954926, theta=-44.006353 -> V=1.0, theta=0.0
% INFO    : Bus 83353	: V=0.9888467, theta=-44.57861 -> V=1.0, theta=0.0
% INFO    : Bus 83354	: V=0.9956363, theta=-43.824793 -> V=1.0, theta=0.0
% INFO    : Bus 83355	: V=0.9974419, theta=-43.520964 -> V=1.0, theta=0.0
% INFO    : Bus 83356	: V=0.9956761, theta=-43.967402 -> V=1.0, theta=0.0
% INFO    : Bus 83357	: V=1.0046433, theta=-42.784311 -> V=1.0, theta=0.0
% INFO    : Bus 83358	: V=1.0037666, theta=-43.314037 -> V=1.0, theta=0.0
% INFO    : Bus 83359	: V=0.9880927, theta=-44.561938 -> V=1.0, theta=0.0
% INFO    : Bus 83360	: V=0.9924414, theta=-44.089003 -> V=1.0, theta=0.0
% INFO    : Bus 83361	: V=0.9883279, theta=-44.570404 -> V=1.0, theta=0.0
% INFO    : Bus 83362	: V=0.994369, theta=-44.317272 -> V=1.0, theta=0.0
% INFO    : Bus 83363	: V=0.9933863, theta=-44.400126 -> V=1.0, theta=0.0
% INFO    : Bus 83364	: V=0.9964606, theta=-44.449128 -> V=1.0, theta=0.0
% INFO    : Bus 83365	: V=0.9952451, theta=-44.465899 -> V=1.0, theta=0.0
% INFO    : Bus 83366	: V=0.9927121, theta=-44.467043 -> V=1.0, theta=0.0
% INFO    : Bus 83367	: V=0.9977323, theta=-44.55359 -> V=1.0, theta=0.0
% INFO    : Bus 83368	: V=0.9943906, theta=-44.374544 -> V=1.0, theta=0.0
% INFO    : Bus 83369	: V=1.006481, theta=-43.97981 -> V=1.0, theta=0.0
% INFO    : Bus 83370	: V=1.0081922, theta=-43.970453 -> V=1.0, theta=0.0
% INFO    : Bus 83371	: V=1.0058399, theta=-44.258456 -> V=1.0, theta=0.0
% INFO    : Bus 83372	: V=1.0041695, theta=-44.401297 -> V=1.0, theta=0.0
% INFO    : Bus 83373	: V=1.0063619, theta=-44.2467 -> V=1.0, theta=0.0
% INFO    : Bus 83374	: V=1.0065852, theta=-44.400571 -> V=1.0, theta=0.0
% INFO    : Bus 83375	: V=1.0087791, theta=-44.020455 -> V=1.0, theta=0.0
% INFO    : Bus 83376	: V=1.0043103, theta=-44.388796 -> V=1.0, theta=0.0
% INFO    : Bus 83377	: V=1.0035705, theta=-44.159125 -> V=1.0, theta=0.0
% INFO    : Bus 83378	: V=1.0005549, theta=-44.401182 -> V=1.0, theta=0.0
% INFO    : Bus 83379	: V=1.0004259, theta=-44.47835 -> V=1.0, theta=0.0
% INFO    : Bus 83380	: V=1.0030658, theta=-44.445129 -> V=1.0, theta=0.0
% INFO    : Bus 83381	: V=1.0023535, theta=-44.10563 -> V=1.0, theta=0.0
% INFO    : Bus 83382	: V=0.9997694, theta=-44.458491 -> V=1.0, theta=0.0
% INFO    : Bus 83383	: V=0.989719, theta=-45.001827 -> V=1.0, theta=0.0
% INFO    : Bus 83384	: V=0.9888841, theta=-44.847007 -> V=1.0, theta=0.0
% INFO    : Bus 83385	: V=0.9828752, theta=-45.012478 -> V=1.0, theta=0.0
% INFO    : Bus 83386	: V=0.9872007, theta=-44.781849 -> V=1.0, theta=0.0
% INFO    : Bus 83387	: V=0.9916946, theta=-44.803609 -> V=1.0, theta=0.0
% INFO    : Bus 83388	: V=0.9935382, theta=-44.767551 -> V=1.0, theta=0.0
% INFO    : Bus 83389	: V=0.9881901, theta=-44.644552 -> V=1.0, theta=0.0
% INFO    : Bus 83390	: V=0.9895033, theta=-45.041167 -> V=1.0, theta=0.0
% INFO    : Bus 83391	: V=0.9849051, theta=-45.255346 -> V=1.0, theta=0.0
% INFO    : Bus 83392	: V=0.9877575, theta=-45.142701 -> V=1.0, theta=0.0
% INFO    : Bus 83393	: V=0.9810287, theta=-45.20067 -> V=1.0, theta=0.0
% INFO    : Bus 83394	: V=0.9798845, theta=-45.409596 -> V=1.0, theta=0.0
% INFO    : Bus 83395	: V=0.9962681, theta=-43.54948 -> V=1.0, theta=0.0
% INFO    : Bus 83396	: V=0.9747808, theta=-44.437558 -> V=1.0, theta=0.0
% INFO    : Bus 83397	: V=0.9747075, theta=-45.373822 -> V=1.0, theta=0.0
% INFO    : Bus 83398	: V=0.9804154, theta=-45.246839 -> V=1.0, theta=0.0
% INFO    : Bus 83399	: V=0.9804515, theta=-45.374797 -> V=1.0, theta=0.0
% INFO    : Bus 83400	: V=0.9906765, theta=-44.756362 -> V=1.0, theta=0.0
% INFO    : Bus 83401	: V=0.9873998, theta=-45.054905 -> V=1.0, theta=0.0
% INFO    : Bus 83402	: V=0.9851449, theta=-45.354265 -> V=1.0, theta=0.0
% INFO    : Bus 83403	: V=0.9815417, theta=-45.436139 -> V=1.0, theta=0.0
% INFO    : Bus 83404	: V=0.9774677, theta=-45.483405 -> V=1.0, theta=0.0
% INFO    : Bus 83405	: V=0.9788082, theta=-45.305816 -> V=1.0, theta=0.0
% INFO    : Bus 83406	: V=0.9845159, theta=-45.073034 -> V=1.0, theta=0.0
% INFO    : Bus 83407	: V=0.9844846, theta=-45.082879 -> V=1.0, theta=0.0
% INFO    : Bus 83408	: V=0.9827912, theta=-45.240177 -> V=1.0, theta=0.0
% INFO    : Bus 83409	: V=0.9838058, theta=-45.186901 -> V=1.0, theta=0.0
% INFO    : Bus 83410	: V=0.9911332, theta=-44.630336 -> V=1.0, theta=0.0
% INFO    : Bus 83411	: V=0.9881273, theta=-44.937327 -> V=1.0, theta=0.0
% INFO    : Bus 83412	: V=1.0010048, theta=-43.51216 -> V=1.0, theta=0.0
% INFO    : Bus 83413	: V=0.9926896, theta=-44.650109 -> V=1.0, theta=0.0
% INFO    : Bus 83414	: V=0.9919194, theta=-44.777425 -> V=1.0, theta=0.0
% INFO    : Bus 83415	: V=0.9936731, theta=-44.668615 -> V=1.0, theta=0.0
% INFO    : Bus 83416	: V=0.9905258, theta=-45.181611 -> V=1.0, theta=0.0
% INFO    : Bus 83417	: V=0.9886282, theta=-45.20166 -> V=1.0, theta=0.0
% INFO    : Bus 83418	: V=0.9860477, theta=-45.30378 -> V=1.0, theta=0.0
% INFO    : Bus 83419	: V=0.9820737, theta=-45.5133 -> V=1.0, theta=0.0
% INFO    : Bus 83420	: V=0.9823563, theta=-45.826681 -> V=1.0, theta=0.0
% INFO    : Bus 83421	: V=0.9840798, theta=-45.657681 -> V=1.0, theta=0.0
% INFO    : Bus 83422	: V=0.9849867, theta=-45.639063 -> V=1.0, theta=0.0
% INFO    : Bus 83423	: V=0.9932777, theta=-44.792984 -> V=1.0, theta=0.0
% INFO    : Bus 83424	: V=0.9884145, theta=-45.64466 -> V=1.0, theta=0.0
% INFO    : Bus 83425	: V=0.9881551, theta=-45.872248 -> V=1.0, theta=0.0
% INFO    : Bus 83426	: V=0.994783, theta=-44.784573 -> V=1.0, theta=0.0
% INFO    : Bus 83427	: V=0.9943421, theta=-45.640185 -> V=1.0, theta=0.0
% INFO    : Bus 83428	: V=0.9947962, theta=-44.796812 -> V=1.0, theta=0.0
% INFO    : Bus 83429	: V=0.9911395, theta=-45.944755 -> V=1.0, theta=0.0
% INFO    : Bus 83430	: V=0.9839057, theta=-46.836619 -> V=1.0, theta=0.0
% INFO    : Bus 83431	: V=0.9827927, theta=-45.825198 -> V=1.0, theta=0.0
% INFO    : Bus 83432	: V=0.9854241, theta=-45.463489 -> V=1.0, theta=0.0
% INFO    : Bus 83433	: V=0.9815034, theta=-46.061932 -> V=1.0, theta=0.0
% INFO    : Bus 83434	: V=0.9812553, theta=-46.069231 -> V=1.0, theta=0.0
% INFO    : Bus 83435	: V=0.9872013, theta=-45.553425 -> V=1.0, theta=0.0
% INFO    : Bus 83436	: V=0.9803479, theta=-46.094373 -> V=1.0, theta=0.0
% INFO    : Bus 83437	: V=0.9883774, theta=-45.189329 -> V=1.0, theta=0.0
% INFO    : Bus 83438	: V=0.9841407, theta=-45.41717 -> V=1.0, theta=0.0
% INFO    : Bus 83439	: V=0.9877005, theta=-45.340333 -> V=1.0, theta=0.0
% INFO    : Bus 83440	: V=0.9866726, theta=-45.492943 -> V=1.0, theta=0.0
% INFO    : Bus 83441	: V=0.9844741, theta=-45.699618 -> V=1.0, theta=0.0
% INFO    : Bus 83442	: V=0.9811117, theta=-45.877691 -> V=1.0, theta=0.0
% INFO    : Bus 83443	: V=0.9794468, theta=-45.918314 -> V=1.0, theta=0.0
% INFO    : Bus 83444	: V=0.9799379, theta=-45.988811 -> V=1.0, theta=0.0
% INFO    : Bus 83445	: V=0.9772201, theta=-46.090524 -> V=1.0, theta=0.0
% INFO    : Bus 83446	: V=0.9802039, theta=-45.612287 -> V=1.0, theta=0.0
% INFO    : Bus 83447	: V=0.985705, theta=-45.585888 -> V=1.0, theta=0.0
% INFO    : Bus 83448	: V=0.9833486, theta=-45.82032 -> V=1.0, theta=0.0
% INFO    : Bus 83449	: V=1.0054712, theta=-44.113005 -> V=1.0, theta=0.0
% INFO    : Bus 83450	: V=1.0019233, theta=-44.521634 -> V=1.0, theta=0.0
% INFO    : Bus 83451	: V=0.9956931, theta=-44.45417 -> V=1.0, theta=0.0
% INFO    : Bus 83452	: V=0.9893316, theta=-44.956593 -> V=1.0, theta=0.0
% INFO    : Bus 83453	: V=0.9872154, theta=-45.232468 -> V=1.0, theta=0.0
% INFO    : Bus 83454	: V=0.9888315, theta=-45.175848 -> V=1.0, theta=0.0
% INFO    : Bus 83455	: V=0.9920907, theta=-45.095401 -> V=1.0, theta=0.0
% INFO    : Bus 83456	: V=0.9853543, theta=-45.509207 -> V=1.0, theta=0.0
% INFO    : Bus 83457	: V=0.98554, theta=-45.559778 -> V=1.0, theta=0.0
% INFO    : Bus 83458	: V=0.9897917, theta=-45.316019 -> V=1.0, theta=0.0
% INFO    : Bus 83459	: V=0.9913889, theta=-45.274784 -> V=1.0, theta=0.0
% INFO    : Bus 83460	: V=0.9990288, theta=-45.319879 -> V=1.0, theta=0.0
% INFO    : Bus 83461	: V=1.0052852, theta=-44.326889 -> V=1.0, theta=0.0
% INFO    : Bus 83462	: V=0.995407, theta=-45.360892 -> V=1.0, theta=0.0
% INFO    : Bus 83463	: V=1.0014442, theta=-44.659734 -> V=1.0, theta=0.0
% INFO    : Bus 83464	: V=0.9996932, theta=-44.727765 -> V=1.0, theta=0.0
% INFO    : Bus 83465	: V=1.0004265, theta=-45.247546 -> V=1.0, theta=0.0
% INFO    : Bus 83466	: V=0.9815444, theta=-45.56807 -> V=1.0, theta=0.0
% INFO    : Bus 83467	: V=1.0021569, theta=-45.217166 -> V=1.0, theta=0.0
% INFO    : Bus 83468	: V=0.9973593, theta=-45.507402 -> V=1.0, theta=0.0
% INFO    : Bus 83469	: V=0.9965245, theta=-45.553521 -> V=1.0, theta=0.0
% INFO    : Bus 83470	: V=0.9797387, theta=-45.980466 -> V=1.0, theta=0.0
% INFO    : Bus 83471	: V=0.9818543, theta=-45.929889 -> V=1.0, theta=0.0
% INFO    : Bus 83472	: V=0.9818691, theta=-45.97327 -> V=1.0, theta=0.0
% INFO    : Bus 83473	: V=0.9918835, theta=-45.356001 -> V=1.0, theta=0.0
% INFO    : Bus 83474	: V=0.9901966, theta=-45.67056 -> V=1.0, theta=0.0
% INFO    : Bus 83475	: V=0.9920123, theta=-45.741162 -> V=1.0, theta=0.0
% INFO    : Bus 83476	: V=0.9885038, theta=-45.8165 -> V=1.0, theta=0.0
% INFO    : Bus 83477	: V=0.9796943, theta=-46.545123 -> V=1.0, theta=0.0
% INFO    : Bus 83478	: V=0.9866759, theta=-46.132886 -> V=1.0, theta=0.0
% INFO    : Bus 83479	: V=0.9825811, theta=-47.189176 -> V=1.0, theta=0.0
% INFO    : Bus 83480	: V=0.984765, theta=-47.075382 -> V=1.0, theta=0.0
% INFO    : Bus 83481	: V=0.9846443, theta=-48.152063 -> V=1.0, theta=0.0
% INFO    : Bus 83482	: V=0.9949866, theta=-45.733525 -> V=1.0, theta=0.0
% INFO    : Bus 83483	: V=0.995159, theta=-46.160518 -> V=1.0, theta=0.0
% INFO    : Bus 83484	: V=1.0021256, theta=-45.631418 -> V=1.0, theta=0.0
% INFO    : Bus 83485	: V=0.9986239, theta=-46.004952 -> V=1.0, theta=0.0
% INFO    : Bus 83486	: V=0.9999478, theta=-45.580455 -> V=1.0, theta=0.0
% INFO    : Bus 83487	: V=1.0071254, theta=-45.015321 -> V=1.0, theta=0.0
% INFO    : Bus 83488	: V=1.0020104, theta=-45.540826 -> V=1.0, theta=0.0
% INFO    : Bus 83489	: V=0.9973536, theta=-45.629404 -> V=1.0, theta=0.0
% INFO    : Bus 83490	: V=0.9968745, theta=-45.6278 -> V=1.0, theta=0.0
% INFO    : Bus 83491	: V=0.9989093, theta=-45.985049 -> V=1.0, theta=0.0
% INFO    : Bus 83492	: V=0.9982221, theta=-44.601452 -> V=1.0, theta=0.0
% INFO    : Bus 83493	: V=1.0074708, theta=-44.182331 -> V=1.0, theta=0.0
% INFO    : Bus 83494	: V=1.0031828, theta=-44.555488 -> V=1.0, theta=0.0
% INFO    : Bus 83495	: V=1.0008722, theta=-44.629386 -> V=1.0, theta=0.0
% INFO    : Bus 83496	: V=0.9823424, theta=-32.522269 -> V=1.0, theta=0.0
% INFO    : Bus 83497	: V=0.9972073, theta=-31.191998 -> V=1.0, theta=0.0
% INFO    : Bus 83498	: V=0.9972275, theta=-31.472164 -> V=1.0, theta=0.0
% INFO    : Bus 83499	: V=1.0056716, theta=-43.006784 -> V=1.0, theta=0.0
% INFO    : Bus 83500	: V=1.007837, theta=-42.617795 -> V=1.0, theta=0.0
% INFO    : Bus 83501	: V=1.0019584, theta=-41.235644 -> V=1.0, theta=0.0
% INFO    : Bus 83502	: V=0.9899297, theta=-54.191652 -> V=1.0, theta=0.0
% INFO    : Bus 83503	: V=0.9922039, theta=-52.429042 -> V=1.0, theta=0.0
% INFO    : Bus 83504	: V=0.9914023, theta=-52.565984 -> V=1.0, theta=0.0
% INFO    : Bus 83505	: V=0.988114, theta=-53.206105 -> V=1.0, theta=0.0
% INFO    : Bus 83506	: V=0.9856874, theta=-53.45861 -> V=1.0, theta=0.0
% INFO    : Bus 83507	: V=0.9881389, theta=-53.186962 -> V=1.0, theta=0.0
% INFO    : Bus 83508	: V=1.0021545, theta=-50.750271 -> V=1.0, theta=0.0
% INFO    : Bus 83509	: V=0.997994, theta=-51.701441 -> V=1.0, theta=0.0
% INFO    : Bus 83510	: V=0.9971733, theta=-52.093993 -> V=1.0, theta=0.0
% INFO    : Bus 83511	: V=0.9850606, theta=-53.186002 -> V=1.0, theta=0.0
% INFO    : Bus 83512	: V=0.9858474, theta=-53.072828 -> V=1.0, theta=0.0
% INFO    : Bus 83513	: V=0.9886733, theta=-52.722794 -> V=1.0, theta=0.0
% INFO    : Bus 83514	: V=0.9932428, theta=-52.319826 -> V=1.0, theta=0.0
% INFO    : Bus 83515	: V=0.992684, theta=-52.382518 -> V=1.0, theta=0.0
% INFO    : Bus 83516	: V=0.9908054, theta=-52.55429 -> V=1.0, theta=0.0
% INFO    : Bus 83517	: V=0.9934851, theta=-52.293259 -> V=1.0, theta=0.0
% INFO    : Bus 83518	: V=0.9921461, theta=-52.489737 -> V=1.0, theta=0.0
% INFO    : Bus 83519	: V=0.991092, theta=-52.909993 -> V=1.0, theta=0.0
% INFO    : Bus 83520	: V=0.9931313, theta=-52.305982 -> V=1.0, theta=0.0
% INFO    : Bus 83521	: V=0.991244, theta=-52.871287 -> V=1.0, theta=0.0
% INFO    : Bus 83522	: V=0.9878605, theta=-56.477287 -> V=1.0, theta=0.0
% INFO    : Bus 83523	: V=0.9871336, theta=-57.439046 -> V=1.0, theta=0.0
% INFO    : Bus 83524	: V=0.9891801, theta=-57.142318 -> V=1.0, theta=0.0
% INFO    : Bus 83525	: V=0.9886182, theta=-56.383566 -> V=1.0, theta=0.0
% INFO    : Bus 83526	: V=0.9886816, theta=-53.332333 -> V=1.0, theta=0.0
% INFO    : Bus 83527	: V=1.0116168, theta=-51.03498 -> V=1.0, theta=0.0
% INFO    : Bus 83528	: V=1.0091612, theta=-51.362915 -> V=1.0, theta=0.0
% INFO    : Bus 83529	: V=1.0095709, theta=-51.291905 -> V=1.0, theta=0.0
% INFO    : Bus 83530	: V=1.0078874, theta=-51.398673 -> V=1.0, theta=0.0
% INFO    : Bus 83531	: V=1.0088644, theta=-51.334701 -> V=1.0, theta=0.0
% INFO    : Bus 83532	: V=1.0078942, theta=-51.410777 -> V=1.0, theta=0.0
% INFO    : Bus 83533	: V=1.0102073, theta=-51.113192 -> V=1.0, theta=0.0
% INFO    : Bus 83534	: V=0.9922548, theta=-53.791504 -> V=1.0, theta=0.0
% INFO    : Bus 83535	: V=0.9925331, theta=-52.593622 -> V=1.0, theta=0.0
% INFO    : Bus 83536	: V=1.0049641, theta=-42.533154 -> V=1.0, theta=0.0
% INFO    : Bus 83537	: V=1.009534, theta=-40.283538 -> V=1.0, theta=0.0
% INFO    : Bus 83538	: V=0.9996434, theta=-41.144841 -> V=1.0, theta=0.0
% INFO    : Bus 83539	: V=1.0177547, theta=-38.782128 -> V=1.0, theta=0.0
% INFO    : Bus 83540	: V=1.0103884, theta=-39.767355 -> V=1.0, theta=0.0
% INFO    : Bus 83541	: V=1.003009, theta=-40.754434 -> V=1.0, theta=0.0
% INFO    : Bus 83542	: V=0.964366, theta=-55.070326 -> V=1.0, theta=0.0
% INFO    : Bus 83543	: V=0.9631691, theta=-57.022828 -> V=1.0, theta=0.0
% INFO    : Bus 83544	: V=0.9624916, theta=-57.037922 -> V=1.0, theta=0.0
% INFO    : Bus 83545	: V=0.9644987, theta=-55.293231 -> V=1.0, theta=0.0
% INFO    : Bus 83546	: V=0.9629462, theta=-57.024491 -> V=1.0, theta=0.0
% INFO    : Bus 83547	: V=1.0150296, theta=-40.802221 -> V=1.0, theta=0.0
% INFO    : Bus 83548	: V=1.0131326, theta=-41.136593 -> V=1.0, theta=0.0
% INFO    : Bus 83549	: V=1.0029951, theta=-43.540357 -> V=1.0, theta=0.0
% INFO    : Bus 83550	: V=1.0034821, theta=-42.832851 -> V=1.0, theta=0.0
% INFO    : Bus 83551	: V=1.0135609, theta=-41.137933 -> V=1.0, theta=0.0
% INFO    : Bus 83552	: V=1.012235, theta=-41.030858 -> V=1.0, theta=0.0
% INFO    : Bus 83553	: V=1.0094108, theta=-41.378808 -> V=1.0, theta=0.0
% INFO    : Bus 83554	: V=0.9977314, theta=-43.385799 -> V=1.0, theta=0.0
% INFO    : Bus 83555	: V=1.0093539, theta=-41.054463 -> V=1.0, theta=0.0
% INFO    : Bus 83556	: V=0.9980863, theta=-42.19715 -> V=1.0, theta=0.0
% INFO    : Bus 83557	: V=0.9944819, theta=-48.789363 -> V=1.0, theta=0.0
% INFO    : Bus 83558	: V=0.9943805, theta=-48.685701 -> V=1.0, theta=0.0
% INFO    : Bus 83559	: V=0.986563, theta=-49.226771 -> V=1.0, theta=0.0
% INFO    : Bus 83560	: V=0.9858678, theta=-49.225662 -> V=1.0, theta=0.0
% INFO    : Bus 83561	: V=0.9966969, theta=-47.577921 -> V=1.0, theta=0.0
% INFO    : Bus 83562	: V=1.0023716, theta=-46.331508 -> V=1.0, theta=0.0
% INFO    : Bus 83563	: V=0.9822499, theta=-48.889384 -> V=1.0, theta=0.0
% INFO    : Bus 83564	: V=0.9821657, theta=-49.042392 -> V=1.0, theta=0.0
% INFO    : Bus 83565	: V=0.9784889, theta=-49.267386 -> V=1.0, theta=0.0
% INFO    : Bus 83566	: V=0.9835699, theta=-48.807268 -> V=1.0, theta=0.0
% INFO    : Bus 83567	: V=0.9804022, theta=-49.111715 -> V=1.0, theta=0.0
% INFO    : Bus 83568	: V=0.9832871, theta=-48.534498 -> V=1.0, theta=0.0
% INFO    : Bus 83569	: V=0.9860897, theta=-49.257219 -> V=1.0, theta=0.0
% INFO    : Bus 83570	: V=0.9851248, theta=-49.116402 -> V=1.0, theta=0.0
% INFO    : Bus 83571	: V=0.9887948, theta=-48.616132 -> V=1.0, theta=0.0
% INFO    : Bus 83572	: V=0.9867634, theta=-49.076412 -> V=1.0, theta=0.0
% INFO    : Bus 83573	: V=1.0011431, theta=-48.315251 -> V=1.0, theta=0.0
% INFO    : Bus 83574	: V=0.9853059, theta=-49.406254 -> V=1.0, theta=0.0
% INFO    : Bus 83575	: V=0.9955135, theta=-48.64527 -> V=1.0, theta=0.0
% INFO    : Bus 83576	: V=0.9870882, theta=-48.699335 -> V=1.0, theta=0.0
% INFO    : Bus 83577	: V=0.9863291, theta=-48.802811 -> V=1.0, theta=0.0
% INFO    : Bus 83578	: V=0.9835229, theta=-49.400174 -> V=1.0, theta=0.0
% INFO    : Bus 83579	: V=0.9841839, theta=-49.303332 -> V=1.0, theta=0.0
% INFO    : Bus 83580	: V=0.9764225, theta=-49.84582 -> V=1.0, theta=0.0
% INFO    : Bus 83581	: V=0.9996612, theta=-48.573926 -> V=1.0, theta=0.0
% INFO    : Bus 83582	: V=0.9902702, theta=-49.77394 -> V=1.0, theta=0.0
% INFO    : Bus 83583	: V=1.0004842, theta=-48.715181 -> V=1.0, theta=0.0
% INFO    : Bus 83584	: V=0.9982499, theta=-48.939553 -> V=1.0, theta=0.0
% INFO    : Bus 83585	: V=0.9959014, theta=-49.720094 -> V=1.0, theta=0.0
% INFO    : Bus 83586	: V=0.9988087, theta=-49.110772 -> V=1.0, theta=0.0
% INFO    : Bus 83587	: V=0.996289, theta=-49.597577 -> V=1.0, theta=0.0
% INFO    : Bus 83588	: V=0.9958717, theta=-49.5955 -> V=1.0, theta=0.0
% INFO    : Bus 83589	: V=1.0003045, theta=-49.018514 -> V=1.0, theta=0.0
% INFO    : Bus 83590	: V=0.9956416, theta=-49.604535 -> V=1.0, theta=0.0
% INFO    : Bus 83591	: V=0.9987816, theta=-49.041745 -> V=1.0, theta=0.0
% INFO    : Bus 83592	: V=0.9974755, theta=-49.198004 -> V=1.0, theta=0.0
% INFO    : Bus 83593	: V=0.9983929, theta=-49.166377 -> V=1.0, theta=0.0
% INFO    : Bus 83594	: V=0.9964545, theta=-49.615112 -> V=1.0, theta=0.0
% INFO    : Bus 83595	: V=0.9963894, theta=-48.699055 -> V=1.0, theta=0.0
% INFO    : Bus 83596	: V=1.0019128, theta=-48.90573 -> V=1.0, theta=0.0
% INFO    : Bus 83597	: V=0.9825235, theta=-51.368323 -> V=1.0, theta=0.0
% INFO    : Bus 83598	: V=0.98381, theta=-51.339238 -> V=1.0, theta=0.0
% INFO    : Bus 83599	: V=0.9847022, theta=-49.297136 -> V=1.0, theta=0.0
% INFO    : Bus 83600	: V=0.9513503, theta=-56.856875 -> V=1.0, theta=0.0
% INFO    : Bus 83601	: V=0.954209, theta=-56.647103 -> V=1.0, theta=0.0
% INFO    : Bus 83602	: V=0.9598866, theta=-56.402641 -> V=1.0, theta=0.0
% INFO    : Bus 83603	: V=0.9640641, theta=-54.768025 -> V=1.0, theta=0.0
% INFO    : Bus 83604	: V=0.9683274, theta=-54.127005 -> V=1.0, theta=0.0
% INFO    : Bus 83605	: V=0.9665634, theta=-54.344637 -> V=1.0, theta=0.0
% INFO    : Bus 83606	: V=0.9655141, theta=-54.564658 -> V=1.0, theta=0.0
% INFO    : Bus 83607	: V=0.9628446, theta=-55.059242 -> V=1.0, theta=0.0
% INFO    : Bus 83608	: V=0.9667712, theta=-54.154846 -> V=1.0, theta=0.0
% INFO    : Bus 83609	: V=0.9708921, theta=-53.944773 -> V=1.0, theta=0.0
% INFO    : Bus 83610	: V=0.96291, theta=-55.101399 -> V=1.0, theta=0.0
% INFO    : Bus 83611	: V=0.9679381, theta=-54.451179 -> V=1.0, theta=0.0
% INFO    : Bus 83612	: V=0.963797, theta=-55.230035 -> V=1.0, theta=0.0
% INFO    : Bus 83613	: V=0.9622504, theta=-54.369959 -> V=1.0, theta=0.0
% INFO    : Bus 83614	: V=0.9682225, theta=-53.715633 -> V=1.0, theta=0.0
% INFO    : Bus 83615	: V=0.9677261, theta=-53.882018 -> V=1.0, theta=0.0
% INFO    : Bus 83616	: V=0.9638513, theta=-54.889259 -> V=1.0, theta=0.0
% INFO    : Bus 83617	: V=0.9842747, theta=-47.25944 -> V=1.0, theta=0.0
% INFO    : Bus 83618	: V=0.9855171, theta=-47.883491 -> V=1.0, theta=0.0
% INFO    : Bus 83619	: V=0.9886918, theta=-48.027511 -> V=1.0, theta=0.0
% INFO    : Bus 83620	: V=0.9883161, theta=-47.977369 -> V=1.0, theta=0.0
% INFO    : Bus 83621	: V=0.9883038, theta=-47.949016 -> V=1.0, theta=0.0
% INFO    : Bus 83622	: V=0.9855122, theta=-48.175402 -> V=1.0, theta=0.0
% INFO    : Bus 83623	: V=0.9890883, theta=-47.809774 -> V=1.0, theta=0.0
% INFO    : Bus 83624	: V=0.9872032, theta=-48.045043 -> V=1.0, theta=0.0
% INFO    : Bus 83625	: V=0.9912464, theta=-47.664524 -> V=1.0, theta=0.0
% INFO    : Bus 83626	: V=0.9950231, theta=-46.91465 -> V=1.0, theta=0.0
% INFO    : Bus 83627	: V=0.9927037, theta=-47.411088 -> V=1.0, theta=0.0
% INFO    : Bus 83628	: V=0.9846839, theta=-48.111313 -> V=1.0, theta=0.0
% INFO    : Bus 83629	: V=0.9848835, theta=-46.699464 -> V=1.0, theta=0.0
% INFO    : Bus 83630	: V=0.9921187, theta=-46.678022 -> V=1.0, theta=0.0
% INFO    : Bus 83631	: V=1.0007714, theta=-46.042268 -> V=1.0, theta=0.0
% INFO    : Bus 83632	: V=0.9984315, theta=-46.432934 -> V=1.0, theta=0.0
% INFO    : Bus 83633	: V=0.9938101, theta=-47.183644 -> V=1.0, theta=0.0
% INFO    : Bus 83634	: V=0.9955528, theta=-46.572196 -> V=1.0, theta=0.0
% INFO    : Bus 83635	: V=1.0122407, theta=-44.004445 -> V=1.0, theta=0.0
% INFO    : Bus 83636	: V=0.9856001, theta=-48.603957 -> V=1.0, theta=0.0
% INFO    : Bus 83637	: V=0.9854705, theta=-48.357718 -> V=1.0, theta=0.0
% INFO    : Bus 83638	: V=0.9850276, theta=-48.059254 -> V=1.0, theta=0.0
% INFO    : Bus 83639	: V=0.9780732, theta=-48.99364 -> V=1.0, theta=0.0
% INFO    : Bus 83640	: V=0.9829254, theta=-48.058573 -> V=1.0, theta=0.0
% INFO    : Bus 83641	: V=0.9857488, theta=-49.271709 -> V=1.0, theta=0.0
% INFO    : Bus 83642	: V=0.9884774, theta=-48.892738 -> V=1.0, theta=0.0
% INFO    : Bus 83643	: V=0.9865911, theta=-49.356372 -> V=1.0, theta=0.0
% INFO    : Bus 83644	: V=0.9811959, theta=-50.573111 -> V=1.0, theta=0.0
% INFO    : Bus 83645	: V=0.985114, theta=-50.703404 -> V=1.0, theta=0.0
% INFO    : Bus 83646	: V=0.9812626, theta=-51.128805 -> V=1.0, theta=0.0
% INFO    : Bus 83647	: V=0.9795469, theta=-51.34153 -> V=1.0, theta=0.0
% INFO    : Bus 83648	: V=0.994555, theta=-48.210128 -> V=1.0, theta=0.0
% INFO    : Bus 83649	: V=0.9944746, theta=-48.86415 -> V=1.0, theta=0.0
% INFO    : Bus 83650	: V=0.9987566, theta=-47.347429 -> V=1.0, theta=0.0
% INFO    : Bus 83651	: V=1.0051843, theta=-46.268463 -> V=1.0, theta=0.0
% INFO    : Bus 83652	: V=1.0034413, theta=-46.304751 -> V=1.0, theta=0.0
% INFO    : Bus 83653	: V=1.0104959, theta=-44.951449 -> V=1.0, theta=0.0
% INFO    : Bus 83654	: V=1.0017563, theta=-46.199039 -> V=1.0, theta=0.0
% INFO    : Bus 83655	: V=1.0051554, theta=-45.77628 -> V=1.0, theta=0.0
% INFO    : Bus 83656	: V=1.0036281, theta=-49.612829 -> V=1.0, theta=0.0
% INFO    : Bus 83657	: V=1.0071462, theta=-49.200711 -> V=1.0, theta=0.0
% INFO    : Bus 83658	: V=1.0149724, theta=-47.266576 -> V=1.0, theta=0.0
% INFO    : Bus 83659	: V=1.0079892, theta=-49.087195 -> V=1.0, theta=0.0
% INFO    : Bus 83660	: V=0.9964924, theta=-49.797219 -> V=1.0, theta=0.0
% INFO    : Bus 83661	: V=1.0123576, theta=-47.863344 -> V=1.0, theta=0.0
% INFO    : Bus 83662	: V=1.0123272, theta=-47.499427 -> V=1.0, theta=0.0
% INFO    : Bus 83663	: V=1.0060706, theta=-47.038743 -> V=1.0, theta=0.0
% INFO    : Bus 83664	: V=0.9610754, theta=-60.962892 -> V=1.0, theta=0.0
% INFO    : Bus 83665	: V=0.9674061, theta=-60.096378 -> V=1.0, theta=0.0
% INFO    : Bus 83666	: V=0.9784489, theta=-59.158942 -> V=1.0, theta=0.0
% INFO    : Bus 83667	: V=0.9821548, theta=-58.654216 -> V=1.0, theta=0.0
% INFO    : Bus 83668	: V=0.9885714, theta=-58.351766 -> V=1.0, theta=0.0
% INFO    : Bus 83669	: V=0.9873523, theta=-57.126267 -> V=1.0, theta=0.0
% INFO    : Bus 83670	: V=0.9906101, theta=-56.849801 -> V=1.0, theta=0.0
% INFO    : Bus 83671	: V=0.9884215, theta=-57.087963 -> V=1.0, theta=0.0
% INFO    : Bus 83672	: V=0.9881979, theta=-58.647378 -> V=1.0, theta=0.0
% INFO    : Bus 83673	: V=0.9893057, theta=-58.266693 -> V=1.0, theta=0.0
% INFO    : Bus 83674	: V=0.9859808, theta=-57.438276 -> V=1.0, theta=0.0
% INFO    : Bus 83675	: V=0.9914433, theta=-56.493415 -> V=1.0, theta=0.0
% INFO    : Bus 83676	: V=0.9896217, theta=-56.987265 -> V=1.0, theta=0.0
% INFO    : Bus 83677	: V=0.9931373, theta=-56.333163 -> V=1.0, theta=0.0
% INFO    : Bus 83678	: V=0.9895879, theta=-56.992367 -> V=1.0, theta=0.0
% INFO    : Bus 83679	: V=0.9859689, theta=-57.276611 -> V=1.0, theta=0.0
% INFO    : Bus 83680	: V=0.9922026, theta=-56.533486 -> V=1.0, theta=0.0
% INFO    : Bus 83681	: V=0.9883161, theta=-57.024289 -> V=1.0, theta=0.0
% INFO    : Bus 83682	: V=0.988577, theta=-56.928719 -> V=1.0, theta=0.0
% INFO    : Bus 83683	: V=0.9916705, theta=-56.451903 -> V=1.0, theta=0.0
% INFO    : Bus 83684	: V=0.991516, theta=-56.452785 -> V=1.0, theta=0.0
% INFO    : Bus 83685	: V=0.9907999, theta=-56.836129 -> V=1.0, theta=0.0
% INFO    : Bus 83686	: V=0.9872977, theta=-57.303667 -> V=1.0, theta=0.0
% INFO    : Bus 83687	: V=0.9861699, theta=-57.530538 -> V=1.0, theta=0.0
% INFO    : Bus 83688	: V=0.986164, theta=-57.57541 -> V=1.0, theta=0.0
% INFO    : Bus 83689	: V=0.9860461, theta=-57.732692 -> V=1.0, theta=0.0
% INFO    : Bus 83690	: V=0.9855606, theta=-57.368938 -> V=1.0, theta=0.0
% INFO    : Bus 83691	: V=0.9872411, theta=-57.044808 -> V=1.0, theta=0.0
% INFO    : Bus 83692	: V=0.984303, theta=-57.1172 -> V=1.0, theta=0.0
% INFO    : Bus 83693	: V=0.9859534, theta=-57.006395 -> V=1.0, theta=0.0
% INFO    : Bus 83694	: V=0.9881255, theta=-56.862822 -> V=1.0, theta=0.0
% INFO    : Bus 83695	: V=0.9878149, theta=-56.855468 -> V=1.0, theta=0.0
% INFO    : Bus 83696	: V=0.9828613, theta=-57.103818 -> V=1.0, theta=0.0
% INFO    : Bus 83697	: V=0.9836431, theta=-57.092554 -> V=1.0, theta=0.0
% INFO    : Bus 83698	: V=0.9834096, theta=-56.991925 -> V=1.0, theta=0.0
% INFO    : Bus 83699	: V=0.986467, theta=-57.37449 -> V=1.0, theta=0.0
% INFO    : Bus 83700	: V=0.986914, theta=-56.564985 -> V=1.0, theta=0.0
% INFO    : Bus 83701	: V=0.9894405, theta=-55.708773 -> V=1.0, theta=0.0
% INFO    : Bus 83702	: V=0.9868379, theta=-56.333121 -> V=1.0, theta=0.0
% INFO    : Bus 83703	: V=0.9960665, theta=-54.725243 -> V=1.0, theta=0.0
% INFO    : Bus 83704	: V=0.9919537, theta=-55.247553 -> V=1.0, theta=0.0
% INFO    : Bus 83705	: V=0.9970916, theta=-54.621889 -> V=1.0, theta=0.0
% INFO    : Bus 83706	: V=0.9943313, theta=-54.953867 -> V=1.0, theta=0.0
% INFO    : Bus 83707	: V=0.9906457, theta=-55.765563 -> V=1.0, theta=0.0
% INFO    : Bus 83708	: V=0.9861906, theta=-56.333061 -> V=1.0, theta=0.0
% INFO    : Bus 83709	: V=0.9813763, theta=-57.140179 -> V=1.0, theta=0.0
% INFO    : Bus 83710	: V=0.9815167, theta=-57.075864 -> V=1.0, theta=0.0
% INFO    : Bus 83711	: V=0.9821719, theta=-56.583833 -> V=1.0, theta=0.0
% INFO    : Bus 83712	: V=0.9790312, theta=-57.345414 -> V=1.0, theta=0.0
% INFO    : Bus 83713	: V=0.9858695, theta=-57.446937 -> V=1.0, theta=0.0
% INFO    : Bus 83714	: V=0.9806922, theta=-57.295543 -> V=1.0, theta=0.0
% INFO    : Bus 83715	: V=0.9782861, theta=-57.486857 -> V=1.0, theta=0.0
% INFO    : Bus 83716	: V=0.9822613, theta=-57.584031 -> V=1.0, theta=0.0
% INFO    : Bus 83717	: V=0.9788105, theta=-57.669174 -> V=1.0, theta=0.0
% INFO    : Bus 83718	: V=0.9887863, theta=-59.019407 -> V=1.0, theta=0.0
% INFO    : Bus 83719	: V=0.989267, theta=-57.235989 -> V=1.0, theta=0.0
% INFO    : Bus 83720	: V=0.9886072, theta=-58.630773 -> V=1.0, theta=0.0
% INFO    : Bus 83721	: V=0.9877446, theta=-58.825145 -> V=1.0, theta=0.0
% INFO    : Bus 83722	: V=0.9879147, theta=-59.200571 -> V=1.0, theta=0.0
% INFO    : Bus 83723	: V=0.986354, theta=-59.267915 -> V=1.0, theta=0.0
% INFO    : Bus 83724	: V=0.9858117, theta=-56.19684 -> V=1.0, theta=0.0
% INFO    : Bus 83725	: V=0.9837182, theta=-56.822635 -> V=1.0, theta=0.0
% INFO    : Bus 83726	: V=0.9773707, theta=-57.376539 -> V=1.0, theta=0.0
% INFO    : Bus 83727	: V=0.9804502, theta=-58.130695 -> V=1.0, theta=0.0
% INFO    : Bus 83728	: V=0.9799331, theta=-58.433833 -> V=1.0, theta=0.0
% INFO    : Bus 83729	: V=0.9784788, theta=-58.058606 -> V=1.0, theta=0.0
% INFO    : Bus 83730	: V=0.9873376, theta=-59.337521 -> V=1.0, theta=0.0
% INFO    : Bus 83731	: V=0.983382, theta=-58.086707 -> V=1.0, theta=0.0
% INFO    : Bus 83732	: V=0.98392, theta=-57.501231 -> V=1.0, theta=0.0
% INFO    : Bus 83733	: V=0.9840145, theta=-58.27357 -> V=1.0, theta=0.0
% INFO    : Bus 83734	: V=0.9853604, theta=-57.232916 -> V=1.0, theta=0.0
% INFO    : Bus 83735	: V=0.9854357, theta=-57.728944 -> V=1.0, theta=0.0
% INFO    : Bus 83736	: V=0.9865662, theta=-58.788864 -> V=1.0, theta=0.0
% INFO    : Bus 83737	: V=0.9886621, theta=-58.180716 -> V=1.0, theta=0.0
% INFO    : Bus 83738	: V=0.986351, theta=-59.270873 -> V=1.0, theta=0.0
% INFO    : Bus 83739	: V=0.9860996, theta=-59.212561 -> V=1.0, theta=0.0
% INFO    : Bus 83740	: V=0.9846299, theta=-56.570363 -> V=1.0, theta=0.0
% INFO    : Bus 83741	: V=0.9987328, theta=-54.394731 -> V=1.0, theta=0.0
% INFO    : Bus 83742	: V=0.9991005, theta=-54.332171 -> V=1.0, theta=0.0
% INFO    : Bus 83743	: V=0.9963122, theta=-54.692159 -> V=1.0, theta=0.0
% INFO    : Bus 83744	: V=0.9958967, theta=-54.6823 -> V=1.0, theta=0.0
% INFO    : Bus 83745	: V=0.9909163, theta=-55.200274 -> V=1.0, theta=0.0
% INFO    : Bus 83746	: V=0.986219, theta=-55.991979 -> V=1.0, theta=0.0
% INFO    : Bus 83747	: V=0.9872953, theta=-55.93446 -> V=1.0, theta=0.0
% INFO    : Bus 83748	: V=0.9856057, theta=-57.55771 -> V=1.0, theta=0.0
% INFO    : Bus 83749	: V=0.986261, theta=-56.666703 -> V=1.0, theta=0.0
% INFO    : Bus 83750	: V=0.9845918, theta=-57.430375 -> V=1.0, theta=0.0
% INFO    : Bus 83751	: V=0.9846, theta=-57.62316 -> V=1.0, theta=0.0
% INFO    : Bus 83752	: V=0.9818496, theta=-56.377909 -> V=1.0, theta=0.0
% INFO    : Bus 83753	: V=0.985969, theta=-57.634103 -> V=1.0, theta=0.0
% INFO    : Bus 83754	: V=0.9852323, theta=-57.760668 -> V=1.0, theta=0.0
% INFO    : Bus 83755	: V=0.987463, theta=-58.775839 -> V=1.0, theta=0.0
% INFO    : Bus 83756	: V=0.989094, theta=-58.684339 -> V=1.0, theta=0.0
% INFO    : Bus 83757	: V=0.9884488, theta=-58.527079 -> V=1.0, theta=0.0
% INFO    : Bus 83758	: V=0.9893448, theta=-58.324732 -> V=1.0, theta=0.0
% INFO    : Bus 83759	: V=0.9887528, theta=-58.373653 -> V=1.0, theta=0.0
% INFO    : Bus 83760	: V=0.9785809, theta=-56.815719 -> V=1.0, theta=0.0
% INFO    : Bus 83761	: V=0.9797262, theta=-57.866192 -> V=1.0, theta=0.0
% INFO    : Bus 83762	: V=0.9843832, theta=-57.651828 -> V=1.0, theta=0.0
% INFO    : Bus 83763	: V=0.9829079, theta=-57.938998 -> V=1.0, theta=0.0
% INFO    : Bus 83764	: V=0.9792004, theta=-56.455426 -> V=1.0, theta=0.0
% INFO    : Bus 83765	: V=0.9747028, theta=-56.732824 -> V=1.0, theta=0.0
% INFO    : Bus 83766	: V=0.9830891, theta=-59.608293 -> V=1.0, theta=0.0
% INFO    : Bus 83767	: V=0.9927874, theta=-58.513925 -> V=1.0, theta=0.0
% INFO    : Bus 83768	: V=0.9915025, theta=-58.738274 -> V=1.0, theta=0.0
% INFO    : Bus 83769	: V=0.9917735, theta=-58.700218 -> V=1.0, theta=0.0
% INFO    : Bus 83770	: V=0.9911405, theta=-58.770934 -> V=1.0, theta=0.0
% INFO    : Bus 83771	: V=0.9884495, theta=-59.201922 -> V=1.0, theta=0.0
% INFO    : Bus 83772	: V=0.9838421, theta=-59.145036 -> V=1.0, theta=0.0
% INFO    : Bus 83773	: V=0.9840973, theta=-58.837815 -> V=1.0, theta=0.0
% INFO    : Bus 83774	: V=0.9839242, theta=-58.727402 -> V=1.0, theta=0.0
% INFO    : Bus 83775	: V=0.9884711, theta=-59.136871 -> V=1.0, theta=0.0
% INFO    : Bus 83776	: V=0.987433, theta=-58.192441 -> V=1.0, theta=0.0
% INFO    : Bus 83777	: V=0.9859798, theta=-58.750458 -> V=1.0, theta=0.0
% INFO    : Bus 83778	: V=0.9868085, theta=-57.652481 -> V=1.0, theta=0.0
% INFO    : Bus 83779	: V=0.9862952, theta=-57.921944 -> V=1.0, theta=0.0
% INFO    : Bus 83780	: V=0.9865928, theta=-57.913698 -> V=1.0, theta=0.0
% INFO    : Bus 83781	: V=0.986919, theta=-58.414296 -> V=1.0, theta=0.0
% INFO    : Bus 83782	: V=0.986299, theta=-58.584499 -> V=1.0, theta=0.0
% INFO    : Bus 83783	: V=0.9851473, theta=-59.174075 -> V=1.0, theta=0.0
% INFO    : Bus 83784	: V=0.986194, theta=-58.779491 -> V=1.0, theta=0.0
% INFO    : Bus 83785	: V=0.9839546, theta=-58.743984 -> V=1.0, theta=0.0
% INFO    : Bus 83786	: V=0.9851739, theta=-58.561989 -> V=1.0, theta=0.0
% INFO    : Bus 83787	: V=0.9857355, theta=-58.764256 -> V=1.0, theta=0.0
% INFO    : Bus 83788	: V=0.9806273, theta=-56.655064 -> V=1.0, theta=0.0
% INFO    : Bus 83789	: V=0.9871725, theta=-56.741734 -> V=1.0, theta=0.0
% INFO    : Bus 83790	: V=0.9872796, theta=-57.531836 -> V=1.0, theta=0.0
% INFO    : Bus 83791	: V=0.9796558, theta=-57.116468 -> V=1.0, theta=0.0
% INFO    : Bus 83792	: V=0.982415, theta=-57.370017 -> V=1.0, theta=0.0
% INFO    : Bus 83793	: V=0.9786071, theta=-58.101886 -> V=1.0, theta=0.0
% INFO    : Bus 83794	: V=0.9788214, theta=-58.702001 -> V=1.0, theta=0.0
% INFO    : Bus 83795	: V=0.9796297, theta=-56.788158 -> V=1.0, theta=0.0
% INFO    : Bus 83796	: V=0.9840928, theta=-59.68963 -> V=1.0, theta=0.0
% INFO    : Bus 83797	: V=0.9862738, theta=-58.215741 -> V=1.0, theta=0.0
% INFO    : Bus 83798	: V=0.9851228, theta=-59.44965 -> V=1.0, theta=0.0
% INFO    : Bus 83799	: V=0.9789636, theta=-57.77808 -> V=1.0, theta=0.0
% INFO    : Bus 83800	: V=0.9920025, theta=-58.67428 -> V=1.0, theta=0.0
% INFO    : Bus 83801	: V=0.9916064, theta=-58.840792 -> V=1.0, theta=0.0
% INFO    : Bus 83802	: V=0.9946362, theta=-58.196017 -> V=1.0, theta=0.0
% INFO    : Bus 83803	: V=0.9892352, theta=-59.019432 -> V=1.0, theta=0.0
% INFO    : Bus 83804	: V=0.9872752, theta=-56.69136 -> V=1.0, theta=0.0
% INFO    : Bus 83805	: V=0.9808142, theta=-58.46795 -> V=1.0, theta=0.0
% INFO    : Bus 83806	: V=0.9821651, theta=-56.07022 -> V=1.0, theta=0.0
% INFO    : Bus 83807	: V=0.9922635, theta=-54.588546 -> V=1.0, theta=0.0
% INFO    : Bus 83808	: V=0.9873033, theta=-56.518031 -> V=1.0, theta=0.0
% INFO    : Bus 83809	: V=0.9878132, theta=-57.000218 -> V=1.0, theta=0.0
% INFO    : Bus 83810	: V=0.9828416, theta=-59.63426 -> V=1.0, theta=0.0
% INFO    : Bus 83811	: V=0.9831225, theta=-54.758209 -> V=1.0, theta=0.0
% INFO    : Bus 83812	: V=0.97504, theta=-54.269605 -> V=1.0, theta=0.0
% INFO    : Bus 83813	: V=1.0071073, theta=-54.160057 -> V=1.0, theta=0.0
% INFO    : Bus 83814	: V=0.9949017, theta=-55.841568 -> V=1.0, theta=0.0
% INFO    : Bus 83815	: V=0.9986493, theta=-55.109627 -> V=1.0, theta=0.0
% INFO    : Bus 83816	: V=0.9671794, theta=-56.419303 -> V=1.0, theta=0.0
% INFO    : Bus 83817	: V=0.97146, theta=-56.15854 -> V=1.0, theta=0.0
% INFO    : Bus 83818	: V=0.9753862, theta=-54.712013 -> V=1.0, theta=0.0
% INFO    : Bus 83819	: V=0.9723143, theta=-55.928861 -> V=1.0, theta=0.0
% INFO    : Bus 83820	: V=0.9706822, theta=-56.001325 -> V=1.0, theta=0.0
% INFO    : Bus 83821	: V=0.9653728, theta=-55.913398 -> V=1.0, theta=0.0
% INFO    : Bus 83822	: V=0.9678349, theta=-55.990243 -> V=1.0, theta=0.0
% INFO    : Bus 83823	: V=0.9640803, theta=-56.535115 -> V=1.0, theta=0.0
% INFO    : Bus 83824	: V=0.9618929, theta=-56.414113 -> V=1.0, theta=0.0
% INFO    : Bus 83825	: V=0.9711094, theta=-54.544408 -> V=1.0, theta=0.0
% INFO    : Bus 83826	: V=0.971003, theta=-55.151886 -> V=1.0, theta=0.0
% INFO    : Bus 83827	: V=0.9757224, theta=-54.508035 -> V=1.0, theta=0.0
% INFO    : Bus 83828	: V=0.9623526, theta=-56.206218 -> V=1.0, theta=0.0
% INFO    : Bus 83829	: V=0.9988338, theta=-55.488543 -> V=1.0, theta=0.0
% INFO    : Bus 83830	: V=1.0028643, theta=-54.707444 -> V=1.0, theta=0.0
% INFO    : Bus 83831	: V=1.004393, theta=-53.467652 -> V=1.0, theta=0.0
% INFO    : Bus 83832	: V=0.9975023, theta=-54.62688 -> V=1.0, theta=0.0
% INFO    : Bus 83833	: V=0.9977288, theta=-54.647375 -> V=1.0, theta=0.0
% INFO    : Bus 83834	: V=1.0026059, theta=-53.890252 -> V=1.0, theta=0.0
% INFO    : Bus 83835	: V=0.9945215, theta=-54.958501 -> V=1.0, theta=0.0
% INFO    : Bus 83836	: V=0.9904002, theta=-55.961554 -> V=1.0, theta=0.0
% INFO    : Bus 83837	: V=0.9861335, theta=-48.812402 -> V=1.0, theta=0.0
% INFO    : Bus 83838	: V=0.9861026, theta=-48.976869 -> V=1.0, theta=0.0
% INFO    : Bus 83839	: V=0.9827405, theta=-49.500765 -> V=1.0, theta=0.0
% INFO    : Bus 83840	: V=0.9794062, theta=-50.266464 -> V=1.0, theta=0.0
% INFO    : Bus 83841	: V=0.9660588, theta=-53.321385 -> V=1.0, theta=0.0
% INFO    : Bus 83842	: V=0.9903098, theta=-46.625321 -> V=1.0, theta=0.0
% INFO    : Bus 83843	: V=0.9870339, theta=-47.634226 -> V=1.0, theta=0.0
% INFO    : Bus 83844	: V=0.9814678, theta=-48.561488 -> V=1.0, theta=0.0
% INFO    : Bus 83845	: V=0.9783318, theta=-48.58988 -> V=1.0, theta=0.0
% INFO    : Bus 83846	: V=0.9804165, theta=-48.358112 -> V=1.0, theta=0.0
% INFO    : Bus 83847	: V=0.987138, theta=-47.315052 -> V=1.0, theta=0.0
% INFO    : Bus 83848	: V=0.9835979, theta=-47.956077 -> V=1.0, theta=0.0
% INFO    : Bus 83849	: V=0.9621114, theta=-53.669132 -> V=1.0, theta=0.0
% INFO    : Bus 83850	: V=0.9752401, theta=-51.105557 -> V=1.0, theta=0.0
% INFO    : Bus 83851	: V=0.9769208, theta=-49.325413 -> V=1.0, theta=0.0
% INFO    : Bus 83852	: V=0.9902334, theta=-46.86198 -> V=1.0, theta=0.0
% INFO    : Bus 83853	: V=0.9635742, theta=-55.347351 -> V=1.0, theta=0.0
% INFO    : Bus 83854	: V=0.9628068, theta=-54.773645 -> V=1.0, theta=0.0
% INFO    : Bus 83855	: V=0.9638857, theta=-54.794593 -> V=1.0, theta=0.0
% INFO    : Bus 83856	: V=0.9635505, theta=-54.786877 -> V=1.0, theta=0.0
% INFO    : Bus 83857	: V=0.9631287, theta=-54.746106 -> V=1.0, theta=0.0
% INFO    : Bus 83858	: V=0.9614235, theta=-55.176463 -> V=1.0, theta=0.0
% INFO    : Bus 83859	: V=0.9636235, theta=-54.758735 -> V=1.0, theta=0.0
% INFO    : Bus 83860	: V=0.9649542, theta=-54.626197 -> V=1.0, theta=0.0
% INFO    : Bus 83861	: V=0.9631724, theta=-54.800784 -> V=1.0, theta=0.0
% INFO    : Bus 83862	: V=0.9619395, theta=-55.02958 -> V=1.0, theta=0.0
% INFO    : Bus 83863	: V=0.9642362, theta=-54.717655 -> V=1.0, theta=0.0
% INFO    : Bus 83864	: V=0.9643528, theta=-54.764498 -> V=1.0, theta=0.0
% INFO    : Bus 83865	: V=0.9642207, theta=-55.135379 -> V=1.0, theta=0.0
% INFO    : Bus 83866	: V=0.962708, theta=-54.503884 -> V=1.0, theta=0.0
% INFO    : Bus 83867	: V=0.964736, theta=-54.41079 -> V=1.0, theta=0.0
% INFO    : Bus 83868	: V=0.9682229, theta=-53.790352 -> V=1.0, theta=0.0
% INFO    : Bus 83869	: V=0.9663098, theta=-54.440852 -> V=1.0, theta=0.0
% INFO    : Bus 83870	: V=0.9623755, theta=-54.68142 -> V=1.0, theta=0.0
% INFO    : Bus 83871	: V=0.9646454, theta=-54.421334 -> V=1.0, theta=0.0
% INFO    : Bus 83872	: V=0.9641412, theta=-54.4399 -> V=1.0, theta=0.0
% INFO    : Bus 83873	: V=0.9685242, theta=-53.907314 -> V=1.0, theta=0.0
% INFO    : Bus 83874	: V=0.9674325, theta=-54.047916 -> V=1.0, theta=0.0
% INFO    : Bus 83875	: V=0.9677792, theta=-54.057949 -> V=1.0, theta=0.0
% INFO    : Bus 83876	: V=0.9653372, theta=-54.30871 -> V=1.0, theta=0.0
% INFO    : Bus 83877	: V=0.9665418, theta=-54.153222 -> V=1.0, theta=0.0
% INFO    : Bus 83878	: V=0.966596, theta=-54.18013 -> V=1.0, theta=0.0
% INFO    : Bus 83879	: V=0.965659, theta=-54.341273 -> V=1.0, theta=0.0
% INFO    : Bus 83880	: V=0.9663252, theta=-54.205304 -> V=1.0, theta=0.0
% INFO    : Bus 83881	: V=0.9645524, theta=-54.296015 -> V=1.0, theta=0.0
% INFO    : Bus 83882	: V=0.9662904, theta=-55.081564 -> V=1.0, theta=0.0
% INFO    : Bus 83883	: V=0.9708479, theta=-54.386363 -> V=1.0, theta=0.0
% INFO    : Bus 83884	: V=0.9661197, theta=-55.335796 -> V=1.0, theta=0.0
% INFO    : Bus 83885	: V=0.9681404, theta=-55.200275 -> V=1.0, theta=0.0
% INFO    : Bus 83886	: V=0.9706634, theta=-54.136584 -> V=1.0, theta=0.0
% INFO    : Bus 83887	: V=0.9661219, theta=-55.137664 -> V=1.0, theta=0.0
% INFO    : Bus 83888	: V=0.9664235, theta=-55.029089 -> V=1.0, theta=0.0
% INFO    : Bus 83889	: V=0.9669864, theta=-55.1514 -> V=1.0, theta=0.0
% INFO    : Bus 83890	: V=0.9647769, theta=-55.808721 -> V=1.0, theta=0.0
% INFO    : Bus 83891	: V=0.9645599, theta=-55.362742 -> V=1.0, theta=0.0
% INFO    : Bus 83892	: V=0.9640699, theta=-55.981294 -> V=1.0, theta=0.0
% INFO    : Bus 83893	: V=0.9638625, theta=-55.706038 -> V=1.0, theta=0.0
% INFO    : Bus 83894	: V=0.9686015, theta=-53.938678 -> V=1.0, theta=0.0
% INFO    : Bus 83895	: V=0.9654808, theta=-55.166359 -> V=1.0, theta=0.0
% INFO    : Bus 83896	: V=0.9617111, theta=-55.872209 -> V=1.0, theta=0.0
% INFO    : Bus 83897	: V=0.963878, theta=-55.493591 -> V=1.0, theta=0.0
% INFO    : Bus 83898	: V=0.9643339, theta=-55.391593 -> V=1.0, theta=0.0
% INFO    : Bus 83899	: V=0.9624065, theta=-55.915365 -> V=1.0, theta=0.0
% INFO    : Bus 83900	: V=0.9612285, theta=-56.332886 -> V=1.0, theta=0.0
% INFO    : Bus 83901	: V=0.9622505, theta=-56.157062 -> V=1.0, theta=0.0
% INFO    : Bus 83902	: V=0.9628408, theta=-55.513701 -> V=1.0, theta=0.0
% INFO    : Bus 83903	: V=0.9624022, theta=-55.792315 -> V=1.0, theta=0.0
% INFO    : Bus 83904	: V=0.963588, theta=-55.05919 -> V=1.0, theta=0.0
% INFO    : Bus 83905	: V=0.9640122, theta=-55.017244 -> V=1.0, theta=0.0
% INFO    : Bus 83906	: V=0.9598696, theta=-55.160206 -> V=1.0, theta=0.0
% INFO    : Bus 83907	: V=0.9647936, theta=-55.047192 -> V=1.0, theta=0.0
% INFO    : Bus 83908	: V=0.961933, theta=-55.370739 -> V=1.0, theta=0.0
% INFO    : Bus 83909	: V=0.9641842, theta=-54.914566 -> V=1.0, theta=0.0
% INFO    : Bus 83910	: V=0.9639332, theta=-55.359679 -> V=1.0, theta=0.0
% INFO    : Bus 83911	: V=0.9645904, theta=-54.986798 -> V=1.0, theta=0.0
% INFO    : Bus 83912	: V=0.9637687, theta=-55.240427 -> V=1.0, theta=0.0
% INFO    : Bus 83913	: V=0.964818, theta=-54.819807 -> V=1.0, theta=0.0
% INFO    : Bus 83914	: V=0.9656041, theta=-54.888289 -> V=1.0, theta=0.0
% INFO    : Bus 83915	: V=0.9676757, theta=-53.819617 -> V=1.0, theta=0.0
% INFO    : Bus 83916	: V=0.9628476, theta=-55.526194 -> V=1.0, theta=0.0
% INFO    : Bus 83917	: V=0.9670689, theta=-54.871057 -> V=1.0, theta=0.0
% INFO    : Bus 83918	: V=0.9671952, theta=-54.897071 -> V=1.0, theta=0.0
% INFO    : Bus 83919	: V=0.964059, theta=-55.20759 -> V=1.0, theta=0.0
% INFO    : Bus 83920	: V=0.9721384, theta=-53.499212 -> V=1.0, theta=0.0
% INFO    : Bus 83921	: V=0.9699691, theta=-54.093344 -> V=1.0, theta=0.0
% INFO    : Bus 83922	: V=0.9620605, theta=-54.382694 -> V=1.0, theta=0.0
% INFO    : Bus 83923	: V=0.9745209, theta=-52.862683 -> V=1.0, theta=0.0
% INFO    : Bus 83924	: V=0.9715748, theta=-53.500611 -> V=1.0, theta=0.0
% INFO    : Bus 83925	: V=0.9714891, theta=-53.418273 -> V=1.0, theta=0.0
% INFO    : Bus 83926	: V=0.9698783, theta=-53.806065 -> V=1.0, theta=0.0
% INFO    : Bus 83927	: V=0.966953, theta=-54.112616 -> V=1.0, theta=0.0
% INFO    : Bus 83928	: V=0.9649629, theta=-54.271981 -> V=1.0, theta=0.0
% INFO    : Bus 83929	: V=0.9679133, theta=-53.97461 -> V=1.0, theta=0.0
% INFO    : Bus 83930	: V=0.9639711, theta=-54.666152 -> V=1.0, theta=0.0
% INFO    : Bus 83931	: V=0.9690516, theta=-53.43488 -> V=1.0, theta=0.0
% INFO    : Bus 83932	: V=0.9675423, theta=-53.87617 -> V=1.0, theta=0.0
% INFO    : Bus 83933	: V=0.9697567, theta=-53.177436 -> V=1.0, theta=0.0
% INFO    : Bus 83934	: V=0.9675585, theta=-53.665568 -> V=1.0, theta=0.0
% INFO    : Bus 83935	: V=0.9639928, theta=-54.364312 -> V=1.0, theta=0.0
% INFO    : Bus 83936	: V=0.9739031, theta=-52.362964 -> V=1.0, theta=0.0
% INFO    : Bus 83937	: V=0.9752393, theta=-52.18905 -> V=1.0, theta=0.0
% INFO    : Bus 83938	: V=0.9724029, theta=-53.033999 -> V=1.0, theta=0.0
% INFO    : Bus 83939	: V=0.9657017, theta=-54.153942 -> V=1.0, theta=0.0
% INFO    : Bus 83940	: V=0.9670412, theta=-54.196344 -> V=1.0, theta=0.0
% INFO    : Bus 83941	: V=0.9633393, theta=-54.536549 -> V=1.0, theta=0.0
% INFO    : Bus 83942	: V=0.9623726, theta=-54.557852 -> V=1.0, theta=0.0
% INFO    : Bus 83943	: V=0.9626999, theta=-54.327281 -> V=1.0, theta=0.0
% INFO    : Bus 83944	: V=0.9640612, theta=-54.669567 -> V=1.0, theta=0.0
% INFO    : Bus 83945	: V=0.9632056, theta=-54.443433 -> V=1.0, theta=0.0
% INFO    : Bus 83946	: V=0.9647355, theta=-54.006724 -> V=1.0, theta=0.0
% INFO    : Bus 83947	: V=0.9630277, theta=-53.881804 -> V=1.0, theta=0.0
% INFO    : Bus 83948	: V=0.9704561, theta=-53.332933 -> V=1.0, theta=0.0
% INFO    : Bus 83949	: V=0.9691317, theta=-53.782231 -> V=1.0, theta=0.0
% INFO    : Bus 83950	: V=0.9634444, theta=-54.156388 -> V=1.0, theta=0.0
% INFO    : Bus 83951	: V=0.9790101, theta=-51.540773 -> V=1.0, theta=0.0
% INFO    : Bus 83952	: V=0.9808634, theta=-51.2929 -> V=1.0, theta=0.0
% INFO    : Bus 83953	: V=0.9646106, theta=-55.434584 -> V=1.0, theta=0.0
% INFO    : Bus 83954	: V=0.9644476, theta=-55.180816 -> V=1.0, theta=0.0
% INFO    : Bus 83955	: V=0.9737909, theta=-56.506117 -> V=1.0, theta=0.0
% INFO    : Bus 83956	: V=0.9760961, theta=-56.761745 -> V=1.0, theta=0.0
% INFO    : Bus 83957	: V=0.9937013, theta=-55.177597 -> V=1.0, theta=0.0
% INFO    : Bus 83958	: V=0.9932721, theta=-55.390437 -> V=1.0, theta=0.0
% INFO    : Bus 83959	: V=1.0074563, theta=-38.969719 -> V=1.0, theta=0.0
% INFO    : Bus 83960	: V=1.0074849, theta=-39.112312 -> V=1.0, theta=0.0
% INFO    : Bus 83961	: V=1.0105198, theta=-38.455804 -> V=1.0, theta=0.0
% INFO    : Bus 83962	: V=0.9813262, theta=-56.144019 -> V=1.0, theta=0.0
% INFO    : Bus 83963	: V=0.9865843, theta=-54.628892 -> V=1.0, theta=0.0
% INFO    : Bus 83964	: V=0.9771239, theta=-56.283733 -> V=1.0, theta=0.0
% INFO    : Bus 83965	: V=0.9783054, theta=-56.505456 -> V=1.0, theta=0.0
% INFO    : Bus 83966	: V=0.973477, theta=-57.740735 -> V=1.0, theta=0.0
% INFO    : Bus 83967	: V=0.9966774, theta=-53.514784 -> V=1.0, theta=0.0
% INFO    : Bus 83968	: V=0.9923197, theta=-54.506357 -> V=1.0, theta=0.0
% INFO    : Bus 83969	: V=0.9755966, theta=-56.023453 -> V=1.0, theta=0.0
% INFO    : Bus 83970	: V=0.9655637, theta=-53.723389 -> V=1.0, theta=0.0
% INFO    : Bus 83971	: V=0.9730794, theta=-52.220643 -> V=1.0, theta=0.0
% INFO    : Bus 83972	: V=0.9814535, theta=-50.527084 -> V=1.0, theta=0.0
% INFO    : Bus 83973	: V=0.9703468, theta=-52.75205 -> V=1.0, theta=0.0
% INFO    : Bus 83974	: V=0.9699218, theta=-52.927426 -> V=1.0, theta=0.0
% INFO    : Bus 83975	: V=0.9683911, theta=-53.409816 -> V=1.0, theta=0.0
% INFO    : Bus 83976	: V=0.9762547, theta=-50.387122 -> V=1.0, theta=0.0
% INFO    : Bus 83977	: V=0.9729197, theta=-52.486143 -> V=1.0, theta=0.0
% INFO    : Bus 83978	: V=0.9727882, theta=-52.656752 -> V=1.0, theta=0.0
% INFO    : Bus 83979	: V=1.0117424, theta=-43.750881 -> V=1.0, theta=0.0
% INFO    : Bus 83980	: V=1.0127854, theta=-43.21926 -> V=1.0, theta=0.0
% INFO    : Bus 83981	: V=1.012078, theta=-43.06829 -> V=1.0, theta=0.0
% INFO    : Bus 83982	: V=1.0100394, theta=-43.735895 -> V=1.0, theta=0.0
% INFO    : Bus 83983	: V=1.0142367, theta=-41.850567 -> V=1.0, theta=0.0
% INFO    : Bus 83984	: V=1.0166241, theta=-42.39265 -> V=1.0, theta=0.0
% INFO    : Bus 83985	: V=1.0164809, theta=-41.715622 -> V=1.0, theta=0.0
% INFO    : Bus 83986	: V=0.9830355, theta=-48.226249 -> V=1.0, theta=0.0
% INFO    : Bus 83987	: V=0.9897019, theta=-47.729084 -> V=1.0, theta=0.0
% INFO    : Bus 83988	: V=0.975847, theta=-48.669999 -> V=1.0, theta=0.0
% INFO    : Bus 83989	: V=0.9775219, theta=-48.650989 -> V=1.0, theta=0.0
% INFO    : Bus 83990	: V=0.9758736, theta=-49.040762 -> V=1.0, theta=0.0
% INFO    : Bus 83991	: V=0.9736417, theta=-49.105983 -> V=1.0, theta=0.0
% INFO    : Bus 83992	: V=0.9765059, theta=-49.116426 -> V=1.0, theta=0.0
% INFO    : Bus 83993	: V=0.9778377, theta=-48.71628 -> V=1.0, theta=0.0
% INFO    : Bus 83994	: V=0.9856841, theta=-47.919683 -> V=1.0, theta=0.0
% INFO    : Bus 83995	: V=0.9858677, theta=-47.959034 -> V=1.0, theta=0.0
% INFO    : Bus 83996	: V=0.9820084, theta=-48.364207 -> V=1.0, theta=0.0
% INFO    : Bus 83997	: V=0.9862467, theta=-47.86508 -> V=1.0, theta=0.0
% INFO    : Bus 83998	: V=0.9693628, theta=-49.477634 -> V=1.0, theta=0.0
% INFO    : Bus 83999	: V=0.9879448, theta=-47.692349 -> V=1.0, theta=0.0
% INFO    : Bus 84000	: V=0.9830177, theta=-48.326972 -> V=1.0, theta=0.0
% INFO    : Bus 84001	: V=0.9843923, theta=-47.89677 -> V=1.0, theta=0.0
% INFO    : Bus 84002	: V=0.9831421, theta=-48.045243 -> V=1.0, theta=0.0
% INFO    : Bus 84003	: V=0.9870611, theta=-47.491502 -> V=1.0, theta=0.0
% INFO    : Bus 84004	: V=0.9870513, theta=-47.73401 -> V=1.0, theta=0.0
% INFO    : Bus 84005	: V=0.9887988, theta=-47.344359 -> V=1.0, theta=0.0
% INFO    : Bus 84006	: V=0.9869656, theta=-47.579196 -> V=1.0, theta=0.0
% INFO    : Bus 84007	: V=0.9908784, theta=-47.158544 -> V=1.0, theta=0.0
% INFO    : Bus 84008	: V=0.9884762, theta=-47.597726 -> V=1.0, theta=0.0
% INFO    : Bus 84009	: V=0.9917901, theta=-47.188571 -> V=1.0, theta=0.0
% INFO    : Bus 84010	: V=0.9814723, theta=-47.712824 -> V=1.0, theta=0.0
% INFO    : Bus 84011	: V=0.9908149, theta=-47.058009 -> V=1.0, theta=0.0
% INFO    : Bus 84012	: V=0.9891158, theta=-47.283781 -> V=1.0, theta=0.0
% INFO    : Bus 84013	: V=0.9884767, theta=-47.407148 -> V=1.0, theta=0.0
% INFO    : Bus 84014	: V=0.9771953, theta=-49.069796 -> V=1.0, theta=0.0
% INFO    : Bus 84015	: V=1.005732, theta=-45.344794 -> V=1.0, theta=0.0
% INFO    : Bus 84016	: V=1.0073088, theta=-45.205185 -> V=1.0, theta=0.0
% INFO    : Bus 84017	: V=1.0017648, theta=-45.961616 -> V=1.0, theta=0.0
% INFO    : Bus 84018	: V=0.9999626, theta=-46.282861 -> V=1.0, theta=0.0
% INFO    : Bus 84019	: V=0.9849331, theta=-48.445866 -> V=1.0, theta=0.0
% INFO    : Bus 84020	: V=0.9944807, theta=-47.19532 -> V=1.0, theta=0.0
% INFO    : Bus 84021	: V=0.9961519, theta=-46.700608 -> V=1.0, theta=0.0
% INFO    : Bus 84022	: V=0.9861916, theta=-47.630421 -> V=1.0, theta=0.0
% INFO    : Bus 84023	: V=0.9929812, theta=-47.056535 -> V=1.0, theta=0.0
% INFO    : Bus 84024	: V=0.9873838, theta=-48.034021 -> V=1.0, theta=0.0
% INFO    : Bus 84025	: V=0.9904635, theta=-47.330149 -> V=1.0, theta=0.0
% INFO    : Bus 84026	: V=0.9930269, theta=-47.154807 -> V=1.0, theta=0.0
% INFO    : Bus 84027	: V=0.990637, theta=-47.4469 -> V=1.0, theta=0.0
% INFO    : Bus 84028	: V=0.9928719, theta=-47.188336 -> V=1.0, theta=0.0
% INFO    : Bus 84029	: V=0.9984219, theta=-46.485018 -> V=1.0, theta=0.0
% INFO    : Bus 84030	: V=0.9968498, theta=-46.450707 -> V=1.0, theta=0.0
% INFO    : Bus 84031	: V=0.9979229, theta=-46.578602 -> V=1.0, theta=0.0
% INFO    : Bus 84032	: V=0.9938047, theta=-46.869272 -> V=1.0, theta=0.0
% INFO    : Bus 84033	: V=0.990715, theta=-47.208424 -> V=1.0, theta=0.0
% INFO    : Bus 84034	: V=0.9826899, theta=-48.480023 -> V=1.0, theta=0.0
% INFO    : Bus 84035	: V=0.9840507, theta=-48.62265 -> V=1.0, theta=0.0
% INFO    : Bus 84036	: V=0.9894627, theta=-47.768976 -> V=1.0, theta=0.0
% INFO    : Bus 84037	: V=0.9874879, theta=-48.053895 -> V=1.0, theta=0.0
% INFO    : Bus 84038	: V=0.9920228, theta=-47.323486 -> V=1.0, theta=0.0
% INFO    : Bus 84039	: V=0.9879454, theta=-47.954267 -> V=1.0, theta=0.0
% INFO    : Bus 84040	: V=0.9859965, theta=-48.137023 -> V=1.0, theta=0.0
% INFO    : Bus 84041	: V=0.9842091, theta=-48.267865 -> V=1.0, theta=0.0
% INFO    : Bus 84042	: V=0.9848303, theta=-48.173906 -> V=1.0, theta=0.0
% INFO    : Bus 84043	: V=0.9817453, theta=-48.502192 -> V=1.0, theta=0.0
% INFO    : Bus 84044	: V=0.9801091, theta=-49.001461 -> V=1.0, theta=0.0
% INFO    : Bus 84045	: V=0.9856455, theta=-48.507389 -> V=1.0, theta=0.0
% INFO    : Bus 84046	: V=0.9810298, theta=-48.99074 -> V=1.0, theta=0.0
% INFO    : Bus 84047	: V=0.9797632, theta=-49.205955 -> V=1.0, theta=0.0
% INFO    : Bus 84048	: V=0.9821846, theta=-48.819354 -> V=1.0, theta=0.0
% INFO    : Bus 84049	: V=0.9789578, theta=-49.248636 -> V=1.0, theta=0.0
% INFO    : Bus 84050	: V=0.9769266, theta=-49.18468 -> V=1.0, theta=0.0
% INFO    : Bus 84051	: V=0.9751948, theta=-49.472204 -> V=1.0, theta=0.0
% INFO    : Bus 84052	: V=0.9718956, theta=-49.839503 -> V=1.0, theta=0.0
% INFO    : Bus 84053	: V=0.9721273, theta=-49.645918 -> V=1.0, theta=0.0
% INFO    : Bus 84054	: V=0.9724178, theta=-48.985683 -> V=1.0, theta=0.0
% INFO    : Bus 84055	: V=0.975056, theta=-49.416975 -> V=1.0, theta=0.0
% INFO    : Bus 84056	: V=0.9773214, theta=-48.879699 -> V=1.0, theta=0.0
% INFO    : Bus 84057	: V=0.9801316, theta=-48.505625 -> V=1.0, theta=0.0
% INFO    : Bus 84058	: V=0.9791957, theta=-48.566017 -> V=1.0, theta=0.0
% INFO    : Bus 84059	: V=0.9939564, theta=-46.963726 -> V=1.0, theta=0.0
% INFO    : Bus 84060	: V=0.992393, theta=-47.28827 -> V=1.0, theta=0.0
% INFO    : Bus 84061	: V=0.9950223, theta=-46.715403 -> V=1.0, theta=0.0
% INFO    : Bus 84062	: V=0.9912155, theta=-47.546148 -> V=1.0, theta=0.0
% INFO    : Bus 84063	: V=1.0017178, theta=-46.013412 -> V=1.0, theta=0.0
% INFO    : Bus 84064	: V=0.9992329, theta=-46.246565 -> V=1.0, theta=0.0
% INFO    : Bus 84065	: V=0.9770746, theta=-48.734052 -> V=1.0, theta=0.0
% INFO    : Bus 84066	: V=0.9772776, theta=-48.766391 -> V=1.0, theta=0.0
% INFO    : Bus 84067	: V=0.9841246, theta=-48.111015 -> V=1.0, theta=0.0
% INFO    : Bus 84068	: V=0.9834311, theta=-48.233906 -> V=1.0, theta=0.0
% INFO    : Bus 84069	: V=0.9975042, theta=-47.063348 -> V=1.0, theta=0.0
% INFO    : Bus 84070	: V=0.9978231, theta=-47.198698 -> V=1.0, theta=0.0
% INFO    : Bus 84071	: V=0.9940686, theta=-47.474992 -> V=1.0, theta=0.0
% INFO    : Bus 84072	: V=0.9951214, theta=-47.085576 -> V=1.0, theta=0.0
% INFO    : Bus 84073	: V=1.0001547, theta=-45.718088 -> V=1.0, theta=0.0
% INFO    : Bus 84074	: V=1.0000785, theta=-46.213885 -> V=1.0, theta=0.0
% INFO    : Bus 84075	: V=0.9761001, theta=-48.326173 -> V=1.0, theta=0.0
% INFO    : Bus 84076	: V=0.9796414, theta=-48.531004 -> V=1.0, theta=0.0
% INFO    : Bus 84077	: V=0.9730859, theta=-49.364152 -> V=1.0, theta=0.0
% INFO    : Bus 84078	: V=0.9775764, theta=-55.778854 -> V=1.0, theta=0.0
% INFO    : Bus 84079	: V=0.9650609, theta=-57.914925 -> V=1.0, theta=0.0
% INFO    : Bus 84080	: V=0.9822168, theta=-55.263002 -> V=1.0, theta=0.0
% INFO    : Bus 84081	: V=0.9712853, theta=-57.273949 -> V=1.0, theta=0.0
% INFO    : Bus 84082	: V=0.9681172, theta=-57.416085 -> V=1.0, theta=0.0
% INFO    : Bus 84083	: V=0.971095, theta=-57.090709 -> V=1.0, theta=0.0
% INFO    : Bus 84084	: V=0.9721393, theta=-56.817897 -> V=1.0, theta=0.0
% INFO    : Bus 84085	: V=0.9674674, theta=-57.590208 -> V=1.0, theta=0.0
% INFO    : Bus 84086	: V=0.9905032, theta=-54.576941 -> V=1.0, theta=0.0
% INFO    : Bus 84087	: V=0.9901144, theta=-54.815024 -> V=1.0, theta=0.0
% INFO    : Bus 84088	: V=0.9785752, theta=-57.468295 -> V=1.0, theta=0.0
% INFO    : Bus 84089	: V=0.9940577, theta=-45.733323 -> V=1.0, theta=0.0
% INFO    : Bus 84090	: V=0.9925668, theta=-46.13546 -> V=1.0, theta=0.0
% INFO    : Bus 84091	: V=0.9903702, theta=-45.668544 -> V=1.0, theta=0.0
% INFO    : Bus 84092	: V=0.9976996, theta=-45.076926 -> V=1.0, theta=0.0
% INFO    : Bus 84093	: V=0.9969292, theta=-45.236339 -> V=1.0, theta=0.0
% INFO    : Bus 84094	: V=0.9998175, theta=-44.095432 -> V=1.0, theta=0.0
% INFO    : Bus 84095	: V=0.9838381, theta=-54.322509 -> V=1.0, theta=0.0
% INFO    : Bus 84096	: V=0.9875396, theta=-54.499378 -> V=1.0, theta=0.0
% INFO    : Bus 84097	: V=0.9889544, theta=-54.186077 -> V=1.0, theta=0.0
% INFO    : Bus 84098	: V=0.9942625, theta=-52.76113 -> V=1.0, theta=0.0
% INFO    : Bus 84099	: V=0.9902721, theta=-53.448953 -> V=1.0, theta=0.0
% INFO    : Bus 84100	: V=0.9894433, theta=-53.072498 -> V=1.0, theta=0.0
% INFO    : Bus 84101	: V=0.9886199, theta=-56.633135 -> V=1.0, theta=0.0
% INFO    : Bus 84102	: V=0.9872836, theta=-56.833568 -> V=1.0, theta=0.0
% INFO    : Bus 84103	: V=0.9882141, theta=-56.505603 -> V=1.0, theta=0.0
% INFO    : Bus 84104	: V=0.9798858, theta=-57.401735 -> V=1.0, theta=0.0
% INFO    : Bus 84105	: V=0.9834593, theta=-57.557361 -> V=1.0, theta=0.0
% INFO    : Bus 84106	: V=0.9722974, theta=-43.719163 -> V=1.0, theta=0.0
% INFO    : Bus 84107	: V=1.0168893, theta=-41.832432 -> V=1.0, theta=0.0
% INFO    : Bus 84108	: V=1.015045, theta=-42.180613 -> V=1.0, theta=0.0
% INFO    : Bus 84109	: V=1.012385, theta=-42.526318 -> V=1.0, theta=0.0
% INFO    : Bus 84110	: V=1.0173072, theta=-41.689359 -> V=1.0, theta=0.0
% INFO    : Bus 84111	: V=1.018209, theta=-41.628136 -> V=1.0, theta=0.0
% INFO    : Bus 84112	: V=1.0177873, theta=-41.350474 -> V=1.0, theta=0.0
% INFO    : Bus 84113	: V=1.0159279, theta=-41.722924 -> V=1.0, theta=0.0
% INFO    : Bus 84114	: V=1.0105072, theta=-41.379912 -> V=1.0, theta=0.0
% INFO    : Bus 84115	: V=0.9961793, theta=-51.25033 -> V=1.0, theta=0.0
% INFO    : Bus 84116	: V=0.9967847, theta=-51.762229 -> V=1.0, theta=0.0
% INFO    : Bus 84117	: V=0.9893202, theta=-52.991248 -> V=1.0, theta=0.0
% INFO    : Bus 84118	: V=0.9772369, theta=-55.752044 -> V=1.0, theta=0.0
% INFO    : Bus 84119	: V=0.9811733, theta=-54.201192 -> V=1.0, theta=0.0
% INFO    : Bus 84120	: V=0.9829422, theta=-53.512913 -> V=1.0, theta=0.0
% INFO    : Bus 84121	: V=0.9872342, theta=-52.985646 -> V=1.0, theta=0.0
% INFO    : Bus 84122	: V=0.9852638, theta=-53.661457 -> V=1.0, theta=0.0
% INFO    : Bus 84123	: V=0.967641, theta=-55.569253 -> V=1.0, theta=0.0
% INFO    : Bus 84124	: V=0.9996057, theta=-54.064436 -> V=1.0, theta=0.0
% INFO    : Bus 84125	: V=0.9987654, theta=-54.155369 -> V=1.0, theta=0.0
% INFO    : Bus 84126	: V=1.0059944, theta=-52.794601 -> V=1.0, theta=0.0
% INFO    : Bus 84127	: V=0.9969896, theta=-54.226313 -> V=1.0, theta=0.0
% INFO    : Bus 84128	: V=0.9984591, theta=-54.154835 -> V=1.0, theta=0.0
% INFO    : Bus 84129	: V=0.9994515, theta=-54.033926 -> V=1.0, theta=0.0
% INFO    : Bus 84130	: V=0.995566, theta=-54.426361 -> V=1.0, theta=0.0
% INFO    : Bus 84131	: V=0.9967745, theta=-53.731873 -> V=1.0, theta=0.0
% INFO    : Bus 84132	: V=1.0031372, theta=-53.22837 -> V=1.0, theta=0.0
% INFO    : Bus 84133	: V=1.0125101, theta=-52.139906 -> V=1.0, theta=0.0
% INFO    : Bus 84134	: V=1.0040905, theta=-52.53318 -> V=1.0, theta=0.0
% INFO    : Bus 84135	: V=1.0001909, theta=-53.331365 -> V=1.0, theta=0.0
% INFO    : Bus 84136	: V=1.0025743, theta=-53.200804 -> V=1.0, theta=0.0
% INFO    : Bus 84137	: V=0.9984577, theta=-53.346596 -> V=1.0, theta=0.0
% INFO    : Bus 84138	: V=1.0117612, theta=-51.440429 -> V=1.0, theta=0.0
% INFO    : Bus 84139	: V=0.9996417, theta=-52.942458 -> V=1.0, theta=0.0
% INFO    : Bus 84140	: V=1.0129866, theta=-51.168043 -> V=1.0, theta=0.0
% INFO    : Bus 84141	: V=1.0115995, theta=-51.471231 -> V=1.0, theta=0.0
% INFO    : Bus 84142	: V=1.0164813, theta=-50.298944 -> V=1.0, theta=0.0
% INFO    : Bus 84143	: V=1.0147427, theta=-50.68206 -> V=1.0, theta=0.0
% INFO    : Bus 84144	: V=1.0052612, theta=-52.449899 -> V=1.0, theta=0.0
% INFO    : Bus 84145	: V=1.0092245, theta=-51.556583 -> V=1.0, theta=0.0
% INFO    : Bus 84146	: V=1.0064805, theta=-51.847796 -> V=1.0, theta=0.0
% INFO    : Bus 84147	: V=1.0051699, theta=-52.640337 -> V=1.0, theta=0.0
% INFO    : Bus 84148	: V=1.0032463, theta=-52.84449 -> V=1.0, theta=0.0
% INFO    : Bus 84149	: V=1.0033847, theta=-53.92366 -> V=1.0, theta=0.0
% INFO    : Bus 84150	: V=1.0064744, theta=-39.584274 -> V=1.0, theta=0.0
% INFO    : Bus 84151	: V=1.0069204, theta=-39.659869 -> V=1.0, theta=0.0
% INFO    : Bus 84152	: V=1.0008092, theta=-40.120364 -> V=1.0, theta=0.0
% INFO    : Bus 84153	: V=0.9621032, theta=-52.587099 -> V=1.0, theta=0.0
% INFO    : Bus 84154	: V=0.9606412, theta=-52.463732 -> V=1.0, theta=0.0
% INFO    : Bus 84155	: V=0.964461, theta=-52.424278 -> V=1.0, theta=0.0
% INFO    : Bus 84156	: V=0.9653043, theta=-52.270089 -> V=1.0, theta=0.0
% INFO    : Bus 84157	: V=0.9643137, theta=-55.473877 -> V=1.0, theta=0.0
% INFO    : Bus 84158	: V=0.9643236, theta=-53.286403 -> V=1.0, theta=0.0
% INFO    : Bus 84159	: V=0.9636945, theta=-52.802431 -> V=1.0, theta=0.0
% INFO    : Bus 84160	: V=0.9716021, theta=-52.443758 -> V=1.0, theta=0.0
% INFO    : Bus 84161	: V=0.9750824, theta=-50.936179 -> V=1.0, theta=0.0
% INFO    : Bus 84162	: V=0.9695898, theta=-52.068355 -> V=1.0, theta=0.0
% INFO    : Bus 84163	: V=0.9675265, theta=-55.453041 -> V=1.0, theta=0.0
% INFO    : Bus 84164	: V=0.9632613, theta=-56.093571 -> V=1.0, theta=0.0
% INFO    : Bus 84165	: V=0.9530896, theta=-57.092288 -> V=1.0, theta=0.0
% INFO    : Bus 84166	: V=0.9473408, theta=-58.440038 -> V=1.0, theta=0.0
% INFO    : Bus 84167	: V=1.0069469, theta=-56.017942 -> V=1.0, theta=0.0
% INFO    : Bus 84168	: V=0.9980353, theta=-57.768622 -> V=1.0, theta=0.0
% INFO    : Bus 84169	: V=1.0054625, theta=-56.248554 -> V=1.0, theta=0.0
% INFO    : Bus 84170	: V=1.0055295, theta=-56.19289 -> V=1.0, theta=0.0
% INFO    : Bus 84171	: V=1.0095873, theta=-55.580582 -> V=1.0, theta=0.0
% INFO    : Bus 84172	: V=0.9979641, theta=-56.748231 -> V=1.0, theta=0.0
% INFO    : Bus 84173	: V=0.9989093, theta=-56.699561 -> V=1.0, theta=0.0
% INFO    : Bus 84174	: V=1.0055676, theta=-55.957483 -> V=1.0, theta=0.0
% INFO    : Bus 84175	: V=0.9990912, theta=-56.676071 -> V=1.0, theta=0.0
% INFO    : Bus 84176	: V=1.0085724, theta=-55.51787 -> V=1.0, theta=0.0
% INFO    : Bus 84177	: V=1.0042229, theta=-56.16947 -> V=1.0, theta=0.0
% INFO    : Bus 84178	: V=1.0052623, theta=-55.80366 -> V=1.0, theta=0.0
% INFO    : Bus 84179	: V=0.991618, theta=-57.125093 -> V=1.0, theta=0.0
% INFO    : Bus 84180	: V=0.9965819, theta=-57.129808 -> V=1.0, theta=0.0
% INFO    : Bus 84181	: V=0.9972347, theta=-56.683041 -> V=1.0, theta=0.0
% INFO    : Bus 84182	: V=1.0003494, theta=-56.634521 -> V=1.0, theta=0.0
% INFO    : Bus 84183	: V=1.0033819, theta=-56.415741 -> V=1.0, theta=0.0
% INFO    : Bus 84184	: V=0.9920418, theta=-57.902325 -> V=1.0, theta=0.0
% INFO    : Bus 84185	: V=0.9945492, theta=-58.258162 -> V=1.0, theta=0.0
% INFO    : Bus 84186	: V=0.9952586, theta=-57.775502 -> V=1.0, theta=0.0
% INFO    : Bus 84187	: V=0.993837, theta=-58.300131 -> V=1.0, theta=0.0
% INFO    : Bus 84188	: V=0.9904489, theta=-58.53467 -> V=1.0, theta=0.0
% INFO    : Bus 84189	: V=0.9892585, theta=-58.612578 -> V=1.0, theta=0.0
% INFO    : Bus 84190	: V=0.9864552, theta=-58.055263 -> V=1.0, theta=0.0
% INFO    : Bus 84191	: V=1.0120177, theta=-55.029685 -> V=1.0, theta=0.0
% INFO    : Bus 84192	: V=0.9625832, theta=-55.859482 -> V=1.0, theta=0.0
% INFO    : Bus 84193	: V=0.9718264, theta=-54.983897 -> V=1.0, theta=0.0
% INFO    : Bus 84194	: V=0.9813952, theta=-54.349923 -> V=1.0, theta=0.0
% INFO    : Bus 84195	: V=0.9763275, theta=-54.680544 -> V=1.0, theta=0.0
% INFO    : Bus 84196	: V=0.9795238, theta=-54.572104 -> V=1.0, theta=0.0
% INFO    : Bus 84197	: V=0.9779669, theta=-54.594985 -> V=1.0, theta=0.0
% INFO    : Bus 84198	: V=0.9756945, theta=-54.785313 -> V=1.0, theta=0.0
% INFO    : Bus 84199	: V=0.9666366, theta=-55.485195 -> V=1.0, theta=0.0
% INFO    : Bus 84200	: V=0.973878, theta=-54.929842 -> V=1.0, theta=0.0
% INFO    : Bus 84201	: V=0.9763032, theta=-54.721689 -> V=1.0, theta=0.0
% INFO    : Bus 84202	: V=0.965741, theta=-55.599923 -> V=1.0, theta=0.0
% INFO    : Bus 84203	: V=0.971524, theta=-55.455091 -> V=1.0, theta=0.0
% INFO    : Bus 84204	: V=0.9801406, theta=-54.52846 -> V=1.0, theta=0.0
% INFO    : Bus 84205	: V=0.9748472, theta=-54.920728 -> V=1.0, theta=0.0
% INFO    : Bus 84206	: V=0.996924, theta=-51.388205 -> V=1.0, theta=0.0
% INFO    : Bus 84207	: V=0.9952742, theta=-52.581422 -> V=1.0, theta=0.0
% INFO    : Bus 84208	: V=0.9898099, theta=-53.452023 -> V=1.0, theta=0.0
% INFO    : Bus 84209	: V=0.9672702, theta=-54.775509 -> V=1.0, theta=0.0
% INFO    : Bus 84210	: V=0.9718323, theta=-54.863127 -> V=1.0, theta=0.0
% INFO    : Bus 84211	: V=0.9784847, theta=-54.307507 -> V=1.0, theta=0.0
% INFO    : Bus 84212	: V=0.9647152, theta=-55.162508 -> V=1.0, theta=0.0
% INFO    : Bus 84213	: V=0.9613555, theta=-56.055802 -> V=1.0, theta=0.0
% INFO    : Bus 84214	: V=0.9799874, theta=-54.536139 -> V=1.0, theta=0.0
% INFO    : Bus 84215	: V=0.9747557, theta=-55.312773 -> V=1.0, theta=0.0
% INFO    : Bus 84216	: V=0.9786433, theta=-54.586314 -> V=1.0, theta=0.0
% INFO    : Bus 84217	: V=0.9757287, theta=-55.198912 -> V=1.0, theta=0.0
% INFO    : Bus 84218	: V=0.9639698, theta=-55.950985 -> V=1.0, theta=0.0
% INFO    : Bus 84219	: V=0.9646964, theta=-55.961193 -> V=1.0, theta=0.0
% INFO    : Bus 84220	: V=0.9625568, theta=-55.812347 -> V=1.0, theta=0.0
% INFO    : Bus 84221	: V=0.962348, theta=-56.078801 -> V=1.0, theta=0.0
% INFO    : Bus 84222	: V=0.9718244, theta=-55.470883 -> V=1.0, theta=0.0
% INFO    : Bus 84223	: V=0.9729259, theta=-55.54955 -> V=1.0, theta=0.0
% INFO    : Bus 84224	: V=0.9672123, theta=-56.082492 -> V=1.0, theta=0.0
% INFO    : Bus 84225	: V=0.9800423, theta=-55.445323 -> V=1.0, theta=0.0
% INFO    : Bus 84226	: V=0.9871966, theta=-53.801938 -> V=1.0, theta=0.0
% INFO    : Bus 84227	: V=0.9816392, theta=-54.313193 -> V=1.0, theta=0.0
% INFO    : Bus 84228	: V=0.9871337, theta=-53.678381 -> V=1.0, theta=0.0
% INFO    : Bus 84229	: V=0.9868304, theta=-53.965535 -> V=1.0, theta=0.0
% INFO    : Bus 84230	: V=0.9727637, theta=-55.061877 -> V=1.0, theta=0.0
% INFO    : Bus 84231	: V=0.9769094, theta=-52.173878 -> V=1.0, theta=0.0
% INFO    : Bus 84232	: V=0.9707557, theta=-53.386137 -> V=1.0, theta=0.0
% INFO    : Bus 84233	: V=0.9756321, theta=-52.132179 -> V=1.0, theta=0.0
% INFO    : Bus 84234	: V=0.9705139, theta=-52.584713 -> V=1.0, theta=0.0
% INFO    : Bus 84235	: V=0.9702484, theta=-51.98983 -> V=1.0, theta=0.0
% INFO    : Bus 84236	: V=0.9715538, theta=-52.51159 -> V=1.0, theta=0.0
% INFO    : Bus 84237	: V=0.9713908, theta=-52.547715 -> V=1.0, theta=0.0
% INFO    : Bus 84238	: V=0.9716345, theta=-52.95285 -> V=1.0, theta=0.0
% INFO    : Bus 84239	: V=0.9720204, theta=-52.957937 -> V=1.0, theta=0.0
% INFO    : Bus 84240	: V=0.9705993, theta=-52.96181 -> V=1.0, theta=0.0
% INFO    : Bus 84241	: V=0.9735886, theta=-52.203661 -> V=1.0, theta=0.0
% INFO    : Bus 84242	: V=0.9734932, theta=-51.875084 -> V=1.0, theta=0.0
% INFO    : Bus 84243	: V=0.9745904, theta=-51.777599 -> V=1.0, theta=0.0
% INFO    : Bus 84244	: V=0.9822299, theta=-50.263615 -> V=1.0, theta=0.0
% INFO    : Bus 84245	: V=0.9704784, theta=-51.991442 -> V=1.0, theta=0.0
% INFO    : Bus 84246	: V=0.971027, theta=-51.828309 -> V=1.0, theta=0.0
% INFO    : Bus 84247	: V=0.975199, theta=-51.622728 -> V=1.0, theta=0.0
% INFO    : Bus 84248	: V=0.9809238, theta=-51.459043 -> V=1.0, theta=0.0
% INFO    : Bus 84249	: V=0.9767247, theta=-52.160495 -> V=1.0, theta=0.0
% INFO    : Bus 84250	: V=0.9740675, theta=-52.935291 -> V=1.0, theta=0.0
% INFO    : Bus 84251	: V=0.9816667, theta=-53.463701 -> V=1.0, theta=0.0
% INFO    : Bus 84252	: V=0.9785103, theta=-53.124581 -> V=1.0, theta=0.0
% INFO    : Bus 84253	: V=0.9786624, theta=-50.936621 -> V=1.0, theta=0.0
% INFO    : Bus 84254	: V=0.9710588, theta=-52.69846 -> V=1.0, theta=0.0
% INFO    : Bus 84255	: V=0.9745211, theta=-57.629641 -> V=1.0, theta=0.0
% INFO    : Bus 84256	: V=0.9667652, theta=-59.296035 -> V=1.0, theta=0.0
% INFO    : Bus 84257	: V=0.96607, theta=-59.656357 -> V=1.0, theta=0.0
% INFO    : Bus 84258	: V=0.9771105, theta=-59.976378 -> V=1.0, theta=0.0
% INFO    : Bus 84259	: V=0.9826966, theta=-59.060065 -> V=1.0, theta=0.0
% INFO    : Bus 84260	: V=0.9809754, theta=-59.292062 -> V=1.0, theta=0.0
% INFO    : Bus 84261	: V=0.9841845, theta=-58.528895 -> V=1.0, theta=0.0
% INFO    : Bus 84262	: V=0.9850894, theta=-58.049259 -> V=1.0, theta=0.0
% INFO    : Bus 84263	: V=0.9827153, theta=-60.132986 -> V=1.0, theta=0.0
% INFO    : Bus 84264	: V=0.9825865, theta=-60.106136 -> V=1.0, theta=0.0
% INFO    : Bus 84265	: V=0.9780144, theta=-59.482565 -> V=1.0, theta=0.0
% INFO    : Bus 84266	: V=0.9798113, theta=-58.890389 -> V=1.0, theta=0.0
% INFO    : Bus 84267	: V=0.9801719, theta=-58.886335 -> V=1.0, theta=0.0
% INFO    : Bus 84268	: V=1.0173396, theta=-38.099275 -> V=1.0, theta=0.0
% INFO    : Bus 84269	: V=1.0094126, theta=-39.085559 -> V=1.0, theta=0.0
% INFO    : Bus 84270	: V=1.0193852, theta=-37.519141 -> V=1.0, theta=0.0
% INFO    : Bus 84271	: V=1.0182799, theta=-37.882812 -> V=1.0, theta=0.0
% INFO    : Bus 84272	: V=0.9592375, theta=-57.522747 -> V=1.0, theta=0.0
% INFO    : Bus 84273	: V=0.9566193, theta=-57.774483 -> V=1.0, theta=0.0
% INFO    : Bus 84274	: V=0.9601169, theta=-57.270206 -> V=1.0, theta=0.0
% INFO    : Bus 84275	: V=0.9608901, theta=-57.685551 -> V=1.0, theta=0.0
% INFO    : Bus 84276	: V=0.9622302, theta=-57.352434 -> V=1.0, theta=0.0
% INFO    : Bus 84277	: V=0.9676101, theta=-56.998747 -> V=1.0, theta=0.0
% INFO    : Bus 84278	: V=0.9488802, theta=-57.260712 -> V=1.0, theta=0.0
% INFO    : Bus 84279	: V=0.9572459, theta=-56.510922 -> V=1.0, theta=0.0
% INFO    : Bus 84280	: V=0.9590979, theta=-56.530802 -> V=1.0, theta=0.0
% INFO    : Bus 84281	: V=0.954569, theta=-55.196241 -> V=1.0, theta=0.0
% INFO    : Bus 84282	: V=0.9628871, theta=-54.90636 -> V=1.0, theta=0.0
% INFO    : Bus 84283	: V=0.9596939, theta=-56.053683 -> V=1.0, theta=0.0
% INFO    : Bus 84284	: V=0.955744, theta=-56.201451 -> V=1.0, theta=0.0
% INFO    : Bus 84285	: V=0.953273, theta=-56.006057 -> V=1.0, theta=0.0
% INFO    : Bus 84286	: V=0.9535546, theta=-55.424576 -> V=1.0, theta=0.0
% INFO    : Bus 84287	: V=0.9792854, theta=-51.733644 -> V=1.0, theta=0.0
% INFO    : Bus 84288	: V=0.9771585, theta=-52.096214 -> V=1.0, theta=0.0
% INFO    : Bus 84289	: V=0.9763575, theta=-52.107945 -> V=1.0, theta=0.0
% INFO    : Bus 84290	: V=0.9748388, theta=-52.217383 -> V=1.0, theta=0.0
% INFO    : Bus 84291	: V=0.9785275, theta=-51.817437 -> V=1.0, theta=0.0
% INFO    : Bus 84292	: V=0.9761068, theta=-52.317756 -> V=1.0, theta=0.0
% INFO    : Bus 84293	: V=0.9780722, theta=-52.166854 -> V=1.0, theta=0.0
% INFO    : Bus 84294	: V=0.9743035, theta=-52.419455 -> V=1.0, theta=0.0
% INFO    : Bus 84295	: V=0.9615798, theta=-53.591801 -> V=1.0, theta=0.0
% INFO    : Bus 84296	: V=0.97832, theta=-51.782919 -> V=1.0, theta=0.0
% INFO    : Bus 84297	: V=0.973733, theta=-52.39818 -> V=1.0, theta=0.0
% INFO    : Bus 84298	: V=0.9753343, theta=-52.117029 -> V=1.0, theta=0.0
% INFO    : Bus 84299	: V=0.9762691, theta=-52.065974 -> V=1.0, theta=0.0
% INFO    : Bus 84300	: V=0.973117, theta=-52.375814 -> V=1.0, theta=0.0
% INFO    : Bus 84301	: V=0.9731132, theta=-52.390524 -> V=1.0, theta=0.0
% INFO    : Bus 84302	: V=0.9819608, theta=-51.378201 -> V=1.0, theta=0.0
% INFO    : Bus 84303	: V=0.9791417, theta=-51.855911 -> V=1.0, theta=0.0
% INFO    : Bus 84304	: V=0.9777331, theta=-52.065124 -> V=1.0, theta=0.0
% INFO    : Bus 84305	: V=0.9760411, theta=-52.084149 -> V=1.0, theta=0.0
% INFO    : Bus 84306	: V=0.9756838, theta=-52.080778 -> V=1.0, theta=0.0
% INFO    : Bus 84307	: V=0.9753701, theta=-52.092955 -> V=1.0, theta=0.0
% INFO    : Bus 84308	: V=0.9746421, theta=-52.088276 -> V=1.0, theta=0.0
% INFO    : Bus 84309	: V=0.9765182, theta=-51.856287 -> V=1.0, theta=0.0
% INFO    : Bus 84310	: V=0.9744543, theta=-52.122937 -> V=1.0, theta=0.0
% INFO    : Bus 84311	: V=0.9774615, theta=-51.689683 -> V=1.0, theta=0.0
% INFO    : Bus 84312	: V=0.9784328, theta=-51.5525 -> V=1.0, theta=0.0
% INFO    : Bus 84313	: V=0.9779801, theta=-51.529965 -> V=1.0, theta=0.0
% INFO    : Bus 84314	: V=0.9799189, theta=-51.38405 -> V=1.0, theta=0.0
% INFO    : Bus 84315	: V=0.9792262, theta=-51.456799 -> V=1.0, theta=0.0
% INFO    : Bus 84316	: V=0.982269, theta=-50.917007 -> V=1.0, theta=0.0
% INFO    : Bus 84317	: V=0.9890624, theta=-50.066273 -> V=1.0, theta=0.0
% INFO    : Bus 84318	: V=0.9892646, theta=-50.005499 -> V=1.0, theta=0.0
% INFO    : Bus 84319	: V=0.9898017, theta=-49.811836 -> V=1.0, theta=0.0
% INFO    : Bus 84320	: V=0.9803937, theta=-51.171462 -> V=1.0, theta=0.0
% INFO    : Bus 84321	: V=0.9831701, theta=-51.10671 -> V=1.0, theta=0.0
% INFO    : Bus 84322	: V=0.9887245, theta=-50.568217 -> V=1.0, theta=0.0
% INFO    : Bus 84323	: V=0.9891584, theta=-50.445904 -> V=1.0, theta=0.0
% INFO    : Bus 84324	: V=0.9875257, theta=-50.694242 -> V=1.0, theta=0.0
% INFO    : Bus 84325	: V=0.990689, theta=-50.310746 -> V=1.0, theta=0.0
% INFO    : Bus 84326	: V=0.9929399, theta=-49.938168 -> V=1.0, theta=0.0
% INFO    : Bus 84327	: V=0.9916007, theta=-50.181048 -> V=1.0, theta=0.0
% INFO    : Bus 84328	: V=0.9894285, theta=-50.487073 -> V=1.0, theta=0.0
% INFO    : Bus 84329	: V=0.9743199, theta=-52.472135 -> V=1.0, theta=0.0
% INFO    : Bus 84330	: V=0.9776176, theta=-52.00371 -> V=1.0, theta=0.0
% INFO    : Bus 84331	: V=0.9741871, theta=-52.271293 -> V=1.0, theta=0.0
% INFO    : Bus 84332	: V=0.9777686, theta=-51.883864 -> V=1.0, theta=0.0
% INFO    : Bus 84333	: V=0.9701755, theta=-53.27536 -> V=1.0, theta=0.0
% INFO    : Bus 84334	: V=0.9693467, theta=-53.255055 -> V=1.0, theta=0.0
% INFO    : Bus 84335	: V=0.9675239, theta=-53.541427 -> V=1.0, theta=0.0
% INFO    : Bus 84336	: V=0.9666777, theta=-53.329642 -> V=1.0, theta=0.0
% INFO    : Bus 84337	: V=0.967128, theta=-53.175041 -> V=1.0, theta=0.0
% INFO    : Bus 84338	: V=0.9715599, theta=-52.525501 -> V=1.0, theta=0.0
% INFO    : Bus 84339	: V=0.97145, theta=-52.412996 -> V=1.0, theta=0.0
% INFO    : Bus 84340	: V=0.9716193, theta=-52.524529 -> V=1.0, theta=0.0
% INFO    : Bus 84341	: V=0.9631107, theta=-53.683479 -> V=1.0, theta=0.0
% INFO    : Bus 84342	: V=0.9641948, theta=-53.510212 -> V=1.0, theta=0.0
% INFO    : Bus 84343	: V=0.9580089, theta=-54.763412 -> V=1.0, theta=0.0
% INFO    : Bus 84344	: V=0.9630617, theta=-54.126099 -> V=1.0, theta=0.0
% INFO    : Bus 84345	: V=0.9575337, theta=-54.848654 -> V=1.0, theta=0.0
% INFO    : Bus 84346	: V=0.9551722, theta=-54.894472 -> V=1.0, theta=0.0
% INFO    : Bus 84347	: V=0.9634598, theta=-54.159525 -> V=1.0, theta=0.0
% INFO    : Bus 84348	: V=0.9619206, theta=-54.225231 -> V=1.0, theta=0.0
% INFO    : Bus 84349	: V=0.9917806, theta=-50.195024 -> V=1.0, theta=0.0
% INFO    : Bus 84350	: V=0.9895443, theta=-50.412956 -> V=1.0, theta=0.0
% INFO    : Bus 84351	: V=0.9799589, theta=-51.680192 -> V=1.0, theta=0.0
% INFO    : Bus 84352	: V=0.9769396, theta=-52.231381 -> V=1.0, theta=0.0
% INFO    : Bus 84353	: V=1.0093755, theta=-42.059498 -> V=1.0, theta=0.0
% INFO    : Bus 84354	: V=0.9708732, theta=-58.818317 -> V=1.0, theta=0.0
% INFO    : Bus 84355	: V=0.9656614, theta=-57.080734 -> V=1.0, theta=0.0
% INFO    : Bus 84356	: V=0.9911314, theta=-49.214763 -> V=1.0, theta=0.0
% INFO    : Bus 84357	: V=0.9944015, theta=-47.28572 -> V=1.0, theta=0.0
% INFO    : Bus 84358	: V=1.0029859, theta=-46.869161 -> V=1.0, theta=0.0
% INFO    : Bus 84359	: V=0.9977296, theta=-47.266909 -> V=1.0, theta=0.0
% INFO    : Bus 84360	: V=0.9992788, theta=-46.527181 -> V=1.0, theta=0.0
% INFO    : Bus 84361	: V=0.9973161, theta=-47.197603 -> V=1.0, theta=0.0
% INFO    : Bus 84362	: V=0.9969531, theta=-47.056674 -> V=1.0, theta=0.0
% INFO    : Bus 84363	: V=0.9963099, theta=-47.104181 -> V=1.0, theta=0.0
% INFO    : Bus 84364	: V=1.0200494, theta=-40.029994 -> V=1.0, theta=0.0
% INFO    : Bus 84365	: V=1.0194271, theta=-40.310861 -> V=1.0, theta=0.0
% INFO    : Bus 84366	: V=1.0068453, theta=-52.332399 -> V=1.0, theta=0.0
% INFO    : Bus 84367	: V=1.0061111, theta=-52.380261 -> V=1.0, theta=0.0
% INFO    : Bus 84368	: V=1.0046445, theta=-52.661712 -> V=1.0, theta=0.0
% INFO    : Bus 84369	: V=1.0063402, theta=-51.884651 -> V=1.0, theta=0.0
% INFO    : Bus 84370	: V=1.0035112, theta=-52.60409 -> V=1.0, theta=0.0
% INFO    : Bus 84371	: V=0.9967818, theta=-53.098229 -> V=1.0, theta=0.0
% INFO    : Bus 84372	: V=1.0071674, theta=-52.195058 -> V=1.0, theta=0.0
% INFO    : Bus 84373	: V=0.9641418, theta=-59.220039 -> V=1.0, theta=0.0
% INFO    : Bus 84374	: V=0.9960361, theta=-55.342399 -> V=1.0, theta=0.0
% INFO    : Bus 84375	: V=0.9869302, theta=-56.769665 -> V=1.0, theta=0.0
% INFO    : Bus 84376	: V=0.9873693, theta=-48.117375 -> V=1.0, theta=0.0
% INFO    : Bus 84377	: V=0.994396, theta=-45.988804 -> V=1.0, theta=0.0
% INFO    : Bus 84378	: V=0.9872409, theta=-48.679621 -> V=1.0, theta=0.0
% INFO    : Bus 84379	: V=0.9814895, theta=-49.03522 -> V=1.0, theta=0.0
% INFO    : Bus 84380	: V=0.9868382, theta=-48.880577 -> V=1.0, theta=0.0
% INFO    : Bus 84381	: V=0.9873242, theta=-48.642402 -> V=1.0, theta=0.0
% INFO    : Bus 84382	: V=0.9829436, theta=-50.944997 -> V=1.0, theta=0.0
% INFO    : Bus 84383	: V=0.9935417, theta=-46.699162 -> V=1.0, theta=0.0
% INFO    : Bus 84384	: V=0.9870245, theta=-47.214893 -> V=1.0, theta=0.0
% INFO    : Bus 84385	: V=0.9936527, theta=-43.75905 -> V=1.0, theta=0.0
% INFO    : Bus 84386	: V=0.982857, theta=-45.158225 -> V=1.0, theta=0.0
% INFO    : Bus 84387	: V=0.9747108, theta=-59.25538 -> V=1.0, theta=0.0
% INFO    : Bus 84388	: V=0.9690398, theta=-56.108939 -> V=1.0, theta=0.0
% INFO    : Bus 84389	: V=0.9701598, theta=-56.475994 -> V=1.0, theta=0.0
% INFO    : Bus 84390	: V=0.9658104, theta=-55.765388 -> V=1.0, theta=0.0
% INFO    : Bus 84391	: V=0.9695894, theta=-54.991064 -> V=1.0, theta=0.0
% INFO    : Bus 84392	: V=0.9742087, theta=-58.267765 -> V=1.0, theta=0.0
% INFO    : Bus 84393	: V=0.9729506, theta=-57.347124 -> V=1.0, theta=0.0
% INFO    : Bus 84394	: V=0.9777587, theta=-58.14145 -> V=1.0, theta=0.0
% INFO    : Bus 84395	: V=0.9810226, theta=-57.753311 -> V=1.0, theta=0.0
% INFO    : Bus 84396	: V=0.9796051, theta=-58.23305 -> V=1.0, theta=0.0
% INFO    : Bus 84397	: V=0.978849, theta=-56.964211 -> V=1.0, theta=0.0
% INFO    : Bus 84398	: V=0.977894, theta=-57.735312 -> V=1.0, theta=0.0
% INFO    : Bus 84399	: V=0.9792147, theta=-56.969064 -> V=1.0, theta=0.0
% INFO    : Bus 84400	: V=0.9780506, theta=-58.526602 -> V=1.0, theta=0.0
% INFO    : Bus 84401	: V=0.982402, theta=-56.256548 -> V=1.0, theta=0.0
% INFO    : Bus 84402	: V=0.9832264, theta=-56.905869 -> V=1.0, theta=0.0
% INFO    : Bus 84403	: V=0.9766374, theta=-53.188333 -> V=1.0, theta=0.0
% INFO    : Bus 84404	: V=0.9938432, theta=-50.7087 -> V=1.0, theta=0.0
% INFO    : Bus 84405	: V=0.9974291, theta=-49.684036 -> V=1.0, theta=0.0
% INFO    : Bus 84406	: V=0.996321, theta=-50.108371 -> V=1.0, theta=0.0
% INFO    : Bus 84407	: V=0.9865285, theta=-51.465299 -> V=1.0, theta=0.0
% INFO    : Bus 84408	: V=0.9976959, theta=-49.69334 -> V=1.0, theta=0.0
% INFO    : Bus 84409	: V=0.995535, theta=-50.125176 -> V=1.0, theta=0.0
% INFO    : Bus 84410	: V=0.9701585, theta=-56.12101 -> V=1.0, theta=0.0
% INFO    : Bus 84411	: V=0.9797719, theta=-57.555307 -> V=1.0, theta=0.0
% INFO    : Bus 84412	: V=0.9785348, theta=-58.11171 -> V=1.0, theta=0.0
% INFO    : Bus 84413	: V=0.9815992, theta=-57.938139 -> V=1.0, theta=0.0
% INFO    : Bus 84414	: V=0.9789319, theta=-57.996653 -> V=1.0, theta=0.0
% INFO    : Bus 84415	: V=0.9781891, theta=-58.238687 -> V=1.0, theta=0.0
% INFO    : Bus 84416	: V=0.9794025, theta=-58.578914 -> V=1.0, theta=0.0
% INFO    : Bus 84417	: V=0.9844249, theta=-57.378372 -> V=1.0, theta=0.0
% INFO    : Bus 84418	: V=0.988528, theta=-55.532056 -> V=1.0, theta=0.0
% INFO    : Bus 84419	: V=0.9886985, theta=-56.215981 -> V=1.0, theta=0.0
% INFO    : Bus 84420	: V=0.9798533, theta=-58.505352 -> V=1.0, theta=0.0
% INFO    : Bus 84421	: V=0.9776771, theta=-58.699133 -> V=1.0, theta=0.0
% INFO    : Bus 84422	: V=0.9796522, theta=-58.391534 -> V=1.0, theta=0.0
% INFO    : Bus 84423	: V=0.9801287, theta=-56.875781 -> V=1.0, theta=0.0
% INFO    : Bus 84424	: V=0.9905581, theta=-54.452692 -> V=1.0, theta=0.0
% INFO    : Bus 84425	: V=0.9783635, theta=-58.085689 -> V=1.0, theta=0.0
% INFO    : Bus 84426	: V=0.9895563, theta=-46.440929 -> V=1.0, theta=0.0
% INFO    : Bus 84427	: V=0.9897318, theta=-46.333967 -> V=1.0, theta=0.0
% INFO    : Bus 84428	: V=0.9938621, theta=-45.561007 -> V=1.0, theta=0.0
% INFO    : Bus 84429	: V=0.9962196, theta=-45.475044 -> V=1.0, theta=0.0
% INFO    : Bus 84430	: V=0.9950728, theta=-45.628919 -> V=1.0, theta=0.0
% INFO    : Bus 84431	: V=0.9924524, theta=-45.851267 -> V=1.0, theta=0.0
% INFO    : Bus 84432	: V=0.992069, theta=-46.025478 -> V=1.0, theta=0.0
% INFO    : Bus 84433	: V=0.9952312, theta=-45.646084 -> V=1.0, theta=0.0
% INFO    : Bus 84434	: V=0.9970176, theta=-45.629173 -> V=1.0, theta=0.0
% INFO    : Bus 84435	: V=0.9974148, theta=-53.756478 -> V=1.0, theta=0.0
% INFO    : Bus 84436	: V=0.9950113, theta=-54.532778 -> V=1.0, theta=0.0
% INFO    : Bus 84437	: V=0.9936377, theta=-54.113583 -> V=1.0, theta=0.0
% INFO    : Bus 84438	: V=0.9784102, theta=-56.126645 -> V=1.0, theta=0.0
% INFO    : Bus 84439	: V=0.9787667, theta=-56.197462 -> V=1.0, theta=0.0
% INFO    : Bus 84440	: V=0.9813318, theta=-56.712481 -> V=1.0, theta=0.0
% INFO    : Bus 84441	: V=1.0039218, theta=-41.71626 -> V=1.0, theta=0.0
% INFO    : Bus 84442	: V=1.0017937, theta=-41.680154 -> V=1.0, theta=0.0
% INFO    : Bus 84443	: V=1.0045929, theta=-41.482241 -> V=1.0, theta=0.0
% INFO    : Bus 84444	: V=1.0157338, theta=-38.709392 -> V=1.0, theta=0.0
% INFO    : Bus 84445	: V=1.0135674, theta=-39.104818 -> V=1.0, theta=0.0
% INFO    : Bus 84446	: V=1.0119087, theta=-39.354685 -> V=1.0, theta=0.0
% INFO    : Bus 84447	: V=1.0113938, theta=-39.771287 -> V=1.0, theta=0.0
% INFO    : Bus 84448	: V=1.0095115, theta=-40.15399 -> V=1.0, theta=0.0
% INFO    : Bus 84449	: V=1.009908, theta=-40.06542 -> V=1.0, theta=0.0
% INFO    : Bus 84450	: V=1.0069, theta=-40.423473 -> V=1.0, theta=0.0
% INFO    : Bus 84451	: V=1.0061917, theta=-40.428801 -> V=1.0, theta=0.0
% INFO    : Bus 84452	: V=0.965851, theta=-57.653177 -> V=1.0, theta=0.0
% INFO    : Bus 84453	: V=0.96282, theta=-58.347248 -> V=1.0, theta=0.0
% INFO    : Bus 84454	: V=0.9621665, theta=-58.600484 -> V=1.0, theta=0.0
% INFO    : Bus 84455	: V=0.955603, theta=-57.078804 -> V=1.0, theta=0.0
% INFO    : Bus 84456	: V=0.9461343, theta=-57.298813 -> V=1.0, theta=0.0
% INFO    : Bus 84457	: V=0.9469601, theta=-57.259639 -> V=1.0, theta=0.0
% INFO    : Bus 84458	: V=0.9490085, theta=-57.047203 -> V=1.0, theta=0.0
% INFO    : Bus 84459	: V=0.9713967, theta=-55.488293 -> V=1.0, theta=0.0
% INFO    : Bus 84460	: V=0.97872, theta=-54.504822 -> V=1.0, theta=0.0
% INFO    : Bus 84461	: V=0.9756933, theta=-55.181465 -> V=1.0, theta=0.0
% INFO    : Bus 84462	: V=0.9743329, theta=-55.28073 -> V=1.0, theta=0.0
% INFO    : Bus 84463	: V=0.9722099, theta=-55.503912 -> V=1.0, theta=0.0
% INFO    : Bus 84464	: V=0.978109, theta=-54.522291 -> V=1.0, theta=0.0
% INFO    : Bus 84465	: V=0.982323, theta=-52.203457 -> V=1.0, theta=0.0
% INFO    : Bus 84466	: V=0.9799454, theta=-52.62654 -> V=1.0, theta=0.0
% INFO    : Bus 84467	: V=0.9779627, theta=-57.422462 -> V=1.0, theta=0.0
% INFO    : Bus 84468	: V=0.9759528, theta=-55.637314 -> V=1.0, theta=0.0
% INFO    : Bus 84469	: V=0.9810189, theta=-55.213037 -> V=1.0, theta=0.0
% INFO    : Bus 84470	: V=0.9808479, theta=-55.537166 -> V=1.0, theta=0.0
% INFO    : Bus 84471	: V=0.9746288, theta=-55.461537 -> V=1.0, theta=0.0
% INFO    : Bus 84472	: V=0.9745393, theta=-55.622259 -> V=1.0, theta=0.0
% INFO    : Bus 84473	: V=0.9750276, theta=-55.707462 -> V=1.0, theta=0.0
% INFO    : Bus 84474	: V=0.9744458, theta=-55.935187 -> V=1.0, theta=0.0
% INFO    : Bus 84475	: V=0.9729251, theta=-55.449277 -> V=1.0, theta=0.0
% INFO    : Bus 84476	: V=0.9796893, theta=-53.185588 -> V=1.0, theta=0.0
% INFO    : Bus 84477	: V=0.9754622, theta=-53.022119 -> V=1.0, theta=0.0
% INFO    : Bus 84478	: V=0.9793221, theta=-53.595079 -> V=1.0, theta=0.0
% INFO    : Bus 84479	: V=0.9770637, theta=-55.90455 -> V=1.0, theta=0.0
% INFO    : Bus 84480	: V=0.9792198, theta=-54.588617 -> V=1.0, theta=0.0
% INFO    : Bus 84481	: V=0.9765047, theta=-55.218763 -> V=1.0, theta=0.0
% INFO    : Bus 84482	: V=0.9769022, theta=-55.83429 -> V=1.0, theta=0.0
% INFO    : Bus 84483	: V=0.9806517, theta=-54.838132 -> V=1.0, theta=0.0
% INFO    : Bus 84484	: V=0.9792762, theta=-55.322823 -> V=1.0, theta=0.0
% INFO    : Bus 84485	: V=0.9761201, theta=-55.266705 -> V=1.0, theta=0.0
% INFO    : Bus 84486	: V=0.9787885, theta=-54.97611 -> V=1.0, theta=0.0
% INFO    : Bus 84487	: V=0.9796036, theta=-55.282213 -> V=1.0, theta=0.0
% INFO    : Bus 84488	: V=0.9816257, theta=-55.246375 -> V=1.0, theta=0.0
% INFO    : Bus 84489	: V=0.9805258, theta=-54.411364 -> V=1.0, theta=0.0
% INFO    : Bus 84490	: V=0.9770561, theta=-55.382119 -> V=1.0, theta=0.0
% INFO    : Bus 84491	: V=0.9712246, theta=-59.894654 -> V=1.0, theta=0.0
% INFO    : Bus 84492	: V=0.9762083, theta=-59.38908 -> V=1.0, theta=0.0
% INFO    : Bus 84493	: V=0.9795746, theta=-57.541903 -> V=1.0, theta=0.0
% INFO    : Bus 84494	: V=0.9789891, theta=-58.309954 -> V=1.0, theta=0.0
% INFO    : Bus 84495	: V=0.9806557, theta=-57.416577 -> V=1.0, theta=0.0
% INFO    : Bus 84496	: V=0.981733, theta=-57.989415 -> V=1.0, theta=0.0
% INFO    : Bus 84497	: V=0.975612, theta=-58.605616 -> V=1.0, theta=0.0
% INFO    : Bus 84498	: V=0.979996, theta=-57.481436 -> V=1.0, theta=0.0
% INFO    : Bus 84499	: V=0.9779951, theta=-58.432816 -> V=1.0, theta=0.0
% INFO    : Bus 84500	: V=0.9767029, theta=-59.4096 -> V=1.0, theta=0.0
% INFO    : Bus 84501	: V=0.9735128, theta=-59.717422 -> V=1.0, theta=0.0
% INFO    : Bus 84502	: V=0.9780273, theta=-58.240637 -> V=1.0, theta=0.0
% INFO    : Bus 84503	: V=0.9781957, theta=-58.743602 -> V=1.0, theta=0.0
% INFO    : Bus 84504	: V=0.9751723, theta=-59.537647 -> V=1.0, theta=0.0
% INFO    : Bus 84505	: V=0.9772212, theta=-59.196655 -> V=1.0, theta=0.0
% INFO    : Bus 84506	: V=0.9791062, theta=-58.083679 -> V=1.0, theta=0.0
% INFO    : Bus 84507	: V=0.977225, theta=-59.134537 -> V=1.0, theta=0.0
% INFO    : Bus 84508	: V=0.9755492, theta=-59.461801 -> V=1.0, theta=0.0
% INFO    : Bus 84509	: V=0.9766025, theta=-59.323465 -> V=1.0, theta=0.0
% INFO    : Bus 84510	: V=0.9749314, theta=-59.884074 -> V=1.0, theta=0.0
% INFO    : Bus 84511	: V=0.9791823, theta=-58.076936 -> V=1.0, theta=0.0
% INFO    : Bus 84512	: V=0.9778957, theta=-59.104678 -> V=1.0, theta=0.0
% INFO    : Bus 84513	: V=0.9744039, theta=-59.021964 -> V=1.0, theta=0.0
% INFO    : Bus 84514	: V=0.9774278, theta=-59.357669 -> V=1.0, theta=0.0
% INFO    : Bus 84515	: V=0.9761123, theta=-59.436171 -> V=1.0, theta=0.0
% INFO    : Bus 84516	: V=0.9735486, theta=-59.7907 -> V=1.0, theta=0.0
% INFO    : Bus 84517	: V=0.9717941, theta=-59.895368 -> V=1.0, theta=0.0
% INFO    : Bus 84518	: V=0.9745769, theta=-59.466541 -> V=1.0, theta=0.0
% INFO    : Bus 84519	: V=0.9757461, theta=-59.516133 -> V=1.0, theta=0.0
% INFO    : Bus 84520	: V=0.9745418, theta=-59.517833 -> V=1.0, theta=0.0
% INFO    : Bus 84521	: V=0.9744685, theta=-59.53553 -> V=1.0, theta=0.0
% INFO    : Bus 84522	: V=0.9784442, theta=-58.887142 -> V=1.0, theta=0.0
% INFO    : Bus 84523	: V=0.9773071, theta=-58.822147 -> V=1.0, theta=0.0
% INFO    : Bus 84524	: V=0.975773, theta=-59.097739 -> V=1.0, theta=0.0
% INFO    : Bus 84525	: V=0.9788315, theta=-58.844367 -> V=1.0, theta=0.0
% INFO    : Bus 84526	: V=0.9781075, theta=-58.802361 -> V=1.0, theta=0.0
% INFO    : Bus 84527	: V=0.9688276, theta=-59.851334 -> V=1.0, theta=0.0
% INFO    : Bus 84528	: V=0.9811353, theta=-56.588237 -> V=1.0, theta=0.0
% INFO    : Bus 84529	: V=0.9809108, theta=-58.21476 -> V=1.0, theta=0.0
% INFO    : Bus 84530	: V=0.9799545, theta=-58.283393 -> V=1.0, theta=0.0
% INFO    : Bus 84531	: V=0.9765836, theta=-58.018012 -> V=1.0, theta=0.0
% INFO    : Bus 84532	: V=0.9776722, theta=-58.328949 -> V=1.0, theta=0.0
% INFO    : Bus 84533	: V=0.9766337, theta=-59.294001 -> V=1.0, theta=0.0
% INFO    : Bus 84534	: V=0.9748977, theta=-59.714155 -> V=1.0, theta=0.0
% INFO    : Bus 84535	: V=0.9746356, theta=-59.859244 -> V=1.0, theta=0.0
% INFO    : Bus 84536	: V=0.9779967, theta=-59.557522 -> V=1.0, theta=0.0
% INFO    : Bus 84537	: V=0.9802627, theta=-57.756926 -> V=1.0, theta=0.0
% INFO    : Bus 84538	: V=0.981023, theta=-58.141499 -> V=1.0, theta=0.0
% INFO    : Bus 84539	: V=0.9789669, theta=-58.515377 -> V=1.0, theta=0.0
% INFO    : Bus 84540	: V=0.9676622, theta=-60.560259 -> V=1.0, theta=0.0
% INFO    : Bus 84541	: V=0.9772266, theta=-57.373648 -> V=1.0, theta=0.0
% INFO    : Bus 84542	: V=0.9788949, theta=-58.906877 -> V=1.0, theta=0.0
% INFO    : Bus 84543	: V=0.9728313, theta=-59.847495 -> V=1.0, theta=0.0
% INFO    : Bus 84544	: V=0.9778607, theta=-58.83797 -> V=1.0, theta=0.0
% INFO    : Bus 84545	: V=0.9859385, theta=-54.640847 -> V=1.0, theta=0.0
% INFO    : Bus 84546	: V=0.9845691, theta=-54.798988 -> V=1.0, theta=0.0
% INFO    : Bus 84547	: V=0.9801534, theta=-55.037659 -> V=1.0, theta=0.0
% INFO    : Bus 84548	: V=0.9834807, theta=-54.78633 -> V=1.0, theta=0.0
% INFO    : Bus 84549	: V=0.9785868, theta=-55.126417 -> V=1.0, theta=0.0
% INFO    : Bus 84550	: V=0.9787817, theta=-55.277398 -> V=1.0, theta=0.0
% INFO    : Bus 84551	: V=0.9778146, theta=-55.395284 -> V=1.0, theta=0.0
% INFO    : Bus 84552	: V=0.9774866, theta=-55.293461 -> V=1.0, theta=0.0
% INFO    : Bus 84553	: V=0.979028, theta=-55.389598 -> V=1.0, theta=0.0
% INFO    : Bus 84554	: V=0.9734967, theta=-54.884469 -> V=1.0, theta=0.0
% INFO    : Bus 84555	: V=0.9687631, theta=-53.737288 -> V=1.0, theta=0.0
% INFO    : Bus 84556	: V=0.9707971, theta=-53.468209 -> V=1.0, theta=0.0
% INFO    : Bus 84557	: V=0.9911679, theta=-54.165429 -> V=1.0, theta=0.0
% INFO    : Bus 84558	: V=0.9898646, theta=-54.260196 -> V=1.0, theta=0.0
% INFO    : Bus 84559	: V=0.9900746, theta=-55.288514 -> V=1.0, theta=0.0
% INFO    : Bus 84560	: V=0.9875748, theta=-54.619767 -> V=1.0, theta=0.0
% INFO    : Bus 84561	: V=0.9716156, theta=-54.966718 -> V=1.0, theta=0.0
% INFO    : Bus 84562	: V=0.970767, theta=-55.541638 -> V=1.0, theta=0.0
% INFO    : Bus 84563	: V=0.9830153, theta=-54.917028 -> V=1.0, theta=0.0
% INFO    : Bus 84564	: V=0.9777838, theta=-53.53914 -> V=1.0, theta=0.0
% INFO    : Bus 84565	: V=0.989596, theta=-51.845658 -> V=1.0, theta=0.0
% INFO    : Bus 84566	: V=0.9802024, theta=-53.571238 -> V=1.0, theta=0.0
% INFO    : Bus 84567	: V=0.9896484, theta=-51.459711 -> V=1.0, theta=0.0
% INFO    : Bus 84568	: V=0.9888509, theta=-51.399793 -> V=1.0, theta=0.0
% INFO    : Bus 84569	: V=0.9867893, theta=-50.662919 -> V=1.0, theta=0.0
% INFO    : Bus 84570	: V=0.9901387, theta=-48.123607 -> V=1.0, theta=0.0
% INFO    : Bus 84571	: V=0.9874532, theta=-48.980462 -> V=1.0, theta=0.0
% INFO    : Bus 84572	: V=0.9900422, theta=-47.983566 -> V=1.0, theta=0.0
% INFO    : Bus 84573	: V=0.9534777, theta=-57.438801 -> V=1.0, theta=0.0
% INFO    : Bus 84574	: V=0.9605141, theta=-56.577107 -> V=1.0, theta=0.0
% INFO    : Bus 84575	: V=0.9738672, theta=-54.514422 -> V=1.0, theta=0.0
% INFO    : Bus 84576	: V=0.9715748, theta=-55.166431 -> V=1.0, theta=0.0
% INFO    : Bus 84577	: V=0.9670476, theta=-55.579619 -> V=1.0, theta=0.0
% INFO    : Bus 84578	: V=0.9762741, theta=-55.494834 -> V=1.0, theta=0.0
% INFO    : Bus 84579	: V=0.9695492, theta=-57.512069 -> V=1.0, theta=0.0
% INFO    : Bus 84580	: V=0.9701084, theta=-57.33629 -> V=1.0, theta=0.0
% INFO    : Bus 84581	: V=1.0116063, theta=-40.650442 -> V=1.0, theta=0.0
% INFO    : Bus 84582	: V=0.9965668, theta=-49.534713 -> V=1.0, theta=0.0
% INFO    : Bus 84583	: V=0.9949317, theta=-49.704725 -> V=1.0, theta=0.0
% INFO    : Bus 84584	: V=0.9921425, theta=-50.026954 -> V=1.0, theta=0.0
% INFO    : Bus 84585	: V=0.9841718, theta=-50.764662 -> V=1.0, theta=0.0
% INFO    : Bus 84586	: V=0.9940174, theta=-49.611878 -> V=1.0, theta=0.0
% INFO    : Bus 84587	: V=0.9888758, theta=-49.331662 -> V=1.0, theta=0.0
% INFO    : Bus 84588	: V=0.9843662, theta=-50.000125 -> V=1.0, theta=0.0
% INFO    : Bus 84589	: V=0.989244, theta=-48.955431 -> V=1.0, theta=0.0
% INFO    : Bus 84590	: V=0.9856812, theta=-49.597795 -> V=1.0, theta=0.0
% INFO    : Bus 84591	: V=0.9837328, theta=-50.14088 -> V=1.0, theta=0.0
% INFO    : Bus 84592	: V=0.9801153, theta=-50.345617 -> V=1.0, theta=0.0
% INFO    : Bus 84593	: V=0.9749625, theta=-49.773903 -> V=1.0, theta=0.0
% INFO    : Bus 84594	: V=0.9727065, theta=-50.071656 -> V=1.0, theta=0.0
% INFO    : Bus 84595	: V=0.9745733, theta=-49.851228 -> V=1.0, theta=0.0
% INFO    : Bus 84596	: V=0.9697904, theta=-49.80162 -> V=1.0, theta=0.0
% INFO    : Bus 84597	: V=0.989787, theta=-48.647419 -> V=1.0, theta=0.0
% INFO    : Bus 84598	: V=0.9893697, theta=-48.31915 -> V=1.0, theta=0.0
% INFO    : Bus 84599	: V=0.9861779, theta=-50.604064 -> V=1.0, theta=0.0
% INFO    : Bus 84600	: V=1.0089293, theta=-41.027715 -> V=1.0, theta=0.0
% INFO    : Bus 84601	: V=0.9982618, theta=-43.032754 -> V=1.0, theta=0.0
% INFO    : Bus 84602	: V=0.994644, theta=-42.704349 -> V=1.0, theta=0.0
% INFO    : Bus 84603	: V=0.9904595, theta=-43.114074 -> V=1.0, theta=0.0
% INFO    : Bus 84604	: V=0.9846509, theta=-43.232172 -> V=1.0, theta=0.0
% INFO    : Bus 84605	: V=1.0018819, theta=-41.748626 -> V=1.0, theta=0.0
% INFO    : Bus 84606	: V=0.9897383, theta=-55.290671 -> V=1.0, theta=0.0
% INFO    : Bus 84607	: V=0.9884597, theta=-55.674075 -> V=1.0, theta=0.0
% INFO    : Bus 84608	: V=0.9881272, theta=-55.792154 -> V=1.0, theta=0.0
% INFO    : Bus 84609	: V=0.989711, theta=-55.262847 -> V=1.0, theta=0.0
% INFO    : Bus 84610	: V=0.9909092, theta=-55.55001 -> V=1.0, theta=0.0
% INFO    : Bus 84611	: V=0.9867998, theta=-56.76443 -> V=1.0, theta=0.0
% INFO    : Bus 84612	: V=0.9875495, theta=-56.9369 -> V=1.0, theta=0.0
% INFO    : Bus 84613	: V=0.9854288, theta=-57.14684 -> V=1.0, theta=0.0
% INFO    : Bus 84614	: V=0.9868411, theta=-56.148687 -> V=1.0, theta=0.0
% INFO    : Bus 84615	: V=0.9861703, theta=-56.246104 -> V=1.0, theta=0.0
% INFO    : Bus 84616	: V=0.9878196, theta=-57.437945 -> V=1.0, theta=0.0
% INFO    : Bus 84617	: V=0.9883671, theta=-57.338064 -> V=1.0, theta=0.0
% INFO    : Bus 84618	: V=0.9865926, theta=-57.569019 -> V=1.0, theta=0.0
% INFO    : Bus 84619	: V=0.9825477, theta=-58.50826 -> V=1.0, theta=0.0
% INFO    : Bus 84620	: V=0.9839494, theta=-57.880896 -> V=1.0, theta=0.0
% INFO    : Bus 84621	: V=0.9851525, theta=-55.803455 -> V=1.0, theta=0.0
% INFO    : Bus 84622	: V=0.9820245, theta=-58.602917 -> V=1.0, theta=0.0
% INFO    : Bus 84623	: V=0.9599962, theta=-57.530434 -> V=1.0, theta=0.0
% INFO    : Bus 84624	: V=0.982833, theta=-56.753116 -> V=1.0, theta=0.0
% INFO    : Bus 84625	: V=0.9897419, theta=-56.130258 -> V=1.0, theta=0.0
% INFO    : Bus 84626	: V=0.9767687, theta=-55.025622 -> V=1.0, theta=0.0
% INFO    : Bus 84627	: V=0.9724089, theta=-55.436922 -> V=1.0, theta=0.0
% INFO    : Bus 84628	: V=0.9698182, theta=-55.98808 -> V=1.0, theta=0.0
% INFO    : Bus 84629	: V=0.9883603, theta=-53.668082 -> V=1.0, theta=0.0
% INFO    : Bus 84630	: V=0.9829479, theta=-54.310137 -> V=1.0, theta=0.0
% INFO    : Bus 84631	: V=1.005646, theta=-52.063179 -> V=1.0, theta=0.0
% INFO    : Bus 84632	: V=0.9803197, theta=-55.390504 -> V=1.0, theta=0.0
% INFO    : Bus 84633	: V=0.9735205, theta=-56.644375 -> V=1.0, theta=0.0
% INFO    : Bus 84634	: V=0.9786586, theta=-55.14025 -> V=1.0, theta=0.0
% INFO    : Bus 84635	: V=0.9872735, theta=-54.619009 -> V=1.0, theta=0.0
% INFO    : Bus 84636	: V=0.9823666, theta=-54.718041 -> V=1.0, theta=0.0
% INFO    : Bus 84637	: V=0.9690411, theta=-55.642142 -> V=1.0, theta=0.0
% INFO    : Bus 84638	: V=0.9718056, theta=-57.073279 -> V=1.0, theta=0.0
% INFO    : Bus 84639	: V=0.959474, theta=-59.282254 -> V=1.0, theta=0.0
% INFO    : Bus 84640	: V=0.9669929, theta=-57.514788 -> V=1.0, theta=0.0
% INFO    : Bus 95338	: V=0.0, theta=0.0 -> V=1.0, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 20401	: Pg=791.86, Qg=38.25 -> Pg=900.0, Qg=98.15
% INFO    : Gen at bus 20401	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20401	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20402	: Pg=486.79, Qg=-81.17 -> Pg=458.95, Qg=50.45
% INFO    : Gen at bus 20402	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20402	: Pg=486.79, Qg=-81.17 -> Pg=458.95, Qg=50.45
% INFO    : Gen at bus 20402	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20402	: Pg=486.79, Qg=-81.17 -> Pg=458.95, Qg=50.45
% INFO    : Gen at bus 20402	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20402	: Pg=476.79, Qg=-81.17 -> Pg=448.95, Qg=50.45
% INFO    : Gen at bus 20402	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20402	: Pg=476.79, Qg=-81.17 -> Pg=448.95, Qg=50.45
% INFO    : Gen at bus 20402	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20403	: Pg=69.36, Qg=40.2 -> Pg=44.975, Qg=8.45
% INFO    : Gen at bus 20403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20403	: Pg=69.36, Qg=40.2 -> Pg=44.975, Qg=8.45
% INFO    : Gen at bus 20403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20403	: Pg=535.1, Qg=261.5 -> Pg=425.0, Qg=40.75
% INFO    : Gen at bus 20403	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20404	: Pg=535.1, Qg=-63.42 -> Pg=400.0, Qg=40.75
% INFO    : Gen at bus 20404	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20404	: Pg=535.1, Qg=-63.42 -> Pg=400.0, Qg=40.75
% INFO    : Gen at bus 20404	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20405	: Pg=111.48, Qg=38.82 -> Pg=83.75, Qg=8.5
% INFO    : Gen at bus 20405	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20405	: Pg=526.18, Qg=38.82 -> Pg=415.5, Qg=40.1
% INFO    : Gen at bus 20405	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20405	: Pg=526.18, Qg=38.82 -> Pg=380.5, Qg=40.1
% INFO    : Gen at bus 20405	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20406	: Pg=664.81, Qg=-55.43 -> Pg=447.95, Qg=96.1
% INFO    : Gen at bus 20406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20406	: Pg=664.81, Qg=-55.43 -> Pg=445.45, Qg=96.1
% INFO    : Gen at bus 20406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20406	: Pg=279.04, Qg=-55.43 -> Pg=205.8, Qg=40.3
% INFO    : Gen at bus 20406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20406	: Pg=518.55, Qg=-55.43 -> Pg=374.15, Qg=74.95
% INFO    : Gen at bus 20406	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20407	: Pg=29.8, Qg=32.42 -> Pg=49.1, Qg=12.65
% INFO    : Gen at bus 20407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20407	: Pg=29.8, Qg=32.42 -> Pg=49.1, Qg=12.65
% INFO    : Gen at bus 20407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20407	: Pg=179.54, Qg=32.42 -> Pg=192.6, Qg=20.0
% INFO    : Gen at bus 20407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20407	: Pg=179.54, Qg=32.42 -> Pg=192.6, Qg=20.0
% INFO    : Gen at bus 20407	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20408	: Pg=215.33, Qg=35.39 -> Pg=190.15, Qg=36.8
% INFO    : Gen at bus 20408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20408	: Pg=215.33, Qg=35.39 -> Pg=190.15, Qg=36.8
% INFO    : Gen at bus 20408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20408	: Pg=215.33, Qg=35.39 -> Pg=190.15, Qg=36.8
% INFO    : Gen at bus 20408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20408	: Pg=215.33, Qg=35.39 -> Pg=190.15, Qg=36.8
% INFO    : Gen at bus 20408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20408	: Pg=215.33, Qg=35.39 -> Pg=190.15, Qg=36.8
% INFO    : Gen at bus 20408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20408	: Pg=215.33, Qg=35.39 -> Pg=190.15, Qg=36.8
% INFO    : Gen at bus 20408	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20409	: Pg=201.35, Qg=26.82 -> Pg=156.6, Qg=29.1
% INFO    : Gen at bus 20409	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20409	: Pg=201.35, Qg=26.82 -> Pg=156.6, Qg=29.1
% INFO    : Gen at bus 20409	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20409	: Pg=211.07, Qg=26.82 -> Pg=161.5, Qg=30.5
% INFO    : Gen at bus 20409	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20410	: Pg=199.7, Qg=96.7 -> Pg=100.65, Qg=15.05
% INFO    : Gen at bus 20410	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20411	: Pg=188.67, Qg=118.0 -> Pg=145.2, Qg=27.25
% INFO    : Gen at bus 20411	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20411	: Pg=37.16, Qg=23.2 -> Pg=28.75, Qg=5.35
% INFO    : Gen at bus 20411	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20411	: Pg=409.35, Qg=186.25 -> Pg=281.55, Qg=59.15
% INFO    : Gen at bus 20411	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20412	: Pg=180.25, Qg=99.88 -> Pg=136.95, Qg=26.05
% INFO    : Gen at bus 20412	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20412	: Pg=180.25, Qg=99.88 -> Pg=136.95, Qg=26.05
% INFO    : Gen at bus 20412	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20412	: Pg=211.07, Qg=99.88 -> Pg=119.0, Qg=16.1
% INFO    : Gen at bus 20412	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20413	: Pg=172.42, Qg=-42.68 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 20413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20413	: Pg=172.42, Qg=-42.68 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 20413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20413	: Pg=172.42, Qg=-42.68 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 20413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20413	: Pg=172.42, Qg=-42.68 -> Pg=122.0, Qg=24.9
% INFO    : Gen at bus 20413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20413	: Pg=265.57, Qg=-42.68 -> Pg=169.0, Qg=38.4
% INFO    : Gen at bus 20413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20413	: Pg=265.57, Qg=-42.68 -> Pg=169.0, Qg=38.4
% INFO    : Gen at bus 20413	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=99.09, Qg=62.0 -> Pg=77.0, Qg=14.35
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=27.8, Qg=17.65 -> Pg=16.95, Qg=4.15
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=27.8, Qg=17.65 -> Pg=16.95, Qg=4.15
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=458.8, Qg=286.9 -> Pg=341.5, Qg=66.3
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=99.09, Qg=62.0 -> Pg=77.0, Qg=14.35
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=82.25, Qg=62.3 -> Pg=64.0, Qg=17.3
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=82.25, Qg=62.3 -> Pg=64.0, Qg=17.3
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=159.54, Qg=99.8 -> Pg=125.5, Qg=23.05
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=27.8, Qg=17.65 -> Pg=16.95, Qg=4.15
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=27.8, Qg=17.65 -> Pg=16.95, Qg=4.15
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=27.8, Qg=17.65 -> Pg=16.95, Qg=4.15
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20414	: Pg=27.8, Qg=17.65 -> Pg=16.95, Qg=4.15
% INFO    : Gen at bus 20414	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20415	: Pg=77.4, Qg=28.09 -> Pg=103.3, Qg=23.85
% INFO    : Gen at bus 20415	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20415	: Pg=77.4, Qg=28.09 -> Pg=103.3, Qg=23.85
% INFO    : Gen at bus 20415	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20415	: Pg=77.4, Qg=28.09 -> Pg=103.3, Qg=23.85
% INFO    : Gen at bus 20415	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20415	: Pg=152.51, Qg=28.09 -> Pg=201.5, Qg=46.25
% INFO    : Gen at bus 20415	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20416	: Pg=159.54, Qg=78.0 -> Pg=105.5, Qg=12.15
% INFO    : Gen at bus 20416	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20417	: Pg=151.12, Qg=-50.8 -> Pg=101.25, Qg=31.8
% INFO    : Gen at bus 20417	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20417	: Pg=151.12, Qg=-50.8 -> Pg=101.25, Qg=31.8
% INFO    : Gen at bus 20417	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20417	: Pg=213.44, Qg=-71.8 -> Pg=140.2, Qg=44.9
% INFO    : Gen at bus 20417	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20417	: Pg=574.44, Qg=-82.66 -> Pg=439.85, Qg=83.05
% INFO    : Gen at bus 20417	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=54.5, Qg=18.1 -> Pg=28.5, Qg=0.0
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=30.12, Qg=16.58 -> Pg=16.4, Qg=3.22
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=30.12, Qg=16.58 -> Pg=16.4, Qg=3.22
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=30.12, Qg=16.58 -> Pg=16.4, Qg=3.22
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=30.12, Qg=16.58 -> Pg=16.4, Qg=3.22
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=30.12, Qg=16.58 -> Pg=16.4, Qg=3.22
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=39.64, Qg=24.8 -> Pg=22.0, Qg=5.75
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=31.71, Qg=19.8 -> Pg=17.0, Qg=4.55
% INFO    : Gen at bus 20418	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20419	: Pg=148.64, Qg=62.19 -> Pg=107.5, Qg=21.5
% INFO    : Gen at bus 20419	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20419	: Pg=148.64, Qg=62.19 -> Pg=107.5, Qg=21.5
% INFO    : Gen at bus 20419	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20419	: Pg=148.64, Qg=62.19 -> Pg=104.25, Qg=21.5
% INFO    : Gen at bus 20419	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20419	: Pg=148.64, Qg=62.19 -> Pg=104.25, Qg=21.5
% INFO    : Gen at bus 20419	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20421	: Pg=127.83, Qg=29.54 -> Pg=99.5, Qg=9.75
% INFO    : Gen at bus 20421	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20421	: Pg=127.83, Qg=29.54 -> Pg=99.5, Qg=9.75
% INFO    : Gen at bus 20421	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20422	: Pg=136.85, Qg=78.3 -> Pg=86.315, Qg=16.15
% INFO    : Gen at bus 20422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20422	: Pg=126.34, Qg=90.3 -> Pg=88.61, Qg=23.9
% INFO    : Gen at bus 20422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20422	: Pg=126.84, Qg=90.7 -> Pg=88.96, Qg=24.0
% INFO    : Gen at bus 20422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20422	: Pg=126.84, Qg=90.7 -> Pg=88.96, Qg=24.0
% INFO    : Gen at bus 20422	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20423	: Pg=73.09, Qg=5.82 -> Pg=85.05, Qg=9.45
% INFO    : Gen at bus 20423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20423	: Pg=73.09, Qg=5.82 -> Pg=85.05, Qg=9.45
% INFO    : Gen at bus 20423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20423	: Pg=73.09, Qg=5.82 -> Pg=85.05, Qg=9.45
% INFO    : Gen at bus 20423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20423	: Pg=73.09, Qg=5.82 -> Pg=85.05, Qg=9.45
% INFO    : Gen at bus 20423	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=123.86, Qg=-14.99 -> Pg=91.0, Qg=17.9
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=122.08, Qg=-14.99 -> Pg=86.6, Qg=17.65
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=111.48, Qg=-14.99 -> Pg=81.25, Qg=16.1
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=111.48, Qg=-14.99 -> Pg=81.25, Qg=16.1
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=111.48, Qg=-14.99 -> Pg=83.75, Qg=23.45
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=190.26, Qg=-14.99 -> Pg=146.0, Qg=40.0
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20425	: Pg=383.49, Qg=-14.99 -> Pg=258.5, Qg=55.4
% INFO    : Gen at bus 20425	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20428	: Pg=68.28, Qg=0.28 -> Pg=74.35, Qg=14.85
% INFO    : Gen at bus 20428	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20428	: Pg=194.54, Qg=0.28 -> Pg=200.1, Qg=0.0
% INFO    : Gen at bus 20428	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20429	: Pg=103.5, Qg=45.6 -> Pg=52.45, Qg=0.0
% INFO    : Gen at bus 20429	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20430	: Pg=200.0, Qg=43.31 -> Pg=101.8, Qg=15.1
% INFO    : Gen at bus 20430	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20430	: Pg=201.3, Qg=43.31 -> Pg=100.95, Qg=15.2
% INFO    : Gen at bus 20430	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20430	: Pg=100.0, Qg=43.31 -> Pg=60.0, Qg=0.0
% INFO    : Gen at bus 20430	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20430	: Pg=99.0, Qg=43.31 -> Pg=49.65, Qg=0.0
% INFO    : Gen at bus 20430	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20431	: Pg=99.0, Qg=34.66 -> Pg=50.25, Qg=0.0
% INFO    : Gen at bus 20431	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20432	: Pg=98.7, Qg=-0.01 -> Pg=49.7, Qg=0.0
% INFO    : Gen at bus 20432	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20433	: Pg=73.16, Qg=0.0 -> Pg=52.3, Qg=0.0
% INFO    : Gen at bus 20433	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20434	: Pg=89.18, Qg=0.0 -> Pg=49.5, Qg=0.0
% INFO    : Gen at bus 20434	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=29.73, Qg=9.9 -> Pg=17.5, Qg=0.0
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=14.67, Qg=7.53 -> Pg=8.635, Qg=1.3
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=14.67, Qg=7.53 -> Pg=8.635, Qg=1.3
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=14.67, Qg=7.53 -> Pg=8.635, Qg=1.3
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=14.67, Qg=7.53 -> Pg=8.635, Qg=1.3
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=14.67, Qg=7.53 -> Pg=8.635, Qg=1.3
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=14.67, Qg=7.53 -> Pg=8.635, Qg=1.3
% INFO    : Gen at bus 20435	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=85.71, Qg=8.0 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=85.71, Qg=8.0 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=85.71, Qg=8.0 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=85.71, Qg=8.0 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=85.71, Qg=8.0 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=85.71, Qg=8.0 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=85.71, Qg=8.0 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20436	: Pg=85.71, Qg=8.0 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20436	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20437	: Pg=84.23, Qg=52.7 -> Pg=65.0, Qg=12.2
% INFO    : Gen at bus 20437	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20437	: Pg=84.23, Qg=52.7 -> Pg=65.0, Qg=12.2
% INFO    : Gen at bus 20437	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20437	: Pg=84.23, Qg=52.7 -> Pg=65.0, Qg=12.2
% INFO    : Gen at bus 20437	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20437	: Pg=84.23, Qg=52.7 -> Pg=65.0, Qg=12.2
% INFO    : Gen at bus 20437	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20438	: Pg=66.39, Qg=41.5 -> Pg=43.5, Qg=9.6
% INFO    : Gen at bus 20438	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20438	: Pg=66.39, Qg=41.5 -> Pg=43.5, Qg=9.6
% INFO    : Gen at bus 20438	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20438	: Pg=66.39, Qg=41.5 -> Pg=43.5, Qg=9.6
% INFO    : Gen at bus 20438	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20438	: Pg=66.39, Qg=41.5 -> Pg=43.5, Qg=9.6
% INFO    : Gen at bus 20438	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20438	: Pg=66.39, Qg=41.5 -> Pg=43.5, Qg=9.6
% INFO    : Gen at bus 20438	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20438	: Pg=66.39, Qg=41.5 -> Pg=43.5, Qg=9.6
% INFO    : Gen at bus 20438	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20439	: Pg=60.45, Qg=40.3 -> Pg=44.0, Qg=10.0
% INFO    : Gen at bus 20439	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20440	: Pg=49.55, Qg=37.5 -> Pg=36.9, Qg=10.4
% INFO    : Gen at bus 20440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20440	: Pg=49.55, Qg=37.5 -> Pg=36.9, Qg=10.4
% INFO    : Gen at bus 20440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20440	: Pg=60.45, Qg=45.8 -> Pg=45.02, Qg=12.75
% INFO    : Gen at bus 20440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20440	: Pg=60.45, Qg=45.8 -> Pg=45.02, Qg=12.75
% INFO    : Gen at bus 20440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20440	: Pg=60.45, Qg=45.8 -> Pg=45.02, Qg=12.75
% INFO    : Gen at bus 20440	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20442	: Pg=58.46, Qg=36.6 -> Pg=34.5, Qg=8.45
% INFO    : Gen at bus 20442	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20442	: Pg=58.46, Qg=36.6 -> Pg=34.5, Qg=8.45
% INFO    : Gen at bus 20442	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20442	: Pg=58.46, Qg=36.6 -> Pg=34.5, Qg=8.45
% INFO    : Gen at bus 20442	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20442	: Pg=58.46, Qg=36.6 -> Pg=34.5, Qg=8.45
% INFO    : Gen at bus 20442	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20444	: Pg=50.54, Qg=16.8 -> Pg=30.5, Qg=0.0
% INFO    : Gen at bus 20444	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20444	: Pg=62.63, Qg=20.8 -> Pg=36.6, Qg=0.0
% INFO    : Gen at bus 20444	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20444	: Pg=61.44, Qg=20.4 -> Pg=32.0, Qg=0.0
% INFO    : Gen at bus 20444	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20445	: Pg=49.55, Qg=31.0 -> Pg=42.0, Qg=7.15
% INFO    : Gen at bus 20445	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20445	: Pg=112.57, Qg=70.4 -> Pg=83.8, Qg=16.25
% INFO    : Gen at bus 20445	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20445	: Pg=68.37, Qg=42.8 -> Pg=50.5, Qg=9.9
% INFO    : Gen at bus 20445	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20445	: Pg=68.37, Qg=42.8 -> Pg=50.5, Qg=9.9
% INFO    : Gen at bus 20445	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20445	: Pg=45.58, Qg=28.5 -> Pg=31.28, Qg=6.6
% INFO    : Gen at bus 20445	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20445	: Pg=45.58, Qg=28.5 -> Pg=31.28, Qg=6.6
% INFO    : Gen at bus 20445	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20446	: Pg=41.42, Qg=20.2 -> Pg=21.9, Qg=3.15
% INFO    : Gen at bus 20446	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20446	: Pg=41.42, Qg=20.2 -> Pg=21.9, Qg=3.15
% INFO    : Gen at bus 20446	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20448	: Pg=41.02, Qg=25.7 -> Pg=29.2, Qg=5.95
% INFO    : Gen at bus 20448	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20448	: Pg=41.02, Qg=25.7 -> Pg=29.2, Qg=5.95
% INFO    : Gen at bus 20448	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20448	: Pg=85.12, Qg=53.2 -> Pg=60.95, Qg=12.3
% INFO    : Gen at bus 20448	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20449	: Pg=39.83, Qg=12.81 -> Pg=27.135, Qg=8.4
% INFO    : Gen at bus 20449	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20449	: Pg=68.37, Qg=12.81 -> Pg=46.575, Qg=14.4
% INFO    : Gen at bus 20449	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20449	: Pg=34.68, Qg=12.81 -> Pg=23.8, Qg=7.3
% INFO    : Gen at bus 20449	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20450	: Pg=60.35, Qg=37.7 -> Pg=44.45, Qg=8.7
% INFO    : Gen at bus 20450	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20450	: Pg=32.7, Qg=20.5 -> Pg=23.0, Qg=4.75
% INFO    : Gen at bus 20450	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20451	: Pg=30.52, Qg=23.1 -> Pg=17.9, Qg=6.4
% INFO    : Gen at bus 20451	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20452	: Pg=24.77, Qg=15.5 -> Pg=17.25, Qg=3.6
% INFO    : Gen at bus 20452	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20453	: Pg=11.94, Qg=7.45 -> Pg=6.775, Qg=1.725
% INFO    : Gen at bus 20453	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20453	: Pg=11.94, Qg=7.45 -> Pg=6.775, Qg=1.725
% INFO    : Gen at bus 20453	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20454	: Pg=5.8, Qg=0.0 -> Pg=3.3, Qg=0.0
% INFO    : Gen at bus 20454	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20454	: Pg=5.8, Qg=0.0 -> Pg=3.3, Qg=0.0
% INFO    : Gen at bus 20454	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20454	: Pg=5.8, Qg=0.0 -> Pg=3.3, Qg=0.0
% INFO    : Gen at bus 20454	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20454	: Pg=5.8, Qg=0.0 -> Pg=3.3, Qg=0.0
% INFO    : Gen at bus 20454	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20455	: Pg=7.92, Qg=6.9 -> Pg=6.55, Qg=1.6
% INFO    : Gen at bus 20455	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20455	: Pg=7.56, Qg=6.9 -> Pg=6.55, Qg=1.6
% INFO    : Gen at bus 20455	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20457	: Pg=21.4, Qg=4.97 -> Pg=11.3, Qg=4.5
% INFO    : Gen at bus 20457	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20457	: Pg=21.4, Qg=4.97 -> Pg=11.3, Qg=4.5
% INFO    : Gen at bus 20457	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20457	: Pg=21.4, Qg=4.97 -> Pg=11.3, Qg=4.5
% INFO    : Gen at bus 20457	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=610.6, Qg=-65.94 -> Pg=459.1, Qg=79.515
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=86.31, Qg=-29.0 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=86.31, Qg=-29.0 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=86.31, Qg=-29.0 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=86.31, Qg=-29.0 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=86.31, Qg=-29.0 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=86.31, Qg=-29.0 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=86.31, Qg=-29.0 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=86.31, Qg=-29.0 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=610.6, Qg=-65.94 -> Pg=459.1, Qg=79.515
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=610.6, Qg=-65.94 -> Pg=459.1, Qg=79.515
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=406.28, Qg=-65.94 -> Pg=217.5, Qg=30.95
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=376.55, Qg=-65.94 -> Pg=210.0, Qg=54.4
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=86.31, Qg=-29.0 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=86.31, Qg=-29.0 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=86.31, Qg=-29.0 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20458	: Pg=86.31, Qg=-29.0 -> Pg=78.55, Qg=12.5
% INFO    : Gen at bus 20458	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20459	: Pg=1133.3, Qg=203.67 -> Pg=1093.15, Qg=85.55
% INFO    : Gen at bus 20459	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20459	: Pg=1085.2, Qg=203.67 -> Pg=1079.0, Qg=86.95
% INFO    : Gen at bus 20459	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20460	: Pg=81.18, Qg=269.63 -> Pg=405.9, Qg=169.15
% INFO    : Gen at bus 20460	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20461	: Pg=691.17, Qg=12.79 -> Pg=426.25, Qg=52.65
% INFO    : Gen at bus 20461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20461	: Pg=691.17, Qg=12.79 -> Pg=426.25, Qg=52.65
% INFO    : Gen at bus 20461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20461	: Pg=84.53, Qg=12.79 -> Pg=48.65, Qg=12.25
% INFO    : Gen at bus 20461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20461	: Pg=84.53, Qg=12.79 -> Pg=48.65, Qg=12.25
% INFO    : Gen at bus 20461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20461	: Pg=84.53, Qg=12.79 -> Pg=48.65, Qg=12.25
% INFO    : Gen at bus 20461	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=314.04, Qg=35.98 -> Pg=284.9, Qg=47.25
% INFO    : Gen at bus 20462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=314.04, Qg=35.98 -> Pg=284.9, Qg=47.25
% INFO    : Gen at bus 20462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=314.04, Qg=35.98 -> Pg=284.9, Qg=47.25
% INFO    : Gen at bus 20462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=314.04, Qg=35.98 -> Pg=284.9, Qg=47.25
% INFO    : Gen at bus 20462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=314.04, Qg=35.98 -> Pg=284.9, Qg=47.25
% INFO    : Gen at bus 20462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=314.04, Qg=35.98 -> Pg=284.9, Qg=47.25
% INFO    : Gen at bus 20462	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20463	: Pg=125.67, Qg=213.47 -> Pg=176.25, Qg=60.95
% INFO    : Gen at bus 20463	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20463	: Pg=280.03, Qg=212.0 -> Pg=141.3, Qg=58.9
% INFO    : Gen at bus 20463	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20463	: Pg=354.85, Qg=213.47 -> Pg=246.55, Qg=74.6
% INFO    : Gen at bus 20463	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20464	: Pg=718.63, Qg=530.61 -> Pg=633.4, Qg=119.2
% INFO    : Gen at bus 20464	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20464	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20464	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20465	: Pg=145.67, Qg=51.04 -> Pg=118.5, Qg=21.05
% INFO    : Gen at bus 20465	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20465	: Pg=96.16, Qg=51.04 -> Pg=118.5, Qg=21.05
% INFO    : Gen at bus 20465	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20465	: Pg=96.16, Qg=51.04 -> Pg=118.5, Qg=21.05
% INFO    : Gen at bus 20465	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20465	: Pg=242.78, Qg=51.04 -> Pg=207.5, Qg=35.05
% INFO    : Gen at bus 20465	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20465	: Pg=180.27, Qg=51.04 -> Pg=207.5, Qg=35.05
% INFO    : Gen at bus 20465	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20465	: Pg=180.27, Qg=51.04 -> Pg=207.5, Qg=35.05
% INFO    : Gen at bus 20465	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=33.29, Qg=13.46 -> Pg=19.3, Qg=4.8
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.49, Qg=13.46 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.49, Qg=13.46 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.49, Qg=13.46 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.49, Qg=13.46 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=33.29, Qg=13.46 -> Pg=19.3, Qg=4.8
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=33.29, Qg=13.46 -> Pg=19.3, Qg=4.8
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=33.29, Qg=13.46 -> Pg=19.3, Qg=4.8
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.49, Qg=13.46 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.49, Qg=13.46 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.49, Qg=13.46 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.49, Qg=13.46 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20466	: Pg=24.49, Qg=13.46 -> Pg=14.195, Qg=3.185
% INFO    : Gen at bus 20466	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20467	: Pg=122.91, Qg=76.6 -> Pg=151.85, Qg=27.0
% INFO    : Gen at bus 20467	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20467	: Pg=122.91, Qg=76.6 -> Pg=151.85, Qg=27.0
% INFO    : Gen at bus 20467	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20467	: Pg=128.95, Qg=76.6 -> Pg=166.7, Qg=30.6
% INFO    : Gen at bus 20467	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20467	: Pg=97.91, Qg=76.6 -> Pg=139.35, Qg=27.0
% INFO    : Gen at bus 20467	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20467	: Pg=97.91, Qg=76.6 -> Pg=139.35, Qg=27.0
% INFO    : Gen at bus 20467	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20468	: Pg=167.74, Qg=154.9 -> Pg=131.5, Qg=35.8
% INFO    : Gen at bus 20468	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20468	: Pg=133.17, Qg=105.4 -> Pg=132.5, Qg=24.35
% INFO    : Gen at bus 20468	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20468	: Pg=133.17, Qg=105.4 -> Pg=132.5, Qg=24.35
% INFO    : Gen at bus 20468	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20468	: Pg=133.17, Qg=105.4 -> Pg=132.5, Qg=24.35
% INFO    : Gen at bus 20468	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20469	: Pg=128.49, Qg=40.8 -> Pg=143.0, Qg=24.35
% INFO    : Gen at bus 20469	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20469	: Pg=139.29, Qg=40.8 -> Pg=143.0, Qg=24.35
% INFO    : Gen at bus 20469	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20469	: Pg=139.29, Qg=40.8 -> Pg=143.0, Qg=24.35
% INFO    : Gen at bus 20469	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20469	: Pg=139.29, Qg=40.8 -> Pg=143.0, Qg=24.35
% INFO    : Gen at bus 20469	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=41.42, Qg=20.2 -> Pg=22.9, Qg=3.15
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=41.42, Qg=20.2 -> Pg=22.9, Qg=3.15
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=26.46, Qg=14.7 -> Pg=15.015, Qg=2.9
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=26.46, Qg=14.7 -> Pg=15.015, Qg=2.9
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=26.46, Qg=14.7 -> Pg=15.015, Qg=2.9
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=26.46, Qg=14.7 -> Pg=15.015, Qg=2.9
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=26.46, Qg=14.7 -> Pg=15.015, Qg=2.9
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=23.48, Qg=14.7 -> Pg=15.015, Qg=2.9
% INFO    : Gen at bus 20470	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20471	: Pg=154.88, Qg=78.4 -> Pg=113.15, Qg=22.4
% INFO    : Gen at bus 20471	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20471	: Pg=154.88, Qg=78.4 -> Pg=113.15, Qg=22.4
% INFO    : Gen at bus 20471	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20472	: Pg=106.49, Qg=95.9 -> Pg=127.35, Qg=22.15
% INFO    : Gen at bus 20472	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20473	: Pg=100.53, Qg=26.66 -> Pg=103.0, Qg=19.5
% INFO    : Gen at bus 20473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20473	: Pg=100.53, Qg=26.66 -> Pg=103.0, Qg=19.5
% INFO    : Gen at bus 20473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20473	: Pg=95.53, Qg=26.66 -> Pg=100.5, Qg=19.5
% INFO    : Gen at bus 20473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20473	: Pg=95.53, Qg=26.66 -> Pg=100.5, Qg=19.5
% INFO    : Gen at bus 20473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20473	: Pg=464.65, Qg=26.66 -> Pg=376.25, Qg=99.2
% INFO    : Gen at bus 20473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20473	: Pg=703.35, Qg=26.66 -> Pg=384.9, Qg=101.65
% INFO    : Gen at bus 20473	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20475	: Pg=81.19, Qg=16.83 -> Pg=84.095, Qg=22.7
% INFO    : Gen at bus 20475	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20476	: Pg=118.91, Qg=58.1 -> Pg=73.0, Qg=9.05
% INFO    : Gen at bus 20476	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20476	: Pg=118.91, Qg=90.0 -> Pg=68.5, Qg=25.0
% INFO    : Gen at bus 20476	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20476	: Pg=390.28, Qg=259.4 -> Pg=346.75, Qg=40.45
% INFO    : Gen at bus 20476	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20477	: Pg=113.05, Qg=82.3 -> Pg=103.9, Qg=19.0
% INFO    : Gen at bus 20477	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20477	: Pg=105.33, Qg=65.9 -> Pg=83.15, Qg=15.25
% INFO    : Gen at bus 20477	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20477	: Pg=105.33, Qg=65.9 -> Pg=83.15, Qg=15.25
% INFO    : Gen at bus 20477	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20479	: Pg=88.59, Qg=52.93 -> Pg=69.7, Qg=12.8
% INFO    : Gen at bus 20479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20479	: Pg=88.59, Qg=52.93 -> Pg=69.7, Qg=12.8
% INFO    : Gen at bus 20479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20479	: Pg=88.59, Qg=52.93 -> Pg=69.7, Qg=12.8
% INFO    : Gen at bus 20479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20479	: Pg=88.59, Qg=52.93 -> Pg=69.7, Qg=12.8
% INFO    : Gen at bus 20479	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20480	: Pg=808.0, Qg=43.64 -> Pg=485.2, Qg=61.55
% INFO    : Gen at bus 20480	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20480	: Pg=84.53, Qg=43.64 -> Pg=48.65, Qg=12.25
% INFO    : Gen at bus 20480	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20480	: Pg=84.53, Qg=43.64 -> Pg=48.65, Qg=12.25
% INFO    : Gen at bus 20480	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20480	: Pg=84.53, Qg=43.64 -> Pg=48.65, Qg=12.25
% INFO    : Gen at bus 20480	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20481	: Pg=64.08, Qg=57.1 -> Pg=65.0, Qg=14.4
% INFO    : Gen at bus 20481	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20481	: Pg=64.08, Qg=57.1 -> Pg=65.0, Qg=14.4
% INFO    : Gen at bus 20481	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20481	: Pg=64.08, Qg=57.1 -> Pg=65.0, Qg=14.4
% INFO    : Gen at bus 20481	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20481	: Pg=64.08, Qg=57.1 -> Pg=65.0, Qg=14.4
% INFO    : Gen at bus 20481	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20483	: Pg=11.59, Qg=2.29 -> Pg=12.0, Qg=1.86
% INFO    : Gen at bus 20483	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20483	: Pg=11.59, Qg=2.29 -> Pg=12.0, Qg=1.86
% INFO    : Gen at bus 20483	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20483	: Pg=11.59, Qg=2.29 -> Pg=12.0, Qg=1.86
% INFO    : Gen at bus 20483	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20483	: Pg=11.59, Qg=2.29 -> Pg=12.0, Qg=1.86
% INFO    : Gen at bus 20483	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20483	: Pg=11.59, Qg=2.29 -> Pg=12.0, Qg=1.86
% INFO    : Gen at bus 20483	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20485	: Pg=74.32, Qg=42.94 -> Pg=50.625, Qg=10.25
% INFO    : Gen at bus 20485	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20485	: Pg=74.32, Qg=42.94 -> Pg=50.625, Qg=10.25
% INFO    : Gen at bus 20485	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20487	: Pg=69.0, Qg=24.23 -> Pg=34.95, Qg=0.0
% INFO    : Gen at bus 20487	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20489	: Pg=7.59, Qg=9.93 -> Pg=10.0, Qg=2.305
% INFO    : Gen at bus 20489	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20489	: Pg=7.59, Qg=9.93 -> Pg=10.0, Qg=2.305
% INFO    : Gen at bus 20489	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20489	: Pg=7.59, Qg=9.93 -> Pg=10.0, Qg=2.305
% INFO    : Gen at bus 20489	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20489	: Pg=7.59, Qg=9.93 -> Pg=10.0, Qg=2.305
% INFO    : Gen at bus 20489	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=15.85, Qg=9.93 -> Pg=11.31, Qg=2.305
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=15.85, Qg=9.93 -> Pg=11.31, Qg=2.305
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=15.85, Qg=9.93 -> Pg=11.31, Qg=2.305
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=15.85, Qg=9.93 -> Pg=11.31, Qg=2.305
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=21.01, Qg=13.1 -> Pg=14.6, Qg=3.0
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=21.01, Qg=13.1 -> Pg=14.6, Qg=3.0
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=23.19, Qg=14.5 -> Pg=15.7, Qg=3.35
% INFO    : Gen at bus 20490	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20493	: Pg=33.58, Qg=37.5 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 20493	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=59.46, Qg=34.83 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=59.46, Qg=34.83 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=41.46, Qg=34.83 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=40.26, Qg=34.83 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=40.26, Qg=34.83 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=40.26, Qg=34.83 -> Pg=36.0, Qg=8.6
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=62.74, Qg=34.83 -> Pg=62.0, Qg=6.0
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=104.05, Qg=34.83 -> Pg=58.5, Qg=15.05
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=104.05, Qg=34.83 -> Pg=58.5, Qg=15.05
% INFO    : Gen at bus 20494	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20496	: Pg=54.5, Qg=26.6 -> Pg=40.0, Qg=4.15
% INFO    : Gen at bus 20496	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20497	: Pg=0.9, Qg=20.9 -> Pg=26.85, Qg=0.0
% INFO    : Gen at bus 20497	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20498	: Pg=9.35, Qg=6.5 -> Pg=6.07, Qg=1.68
% INFO    : Gen at bus 20498	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20498	: Pg=9.35, Qg=6.5 -> Pg=6.07, Qg=1.68
% INFO    : Gen at bus 20498	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20498	: Pg=9.35, Qg=6.5 -> Pg=6.07, Qg=1.68
% INFO    : Gen at bus 20498	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20498	: Pg=9.35, Qg=6.5 -> Pg=6.07, Qg=1.68
% INFO    : Gen at bus 20498	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20498	: Pg=9.35, Qg=6.5 -> Pg=6.07, Qg=1.68
% INFO    : Gen at bus 20498	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20500	: Pg=79.27, Qg=42.97 -> Pg=60.0, Qg=11.45
% INFO    : Gen at bus 20500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20500	: Pg=79.27, Qg=42.97 -> Pg=60.0, Qg=11.45
% INFO    : Gen at bus 20500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20500	: Pg=79.27, Qg=42.97 -> Pg=60.0, Qg=11.45
% INFO    : Gen at bus 20500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20500	: Pg=43.6, Qg=27.3 -> Pg=32.0, Qg=6.3
% INFO    : Gen at bus 20500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20500	: Pg=43.6, Qg=27.3 -> Pg=32.0, Qg=6.3
% INFO    : Gen at bus 20500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20500	: Pg=46.57, Qg=29.1 -> Pg=33.5, Qg=6.7
% INFO    : Gen at bus 20500	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20502	: Pg=37.92, Qg=8.7 -> Pg=35.4, Qg=6.1
% INFO    : Gen at bus 20502	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20502	: Pg=36.37, Qg=8.7 -> Pg=34.6, Qg=6.1
% INFO    : Gen at bus 20502	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20502	: Pg=34.83, Qg=8.7 -> Pg=34.05, Qg=6.15
% INFO    : Gen at bus 20502	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20502	: Pg=33.92, Qg=8.7 -> Pg=33.4, Qg=6.1
% INFO    : Gen at bus 20502	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20504	: Pg=39.14, Qg=24.5 -> Pg=24.75, Qg=5.65
% INFO    : Gen at bus 20504	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20505	: Pg=16.64, Qg=24.2 -> Pg=27.05, Qg=5.6
% INFO    : Gen at bus 20505	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20505	: Pg=16.64, Qg=24.2 -> Pg=27.05, Qg=5.6
% INFO    : Gen at bus 20505	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20505	: Pg=53.5, Qg=51.7 -> Pg=66.75, Qg=11.95
% INFO    : Gen at bus 20505	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20506	: Pg=18.53, Qg=23.6 -> Pg=24.0, Qg=5.45
% INFO    : Gen at bus 20506	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20507	: Pg=17.84, Qg=11.15 -> Pg=12.87, Qg=2.575
% INFO    : Gen at bus 20507	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20507	: Pg=17.84, Qg=11.15 -> Pg=12.87, Qg=2.575
% INFO    : Gen at bus 20507	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20509	: Pg=9.23, Qg=7.87 -> Pg=5.25, Qg=2.185
% INFO    : Gen at bus 20509	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20509	: Pg=9.23, Qg=7.87 -> Pg=5.25, Qg=2.185
% INFO    : Gen at bus 20509	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20509	: Pg=9.23, Qg=7.87 -> Pg=5.25, Qg=2.185
% INFO    : Gen at bus 20509	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20510	: Pg=26.73, Qg=6.2 -> Pg=22.25, Qg=0.0
% INFO    : Gen at bus 20510	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20512	: Pg=11.29, Qg=21.0 -> Pg=16.5, Qg=5.85
% INFO    : Gen at bus 20512	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20513	: Pg=6.24, Qg=1.84 -> Pg=4.255, Qg=0.915
% INFO    : Gen at bus 20513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20513	: Pg=6.24, Qg=1.84 -> Pg=4.255, Qg=0.915
% INFO    : Gen at bus 20513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20513	: Pg=6.24, Qg=1.84 -> Pg=4.255, Qg=0.915
% INFO    : Gen at bus 20513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20513	: Pg=6.24, Qg=1.84 -> Pg=4.255, Qg=0.915
% INFO    : Gen at bus 20513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20513	: Pg=21.11, Qg=1.84 -> Pg=13.15, Qg=3.05
% INFO    : Gen at bus 20513	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20514	: Pg=24.59, Qg=15.5 -> Pg=22.0, Qg=3.6
% INFO    : Gen at bus 20514	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20514	: Pg=24.59, Qg=15.5 -> Pg=22.0, Qg=3.6
% INFO    : Gen at bus 20514	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20515	: Pg=10.39, Qg=-7.9 -> Pg=14.5, Qg=0.0
% INFO    : Gen at bus 20515	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20516	: Pg=14.79, Qg=11.6 -> Pg=17.0, Qg=1.8
% INFO    : Gen at bus 20516	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20517	: Pg=7.89, Qg=4.19 -> Pg=4.685, Qg=1.25
% INFO    : Gen at bus 20517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20517	: Pg=7.89, Qg=4.19 -> Pg=4.685, Qg=1.25
% INFO    : Gen at bus 20517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20517	: Pg=7.89, Qg=4.19 -> Pg=4.685, Qg=1.25
% INFO    : Gen at bus 20517	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20518	: Pg=4.7, Qg=-0.44 -> Pg=4.34, Qg=0.42
% INFO    : Gen at bus 20518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20518	: Pg=4.7, Qg=-0.44 -> Pg=4.34, Qg=0.42
% INFO    : Gen at bus 20518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20518	: Pg=4.7, Qg=-0.44 -> Pg=4.34, Qg=0.42
% INFO    : Gen at bus 20518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20518	: Pg=4.7, Qg=-0.44 -> Pg=4.34, Qg=0.42
% INFO    : Gen at bus 20518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20518	: Pg=4.7, Qg=-0.44 -> Pg=4.34, Qg=0.42
% INFO    : Gen at bus 20518	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20520	: Pg=6.58, Qg=7.15 -> Pg=7.75, Qg=1.65
% INFO    : Gen at bus 20520	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20520	: Pg=6.58, Qg=7.15 -> Pg=7.75, Qg=1.65
% INFO    : Gen at bus 20520	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20522	: Pg=10.07, Qg=2.85 -> Pg=13.8, Qg=1.7
% INFO    : Gen at bus 20522	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.16, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.16, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.16, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.16, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.16, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.16, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=3.16, Qg=2.39 -> Pg=2.4, Qg=0.665
% INFO    : Gen at bus 20523	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20524	: Pg=21.8, Qg=13.6 -> Pg=18.5, Qg=3.15
% INFO    : Gen at bus 20524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20524	: Pg=29.03, Qg=18.2 -> Pg=23.65, Qg=4.2
% INFO    : Gen at bus 20524	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20527	: Pg=1.5, Qg=2.2 -> Pg=3.35, Qg=0.0
% INFO    : Gen at bus 20527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20527	: Pg=1.5, Qg=2.2 -> Pg=3.35, Qg=0.0
% INFO    : Gen at bus 20527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20527	: Pg=1.5, Qg=2.2 -> Pg=3.35, Qg=0.0
% INFO    : Gen at bus 20527	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20528	: Pg=9.49, Qg=15.0 -> Pg=12.5, Qg=4.15
% INFO    : Gen at bus 20528	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20529	: Pg=10.49, Qg=-0.79 -> Pg=13.0, Qg=1.5
% INFO    : Gen at bus 20529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20529	: Pg=10.49, Qg=-0.79 -> Pg=13.0, Qg=1.5
% INFO    : Gen at bus 20529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20529	: Pg=10.49, Qg=-0.79 -> Pg=13.0, Qg=1.5
% INFO    : Gen at bus 20529	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20530	: Pg=12.49, Qg=12.4 -> Pg=14.0, Qg=2.85
% INFO    : Gen at bus 20530	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20531	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20532	: Pg=1310.25, Qg=228.8 -> Pg=722.3, Qg=0.0
% INFO    : Gen at bus 20532	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20533	: Pg=1170.63, Qg=-261.69 -> Pg=1000.0, Qg=98.15
% INFO    : Gen at bus 20533	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20533	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20534	: Pg=925.2, Qg=277.1 -> Pg=517.6, Qg=69.85
% INFO    : Gen at bus 20534	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20535	: Pg=28.44, Qg=21.5 -> Pg=23.35, Qg=5.95
% INFO    : Gen at bus 20535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20535	: Pg=654.6, Qg=165.99 -> Pg=395.3, Qg=49.85
% INFO    : Gen at bus 20535	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20536	: Pg=570.93, Qg=23.95 -> Pg=537.5, Qg=49.05
% INFO    : Gen at bus 20536	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20536	: Pg=563.11, Qg=23.95 -> Pg=520.1, Qg=88.1
% INFO    : Gen at bus 20536	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20536	: Pg=563.11, Qg=23.95 -> Pg=520.1, Qg=88.1
% INFO    : Gen at bus 20536	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20537	: Pg=604.66, Qg=-36.22 -> Pg=455.1, Qg=46.05
% INFO    : Gen at bus 20537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20537	: Pg=604.66, Qg=-36.22 -> Pg=455.1, Qg=46.05
% INFO    : Gen at bus 20537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20537	: Pg=604.66, Qg=-36.22 -> Pg=455.1, Qg=46.05
% INFO    : Gen at bus 20537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20537	: Pg=604.66, Qg=-36.22 -> Pg=455.1, Qg=46.05
% INFO    : Gen at bus 20537	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=133.77, Qg=68.6 -> Pg=87.5, Qg=19.35
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=133.77, Qg=68.6 -> Pg=87.5, Qg=19.35
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=133.77, Qg=68.6 -> Pg=87.5, Qg=19.35
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=86.21, Qg=53.92 -> Pg=56.1, Qg=12.46
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=86.21, Qg=53.92 -> Pg=56.1, Qg=12.46
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=86.21, Qg=53.92 -> Pg=56.1, Qg=12.46
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=86.21, Qg=53.92 -> Pg=56.1, Qg=12.46
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=86.21, Qg=53.92 -> Pg=56.1, Qg=12.46
% INFO    : Gen at bus 20538	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20540	: Pg=253.68, Qg=192.0 -> Pg=163.0, Qg=53.35
% INFO    : Gen at bus 20540	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20541	: Pg=217.61, Qg=-39.62 -> Pg=139.8, Qg=45.75
% INFO    : Gen at bus 20541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20541	: Pg=217.61, Qg=-39.62 -> Pg=139.8, Qg=45.75
% INFO    : Gen at bus 20541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20541	: Pg=235.34, Qg=-39.62 -> Pg=148.75, Qg=49.45
% INFO    : Gen at bus 20541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20541	: Pg=235.34, Qg=-39.62 -> Pg=148.75, Qg=49.45
% INFO    : Gen at bus 20541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20541	: Pg=609.61, Qg=-39.62 -> Pg=482.6, Qg=88.1
% INFO    : Gen at bus 20541	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20542	: Pg=215.33, Qg=-5.6 -> Pg=198.65, Qg=36.8
% INFO    : Gen at bus 20542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20542	: Pg=215.33, Qg=-5.6 -> Pg=198.65, Qg=36.8
% INFO    : Gen at bus 20542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20542	: Pg=215.33, Qg=-5.6 -> Pg=198.65, Qg=36.8
% INFO    : Gen at bus 20542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20542	: Pg=215.33, Qg=-5.6 -> Pg=198.65, Qg=36.8
% INFO    : Gen at bus 20542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20542	: Pg=215.33, Qg=-5.6 -> Pg=198.65, Qg=36.8
% INFO    : Gen at bus 20542	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20543	: Pg=191.19, Qg=20.42 -> Pg=218.55, Qg=45.4
% INFO    : Gen at bus 20543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20543	: Pg=134.65, Qg=20.42 -> Pg=144.45, Qg=28.5
% INFO    : Gen at bus 20543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20543	: Pg=134.65, Qg=20.42 -> Pg=144.45, Qg=28.5
% INFO    : Gen at bus 20543	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20544	: Pg=196.2, Qg=122.7 -> Pg=149.0, Qg=28.35
% INFO    : Gen at bus 20544	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20544	: Pg=196.2, Qg=122.7 -> Pg=149.0, Qg=28.35
% INFO    : Gen at bus 20544	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20544	: Pg=196.2, Qg=122.7 -> Pg=149.0, Qg=28.35
% INFO    : Gen at bus 20544	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20545	: Pg=193.72, Qg=66.06 -> Pg=155.5, Qg=28.0
% INFO    : Gen at bus 20545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20545	: Pg=193.72, Qg=66.06 -> Pg=155.5, Qg=28.0
% INFO    : Gen at bus 20545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20545	: Pg=193.72, Qg=66.06 -> Pg=155.5, Qg=28.0
% INFO    : Gen at bus 20545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20545	: Pg=193.72, Qg=66.06 -> Pg=155.5, Qg=28.0
% INFO    : Gen at bus 20545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20545	: Pg=193.72, Qg=66.06 -> Pg=155.5, Qg=28.0
% INFO    : Gen at bus 20545	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=97.75, Qg=91.88 -> Pg=122.7, Qg=27.25
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=97.75, Qg=91.88 -> Pg=122.7, Qg=27.25
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=97.75, Qg=91.88 -> Pg=122.7, Qg=27.25
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=97.75, Qg=91.88 -> Pg=122.7, Qg=27.25
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=562.66, Qg=91.88 -> Pg=545.0, Qg=97.35
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=562.66, Qg=91.88 -> Pg=545.0, Qg=97.35
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20546	: Pg=209.98, Qg=91.88 -> Pg=234.5, Qg=47.85
% INFO    : Gen at bus 20546	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20547	: Pg=133.11, Qg=9.79 -> Pg=134.1, Qg=24.95
% INFO    : Gen at bus 20547	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20547	: Pg=133.11, Qg=9.79 -> Pg=134.1, Qg=24.95
% INFO    : Gen at bus 20547	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20547	: Pg=133.11, Qg=9.79 -> Pg=134.1, Qg=24.95
% INFO    : Gen at bus 20547	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20547	: Pg=183.58, Qg=9.79 -> Pg=246.5, Qg=57.15
% INFO    : Gen at bus 20547	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20548	: Pg=170.44, Qg=106.6 -> Pg=159.0, Qg=24.65
% INFO    : Gen at bus 20548	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20548	: Pg=170.44, Qg=106.6 -> Pg=159.0, Qg=24.65
% INFO    : Gen at bus 20548	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20548	: Pg=170.44, Qg=106.6 -> Pg=159.0, Qg=24.65
% INFO    : Gen at bus 20548	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20548	: Pg=170.44, Qg=106.6 -> Pg=159.0, Qg=24.65
% INFO    : Gen at bus 20548	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20549	: Pg=162.02, Qg=-32.46 -> Pg=131.75, Qg=23.4
% INFO    : Gen at bus 20549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20549	: Pg=162.02, Qg=-32.46 -> Pg=131.75, Qg=23.4
% INFO    : Gen at bus 20549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20549	: Pg=162.02, Qg=-32.46 -> Pg=131.75, Qg=23.4
% INFO    : Gen at bus 20549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20549	: Pg=162.02, Qg=-32.46 -> Pg=131.75, Qg=23.4
% INFO    : Gen at bus 20549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20549	: Pg=314.22, Qg=-32.46 -> Pg=298.55, Qg=45.4
% INFO    : Gen at bus 20549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20549	: Pg=314.22, Qg=-32.46 -> Pg=298.55, Qg=45.4
% INFO    : Gen at bus 20549	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20550	: Pg=160.03, Qg=114.4 -> Pg=80.75, Qg=30.3
% INFO    : Gen at bus 20550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20550	: Pg=833.86, Qg=310.81 -> Pg=578.25, Qg=63.55
% INFO    : Gen at bus 20550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20550	: Pg=439.87, Qg=215.0 -> Pg=286.95, Qg=33.5
% INFO    : Gen at bus 20550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20550	: Pg=439.87, Qg=215.0 -> Pg=286.95, Qg=33.5
% INFO    : Gen at bus 20550	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20551	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20551	: Pg=139.32, Qg=75.9 -> Pg=97.715, Qg=14.5
% INFO    : Gen at bus 20551	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20551	: Pg=215.62, Qg=117.4 -> Pg=151.23, Qg=22.45
% INFO    : Gen at bus 20551	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20552	: Pg=131.59, Qg=82.3 -> Pg=92.295, Qg=19.0
% INFO    : Gen at bus 20552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20552	: Pg=131.59, Qg=82.3 -> Pg=92.295, Qg=19.0
% INFO    : Gen at bus 20552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20552	: Pg=26.75, Qg=16.7 -> Pg=16.0, Qg=3.85
% INFO    : Gen at bus 20552	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.77, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.77, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.77, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.77, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.77, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.77, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20553	: Pg=17.77, Qg=11.11 -> Pg=16.0, Qg=2.57
% INFO    : Gen at bus 20553	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20554	: Pg=121.88, Qg=76.2 -> Pg=86.5, Qg=17.6
% INFO    : Gen at bus 20554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20554	: Pg=121.88, Qg=76.2 -> Pg=86.5, Qg=17.6
% INFO    : Gen at bus 20554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20554	: Pg=206.11, Qg=147.3 -> Pg=144.56, Qg=39.0
% INFO    : Gen at bus 20554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20554	: Pg=121.88, Qg=92.3 -> Pg=86.5, Qg=25.65
% INFO    : Gen at bus 20554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20554	: Pg=31.71, Qg=19.8 -> Pg=20.0, Qg=4.55
% INFO    : Gen at bus 20554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20554	: Pg=673.83, Qg=275.45 -> Pg=483.82, Qg=55.15
% INFO    : Gen at bus 20554	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=161.72, Qg=79.0 -> Pg=112.1, Qg=12.3
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=456.62, Qg=223.2 -> Pg=260.9, Qg=34.8
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=123.86, Qg=60.5 -> Pg=86.875, Qg=9.4
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=111.48, Qg=54.5 -> Pg=75.94, Qg=8.5
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=113.96, Qg=55.7 -> Pg=77.625, Qg=8.7
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=52.42, Qg=25.6 -> Pg=31.45, Qg=4.0
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=52.42, Qg=25.6 -> Pg=31.45, Qg=4.0
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=52.42, Qg=25.6 -> Pg=31.45, Qg=4.0
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=52.42, Qg=25.6 -> Pg=31.45, Qg=4.0
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20555	: Pg=242.58, Qg=151.7 -> Pg=160.9, Qg=35.05
% INFO    : Gen at bus 20555	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20556	: Pg=105.24, Qg=65.8 -> Pg=59.6, Qg=15.2
% INFO    : Gen at bus 20556	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20557	: Pg=96.01, Qg=1.51 -> Pg=108.56, Qg=29.3
% INFO    : Gen at bus 20557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20557	: Pg=96.01, Qg=1.51 -> Pg=108.56, Qg=29.3
% INFO    : Gen at bus 20557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20557	: Pg=59.4, Qg=1.51 -> Pg=69.795, Qg=14.1
% INFO    : Gen at bus 20557	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20559	: Pg=93.15, Qg=58.3 -> Pg=67.0, Qg=13.5
% INFO    : Gen at bus 20559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20559	: Pg=93.15, Qg=58.3 -> Pg=67.0, Qg=13.5
% INFO    : Gen at bus 20559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20559	: Pg=93.15, Qg=58.3 -> Pg=67.0, Qg=13.5
% INFO    : Gen at bus 20559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20559	: Pg=93.15, Qg=58.3 -> Pg=67.0, Qg=13.5
% INFO    : Gen at bus 20559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20559	: Pg=93.15, Qg=58.3 -> Pg=67.0, Qg=13.5
% INFO    : Gen at bus 20559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20559	: Pg=93.15, Qg=58.3 -> Pg=67.0, Qg=13.5
% INFO    : Gen at bus 20559	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20560	: Pg=93.15, Qg=58.3 -> Pg=83.0, Qg=13.5
% INFO    : Gen at bus 20560	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20560	: Pg=93.15, Qg=58.3 -> Pg=83.0, Qg=13.5
% INFO    : Gen at bus 20560	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20560	: Pg=93.15, Qg=58.3 -> Pg=83.0, Qg=13.5
% INFO    : Gen at bus 20560	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20560	: Pg=93.15, Qg=58.3 -> Pg=83.0, Qg=13.5
% INFO    : Gen at bus 20560	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=85.71, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=85.71, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=85.71, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=85.71, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=85.71, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=85.71, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=85.71, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20561	: Pg=85.71, Qg=53.6 -> Pg=68.25, Qg=12.4
% INFO    : Gen at bus 20561	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20562	: Pg=85.22, Qg=53.3 -> Pg=57.0, Qg=12.3
% INFO    : Gen at bus 20562	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20562	: Pg=28.74, Qg=18.0 -> Pg=28.5, Qg=4.15
% INFO    : Gen at bus 20562	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20562	: Pg=673.83, Qg=384.85 -> Pg=505.0, Qg=97.35
% INFO    : Gen at bus 20562	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=64.71, Qg=40.5 -> Pg=42.65, Qg=9.35
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=64.71, Qg=40.5 -> Pg=42.65, Qg=9.35
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=84.23, Qg=45.79 -> Pg=57.5, Qg=12.2
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=84.23, Qg=45.79 -> Pg=57.5, Qg=12.2
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=84.23, Qg=45.79 -> Pg=57.5, Qg=12.2
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=84.23, Qg=45.79 -> Pg=57.5, Qg=12.2
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20563	: Pg=84.23, Qg=45.79 -> Pg=57.5, Qg=12.2
% INFO    : Gen at bus 20563	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20564	: Pg=83.44, Qg=52.2 -> Pg=62.6, Qg=12.05
% INFO    : Gen at bus 20564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20564	: Pg=102.56, Qg=64.1 -> Pg=72.25, Qg=14.8
% INFO    : Gen at bus 20564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20564	: Pg=105.14, Qg=65.8 -> Pg=73.55, Qg=15.2
% INFO    : Gen at bus 20564	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=32.3, Qg=20.2 -> Pg=28.8, Qg=4.65
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=68.37, Qg=42.8 -> Pg=49.5, Qg=9.9
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=68.37, Qg=42.8 -> Pg=49.5, Qg=9.9
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=68.37, Qg=42.8 -> Pg=49.5, Qg=9.9
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=68.37, Qg=42.8 -> Pg=49.5, Qg=9.9
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=68.37, Qg=42.8 -> Pg=47.0, Qg=9.9
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20565	: Pg=68.37, Qg=42.8 -> Pg=47.0, Qg=9.9
% INFO    : Gen at bus 20565	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20566	: Pg=13.48, Qg=6.58 -> Pg=8.3, Qg=1.02
% INFO    : Gen at bus 20566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20566	: Pg=13.48, Qg=6.58 -> Pg=8.3, Qg=1.02
% INFO    : Gen at bus 20566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20566	: Pg=13.48, Qg=6.58 -> Pg=8.3, Qg=1.02
% INFO    : Gen at bus 20566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20566	: Pg=13.48, Qg=6.58 -> Pg=8.3, Qg=1.02
% INFO    : Gen at bus 20566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20566	: Pg=13.48, Qg=6.58 -> Pg=8.3, Qg=1.02
% INFO    : Gen at bus 20566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20566	: Pg=22.79, Qg=11.1 -> Pg=13.0, Qg=1.7
% INFO    : Gen at bus 20566	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20567	: Pg=66.39, Qg=22.0 -> Pg=38.5, Qg=0.0
% INFO    : Gen at bus 20567	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=16.35, Qg=10.23 -> Pg=9.75, Qg=2.365
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=16.35, Qg=10.23 -> Pg=9.75, Qg=2.365
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=16.35, Qg=10.23 -> Pg=9.75, Qg=2.365
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=16.35, Qg=10.23 -> Pg=9.75, Qg=2.365
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=161.72, Qg=101.1 -> Pg=120.6, Qg=23.35
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=552.04, Qg=345.3 -> Pg=355.55, Qg=79.8
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20568	: Pg=552.64, Qg=345.6 -> Pg=355.85, Qg=79.85
% INFO    : Gen at bus 20568	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20569	: Pg=58.46, Qg=36.6 -> Pg=44.5, Qg=8.45
% INFO    : Gen at bus 20569	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20569	: Pg=58.46, Qg=36.6 -> Pg=44.5, Qg=8.45
% INFO    : Gen at bus 20569	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20569	: Pg=58.46, Qg=36.6 -> Pg=44.5, Qg=8.45
% INFO    : Gen at bus 20569	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20569	: Pg=58.46, Qg=36.6 -> Pg=44.5, Qg=8.45
% INFO    : Gen at bus 20569	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20570	: Pg=21.8, Qg=0.0 -> Pg=14.0, Qg=0.0
% INFO    : Gen at bus 20570	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20570	: Pg=13.25, Qg=6.58 -> Pg=8.755, Qg=1.065
% INFO    : Gen at bus 20570	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20570	: Pg=13.25, Qg=6.58 -> Pg=8.755, Qg=1.065
% INFO    : Gen at bus 20570	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20570	: Pg=13.25, Qg=6.58 -> Pg=8.755, Qg=1.065
% INFO    : Gen at bus 20570	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20570	: Pg=13.25, Qg=6.58 -> Pg=8.755, Qg=1.065
% INFO    : Gen at bus 20570	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20571	: Pg=44.89, Qg=31.2 -> Pg=32.15, Qg=8.05
% INFO    : Gen at bus 20571	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20572	: Pg=9.17, Qg=5.95 -> Pg=7.585, Qg=1.435
% INFO    : Gen at bus 20572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20572	: Pg=9.17, Qg=5.95 -> Pg=7.585, Qg=1.435
% INFO    : Gen at bus 20572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20572	: Pg=9.17, Qg=5.95 -> Pg=7.585, Qg=1.435
% INFO    : Gen at bus 20572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20572	: Pg=9.17, Qg=5.95 -> Pg=7.585, Qg=1.435
% INFO    : Gen at bus 20572	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20573	: Pg=12.16, Qg=7.83 -> Pg=7.3, Qg=1.865
% INFO    : Gen at bus 20573	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20573	: Pg=12.16, Qg=7.83 -> Pg=7.3, Qg=1.865
% INFO    : Gen at bus 20573	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20573	: Pg=12.16, Qg=7.83 -> Pg=7.3, Qg=1.865
% INFO    : Gen at bus 20573	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20575	: Pg=32.7, Qg=20.5 -> Pg=29.5, Qg=4.75
% INFO    : Gen at bus 20575	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20577	: Pg=15.85, Qg=9.9 -> Pg=10.5, Qg=2.275
% INFO    : Gen at bus 20577	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20577	: Pg=15.85, Qg=9.9 -> Pg=10.5, Qg=2.275
% INFO    : Gen at bus 20577	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20578	: Pg=31.71, Qg=19.8 -> Pg=30.5, Qg=4.55
% INFO    : Gen at bus 20578	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20579	: Pg=31.71, Qg=19.8 -> Pg=30.5, Qg=4.55
% INFO    : Gen at bus 20579	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20580	: Pg=15.18, Qg=5.08 -> Pg=20.0, Qg=4.55
% INFO    : Gen at bus 20580	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20581	: Pg=5.17, Qg=3.27 -> Pg=3.075, Qg=0.77
% INFO    : Gen at bus 20581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20581	: Pg=5.17, Qg=3.27 -> Pg=3.075, Qg=0.77
% INFO    : Gen at bus 20581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20581	: Pg=5.17, Qg=3.27 -> Pg=3.075, Qg=0.77
% INFO    : Gen at bus 20581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20581	: Pg=5.17, Qg=3.27 -> Pg=3.075, Qg=0.77
% INFO    : Gen at bus 20581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20581	: Pg=5.17, Qg=3.27 -> Pg=3.075, Qg=0.77
% INFO    : Gen at bus 20581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20581	: Pg=5.17, Qg=3.27 -> Pg=3.075, Qg=0.77
% INFO    : Gen at bus 20581	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20584	: Pg=1.99, Qg=8.21 -> Pg=500.0, Qg=0.0
% INFO    : Gen at bus 20584	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 20584	: Pg=50.14, Qg=8.21 -> Pg=37.3, Qg=7.25
% INFO    : Gen at bus 20584	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 20584	: Pg=24.77, Qg=8.21 -> Pg=16.5, Qg=3.6
% INFO    : Gen at bus 20584	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 20585	: Pg=26.95, Qg=16.9 -> Pg=18.6, Qg=3.9
% INFO    : Gen at bus 20585	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20585	: Pg=23.78, Qg=14.9 -> Pg=16.0, Qg=3.45
% INFO    : Gen at bus 20585	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20585	: Pg=30.72, Qg=19.2 -> Pg=20.5, Qg=4.45
% INFO    : Gen at bus 20585	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20587	: Pg=12.93, Qg=9.8 -> Pg=8.775, Qg=2.725
% INFO    : Gen at bus 20587	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20587	: Pg=12.93, Qg=9.8 -> Pg=8.775, Qg=2.725
% INFO    : Gen at bus 20587	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20588	: Pg=6.32, Qg=1.31 -> Pg=12.35, Qg=0.0
% INFO    : Gen at bus 20588	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20588	: Pg=6.32, Qg=1.31 -> Pg=12.35, Qg=0.0
% INFO    : Gen at bus 20588	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20589	: Pg=23.19, Qg=4.8 -> Pg=12.2, Qg=0.0
% INFO    : Gen at bus 20589	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20589	: Pg=23.19, Qg=4.8 -> Pg=12.2, Qg=0.0
% INFO    : Gen at bus 20589	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20589	: Pg=23.19, Qg=4.8 -> Pg=12.2, Qg=0.0
% INFO    : Gen at bus 20589	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20590	: Pg=21.8, Qg=13.6 -> Pg=14.5, Qg=3.15
% INFO    : Gen at bus 20590	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20590	: Pg=24.77, Qg=18.8 -> Pg=16.0, Qg=5.25
% INFO    : Gen at bus 20590	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20590	: Pg=24.77, Qg=18.8 -> Pg=16.0, Qg=5.25
% INFO    : Gen at bus 20590	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20591	: Pg=6.77, Qg=5.13 -> Pg=3.915, Qg=1.43
% INFO    : Gen at bus 20591	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20591	: Pg=6.77, Qg=5.13 -> Pg=3.915, Qg=1.43
% INFO    : Gen at bus 20591	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20591	: Pg=6.77, Qg=5.13 -> Pg=3.915, Qg=1.43
% INFO    : Gen at bus 20591	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 20592	: Pg=19.82, Qg=12.4 -> Pg=17.0, Qg=2.85
% INFO    : Gen at bus 20592	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81895	: Pg=130.5, Qg=35.73 -> Pg=130.5, Qg=0.0
% INFO    : Gen at bus 81895	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81900	: Pg=91.18, Qg=29.66 -> Pg=90.8, Qg=13.3
% INFO    : Gen at bus 81900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81900	: Pg=81.18, Qg=29.66 -> Pg=85.8, Qg=13.3
% INFO    : Gen at bus 81900	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81904	: Pg=106.0, Qg=38.51 -> Pg=53.0, Qg=0.0
% INFO    : Gen at bus 81904	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81905	: Pg=17.28, Qg=10.8 -> Pg=10.215, Qg=2.49
% INFO    : Gen at bus 81905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81905	: Pg=17.28, Qg=10.8 -> Pg=10.215, Qg=2.49
% INFO    : Gen at bus 81905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81905	: Pg=17.28, Qg=10.8 -> Pg=10.215, Qg=2.49
% INFO    : Gen at bus 81905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81905	: Pg=17.28, Qg=10.8 -> Pg=10.215, Qg=2.49
% INFO    : Gen at bus 81905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81905	: Pg=17.28, Qg=10.8 -> Pg=10.215, Qg=2.49
% INFO    : Gen at bus 81905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81905	: Pg=17.28, Qg=10.8 -> Pg=10.215, Qg=2.49
% INFO    : Gen at bus 81905	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81917	: Pg=59.95, Qg=19.86 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 81917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81917	: Pg=59.95, Qg=19.86 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 81917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81917	: Pg=59.95, Qg=19.86 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 81917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81917	: Pg=59.95, Qg=19.86 -> Pg=40.25, Qg=8.65
% INFO    : Gen at bus 81917	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81921	: Pg=21.92, Qg=25.7 -> Pg=31.55, Qg=4.0
% INFO    : Gen at bus 81921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81921	: Pg=29.94, Qg=43.0 -> Pg=49.4, Qg=6.7
% INFO    : Gen at bus 81921	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81925	: Pg=41.02, Qg=25.7 -> Pg=29.2, Qg=5.95
% INFO    : Gen at bus 81925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81925	: Pg=41.02, Qg=25.7 -> Pg=29.2, Qg=5.95
% INFO    : Gen at bus 81925	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81927	: Pg=21.8, Qg=13.6 -> Pg=13.5, Qg=3.15
% INFO    : Gen at bus 81927	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81952	: Pg=133.77, Qg=74.9 -> Pg=84.375, Qg=15.75
% INFO    : Gen at bus 81952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81952	: Pg=133.77, Qg=74.9 -> Pg=84.375, Qg=15.75
% INFO    : Gen at bus 81952	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81959	: Pg=77.25, Qg=-30.0 -> Pg=73.5, Qg=6.8
% INFO    : Gen at bus 81959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81959	: Pg=77.25, Qg=-30.0 -> Pg=73.5, Qg=6.8
% INFO    : Gen at bus 81959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81959	: Pg=77.25, Qg=-30.0 -> Pg=73.5, Qg=6.8
% INFO    : Gen at bus 81959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81959	: Pg=50.21, Qg=-30.0 -> Pg=60.0, Qg=6.8
% INFO    : Gen at bus 81959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81959	: Pg=50.21, Qg=-30.0 -> Pg=60.0, Qg=6.8
% INFO    : Gen at bus 81959	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81967	: Pg=33.02, Qg=23.1 -> Pg=39.0, Qg=8.3
% INFO    : Gen at bus 81967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81967	: Pg=67.98, Qg=23.1 -> Pg=65.05, Qg=11.45
% INFO    : Gen at bus 81967	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81970	: Pg=70.36, Qg=38.7 -> Pg=50.0, Qg=6.0
% INFO    : Gen at bus 81970	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81972	: Pg=72.44, Qg=35.4 -> Pg=54.05, Qg=5.5
% INFO    : Gen at bus 81972	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81975	: Pg=67.78, Qg=5.3 -> Pg=38.7, Qg=0.0
% INFO    : Gen at bus 81975	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81978	: Pg=8.59, Qg=9.93 -> Pg=10.5, Qg=2.305
% INFO    : Gen at bus 81978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81978	: Pg=8.59, Qg=9.93 -> Pg=10.5, Qg=2.305
% INFO    : Gen at bus 81978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81978	: Pg=8.59, Qg=9.93 -> Pg=10.5, Qg=2.305
% INFO    : Gen at bus 81978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81978	: Pg=8.59, Qg=9.93 -> Pg=10.5, Qg=2.305
% INFO    : Gen at bus 81978	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81979	: Pg=18.47, Qg=13.0 -> Pg=13.0, Qg=3.0
% INFO    : Gen at bus 81979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81979	: Pg=6.01, Qg=14.9 -> Pg=14.5, Qg=3.45
% INFO    : Gen at bus 81979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81979	: Pg=3.8, Qg=10.72 -> Pg=9.565, Qg=2.7
% INFO    : Gen at bus 81979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81979	: Pg=3.8, Qg=10.72 -> Pg=9.565, Qg=2.7
% INFO    : Gen at bus 81979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81979	: Pg=3.8, Qg=10.72 -> Pg=9.565, Qg=2.7
% INFO    : Gen at bus 81979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81979	: Pg=3.8, Qg=10.72 -> Pg=9.565, Qg=2.7
% INFO    : Gen at bus 81979	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81981	: Pg=0.0, Qg=23.7 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 81981	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81982	: Pg=6.16, Qg=11.13 -> Pg=8.83, Qg=3.1
% INFO    : Gen at bus 81982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81982	: Pg=6.16, Qg=11.13 -> Pg=8.83, Qg=3.1
% INFO    : Gen at bus 81982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81982	: Pg=9.39, Qg=11.13 -> Pg=8.83, Qg=3.1
% INFO    : Gen at bus 81982	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81985	: Pg=19.88, Qg=21.3 -> Pg=27.0, Qg=3.3
% INFO    : Gen at bus 81985	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81987	: Pg=0.53, Qg=0.28 -> Pg=0.485, Qg=0.045
% INFO    : Gen at bus 81987	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81988	: Pg=14.96, Qg=11.1 -> Pg=18.5, Qg=1.7
% INFO    : Gen at bus 81988	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81988	: Pg=18.39, Qg=16.0 -> Pg=25.05, Qg=2.5
% INFO    : Gen at bus 81988	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81990	: Pg=35.87, Qg=-5.5 -> Pg=32.9, Qg=0.0
% INFO    : Gen at bus 81990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81990	: Pg=28.81, Qg=-8.7 -> Pg=25.95, Qg=0.0
% INFO    : Gen at bus 81990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81990	: Pg=53.51, Qg=-18.0 -> Pg=49.5, Qg=4.1
% INFO    : Gen at bus 81990	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81991	: Pg=16.95, Qg=4.98 -> Pg=17.55, Qg=4.9
% INFO    : Gen at bus 81991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81991	: Pg=16.95, Qg=4.98 -> Pg=17.55, Qg=4.9
% INFO    : Gen at bus 81991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81991	: Pg=16.95, Qg=4.98 -> Pg=17.55, Qg=4.9
% INFO    : Gen at bus 81991	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81992	: Pg=18.44, Qg=18.6 -> Pg=21.1, Qg=5.15
% INFO    : Gen at bus 81992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81992	: Pg=15.96, Qg=13.6 -> Pg=19.0, Qg=2.95
% INFO    : Gen at bus 81992	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81993	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81994	: Pg=25.88, Qg=-14.7 -> Pg=30.0, Qg=6.3
% INFO    : Gen at bus 81994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 81994	: Pg=9.71, Qg=-7.0 -> Pg=13.0, Qg=3.0
% INFO    : Gen at bus 81994	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82010	: Pg=253.68, Qg=78.41 -> Pg=163.0, Qg=53.35
% INFO    : Gen at bus 82010	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82037	: Pg=99.09, Qg=48.4 -> Pg=52.5, Qg=7.55
% INFO    : Gen at bus 82037	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82052	: Pg=32.7, Qg=20.5 -> Pg=29.5, Qg=4.75
% INFO    : Gen at bus 82052	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82053	: Pg=32.7, Qg=20.5 -> Pg=29.5, Qg=4.75
% INFO    : Gen at bus 82053	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82056	: Pg=28.54, Qg=15.5 -> Pg=20.375, Qg=2.95
% INFO    : Gen at bus 82056	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82056	: Pg=28.54, Qg=15.5 -> Pg=20.375, Qg=2.95
% INFO    : Gen at bus 82056	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82057	: Pg=8.55, Qg=7.05 -> Pg=9.625, Qg=1.225
% INFO    : Gen at bus 82057	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82057	: Pg=8.55, Qg=7.05 -> Pg=9.625, Qg=1.225
% INFO    : Gen at bus 82057	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82058	: Pg=13.63, Qg=7.7 -> Pg=8.985, Qg=7.7
% INFO    : Gen at bus 82058	: Vg=0.9984 -> Vg=1.0
% INFO    : Gen at bus 82058	: Pg=13.63, Qg=7.7 -> Pg=8.985, Qg=7.7
% INFO    : Gen at bus 82058	: Vg=0.9984 -> Vg=1.0
% INFO    : Gen at bus 82058	: Pg=24.77, Qg=15.5 -> Pg=16.5, Qg=15.5
% INFO    : Gen at bus 82058	: Vg=0.9984 -> Vg=1.0
% INFO    : Gen at bus 82060	: Pg=26.75, Qg=14.5 -> Pg=19.1, Qg=2.75
% INFO    : Gen at bus 82060	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 82060	: Pg=26.75, Qg=14.5 -> Pg=19.1, Qg=2.75
% INFO    : Gen at bus 82060	: Vg=1.02 -> Vg=1.0
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
